<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: accountsumm.xsl,v 1.18 2018-09-04 18:03:03 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:util="java:com.psasoft.reports.util.ReportUtilities"
								exclude-result-prefixes="java" 
								extension-element-prefixes="saxon"
								version="2.0">
  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Account Summary'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account">
		<xsl:with-param name="row" select="/all_results/results[@name = 'acct']/row"/>
	</xsl:call-template>
	<xsl:variable name="billmonth" select="substring(/all_results/results[@name = 'acct']/row/cbdate, 5, 2)" />
	<xsl:variable name="cycle" select="/all_results/results[@name = 'acct']/row/cycle" />
	<xsl:variable name="age" select="util:convertToAgingValues($cycle, $billmonth, /all_results/results[@name = 'agesum']/row/*)" />
	
 	<fo:table table-layout="fixed" 
 						width="100%" 
 						space-before="8px">
 		<fo:table-column column-width="3.0in" />
 		<fo:table-column column-width="2.0in" />
 		<fo:table-column column-width="3.0in" />
 		<fo:table-column column-width="2.0in" />
 			<fo:table-body>
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Contact Phone'"/>
						</fo:block>			
					</fo:table-cell>				
					<fo:table-cell>
						<fo:block>
							<xsl:call-template name="phone">
								<xsl:with-param name="npa" select="/all_results/results[@name = 'acct']/row/ctnpa"/>
								<xsl:with-param name="nxx" select="/all_results/results[@name = 'acct']/row/ctnxx"/>
								<xsl:with-param name="line" select="/all_results/results[@name = 'acct']/row/ctline"/>
							</xsl:call-template>
						</fo:block>			
					</fo:table-cell>	
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Master Service Date'"/>
						</fo:block>			
					</fo:table-cell>					
					<fo:table-cell>
						<xsl:if test="/all_results/results[@name = 'acct']/row/mstsrvdate &gt; ''">
							<fo:block>
								<xsl:value-of select="/all_results/results[@name = 'acct']/row/mstsrvdate"/>
							</fo:block>
						</xsl:if>
					</fo:table-cell>															
				</fo:table-row>	
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Active Services'"/>
						</fo:block>			
					</fo:table-cell>				
					<fo:table-cell text-align="right" padding-right="30px">
						<fo:block>
							<xsl:value-of select="count(/all_results/results[@name = 'detail']/row[dcyy = 0])"/>
						</fo:block>			
					</fo:table-cell>	
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Print Class'"/>
						</fo:block>			
					</fo:table-cell>					
					<fo:table-cell>
						<xsl:if test="/all_results/results[@name = 'acct']/row/bacct &gt; 0">
							<fo:block>
								<xsl:choose>
									<xsl:when test="/all_results/results[@name = 'acct']/row/prtpbl = 'Y'">
											<xsl:value-of select="'Y - Print Bill'"/>
									</xsl:when>
									<xsl:when test="/all_results/results[@name = 'acct']/row/prtpbl = 'N'">
											<xsl:value-of select="'N - Do Not Print Bill'"/>
									</xsl:when>
									<xsl:when test="/all_results/results[@name = 'acct']/row/prtpbl = 'P'">
											<xsl:value-of select="'P - Pull Bill'"/>
									</xsl:when>									
									<xsl:otherwise>
											<xsl:value-of select="'Y - Print Bill'"/>
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
							<fo:block>
								<xsl:choose>
									<xsl:when test="/all_results/results[@name = 'acct']/row/prtebl = 'Y'">
											<xsl:value-of select="'Y - Send E-Bill'"/>
									</xsl:when>
									<xsl:when test="/all_results/results[@name = 'acct']/row/prtebl = 'N'">
											<xsl:value-of select="'N - Do Not Send E-Bill'"/>
									</xsl:when>
									<xsl:otherwise>
											<xsl:value-of select="'Y - Send E-Bill'"/>
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>							
						</xsl:if>
					</fo:table-cell>															
				</fo:table-row>					
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Last Bill'"/>
						</fo:block>			
					</fo:table-cell>
					<fo:table-cell text-align="right"
												 padding-right="30px">
						<fo:block>
							<xsl:value-of select="format-number($age/age/last_bill, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>			
					</fo:table-cell>	
					<fo:table-cell text-align="right" padding-right="10px">
							<xsl:if test="/all_results/results[@name = 'acct']/row/wtobal != 0">
								<fo:block xsl:use-attribute-sets="summary-headings">
									<xsl:value-of select="'Write Off Balance'"/>
								</fo:block>			
							</xsl:if>
					</fo:table-cell>					
					<fo:table-cell text-align="right"
												 padding-right="30px">
						<xsl:if test="/all_results/results[@name = 'acct']/row/wtobal != 0">
							<fo:block 
										padding-before="4pt"
										padding-start="4pt"
										padding-after="4pt"
										padding-end="4pt"
										background-color="#FF9933">
								<xsl:value-of select="format-number(/all_results/results[@name = 'acct']/row/wtobal, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
							</fo:block>
						</xsl:if>
					</fo:table-cell>															
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Payments Applied This Month'"/>
						</fo:block>			
					</fo:table-cell>
					<fo:table-cell text-align="right"
												 padding-right="30px">
						<fo:block>
							<xsl:value-of select="format-number($age/age/curr_pay, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>			
					</fo:table-cell>	
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Adjustments Applied This Month'"/>
						</fo:block>			
					</fo:table-cell>					
					<fo:table-cell text-align="right"
												 padding-right="30px">
						<fo:block>
							<xsl:value-of select="format-number($age/age/curr_adj, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>			
					</fo:table-cell>															
				</fo:table-row>					
 			</fo:table-body>
		</fo:table>  

	<xsl:choose>
	<xsl:when test="/all_results/results[@name = 'acct']/row/ppacct = 'Y'">
		<xsl:variable name="acct" select="/all_results/results[@name = 'acct']/row/bacct" />
		<xsl:variable name="ppbal" select="util:convertToPrepayBalances($cycle, $acct)" />

		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			Prepay Account
		</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Prepay Period</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Due Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Account Balance</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Recurring Amount</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block font-weight="bold" color="blue" font-size="10pt">Amount To Renew</fo:block>
						</fo:table-cell>						
					</fo:table-row>
				</fo:table-header>					
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="/all_results/results[@name = 'acct']/row/ppdys &lt; 0">
									<xsl:variable name="months" select="/all_results/results[@name = 'acct']/row/ppdys * -1" />
									<xsl:value-of select="$months" />
									<xsl:value-of select="' Month(s)'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="/all_results/results[@name = 'acct']/row/ppdys" />
									<xsl:value-of select="' Days(s)'" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>			
						</fo:table-cell>					
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="/all_results/results[@name = 'acct']/row/pduedt" />
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($ppbal/ppBalance/trans_balance, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($ppbal/ppBalance/recurring_balance, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block font-weight="bold" color="blue" font-size="10pt">
								<xsl:value-of select="format-number($ppbal/ppBalance/amount_to_renew, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>
					</fo:table-row>					
				</fo:table-body>
			</fo:table>
	</xsl:when>
	<xsl:otherwise>		
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			Account Aging
		</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-header>
					<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Current</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>30 Days</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>60 Days</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>90 Days</fo:block>
							</fo:table-cell>						
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Final Balance</fo:block>
							</fo:table-cell>						
						</fo:table-row>
				</fo:table-header>					
				<fo:table-body>
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number($age/age/curr_bill, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
								</fo:block>			
							</fo:table-cell>					
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number($age/age/day30, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
								</fo:block>			
							</fo:table-cell>				
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number($age/age/day60, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
								</fo:block>			
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number($age/age/day90, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
								</fo:block>			
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number($age/age/due, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
								</fo:block>			
							</fo:table-cell>						
					</fo:table-row>					
				</fo:table-body>
			</fo:table> 			
	</xsl:otherwise>
	</xsl:choose>

	<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
		Selected Services
	</fo:block>
	<xsl:for-each select="/all_results/results[@name = 'detail']/row[cnpa = $areacode and 
													cnxx = $exchange and cline = $line and 
													dccc = $disconnectdatecc and dcyy = $disconnectdateyy and 
													dcmm = $disconnectdatemm and dcdd = $disconnectdatedd]"> 		
 	<fo:table table-layout="fixed" 
 						width="100%" 
 						space-before="8px">
 		<fo:table-column column-width="3.0in" />
 		<fo:table-column column-width="2.0in" />
 		<fo:table-column column-width="3.0in" />
 		<fo:table-column column-width="2.0in" />
 			<fo:table-body>
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Service Number'"/>
						</fo:block>			
					</fo:table-cell>				
					<fo:table-cell>
						<fo:block>
								<xsl:call-template name="phone">
									<xsl:with-param name="npa" select="./cnpa"/>
									<xsl:with-param name="nxx" select="./cnxx"/>
									<xsl:with-param name="line" select="./cline"/>
								</xsl:call-template>
						</fo:block>			
					</fo:table-cell>	
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="' '"/>
						</fo:block>			
					</fo:table-cell>					
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="' '"/>
						</fo:block>
					</fo:table-cell>															
				</fo:table-row>	
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:if test="./dcyy &gt; 0">
								<xsl:value-of select="'Disconnect Date'"/>
							</xsl:if>
						</fo:block>			
					</fo:table-cell>				
					<fo:table-cell>
						<xsl:if test="./dcmm &gt; 0">
							<fo:block>
								<xsl:call-template name="date4parm">
									<xsl:with-param name="cc" select="./dccc"/>
									<xsl:with-param name="yy" select="./dcyy"/>
									<xsl:with-param name="mm" select="./dcmm"/>
									<xsl:with-param name="dd" select="./dcdd"/>
								</xsl:call-template>										
							</fo:block>
						</xsl:if>
					</fo:table-cell>	
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Rate Plan'"/>
						</fo:block>			
					</fo:table-cell>					
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="./crtpln"/>
						</fo:block>
					</fo:table-cell>															
				</fo:table-row>					
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:choose>
								<xsl:when test="./esn != 0">
									<xsl:value-of select="'ESN'"/>							
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'IMEI'"/>							
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>			
					</fo:table-cell>				
					<fo:table-cell>
						<fo:block>
							<xsl:choose>
								<xsl:when test="./esn != 0">
									<xsl:value-of select="format-number(./esn, '00000000000')"/>							
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number(./imei, '000000000000000')"/>							
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>			
					</fo:table-cell>	
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:if test="./superacct != 0">	
								<xsl:value-of select="'Super Account'"/>
							</xsl:if>
						</fo:block>			
					</fo:table-cell>					
					<fo:table-cell>
						<fo:block>
							<xsl:if test="./superacct != 0">
								<xsl:value-of select="format-number(./superacct, '0000000')"/>
							</xsl:if>
						</fo:block>
					</fo:table-cell>															
				</fo:table-row>					
					<fo:table-row>
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="'Contract Expire Date'"/>
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="right"
													 padding-right="30px">
							<fo:block>
								<xsl:call-template name="date4parm">
									<xsl:with-param name="cc" select="./scexcc"/>
									<xsl:with-param name="yy" select="./scexyy"/>
									<xsl:with-param name="mm" select="./scexmm"/>
									<xsl:with-param name="dd" select="./scexdd"/>
								</xsl:call-template>
							</fo:block>			
						</fo:table-cell>			
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="'Total Deposit Amount'"/>
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="right" padding-right="30px">
							<fo:block>
								<xsl:value-of select="format-number(sum(/all_results/results[@name = 'deposits']/row/depamt), '$ ##,###,##0.00;$ -#,###,##0.00')"/>
							</fo:block>			
						</fo:table-cell>								
					</fo:table-row>											
			</fo:table-body>
		</fo:table> 	
	</xsl:for-each>
		
	<xsl:if test="/all_results/results[@name = 'detail']/row[dcyy = 0]">
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			All Active Services
		</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width=".75in" />
			<fo:table-column column-width="1.25in" />
			<fo:table-column column-width="1.25in" />
			<fo:table-column column-width=".5in" />
			<fo:table-column column-width=".5in" />
			<fo:table-column column-width="1.25in" /> 		
			<fo:table-column column-width="1.0in" /> 		
			<fo:table-header>
					<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Service Number</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Super Account</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>ESN / IMEI</fo:block>
							</fo:table-cell>						
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>MIN / IMSI</fo:block>
							</fo:table-cell>	
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Status</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Plan</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Name</fo:block>
							</fo:table-cell> 
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Total Deposit</fo:block>
							</fo:table-cell> 										 						
						</fo:table-row>
				</fo:table-header>					
				<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'detail']/row[dcyy = 0]"> 
						<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:call-template name="phone">
											<xsl:with-param name="npa" select="./cnpa"/>
											<xsl:with-param name="nxx" select="./cnxx"/>
											<xsl:with-param name="line" select="./cline"/>
										</xsl:call-template>
									</fo:block>
								</fo:table-cell>									
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="format-number(./superacct, '0000000')"/>							
									</fo:block>			
								</fo:table-cell>						
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:choose>
											<xsl:when test="./esn != 0">
												<xsl:value-of select="format-number(./esn, '00000000000')"/>							
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="format-number(./imei, '000000000000000')"/>							
											</xsl:otherwise>
										</xsl:choose>
									</fo:block>			
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:choose>
											<xsl:when test="./xnpa != 0">
												<xsl:call-template name="phone">
													<xsl:with-param name="npa" select="./xnpa"/>
													<xsl:with-param name="nxx" select="./xnxx"/>
													<xsl:with-param name="line" select="./xline"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="format-number(./imctry, '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(./imcomp, '00')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(./imnumb, '0000000000')" />						
											</xsl:otherwise>
										</xsl:choose>
									</fo:block>			
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:choose>
											<xsl:when test="./mstat = 'S'">
												<xsl:value-of select="'S'"/>							
											</xsl:when>
											<xsl:when test="/all_results/results[@name = 'acct']/row/crdrat = 'X'">
												<xsl:value-of select="'C'"/>							
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="'A'"/>							
											</xsl:otherwise>
										</xsl:choose>							
									</fo:block>			
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./crtpln"/>
									</fo:block>			
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
										<xsl:value-of select="./bdisc"/>							
									</fo:block>			
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number(./depamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</fo:block>			
								</fo:table-cell>																		
						</fo:table-row>		
					</xsl:for-each>
				</fo:table-body>
			</fo:table>  
		</xsl:if>
	<xsl:if test="/all_results/results[@name = 'detail']/row[dccc &gt; 0]">
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			All Disconnected Services
		</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width=".75in" />
			<fo:table-column column-width="1.25in" />
			<fo:table-column column-width="1.25in" />
			<fo:table-column column-width=".5in" />
			<fo:table-column column-width="1.25in" /> 		
			<fo:table-column column-width="1.25in" /> 
			<fo:table-column column-width="0.75in" /> 		
			<fo:table-header>
					<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Service Number</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Disconnect Date</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Super Account</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>ESN / IMEI</fo:block>
							</fo:table-cell>						
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>MIN / IMSI</fo:block>
							</fo:table-cell>	
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Status</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Name</fo:block>
							</fo:table-cell> 		
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Disconnect Reason</fo:block>
							</fo:table-cell> 	 						
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Total Deposit Amount</fo:block>
							</fo:table-cell> 
						</fo:table-row>
				</fo:table-header>					
				<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'detail']/row[dccc &gt; 0]"> 
						<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:call-template name="phone">
											<xsl:with-param name="npa" select="./cnpa"/>
											<xsl:with-param name="nxx" select="./cnxx"/>
											<xsl:with-param name="line" select="./cline"/>
										</xsl:call-template>
									</fo:block>
								</fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<xsl:if test="./dcyy &gt; 0">
										<fo:block>
											<xsl:call-template name="date4parm">
												<xsl:with-param name="cc" select="./dccc"/>
												<xsl:with-param name="yy" select="./dcyy"/>
												<xsl:with-param name="mm" select="./dcmm"/>
												<xsl:with-param name="dd" select="./dcdd"/>
											</xsl:call-template>										
										</fo:block>
									</xsl:if>
								</fo:table-cell>								
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="format-number(./superacct, '0000000')"/>							
									</fo:block>			
								</fo:table-cell>						
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:choose>
											<xsl:when test="./esn != 0">
												<xsl:value-of select="format-number(./esn, '00000000000')"/>							
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="format-number(./imei, '000000000000000')"/>							
											</xsl:otherwise>
										</xsl:choose>						
									</fo:block>			
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:choose>
											<xsl:when test="./xnpa != 0">
												<xsl:call-template name="phone">
													<xsl:with-param name="npa" select="./xnpa"/>
													<xsl:with-param name="nxx" select="./xnxx"/>
													<xsl:with-param name="line" select="./xline"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="format-number(./imctry, '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(./imcomp, '00')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(./imnumb, '0000000000')" />						
											</xsl:otherwise>
										</xsl:choose>
									</fo:block>			
								</fo:table-cell>								
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:choose>
											<xsl:when test="./dccc = 99">
												<xsl:value-of select="'N'"/>							
											</xsl:when>
											<xsl:when test="/all_results/results[@name = 'acct']/row/wtobal &gt; 0">
												<xsl:value-of select="'W'"/>							
											</xsl:when>
											<xsl:when test="/all_results/results[@name = 'acct']/row/crdrat = 'X'">
												<xsl:value-of select="'C'"/>							
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="'D'"/>							
											</xsl:otherwise>
										</xsl:choose>	
									</fo:block>			
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
										<xsl:value-of select="./bdisc"/>							
									</fo:block>			
								</fo:table-cell>			
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
										<xsl:value-of select="./dscdds"/>							
									</fo:block>			
								</fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number(./depamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</fo:block>			
								</fo:table-cell>															
						</fo:table-row>		
					</xsl:for-each>
				</fo:table-body>
			</fo:table>  
		</xsl:if>		
</xsl:template>

</xsl:stylesheet>
