<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
							  xmlns:fo="http://www.w3.org/1999/XSL/Format" 
							  xmlns:java="http://xml.apache.org/xslt/java" 
				              xmlns:saxon="http://saxon.sf.net/"							  
							  xmlns:fn="http://www.w3.org/2005/02/xpath-functions" 
								extension-element-prefixes="saxon"							  
							  exclude-result-prefixes="java" 
							  version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="'Agent Payments'" />
       

    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>	
<xsl:template name="body_process">
	<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'sel']/row">	
			<xsl:for-each-group select="/all_results/results[@name = 'sel']/row" group-by="./agcd">
				<xsl:variable name="name" select="current-group()[position()=1]/agbusname"/>
				<xsl:variable name="code" select="current-group()[position()=1]/agcd"/>
				<fo:table table-layout="fixed" width="100%" space-before="16px">
						<xsl:call-template name="header">
								<xsl:with-param name="name" select="$name"/>
								<xsl:with-param name="agcd" select="$code"/>
						</xsl:call-template>
						<fo:table-body>
							<xsl:call-template name="detailrow">
							        <xsl:with-param name="name" select="$name"/>
									<xsl:with-param name="agcd" select="$code"/>
							</xsl:call-template>
							<fo:table-row keep-with-next="never">
								<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="6"  text-align="right">
									<fo:block>
										<xsl:value-of select="format-number(sum(/all_results/results[@name = 'sel']/row[agcd = $code]/payamt), '##,###,##0.00')" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>															
					</fo:table-body>
			  </fo:table>
			</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
				<fo:block>No Payments Found</fo:block>
		</xsl:otherwise>
	</xsl:choose>		
		
</xsl:template> 

<xsl:template name="header">
		<xsl:param name="name" />    
		<xsl:param name="agcd" />    
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="1.25in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="6" text-align="left">
								<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px">
										<xsl:value-of select="'Agent: '"/>
										<xsl:value-of select="$agcd"/>
										<xsl:value-of select="' - '"/>
										<xsl:value-of select="$name"/>
								</fo:block>	
						</fo:table-cell>
				</fo:table-row>		
				<fo:table-row keep-with-next="always">
				    	<fo:table-cell xsl:use-attribute-sets="table-headings">
				        	<fo:block>Date</fo:block>
				    	</fo:table-cell>
				    	<fo:table-cell xsl:use-attribute-sets="table-headings">
				        	<fo:block>Account</fo:block>
				    	</fo:table-cell>						    	
				    	<fo:table-cell xsl:use-attribute-sets="table-headings">
				        	<fo:block>Service</fo:block>
				    	</fo:table-cell>	
				    	<fo:table-cell xsl:use-attribute-sets="table-headings">
				        	<fo:block>Disconnected</fo:block>
				    	</fo:table-cell>
				    	<fo:table-cell xsl:use-attribute-sets="table-headings">
				        	<fo:block>Payment Type</fo:block>
				    	</fo:table-cell>	
				    	<fo:table-cell xsl:use-attribute-sets="table-headings">
				        	<fo:block>Amount</fo:block>
				    	</fo:table-cell>									
				</fo:table-row>
		</fo:table-header>
</xsl:template>   
<xsl:template name="detailrow">
		<xsl:param name="name" />
		<xsl:param name="agcd" />      
		<xsl:for-each select="/all_results/results[@name = 'sel']/row[agcd = $agcd]">
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="./paytime" />
						</fo:block>
					</fo:table-cell>				
					<fo:table-cell text-align="left" xsl:use-attribute-sets="table-cells">    
							<fo:block>
								<xsl:value-of select="format-number(./cycle, '000')" />
								<xsl:value-of select="'-'" />
								<xsl:value-of select="format-number(./bacct, '0000000')" />
							</fo:block>	
					</fo:table-cell>									
					<fo:table-cell text-align="left" xsl:use-attribute-sets="table-cells">  
							<fo:block>
								<xsl:call-template name="phone">
									<xsl:with-param name="npa" select="./cnpa"/>
									<xsl:with-param name="nxx" select="./cnxx"/>
									<xsl:with-param name="line" select="./cline"/>
								</xsl:call-template>
							</fo:block>
					</fo:table-cell>								
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
						<fo:block>
							<xsl:choose>
							<xsl:when test="./dccc = 99">
								<xsl:value-of select="'Suspend NP'" />
							</xsl:when>
							<xsl:when test="./dccc &gt; 0">
								<xsl:call-template name="date4parm">
									<xsl:with-param name="cc" select="./dccc" />
									<xsl:with-param name="yy" select="./dcyy" />
									<xsl:with-param name="mm" select="./dcmm" />
									<xsl:with-param name="dd" select="./dcdd" />
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="' '" />
							</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>																			
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="./paytype" />
						</fo:block>
					</fo:table-cell>										
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(./payamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</fo:block>											
					</fo:table-cell>		
			  </fo:table-row>
		</xsl:for-each>
</xsl:template>
</xsl:stylesheet>
