<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: allservbilleffect.xsl,v 1.4 2018-09-04 18:03:02 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" xmlns:saxon="http://saxon.sf.net/"
	xmlns:util="java:com.psasoft.reports.util.ReportUtilities" exclude-result-prefixes="java" extension-element-prefixes="saxon" version="2.0">
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="'Account Billed Effects Summary'" />
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	<xsl:template name="body_process">
		<xsl:call-template name="account">
			<xsl:with-param name="row" select="/all_results/results[@name = 'acct']/row" />
		</xsl:call-template>
		<xsl:variable name="billmonth" select="substring(/all_results/results[@name = 'acct']/row/cbdate, 5, 2)" />
		<xsl:variable name="cycle" select="/all_results/results[@name = 'acct']/row/cycle" />
		<xsl:variable name="age" select="util:convertToAgingValues($cycle, $billmonth, /all_results/results[@name = 'agesum']/row/*)" />
		
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			Account Aging
		</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Current</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>30 Days</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>60 Days</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>90 Days</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Final Balance</fo:block>
						</fo:table-cell>						
					</fo:table-row>
			</fo:table-header>					
			<fo:table-body>
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/curr_bill, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>					
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/day30, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/day60, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/day90, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/due, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>						
				</fo:table-row>					
				<fo:table-row>
					<fo:table-cell number-columns-spanned="6" height="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="' '"/>
						</fo:block>			
					</fo:table-cell>															
				</fo:table-row>	
				<fo:table-row>
					<fo:table-cell text-align="right" padding="5px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Last Bill'"/>
						</fo:block>			
					</fo:table-cell>
					<fo:table-cell text-align="right" padding="5px">
						<fo:block>
							<xsl:value-of select="format-number($age/age/last_bill, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>			
					</fo:table-cell>	
					<fo:table-cell text-align="right" padding="5px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Payments Applied This Month'"/>
						</fo:block>			
					</fo:table-cell>
					<fo:table-cell text-align="right" padding="5px">
						<fo:block>
							<xsl:value-of select="format-number($age/age/curr_pay, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>			
					</fo:table-cell>	
					<fo:table-cell text-align="right" padding="5px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Adjustments Applied This Month'"/>
						</fo:block>			
					</fo:table-cell>					
					<fo:table-cell text-align="right" padding="5px">
						<fo:block>
							<xsl:value-of select="format-number($age/age/curr_adj, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>			
					</fo:table-cell>															
				</fo:table-row>					
			</fo:table-body>
		</fo:table> 		
		
		<xsl:if test="/all_results/results[@name = 'items']/row">
			<fo:block xsl:use-attribute-sets="summary-headings" space-before="12px" space-after="20px"> Equipment / Temporary Items
			</fo:block>
			<fo:block xsl:use-attribute-sets="summary-headings" space-before="12px" space-after="20px"> Overall Items Totals
			</fo:block>
			<fo:table>
				<fo:table-column column-width="3.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								<xsl:value-of select="'Bill Amount'" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								<xsl:value-of select="'Tax Amount'" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								<xsl:value-of select="'Total Amount'" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block font-size="7pt">
								<xsl:value-of select="'Total Equipment Charges'" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block font-size="7pt">
								<xsl:value-of
									select="format-number(sum(/all_results/results[@name = 'items']/row/inamt) + sum(/all_results/results[@name = 'items']/row/rmamt) + sum(/all_results/results[@name = 'items']/row/itmamt), '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block font-size="7pt">
								<xsl:value-of select="format-number(sum(/all_results/results[@name = 'items']/row/totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block font-size="7pt">
								<xsl:value-of
									select="format-number(sum(/all_results/results[@name = 'items']/row/inamt) + sum(/all_results/results[@name = 'items']/row/rmamt) + sum(/all_results/results[@name = 'items']/row/itmamt) + sum(/all_results/results[@name = 'items']/row/totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
			<xsl:for-each-group select="/all_results/results[@name = 'items']/row" group-by="concat(cycle, account)">
				<xsl:variable name="cycle" select="current-group()[position() = 1]/cycle" />
				<xsl:variable name="account" select="current-group()[position() = 1]/account" />
				<xsl:if test="/all_results/results[@name = 'items']/row[cycle = $cycle and account = $account and chgtyp = 'A']">
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="12px" space-after="20px"> Account Items
					</fo:block>
					<fo:table>
						<fo:table-column column-width="3.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-header>
							<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>
										<xsl:value-of select="'Item'" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>
										<xsl:value-of select="'Bill Amount'" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>
										<xsl:value-of select="'Tax Amount'" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>
										<xsl:value-of select="'Total Amount'" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</fo:table-header>
						<fo:table-body>
							<xsl:for-each select="/all_results/results[@name = 'items']/row[cycle = $cycle and account = $account and chgtyp = 'A']">
								<xsl:variable name="color">
									<xsl:choose>
										<xsl:when test="./billrm = 'Y'">
											<xsl:value-of select="'#FF0000'" />
										</xsl:when>
										<xsl:when test="./billin = 'Y'">
											<xsl:value-of select="'#0000FF'" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="'#000000'" />
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block font-size="7pt" color="{$color}">
											<xsl:value-of select="./item" />
											<xsl:value-of select="' - '" />
											<xsl:value-of select="./itmdsc" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block font-size="7pt" color="{$color}">
											<xsl:value-of select="format-number(./inamt + ./rmamt + ./itmamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block font-size="7pt" color="{$color}">
											<xsl:value-of select="format-number(./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block font-size="7pt" color="{$color}">
											<xsl:value-of select="format-number(./inamt + ./rmamt + ./itmamt + ./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</xsl:for-each>
						</fo:table-body>
					</fo:table>
				</xsl:if>
				<xsl:for-each-group select="/all_results/results[@name = 'items']/row[cycle = $cycle and account = $account and cnpa != 0]" group-by="concat(cnpa, cnxx, cline, dccc, dcyy, dcmm, dcdd)">
					<xsl:variable name="cnpa" select="current-group()[position() = 1]/cnpa" />
					<xsl:variable name="cnxx" select="current-group()[position() = 1]/cnxx" />
					<xsl:variable name="cline" select="current-group()[position() = 1]/cline" />
					<xsl:variable name="dccc" select="current-group()[position() = 1]/dccc" />
					<xsl:variable name="dcyy" select="current-group()[position() = 1]/dcyy" />
					<xsl:variable name="dcmm" select="current-group()[position() = 1]/dcmm" />
					<xsl:variable name="dcdd" select="current-group()[position() = 1]/dcdd" />
					<fo:block-container>
						<fo:block xsl:use-attribute-sets="summary-headings" space-before="12px" space-after="20px">
							<xsl:value-of select="'Service Number - '" />
							<xsl:call-template name="phone">
								<xsl:with-param name="npa" select="$cnpa" />
								<xsl:with-param name="nxx" select="$cnxx" />
								<xsl:with-param name="line" select="$cline" />
							</xsl:call-template>
							<xsl:choose>
								<xsl:when test="$dccc = 19 or $dccc = 20">
									<xsl:value-of select="' - '" />
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="$dccc" />
										<xsl:with-param name="yy" select="$dcyy" />
										<xsl:with-param name="mm" select="$dcmm" />
										<xsl:with-param name="dd" select="$dcdd" />
									</xsl:call-template>
								</xsl:when>
								<xsl:when test="$dccc = 99">
									<xsl:value-of select="' - Suspended'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' - Active'" />
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
						<xsl:if test="/all_results/results[@name = 'items']/row[cnpa = $cnpa and cnxx = $cnxx and cline = $cline and dccc = $dccc and dcyy = $dcyy and dcmm = $dcmm and dcdd = $dcdd and chgtyp = 'S']">
							<fo:table>
								<fo:table-column column-width="3.0in" />
								<fo:table-column column-width="1.0in" />
								<fo:table-column column-width="1.0in" />
								<fo:table-column column-width="1.0in" />
								<fo:table-header>
									<fo:table-row>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
											<fo:block>
												<xsl:value-of select="'Item'" />
											</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
											<fo:block>
												<xsl:value-of select="'Bill Amount'" />
											</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
											<fo:block>
												<xsl:value-of select="'Tax Amount'" />
											</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
											<fo:block>
												<xsl:value-of select="'Total Amount'" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-header>
								<fo:table-body>
									<xsl:for-each select="/all_results/results[@name = 'items']/row[cnpa = $cnpa and cnxx = $cnxx and cline = $cline and dccc = $dccc and dcyy = $dcyy and dcmm = $dcmm and dcdd = $dcdd and chgtyp = 'S']">
										<xsl:variable name="color">
											<xsl:choose>
												<xsl:when test="./billrm = 'Y'">
													<xsl:value-of select="'#FF0000'" />
												</xsl:when>
												<xsl:when test="./billin = 'Y'">
													<xsl:value-of select="'#0000FF'" />
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="'#000000'" />
												</xsl:otherwise>
											</xsl:choose>
										</xsl:variable>
										<fo:table-row>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
												<fo:block font-size="7pt" color="{$color}">
													<xsl:value-of select="./item" />
													<xsl:value-of select="' - '" />
													<xsl:value-of select="./itmdsc" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
												<fo:block font-size="7pt" color="{$color}">
													<xsl:value-of select="format-number(./inamt + ./rmamt + ./itmamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
												<fo:block font-size="7pt" color="{$color}">
													<xsl:value-of select="format-number(./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
												<fo:block font-size="7pt" color="{$color}">
													<xsl:value-of select="format-number(./inamt + ./rmamt + ./itmamt + ./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
									</xsl:for-each>
								</fo:table-body>
							</fo:table>
						</xsl:if>
					</fo:block-container>
				</xsl:for-each-group>
			</xsl:for-each-group>
		</xsl:if>
		<xsl:if test="/all_results/results[@name = 'adj']/row">
			<fo:block xsl:use-attribute-sets="summary-headings" space-before="12px" space-after="20px"> Adjustments
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.25in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="1.25in" />
				<fo:table-column column-width="1.25in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Adjustment Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Serv</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Disc Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Batch</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Batch Description</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Post Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Lvl</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Item Code</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Item Description</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Adjustment Description</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Adjustment Amount</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Taxes Amount</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'adj']/row">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="./itcc" />
										<xsl:with-param name="yy" select="./ityy" />
										<xsl:with-param name="mm" select="./itmm" />
										<xsl:with-param name="dd" select="./itdd" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="./cnpa" />
										<xsl:with-param name="nxx" select="./cnxx" />
										<xsl:with-param name="line" select="./cline" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:if test="./dccc &gt; 0">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./dccc" />
											<xsl:with-param name="yy" select="./dcyy" />
											<xsl:with-param name="mm" select="./dcmm" />
											<xsl:with-param name="dd" select="./dcdd" />
										</xsl:call-template>
									</xsl:if>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller">
								<fo:block>
									<xsl:value-of select="format-number(./btchid, '#########0')" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller">
								<fo:block>
									<xsl:value-of select="./btchdsc" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller">
								<fo:block>
									<xsl:choose>
										<xsl:when test="./btchsts = 'P'">
											<xsl:value-of select="./postdate" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="'Not Posted'" />
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="./adjlvl" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="./item" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
								<fo:block>
									<xsl:value-of select="./itmdsc" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
								<fo:block>
									<xsl:value-of select="./adjdsc" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./itmrat, '$ ##,###,##0.00;$ -#,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left" number-columns-spanned="10">
							<fo:block>
								<xsl:value-of select="'Total'" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(sum(/all_results/results[@name = 'adj']/row/itmrat), '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(sum(/all_results/results[@name = 'adj']/row/totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:if test="/all_results/results[@name = 'payment']/row">
			<fo:block xsl:use-attribute-sets="summary-headings" space-before="12px" space-after="20px"> Payments
			</fo:block>
			<fo:table table-layout="fixed" space-before="8px">
				<fo:table-column column-width=".6in" />
				<fo:table-column column-width=".75in" />
				<fo:table-column column-width=".75in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width=".75in" />
				<fo:table-column column-width="1.25in" />
				<fo:table-column column-width=".75in" />
				<fo:table-column column-width="2.25in" />
				<fo:table-column column-width=".75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Batch Id</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Batch Code</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Payment Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Payment Amount</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Refrence</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Billing Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Sequence</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Originating Place</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Entered By</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Status</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'payment']/row">
						<xsl:choose>
							<xsl:when test="btchsts = 'O'">
								<fo:table-row background-color="#CCCC66">
									<xsl:call-template name="payrow">
										<xsl:with-param name="row" select="." />
									</xsl:call-template>
								</fo:table-row>
							</xsl:when>
							<xsl:otherwise>
								<fo:table-row background-color="#FFFFFF">
									<xsl:call-template name="payrow">
										<xsl:with-param name="row" select="." />
									</xsl:call-template>
								</fo:table-row>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>    
		</xsl:if>
		<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'items']/row" />
		<xsl:when test="/all_results/results[@name = 'adj']/row" />
		<xsl:when test="/all_results/results[@name = 'payment']/row" />
		<xsl:otherwise>
				<fo:block>No Current Activity Found</fo:block>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="payrow">
		<xsl:param name="row" />
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/btchid"/>
			</fo:block>
		</fo:table-cell>	
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/usrbchid"/>
			</fo:block>
		</fo:table-cell>																			
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:call-template name="date4parm">
					<xsl:with-param name="cc" select="$row/pycc"/>
					<xsl:with-param name="yy" select="$row/pyyy"/>
					<xsl:with-param name="mm" select="$row/pymm"/>
					<xsl:with-param name="dd" select="$row/pydd"/>
				</xsl:call-template>										
			</fo:block>
		</fo:table-cell>										
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number($row/pmtamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
			</fo:block>
		</fo:table-cell>				
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/refno"/>
			</fo:block>
		</fo:table-cell>								
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:call-template name="date4parm">
					<xsl:with-param name="cc" select="$row/blcc"/>
					<xsl:with-param name="yy" select="$row/blyy"/>
					<xsl:with-param name="mm" select="$row/blmm"/>
					<xsl:with-param name="dd" select="$row/bldd"/>
				</xsl:call-template>										
			</fo:block>
		</fo:table-cell>								
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/seq"/>
			</fo:block>
		</fo:table-cell>						
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/orgplc"/>
			</fo:block>
		</fo:table-cell>	
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/payuser"/>
			</fo:block>
		</fo:table-cell>				
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:choose>
					<xsl:when test="wrtoff = 'W' and btchsts = 'O'">
						<xsl:value-of select="'Write Off '"/>
						<xsl:value-of select="'Not Posted'"/>
					</xsl:when>
					<xsl:when test="wrtoff = 'W'">
						<xsl:value-of select="'Write Off '"/>
						<xsl:value-of select="'Posted'"/>
					</xsl:when>
					<xsl:when test="btchsts = 'O'">
						<xsl:value-of select="'Not Posted'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'Posted'"/>
					</xsl:otherwise>
				</xsl:choose>
			</fo:block>
		</fo:table-cell>				
	</xsl:template>		
</xsl:stylesheet>