<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: allservitemsumm.xsl,v 1.3 2018-09-04 18:03:02 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:util="java:com.psasoft.reports.util.ReportUtilities"
								exclude-result-prefixes="java" 
								extension-element-prefixes="saxon"
								version="2.0">
  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Account Service Item Summary'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account">
		<xsl:with-param name="row" select="/all_results/results[@name = 'acct']/row"/>
	</xsl:call-template>

	<xsl:choose>
	<xsl:when test="/all_results/results[@name = 'items']/row">
		<xsl:for-each-group select="/all_results/results[@name = 'items']/row" group-by="custrecid">
			<xsl:variable name="cycle" select="current-group()[position() = 1]/cycle" />
			<xsl:variable name="account" select="current-group()[position() = 1]/bacct" />
			<xsl:variable name="custrecid" select="current-group()[position() = 1]/custrecid" />

			<xsl:if test="/all_results/results[@name = 'items']/row[custrecid = $custrecid and chgtyp = 'A']">
				<fo:block xsl:use-attribute-sets="summary-headings" space-before="12px">
					Account Items
				</fo:block>
				<fo:table>
			 		<fo:table-column column-width="4.0in" />
			 		<fo:table-column column-width="4.0in" />
		 			<fo:table-body>
						<fo:table-row>
							<fo:table-cell>
								<xsl:for-each select="/all_results/results[@name = 'items']/row[custrecid = $custrecid and chgtyp = 'A' and (position() mod 2) = 0]"> 
									<xsl:variable name="color">
										<xsl:choose>
										<xsl:when test="./billremove = 'Y'">
											<xsl:value-of select="'#FF0000'"/>
										</xsl:when>
										<xsl:when test="./billinstall = 'Y'">
											<xsl:value-of select="'#0000FF'"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="'#000000'"/>
										</xsl:otherwise>
										</xsl:choose>				
									</xsl:variable>
									<fo:block font-size="7pt" color="{$color}" margin-left="20px">
										<xsl:value-of select="./item" />
										<xsl:value-of select="' - '" />
										<xsl:value-of select="./itmdsc" />
										<xsl:value-of select="' ('" />
										<xsl:value-of select="format-number(./rate, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
										<xsl:value-of select="')'" />
									</fo:block>
								</xsl:for-each>
							</fo:table-cell>
							<fo:table-cell>
								<xsl:for-each select="/all_results/results[@name = 'items']/row[custrecid = $custrecid and chgtyp = 'A' and (position() mod 2) = 1]"> 
									<xsl:variable name="color">
										<xsl:choose>
										<xsl:when test="./billremove = 'Y'">
											<xsl:value-of select="'#FF0000'"/>
										</xsl:when>
										<xsl:when test="./billinstall = 'Y'">
											<xsl:value-of select="'#0000FF'"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="'#000000'"/>
										</xsl:otherwise>
										</xsl:choose>				
									</xsl:variable>
									<fo:block font-size="7pt" color="{$color}" margin-left="20px">
										<xsl:value-of select="./item" />
										<xsl:value-of select="' - '" />
										<xsl:value-of select="./itmdsc" />
										<xsl:value-of select="' ('" />
										<xsl:value-of select="format-number(./rate, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
										<xsl:value-of select="')'" />
									</fo:block>
								</xsl:for-each>
							</fo:table-cell>							
						</fo:table-row>
					</fo:table-body>
				</fo:table>

			</xsl:if>

			<xsl:for-each-group select="/all_results/results[@name = 'items']/row[custrecid = $custrecid and cnpa != 0]" group-by="concat(cnpa, cnxx, cline, dccc, dcyy, dcmm, dcdd)">
				<xsl:variable name="cnpa" select="current-group()[position() = 1]/cnpa" />
				<xsl:variable name="cnxx" select="current-group()[position() = 1]/cnxx" />
				<xsl:variable name="cline" select="current-group()[position() = 1]/cline" />
				<xsl:variable name="dccc" select="current-group()[position() = 1]/dccc" />
				<xsl:variable name="dcyy" select="current-group()[position() = 1]/dcyy" />
				<xsl:variable name="dcmm" select="current-group()[position() = 1]/dcmm" />
				<xsl:variable name="dcdd" select="current-group()[position() = 1]/dcdd" />
				<xsl:variable name="servrecid" select="current-group()[position() = 1]/servrecid" />

				<fo:block-container keep-together="always">
					<fo:block xsl:use-attribute-sets="summary-headings" font-size="12px" space-before="12px">
						<xsl:value-of select="'Service Number - '" />
						<xsl:call-template name="phone">
							<xsl:with-param name="npa" select="$cnpa"/>
							<xsl:with-param name="nxx" select="$cnxx"/>
							<xsl:with-param name="line" select="$cline"/>
						</xsl:call-template>
						<xsl:choose>
						<xsl:when test="$dccc = 19 or $dccc = 20">
							<xsl:value-of select="' - '" />
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="$dccc"/>
								<xsl:with-param name="yy" select="$dcyy"/>
								<xsl:with-param name="mm" select="$dcmm"/>
								<xsl:with-param name="dd" select="$dcdd"/>
							</xsl:call-template>					
						</xsl:when>
						<xsl:when test="$dccc = 99">
							<xsl:value-of select="' - Suspended'" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="' - Active'" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
					
					<xsl:if test="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and packrecid = 0 and substring(item, 1, 3) = 'PLN' and billremove = 'N']" >
						<xsl:variable name="planrow" select="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and packrecid = 0 and substring(item, 1, 3) = 'PLN' and billremove = 'N']" />
						<xsl:variable name="color">
							<xsl:choose>
							<xsl:when test="$planrow/billinstall = 'Y'">
								<xsl:value-of select="'#0000FF'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'#000000'"/>
							</xsl:otherwise>
							</xsl:choose>				
						</xsl:variable>
						<fo:block font-size="9pt" color="{$color}" space-before="5px" margin-left="20px" >
							<xsl:value-of select="'Current Plan '" />
							<xsl:value-of select="substring($planrow/item, 4, 2)" />
							<xsl:value-of select="' - '" />
							<xsl:value-of select="$planrow/itmdsc" />
							<xsl:value-of select="' ('" />
							<xsl:value-of select="format-number($planrow/rate, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
							<xsl:value-of select="')'" />
						</fo:block>
					</xsl:if>
				
					<xsl:if test="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and itmtyp = 'K']">
						<fo:block xsl:use-attribute-sets="summary-headings" space-before="5px" margin-left="20px">
							Packages
						</fo:block>
						<xsl:for-each select="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and itmtyp = 'K']">
							<xsl:variable name="packrecid" select="./packrecid" />
							
							<xsl:variable name="packcolor">
								<xsl:choose>
								<xsl:when test="./billremove = 'Y'">
									<xsl:value-of select="'#FF0000'"/>
								</xsl:when>
								<xsl:when test="./billinstall = 'Y'">
									<xsl:value-of select="'#0000FF'"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'#000000'"/>
								</xsl:otherwise>
								</xsl:choose>				
							</xsl:variable>
							<fo:block font-size="9pt" color="{$packcolor}" margin-left="25px">
								<xsl:value-of select="./item" />
								<xsl:value-of select="' - '" />
								<xsl:value-of select="./itmdsc" />
								<xsl:value-of select="' ('" />
								<xsl:value-of select="format-number(./rate, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
								<xsl:value-of select="') '" />
							</fo:block>
							
							<xsl:if test="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and packrecid = $packrecid and substring(item, 1, 3) = 'PLN' and billremove = 'N']" >
								<xsl:variable name="planrow" select="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and packrecid = $packrecid and substring(item, 1, 3) = 'PLN' and billremove = 'N']" />
								<xsl:variable name="plancolor">
									<xsl:choose>
									<xsl:when test="$planrow/billinstall = 'Y'">
										<xsl:value-of select="'#0000FF'"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="'#000000'"/>
									</xsl:otherwise>
									</xsl:choose>				
								</xsl:variable>
								<fo:block font-size="9pt" color="{$plancolor}" space-before="5px" margin-left="30px">
									<xsl:value-of select="'Current Plan '" />
									<xsl:value-of select="substring($planrow/item, 4, 2)" />
									<xsl:value-of select="' - '" />
									<xsl:value-of select="$planrow/itmdsc" />
									<xsl:value-of select="' ('" />
									<xsl:value-of select="format-number($planrow/rate, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									<xsl:value-of select="')'" />
								</fo:block>
							</xsl:if>
							<fo:table>
						 		<fo:table-column column-width="4.0in" />
						 		<fo:table-column column-width="4.0in" />
					 			<fo:table-body>
									<fo:table-row>
										<fo:table-cell>
											<xsl:for-each select="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and packrecid = $packrecid and not(substring(item, 1, 3) = 'PLN' and billremove = 'N') and (position() mod 2) = 0]">
												<xsl:variable name="rowcolor">
													<xsl:choose>
													<xsl:when test="./billremove = 'Y'">
														<xsl:value-of select="'#FF0000'"/>
													</xsl:when>
													<xsl:when test="./billinstall = 'Y'">
														<xsl:value-of select="'#0000FF'"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="'#000000'"/>
													</xsl:otherwise>
													</xsl:choose>				
												</xsl:variable>
												<fo:block font-size="7pt" color="{$rowcolor}" margin-left="30px">
													<xsl:value-of select="./item" />
													<xsl:value-of select="' - '" />
													<xsl:value-of select="./itmdsc" />
													<xsl:value-of select="' ('" />
													<xsl:value-of select="format-number(./rate, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													<xsl:value-of select="')'" />
												</fo:block>
											</xsl:for-each>
										</fo:table-cell>
										<fo:table-cell>
											<xsl:for-each select="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and packrecid = $packrecid and not(substring(item, 1, 3) = 'PLN' and billremove = 'N') and (position() mod 2) = 1]">
												<xsl:variable name="rowcolor">
													<xsl:choose>
													<xsl:when test="./billremove = 'Y'">
														<xsl:value-of select="'#FF0000'"/>
													</xsl:when>
													<xsl:when test="./billinstall = 'Y'">
														<xsl:value-of select="'#0000FF'"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="'#000000'"/>
													</xsl:otherwise>
													</xsl:choose>				
												</xsl:variable>
												<fo:block font-size="7pt" color="{$rowcolor}" margin-left="30px">
													<xsl:value-of select="./item" />
													<xsl:value-of select="' - '" />
													<xsl:value-of select="./itmdsc" />
													<xsl:value-of select="' ('" />
													<xsl:value-of select="format-number(./rate, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													<xsl:value-of select="')'" />
												</fo:block>
											</xsl:for-each>
										</fo:table-cell>									
									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</xsl:for-each>
						<fo:block space-before="5px" margin-left="20px">
							<xsl:value-of select="' '" />
						</fo:block>
					</xsl:if>
					<xsl:if test="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and itmtyp != 'K' and packrecid = 0]">
						<fo:block xsl:use-attribute-sets="summary-headings" space-before="5px" margin-left="20px">
							Stand-Alone Items
						</fo:block>
						<fo:table>
					 		<fo:table-column column-width="4.0in" />
					 		<fo:table-column column-width="4.0in" />
				 			<fo:table-body>
								<fo:table-row>
									<fo:table-cell>
										<xsl:for-each select="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and itmtyp != 'K' and packrecid = 0 and (position() mod 2) = 0]">
											<xsl:variable name="color">
												<xsl:choose>
												<xsl:when test="./billremove = 'Y'">
													<xsl:value-of select="'#FF0000'"/>
												</xsl:when>
												<xsl:when test="./billinstall = 'Y'">
													<xsl:value-of select="'#0000FF'"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="'#000000'"/>
												</xsl:otherwise>
												</xsl:choose>				
											</xsl:variable>
											<fo:block font-size="7pt" color="{$color}" margin-left="25px">
												<xsl:value-of select="./item" />
												<xsl:value-of select="' - '" />
												<xsl:value-of select="./itmdsc" />
												<xsl:value-of select="' ('" />
												<xsl:value-of select="format-number(./rate, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												<xsl:value-of select="')'" />
											</fo:block>
										</xsl:for-each>
									</fo:table-cell>
									<fo:table-cell>
										<xsl:for-each select="/all_results/results[@name = 'items']/row[servrecid = $servrecid and chgtyp = 'S' and itmtyp != 'K' and packrecid = 0 and (position() mod 2) = 1]">
											<xsl:variable name="color">
												<xsl:choose>
												<xsl:when test="./billremove = 'Y'">
													<xsl:value-of select="'#FF0000'"/>
												</xsl:when>
												<xsl:when test="./billinstall = 'Y'">
													<xsl:value-of select="'#0000FF'"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="'#000000'"/>
												</xsl:otherwise>
												</xsl:choose>				
											</xsl:variable>
											<fo:block font-size="7pt" color="{$color}" margin-left="25px">
												<xsl:value-of select="./item" />
												<xsl:value-of select="' - '" />
												<xsl:value-of select="./itmdsc" />
												<xsl:value-of select="' ('" />
												<xsl:value-of select="format-number(./rate, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												<xsl:value-of select="')'" />
											</fo:block>
										</xsl:for-each>
									</fo:table-cell>								
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</xsl:if>
				</fo:block-container>
			</xsl:for-each-group>
		</xsl:for-each-group>
		
	</xsl:when>
	<xsl:otherwise>
		<fo:block xsl:use-attribute-sets="summary-headings" space-before="12px">No Information found</fo:block>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
