<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: billinvoices_detail.xsl,v 1.2 2018-08-09 20:00:04 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
								exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="concat('Bill Invoices ', $invoice_date_range[1], ' to ', $invoice_date_range[2])" />  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'invoices']/row">
			<fo:table table-layout="fixed" space-before="8px">
				<fo:table-column column-width="0.75in" />
                <fo:table-column column-width="0.75in" />
                <fo:table-column column-width="0.75in" />
				<fo:table-column column-width="1.25in" />
				<fo:table-column column-width="0.60in" />
				<fo:table-column column-width="0.60in" />
				<fo:table-column column-width="0.40in" />
				<fo:table-column column-width="0.60in" />
				<fo:table-column column-width="0.60in" />
				<fo:table-column column-width="0.60in" />
				<fo:table-column column-width="0.60in" />
				<fo:table-column column-width="0.60in" />
				<fo:table-column column-width="0.60in" />
				<fo:table-column column-width="0.60in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Account</fo:block>
						</fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-headings">
                            <fo:block>MDN</fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-headings">
                            <fo:block>Disc Date</fo:block>
                        </fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Name</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Invoice #</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Invoice Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Invc Type</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Bill Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Invoice Amount</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Last Pay Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Total Adjs</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Total Returns</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Total Pmts</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Balance</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'invoices']/row">
						<xsl:variable name="recid" select="./recordid" />
						<fo:table-row>
							<xsl:call-template name="payrow">
								<xsl:with-param name="row" select="." />
							</xsl:call-template>
						</fo:table-row>
						<xsl:if test="/all_results/results[@name = 'trans']/row[recordid = $recid]">
							<fo:table-row>
								<fo:table-cell number-columns-spanned="3">
									<fo:block>
										<xsl:value-of select="' '"/>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell number-columns-spanned="9" padding="5px">
									<xsl:call-template name="transtable">
										<xsl:with-param name="recid" select="$recid" />
									</xsl:call-template>
								</fo:table-cell>
							</fo:table-row>
						</xsl:if>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:when>
		<xsl:otherwise>
			<fo:block>No Bill Invoices Found</fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="payrow">
	<xsl:param name="row" />
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
		<fo:block>
			<xsl:value-of select="format-number(./cycle, '000')" />
			<xsl:value-of select="'-'" />
			<xsl:value-of select="format-number(./account, '0000000')" />
		</fo:block>
	</fo:table-cell>
    <fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
        <fo:block>
                <xsl:call-template name="phone">
                    <xsl:with-param name="npa" select="./cnpa"/>
                    <xsl:with-param name="nxx" select="./cnxx"/>
                    <xsl:with-param name="line" select="./cline"/>
                </xsl:call-template>
        </fo:block>         
    </fo:table-cell> 
    <fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
        <xsl:if test="./dcmm &gt; 0">
            <fo:block>
                <xsl:call-template name="date4parm">
                    <xsl:with-param name="cc" select="./dccc"/>
                    <xsl:with-param name="yy" select="./dcyy"/>
                    <xsl:with-param name="mm" select="./dcmm"/>
                    <xsl:with-param name="dd" select="./dcdd"/>
                </xsl:call-template>                                        
            </fo:block>
        </xsl:if>
    </fo:table-cell>    
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
		<fo:block>
			<xsl:value-of select="./fname" />
			<xsl:value-of select="' '" />
			<xsl:value-of select="./lname" />
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
		<fo:block>
			<xsl:value-of select="$row/recordid" />
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
		<fo:block>
			<xsl:value-of select="$row/invoicedt" />
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
		<fo:block>
			<xsl:choose>
				<xsl:when test="$row/invtype = '1'">
					<xsl:value-of select="'POS'" />
				</xsl:when>
				<xsl:when test="$row/invtype = '2'">
					<xsl:value-of select="'Cycle'" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$row/invtype" />
				</xsl:otherwise>
			</xsl:choose>
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
		<fo:block>
			<xsl:value-of select="$row/ibilldate" />
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
		<fo:block>
			<xsl:value-of select="format-number($row/invcamnt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
		<fo:block>
			<xsl:value-of select="$row/lastpaydt" />
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
		<fo:block>
			<xsl:value-of select="format-number($row/totadj, '$ ##,###,##0.00;$ -#,###,##0.00')" />
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
		<fo:block>
			<xsl:value-of select="format-number($row/totreturn, '$ ##,###,##0.00;$ -#,###,##0.00')" />
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
		<fo:block>
			<xsl:value-of select="format-number($row/totpmt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
		</fo:block>
	</fo:table-cell>
	<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
		<fo:block>
			<xsl:value-of select="format-number($row/balance, '$ ##,###,##0.00;$ -#,###,##0.00')" />
		</fo:block>
	</fo:table-cell>
</xsl:template>		

<xsl:template name="transtable">
	<xsl:param name="recid" />
	<fo:table table-layout="fixed" space-before="8px">
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="2.00in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-header>
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Trans Date</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Trans Type</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Trans Amount</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</fo:table-header>
		<fo:table-body>
			<xsl:for-each select="/all_results/results[@name = 'trans']/row[recordid = $recid]">
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
						<fo:block>
							<xsl:value-of select="./pmtdate" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
						<fo:block>
							<xsl:choose>
								<xsl:when test="./trnstype = 'A'">
									<xsl:value-of select="'Adjustment'" />
								</xsl:when>
								<xsl:when test="./trnstype = 'P'">
									<xsl:value-of select="'Payment'" />
								</xsl:when>
								<xsl:when test="./trnstype = 'R'">
									<xsl:value-of select="'Return'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="./trnstype" />
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(./pmtamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</fo:block>
					</fo:table-cell>				
				</fo:table-row>
			</xsl:for-each>
		</fo:table-body>
	</fo:table>
</xsl:template>

</xsl:stylesheet>






