<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: calldetail-html.xsl,v 1.2 2016-06-10 17:01:11 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:util="java:com.psasoft.util.DelegateUtilities"
				exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl" />
  <xsl:import href="callsummary-html.xsl" />
  
  <xsl:output method="html" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Call Detail Report'"/>  

<xsl:template match="/">
	<html>
	    <head>
	      <title><xsl:value-of select="$title"/></title>
	      <META http-equiv="Content-Style-Type" content="text/css"/>
	      <style type="text/css">
	        a { color: black; border: none; text-decoration: none; }
	        .category-label {
	        	font-family: sans-serif;
	        	font-size: 10pt;
	        	color: navy;
	        	margin-bottom: 8px;
	        	font-weight: bold;
	        }
	        .summary-headings {
	        	font-family: sans-serif;
	        	font-size: 9pt;
	        	color: navy;
	        	padding: 4px;
	        	font-weight: bold;
	        }
	        .table-headings {
	        	font-family: sans-serif;
	        	font-size: 10pt;
	        	color: navy;
	        	background-color: white;
	        	font-weight: bold;
	        	text-align: center;
	        	vertical-align: center;
	        	border: 1pt, solid, navy;
	        	padding: 2pt;
	        }
	        .table-cells {
	        	font-family: sans-serif;
	        	font-size: 8pt;
	        	color: navy;
	        	background-color: white;
	        	border: 1pt, solid, navy;
	        	padding: 2pt;
	        }
	        .table-cells-smaller {
	        	font-family: sans-serif;
	        	font-size: 6pt;
	        	color: navy;
	        	background-color: white;
	        	border: 1pt, solid, navy;
	        	padding: 2pt;
	        }
	      </style>
	    </head>
	    <body bgcolor="white" marginwidth="6" marginheight="6" leftmargin="6" topmargin="6">
			<xsl:call-template name="body_process" />
		</body>
	</html>
</xsl:template>

<xsl:template name="body_process">
	<xsl:variable name="rating" select="util:getDataAreaString('RATING')" />
	<xsl:if test="$rating != 'N'">
		<h2 class="component-1" color="red">
			** NOTE ** - Rating is in progress.  Information subject to change
		</h2>
	</xsl:if>	
	<xsl:call-template name="minsummary" />
	<xsl:call-template name="aircert" />
	<xsl:call-template name="roamsummary" />
	<xsl:choose>
		<xsl:when test="exists(/all_results/results[@name = 'calldetail']/row)">
			<h1 class="category-label">Calls:</h1>
			<table width="100%" style="margin-top: 16px">
				<thead>
					<tr>
						<th class="table-headings"> To </th>
						<th class="table-headings"> Called Number </th>
						<th class="table-headings"> Called Date </th>
						<th class="table-headings"> Called Time </th>
						<th class="table-headings"> Dur. </th>
						<th class="table-headings"> Place </th>
						<th class="table-headings"> St </th>
						<th class="table-headings"> Airtime $ </th>
						<th class="table-headings"> Other $ </th>
						<th class="table-headings"> Total $ </th>
						<th class="table-headings"> Rt Per </th>
						<th class="table-headings"> Caller Id </th>
					</tr>
				</thead>
				<tbody>
					<xsl:for-each select="/all_results/results[@name = 'calldetail']/row">
						<xsl:sort select="./cdcc" data-type="number" />
						<xsl:sort select="./cdyy" data-type="number" />
						<xsl:sort select="./cdmm" data-type="number" />
						<xsl:sort select="./cddd" data-type="number" />
						<xsl:sort select="./sucnhh" data-type="number" />
						<xsl:sort select="./sucnmm" data-type="number" />
						<xsl:sort select="./sucnss" data-type="number" />
						<tr>
							<td class="table-cells-smaller" align="center">
								<xsl:choose>
									<xsl:when test="./caltyp = '1' and rr = '/LR'">
										<xsl:value-of select="'L'" />
									</xsl:when>
									<xsl:when test="./caltyp = '1'">
										<xsl:value-of select="'H'" />
									</xsl:when>
									<xsl:when test="./caltyp = '2'">
										<xsl:value-of select="'R'" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="./caltyp" />
									</xsl:otherwise>
								</xsl:choose>
							</td>
							<td class="table-cells-smaller" align="left">
								<xsl:choose>
									<xsl:when test="./cdnpa != 0 and ./cdnxx != 0 and ./cdline != 0">
										<xsl:value-of select="'('" />
										<xsl:value-of select="format-number(./cdnpa, '000')" />
										<xsl:value-of select="')'" />
										<xsl:value-of select="format-number(./cdnxx, '000')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number(./cdline, '0000')" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="./cdnpa != 0">
											<xsl:value-of select="./cdnpa" />
											<xsl:value-of select="' '" />
										</xsl:if>
										<xsl:if test="./cdnxx != 0">
											<xsl:value-of select="./cdnxx" />
											<xsl:value-of select="' '" />
										</xsl:if>
										<xsl:if test="./cdline != 0">
											<xsl:value-of select="./cdline" />
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:value-of select="./rr" />
							</td>
							<td class="table-cells-smaller" align="center">
								<xsl:if test="./cdcc != 0 and ./cdyy != 0 and ./cdmm != 0 and ./cddd != 0">
									<xsl:value-of select="format-number(./cdmm, '00')" />
									<xsl:value-of select="'/'" />
									<xsl:value-of select="format-number(./cddd, '00')" />
									<xsl:value-of select="'/'" />
									<xsl:value-of select="format-number(./cdcc, '00')" />
									<xsl:value-of select="format-number(./cdyy, '00')" />
								</xsl:if>
							</td>
							<td class="table-cells-smaller" align="center">
								<xsl:value-of select="format-number(./sucnhh, '00')" />
								<xsl:value-of select="':'" />
								<xsl:value-of select="format-number(./sucnmm, '00')" />
								<xsl:value-of select="':'" />
								<xsl:value-of select="format-number(./sucnss, '00')" />
							</td>
							<td class="table-cells-smaller" align="right">
								<xsl:value-of select="format-number(./suchmn, '##0')" />
								<xsl:value-of select="':'" />
								<xsl:value-of select="format-number(./suchss, '00')" />
							</td>
							<td class="table-cells-smaller" align="left">
								<xsl:value-of select="./cdpc" />
							</td>
							<td class="table-cells-smaller" align="center">
								<xsl:value-of select="./cdst" />
							</td>
							<td class="table-cells-smaller" align="right">
								<xsl:value-of select="format-number(./sucg, '##0.00')" />
							</td>
							<td class="table-cells-smaller" align="right">
								<xsl:choose>
									<xsl:when test="./tlcg > 0.00">
										<xsl:value-of select="format-number(./tlcg, '##0.00')" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="format-number(0.00, '##0.00')" />
									</xsl:otherwise>
								</xsl:choose>
							</td>
							<td class="table-cells-smaller" align="right">
								<xsl:value-of select="format-number(./ttchtx, '##0.00')" />
							</td>
							<td class="table-cells-smaller" align="center">
								<xsl:choose>
									<xsl:when test="./freeft &gt; ''">
										<xsl:value-of select="'FR'" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="./rapd" />
									</xsl:otherwise>
								</xsl:choose>
							</td>
							<td class="table-cells-smaller" align="left">
								<xsl:choose>
									<xsl:when test="./cinpa != 0 and ./cinxx != 0">
										<xsl:value-of select="'('" />
										<xsl:value-of select="format-number(./cinpa, '000')" />
										<xsl:value-of select="')'" />
										<xsl:value-of select="format-number(./cinxx, '000')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number(./ciline, '0000')" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="./cinpa != 0">
											<xsl:value-of select="./cinpa" />
											<xsl:value-of select="' '" />
										</xsl:if>
										<xsl:if test="./cinxx != 0">
											<xsl:value-of select="./cinxx" />
											<xsl:value-of select="' '" />
										</xsl:if>
										<xsl:if test="./ciline != 0">
											<xsl:value-of select="./ciline" />
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:when>
		<xsl:otherwise>
			<h1 class="category-label">No Information Found</h1>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
</xsl:stylesheet>






