<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: calldetail.xsl,v 1.19 2016-08-03 15:22:16 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:util="java:com.psasoft.util.DelegateUtilities"
				exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl" />
  <xsl:import href="Format.xsl" />
  <xsl:import href="subtemplates.xsl" /> 
  <xsl:import href="callsummary.xsl" />
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Call Detail Report'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		<xsl:call-template name="make-layout-master-set-landscape" />
		<xsl:call-template name="make-body-landscape" />
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account_service">
		<xsl:with-param name="row" select="/all_results/results[@name = 'acctservice']/row"/>
	</xsl:call-template>
	<xsl:variable name="rating" select="util:getDataAreaString('RATING')" />
	<xsl:if test="$rating != 'N'">
		<fo:block xsl:use-attribute-sets="component-1" color="red">
			** NOTE ** - Rating is in progress.  Information subject to change
		</fo:block>
	</xsl:if>	
	<xsl:if test="$customerCode = 'NWMC' or $customerCode = 'nwmc'">
		<fo:block xsl:use-attribute-sets="component-1" color="red">
			** NOTE ** - This report does not reflect real time customer usage. Only usage records that have been processed will be displayed.  Therefore, you may have outstanding usage that could affect your plan.
		</fo:block>
	</xsl:if>
		
	<xsl:call-template name="minsummary">
		<xsl:with-param name="from-web" select="'N'" />
	</xsl:call-template>
	<xsl:call-template name="aircert" />
	<xsl:call-template name="roamsummary">
		<xsl:with-param name="from-web" select="'N'" />
	</xsl:call-template>
	<xsl:call-template name="call-detail">
		<xsl:with-param name="from-web" select="'N'" />
	</xsl:call-template>

</xsl:template>

<xsl:template name="call-detail">
	<xsl:param name="from-web" />
	
	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'calldetail']/row)">
			
		<fo:block xsl:use-attribute-sets="category-label" keep-with-next="always">Calls: 	</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<xsl:if test="$from-web = 'N'">
				<fo:table-column column-width="0.25in" />
			</xsl:if>
			<fo:table-column column-width="0.25in" />
			<xsl:if test="$from-web = 'N'">
				<fo:table-column column-width="0.25in" />
			</xsl:if>
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.25in" />
			<xsl:if test="$from-web = 'N'">
				<fo:table-column column-width="0.35in" />
				<fo:table-column column-width="0.35in" />
			</xsl:if>
			<fo:table-column column-width="0.5in" />
			<xsl:if test="$from-web = 'N'">
				<fo:table-column column-width="0.5in" />
			</xsl:if>
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.35in" />
			<fo:table-column column-width="1.0in" />			
			<xsl:if test="$from-web = 'N'">
				<fo:table-column column-width="1.3in" />			
			</xsl:if>
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Rt</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>To</fo:block>
					</fo:table-cell>
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Ty</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Called Number</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Called Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Called Time</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Dur.</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Place</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>St</fo:block>
					</fo:table-cell>
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Srv Sid</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Hm Sid</fo:block>
						</fo:table-cell>	
					</xsl:if>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Airtime $</fo:block>
					</fo:table-cell>	
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Toll $</fo:block>
						</fo:table-cell>							
					</xsl:if>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total $</fo:block>
					</fo:table-cell>		
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Rt Per</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Caller Id</fo:block>
					</fo:table-cell>							
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>ESN / MEID / IMSI</fo:block>
						</fo:table-cell>							
					</xsl:if>
				</fo:table-row>
			</fo:table-header>					
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'calldetail']/row">
					<xsl:sort select="./cdcc" data-type="number" />
					<xsl:sort select="./cdyy" data-type="number" />
					<xsl:sort select="./cdmm" data-type="number" />
					<xsl:sort select="./cddd" data-type="number" />
					<xsl:sort select="./sucnhh" data-type="number" />
					<xsl:sort select="./sucnmm" data-type="number" />
					<xsl:sort select="./sucnss" data-type="number" />
					<fo:table-row>
						<xsl:if test="$from-web = 'N'">
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:choose>
										<xsl:when test="./rated = '1'">
											<xsl:value-of select="'Y'" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="'N'" />
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<xsl:choose>
								<xsl:when test="./caltyp = '1' and rr = '/LR'">
									<fo:block>
										<xsl:value-of select="'L'" />
									</fo:block>
								</xsl:when>
								<xsl:when test="./caltyp = '1'">
									<fo:block>
										<xsl:value-of select="'H'" />
									</fo:block>
								</xsl:when>
								<xsl:when test="./caltyp = '2'">
									<fo:block>
										<xsl:value-of select="'R'" />
									</fo:block>
								</xsl:when>
								<xsl:otherwise>
									<fo:block>
										<xsl:value-of select="./caltyp" />
									</fo:block>
								</xsl:otherwise>
							</xsl:choose>
						</fo:table-cell>
						<xsl:if test="$from-web = 'N'">
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="./rectype" />
								</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./cdnpa != 0 and ./cdnxx != 0 and ./cdline != 0">
										<xsl:value-of select="'('" />
										<xsl:value-of select="format-number(./cdnpa, '000')" />
										<xsl:value-of select="')'" />
										<xsl:value-of select="format-number(./cdnxx, '000')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number(./cdline, '0000')" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="./cdnpa != 0">
											<xsl:value-of select="./cdnpa" />
											<xsl:value-of select="' '" />
										</xsl:if>
										<xsl:if test="./cdnxx != 0">
											<xsl:value-of select="./cdnxx" />
											<xsl:value-of select="' '" />
										</xsl:if>
										<xsl:if test="./cdline != 0">
											<xsl:value-of select="./cdline" />
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:value-of select="./rr" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:if test="./cdcc != 0 and ./cdyy != 0 and ./cdmm != 0 and ./cddd != 0">
									<xsl:value-of select="format-number(./cdmm, '00')" />
									<xsl:value-of select="'/'" />
									<xsl:value-of select="format-number(./cddd, '00')" />
									<xsl:value-of select="'/'" />
									<xsl:value-of select="format-number(./cdcc, '00')" />
									<xsl:value-of select="format-number(./cdyy, '00')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="format-number(./sucnhh, '00')" />
								<xsl:value-of select="':'" />
								<xsl:value-of select="format-number(./sucnmm, '00')" />
								<xsl:value-of select="':'" />
								<xsl:value-of select="format-number(./sucnss, '00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./suchmn, '##0')" />
								<xsl:value-of select="':'" />
								<xsl:value-of select="format-number(./suchss, '00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
							<fo:block>
								<xsl:value-of select="./cdpc" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="./cdst" />
							</fo:block>
						</fo:table-cell>
						<xsl:if test="$from-web = 'N'">			
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="./svsid" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="./hmsid" />
								</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./sucg, '##0.00')" />
							</fo:block>
						</fo:table-cell>
						<xsl:if test="$from-web = 'N'">
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
								<fo:block>
									<xsl:choose>
										<xsl:when test="./tlcg > 0.00">
											<xsl:value-of select="format-number(./tlcg, '##0.00')" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number(0.00, '##0.00')" />
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./ttchtx, '##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./freeft &gt; ''">
										<xsl:value-of select="'FR'" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="./rapd" />
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./cinpa != 0 and ./cinxx != 0">
										<xsl:value-of select="'('" />
										<xsl:value-of select="format-number(./cinpa, '000')" />
										<xsl:value-of select="')'" />
										<xsl:value-of select="format-number(./cinxx, '000')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number(./ciline, '0000')" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="./cinpa != 0">
											<xsl:value-of select="./cinpa" />
											<xsl:value-of select="' '" />
										</xsl:if>
										<xsl:if test="./cinxx != 0">
											<xsl:value-of select="./cinxx" />
											<xsl:value-of select="' '" />
										</xsl:if>
										<xsl:if test="./ciline != 0">
											<xsl:value-of select="./ciline" />
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<xsl:if test="$from-web = 'N'">
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<xsl:if test="normalize-space(./esnime) > '' and normalize-space(./esnime) != '0'">
									<fo:block>
										<xsl:value-of select="./esnime" />
									</fo:block>
								</xsl:if>
								<xsl:if test="normalize-space(./lovfl) > '' and normalize-space(./lovfl) != '0'">
									<fo:block>
										<xsl:value-of select="format-number(./lnpa, '000')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number(./lnxx, '000')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number(./lline, '0000')" />
										<xsl:value-of select="format-number(./lovfl, '00000')" />
									</fo:block>
								</xsl:if>
							</fo:table-cell>
						</xsl:if>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>			
	</xsl:when>
	<xsl:otherwise>
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			No Information Found
		</fo:block>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>
</xsl:stylesheet>






