<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: callsummary-html.xsl,v 1.8 2016-06-10 17:01:11 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:util="java:com.psasoft.util.DelegateUtilities"
				exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  
  <xsl:output method="html" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Call and Data Summary Report'"/>  

<xsl:template match="/">
	<html>
	    <head>
	      <title><xsl:value-of select="$title"/></title>
	      <META http-equiv="Content-Style-Type" content="text/css"/>
	      <style type="text/css">
	        a { color: black; border: none; text-decoration: none; }
	        .category-label {
	        	font-family: sans-serif;
	        	font-size: 10pt;
	        	color: navy;
	        	margin-bottom: 8px;
	        	font-weight: bold;
	        }
	        .summary-headings {
	        	font-family: sans-serif;
	        	font-size: 9pt;
	        	color: navy;
	        	padding: 4px;
	        	font-weight: bold;
	        }
	        .table-headings {
	        	font-family: sans-serif;
	        	font-size: 10pt;
	        	color: navy;
	        	background-color: white;
	        	font-weight: bold;
	        	text-align: center;
	        	vertical-align: center;
	        	border: 1pt, solid, navy;
	        	padding: 2pt;
	        }
	        .table-cells {
	        	font-family: sans-serif;
	        	font-size: 8pt;
	        	color: navy;
	        	background-color: white;
	        	border: 1pt, solid, navy;
	        	padding: 2pt;
	        }
	        .table-cells-smaller {
	        	font-family: sans-serif;
	        	font-size: 6pt;
	        	color: navy;
	        	background-color: white;
	        	border: 1pt, solid, navy;
	        	padding: 2pt;
	        }
	      </style>
	    </head>
	    <body bgcolor="white" marginwidth="6" marginheight="6" leftmargin="6" topmargin="6">
			<xsl:call-template name="body_process" />
		</body>
	</html>
</xsl:template>

<xsl:template name="body_process">
	<xsl:variable name="rating" select="util:getDataAreaString('RATING')" />
	<xsl:if test="$rating != 'N'">
		<h2 class="component-1" color="red">
			** NOTE ** - Rating is in progress.  Information subject to change
		</h2>
	</xsl:if>	

	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'calldetail']/row) or exists(/all_results/results[@name = 'aircert']/row) or exists(/all_results/results[@name = 'datasum']/row)">
			<xsl:call-template name="minsummary" />
			<xsl:call-template name="aircert" />
			<xsl:call-template name="roamsummary" />
			<xsl:call-template name="datasummary" />
		</xsl:when>
		<xsl:otherwise>
			<h2>
				No Information Found
			</h2>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="minsummary">
	<xsl:if test="exists(/all_results/results[@name = 'calldetail']/row)">
		<xsl:variable name="ratedchg" select="sum(/all_results/results[@name = 'calldetail']/row[rated = '1']/ttchtx)" />
		<xsl:variable name="homemin" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and rr != '/LR']/suchmn) + (sum(/all_results/results/row[./caltyp = '1' and rr != '/LR']/suchss) div 60)" />
		<xsl:variable name="lrmin" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and rr = '/LR']/suchmn) + (sum(/all_results/results/row[./caltyp = '1' and rr = '/LR']/suchss) div 60)" />
		<xsl:variable name="rmin" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '2']/suchmn) + (sum(/all_results/results/row[./caltyp = '2']/suchss) div 60)" />
		<xsl:variable name="freeopmin" select="sum(/all_results/results[@name = 'calldetail']/row[ ./freeft &gt; '']/suchmn) + (sum(/all_results/results/row[./freeft &gt; '']/suchss) div 60)" />

		<xsl:variable name="pr1min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1']/suchmn) + (sum(/all_results/results/row[./rapd = '1']/suchss) div 60)" />
		<xsl:variable name="pr2min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2']/suchmn) + (sum(/all_results/results/row[./rapd = '2']/suchss) div 60)" />
		<xsl:variable name="pr3min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3']/suchmn) + (sum(/all_results/results/row[./rapd = '3']/suchss) div 60)" />
		<xsl:variable name="pr4min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4']/suchmn) + (sum(/all_results/results/row[./rapd = '4']/suchss) div 60)" />
		<xsl:variable name="pr5min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5']/suchmn) + (sum(/all_results/results/row[./rapd = '5']/suchss) div 60)" />

		<xsl:variable name="pr1minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '1' and ./freeft != '']/suchmn) + (sum(/all_results/results/row[./caltyp = '1' and ./rapd = '1' and ./freeft != '']/suchss) div 60)" />
		<xsl:variable name="pr2minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '2' and ./freeft != '']/suchmn) + (sum(/all_results/results/row[./caltyp = '1' and ./rapd = '2' and ./freeft != '']/suchss) div 60)" />
		<xsl:variable name="pr3minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '3' and ./freeft != '']/suchmn) + (sum(/all_results/results/row[./caltyp = '1' and ./rapd = '3' and ./freeft != '']/suchss) div 60)" />
		<xsl:variable name="pr4minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '4' and ./freeft != '']/suchmn) + (sum(/all_results/results/row[./caltyp = '1' and ./rapd = '4' and ./freeft != '']/suchss) div 60)" />
		<xsl:variable name="pr5minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '5' and ./freeft != '']/suchmn) + (sum(/all_results/results/row[./caltyp = '1' and ./rapd = '5' and ./freeft != '']/suchss) div 60)" />

		<xsl:variable name="pr1minrp" select="sum(/all_results/results[@name = 'calldetail']/row[substring(rpc1, 2, 1) = '1']/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc2, 2, 1) = '1']/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc3, 2, 1) = '1']/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc4, 2, 1) = '1']/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc5, 2, 1) = '1']/rpm5)" />
		<xsl:variable name="pr2minrp" select="sum(/all_results/results[@name = 'calldetail']/row[substring(rpc1, 2, 1) = '2']/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc2, 2, 1) = '2']/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc3, 2, 1) = '2']/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc4, 2, 1) = '2']/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc5, 2, 1) = '2']/rpm5)" />
		<xsl:variable name="pr3minrp" select="sum(/all_results/results[@name = 'calldetail']/row[substring(rpc1, 2, 1) = '3']/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc2, 2, 1) = '3']/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc3, 2, 1) = '3']/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc4, 2, 1) = '3']/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc5, 2, 1) = '3']/rpm5)" />
		<xsl:variable name="pr4minrp" select="sum(/all_results/results[@name = 'calldetail']/row[substring(rpc1, 2, 1) = '4']/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc2, 2, 1) = '4']/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc3, 2, 1) = '4']/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc4, 2, 1) = '4']/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc5, 2, 1) = '4']/rpm5)" />
		<xsl:variable name="pr5minrp" select="sum(/all_results/results[@name = 'calldetail']/row[substring(rpc1, 2, 1) = '5']/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc2, 2, 1) = '5']/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc3, 2, 1) = '5']/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc4, 2, 1) = '5']/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[substring(rpc5, 2, 1) = '5']/rpm5)" />

		<xsl:variable name="pr1minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1']/apm1) + sum(/all_results/results/row[./rapd = '1']/a2m1)" />
		<xsl:variable name="pr2minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2']/apm1) + sum(/all_results/results/row[./rapd = '2']/a2m1)" />
		<xsl:variable name="pr3minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3']/apm1) + sum(/all_results/results/row[./rapd = '3']/a2m1)" />
		<xsl:variable name="pr4minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4']/apm1) + sum(/all_results/results/row[./rapd = '4']/a2m1)" />
		<xsl:variable name="pr5minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5']/apm1) + sum(/all_results/results/row[./rapd = '5']/a2m1)" />

		<xsl:variable name="pr1calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1']/callcnt)" />
		<xsl:variable name="pr2calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2']/callcnt)" />
		<xsl:variable name="pr3calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3']/callcnt)" />
		<xsl:variable name="pr4calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4']/callcnt)" />
		<xsl:variable name="pr5calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5']/callcnt)" />
		
		<table width="100%">
			<tr>
				<td align="left" class="category-label">
					<xsl:value-of select="' '" />
				</td>
				<td align="center" class="category-label">
					<xsl:value-of select="'Mins'" />
				</td>
				<td align="left" class="category-label">
					<xsl:value-of select="' '" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="'Total Min'" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="'Total Calls'" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="'Plan Min'" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="'Free Min'" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="'Cert Min'" />
				</td>
			</tr>
			<tr>
				<td align="left" class="category-label">Home: </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($homemin, '##,##0.0')" />
				</td>
				<td align="left" class="category-label">Peak (Period 1): </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr1min, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr1calls, '##,##0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr1minrp, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr1minfr, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr1minat, '##,##0.0')" />
				</td>
			</tr>
			<tr>
				<td align="left" class="category-label">Expanded Home: </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($lrmin, '##,##0.0')" />
				</td>
				<td align="left" class="category-label">Off-Peak (Period 2): </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr2min, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr2calls, '##,##0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr2minrp, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr2minfr, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr2minat, '##,##0.0')" />
				</td>
			</tr>
			<tr>
				<td align="left" class="category-label">Roam: </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($rmin, '##,##0.0')" />
				</td>
				<td align="left" class="category-label">Weekends (Period 3): </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr3min, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr3calls, '##,##0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr3minrp, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr3minfr, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr3minat, '##,##0.0')" />
				</td>
			</tr>
			<tr>
				<td align="left" class="category-label">Free Option: </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($freeopmin, '##,##0.0')" />
				</td>
				<td align="left" class="category-label">Mobile-to-Mobile (Period 4): </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr4min, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr4calls, '##,##0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr4minrp, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr4minfr, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr4minat, '##,##0.0')" />
				</td>
			</tr>
			<tr>
				<td align="left" class="category-label">Rated Charges: </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($ratedchg, '##,##0.00')" />
				</td>
				<td align="left" class="category-label">Special (Period 5): </td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr5min, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr5calls, '##,##0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr5minrp, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr5minfr, '##,##0.0')" />
				</td>
				<td align="right" class="summary-headings" style="margin-right: 5px;">
					<xsl:value-of select="format-number($pr5minat, '##,##0.0')" />
				</td>
			</tr>
		</table>
	</xsl:if>
</xsl:template>

<xsl:template name="aircert">
	<xsl:if test="exists(/all_results/results[@name = 'aircert']/row)">
		<h1 class="category-label">Airtime Certificates:</h1>
		<table>
			<thead>
				<tr>
					<th class="table-headings"> Cert Level </th>
					<th class="table-headings"> Cert Code </th>
					<th class="table-headings"> Cert Name </th>
					<th class="table-headings"> Begin Date </th>
					<th class="table-headings"> End Date </th>
					<th class="table-headings"> Minutes Used </th>
					<th class="table-headings"> Max Minutes </th>
					<th class="table-headings"> Minutes Remaining </th>
				</tr>
			</thead>
			<tbody>
				<xsl:for-each select="/all_results/results[@name = 'aircert']/row">
					<tr>
						<td class="table-cells" align="center">
							<xsl:choose>
								<xsl:when test="./acct > '0'">
									<xsl:value-of select="'Acct'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'Serv'" />
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="table-cells" align="center">
							<xsl:value-of select="./crtnam" />
						</td>
						<td class="table-cells" align="left">
							<xsl:value-of select="./crtdsc" />
						</td>
						<td class="table-cells" align="center">
							<xsl:value-of select="./fromdate" />
						</td>
						<td class="table-cells" align="center">
							<xsl:value-of select="./todate" />
						</td>
						<td class="table-cells" align="right">
							<xsl:if test="./mxmalw">
								<xsl:value-of select="format-number(./mnusct, '##,##0')" />
							</xsl:if>
						</td>
						<td class="table-cells" align="right">
							<xsl:value-of select="format-number(./mxmalw, '##,##0')" />
						</td>
						<td class="table-cells" align="right">
							<xsl:if test="./mxmalw">
								<xsl:value-of select="format-number((./mxmalw - ./mnusct), '##,##0')" />
							</xsl:if>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<div style="margin-bottom: 12px" class="category-label">
		</div>
	</xsl:if>
</xsl:template>

<xsl:template name="roamsummary">
	<xsl:if test="exists(/all_results/results[@name = 'roamsummary']/row)">
	<h1 class="category-label">Roaming Summary:</h1>
	<table style="margin-top: 16px">
		<thead>
			<tr>
				<th class="table-headings"> Serving Place </th>
				<th class="table-headings"> Minutes </th>
				<th class="table-headings"> Charges </th>
			</tr>
		</thead>
		<tbody>
			<xsl:for-each select="/all_results/results[@name = 'roamsummary']/row">
				<xsl:variable name="totmin" select="./totmin + (./totsec div 60)" />
				<tr>
					<td class="table-cells" align="left">
						<xsl:value-of select="normalize-space(./svpc)" />
						<xsl:value-of select="', '" />
						<xsl:value-of select="./svst" />
					</td>
					<td class="table-cells" align="right">
						<xsl:value-of select="format-number($totmin, '##,##0')" />
					</td>
					<td class="table-cells" align="right">
						<xsl:value-of select="format-number(./totchg, '###,##0.00')" />
					</td>
				</tr>
			</xsl:for-each>
		</tbody>
	</table>
	<div style="margin-bottom: 12px" class="category-label">
	</div>
</xsl:if>
</xsl:template>

<xsl:template name="datasummary">
	<xsl:if test="exists(/all_results/results[@name = 'datasum']/row)">
		<h1 class="category-label"> Data Usage Summary</h1>
		<table width="100%" style="margin-top: 16px;">
			<thead>
				<tr>
					<th class="table-headings"> Data Feature </th>
					<th class="table-headings"> Rt Per </th>
					<th class="table-headings"> Charge Indicator </th>
					<th class="table-headings"> Cl Di </th>
					<th class="table-headings"> Network ID </th>
					<th class="table-headings"> Qty Ty </th>
					<th class="table-headings"> Incoming </th>
					<th class="table-headings">
						Incoming Remaining
						<div style="font-size: 5pt">*Combined Periods</div>
					</th>
					<th class="table-headings"> Outgoing </th>
					<th class="table-headings">
						Outgoing Remaining
						<div style="font-size: 5pt">*Combined Periods</div>
					</th>
					<th class="table-headings"> Charges </th>
				</tr>
			</thead>
			<tbody>
				<xsl:for-each-group select="/all_results/results[@name = 'datasum']/row" group-by="dataft">
					<xsl:variable name="dataft" select="current-grouping-key()" />
					<xsl:for-each-group select="current-group()" group-by="concat(apnni, apnoi, chargedesc, c1rapd, cldi, dqtytp, datartid)">
						<xsl:sort select="apnni" />
						<xsl:sort select="apnoi" />
						<xsl:sort select="chargedesc" />
						<xsl:sort select="c1rapd" />
						<xsl:variable name="apnni" select="current-group()[position() = 1]/apnni" />
						<xsl:variable name="apnoi" select="current-group()[position() = 1]/apnoi" />
						<xsl:variable name="chargedesc" select="current-group()[position() = 1]/chargedesc" />
						<xsl:variable name="ratepd" select="current-group()[position() = 1]/c1rapd" />
						<xsl:variable name="cldi" select="current-group()[position() = 1]/cldi" />
						<xsl:variable name="dqtytp" select="current-group()[position() = 1]/dqtytp" />
						<xsl:variable name="datartid" select="current-group()[position() = 1]/datartid" />
						<xsl:variable name="dtadirin">
							<xsl:choose>
							<xsl:when test="exists(current-group()[cldi = $cldi]/datadir) and current-group()[cldi = $cldi]/datadir > ''">						
								<xsl:value-of select="current-group()[cldi = $cldi]/datadir" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'0'" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="dtadirout">
							<xsl:choose>
							<xsl:when test="exists(current-group()[cldi = $cldi]/datadir) and current-group()[cldi = $cldi]/datadir > ''">						
								<xsl:value-of select="current-group()[cldi = $cldi]/datadir" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'0'" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="inunitcount">
							<xsl:choose>
								<xsl:when test="current-group()[cldi = $cldi]/unitcount and current-group()[cldi = $cldi]/dqtytp = 'EA'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/unitcount, '###,##0;-##,##0')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'BT'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/adj_unitcount, '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'KB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/adj_unitcount div 1024, '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'MB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/adj_unitcount div (1024 * 1024), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'GB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/adj_unitcount div (1024 * 1024 * 1024), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="outunitcount">
							<xsl:choose>
								<xsl:when test="current-group()[cldi = $cldi]/unitcount and current-group()[cldi = $cldi]/dqtytp = 'EA'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/unitcount, '###,##0;-##,##0')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'BT'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/adj_unitcount, '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'KB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/adj_unitcount div 1024, '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'MB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/adj_unitcount div (1024 * 1024), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'GB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/adj_unitcount div (1024 * 1024 * 1024), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="inremain">
							<xsl:choose>
								<xsl:when test="$dtadirin = '0'">
									<xsl:value-of select="' '" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'EA'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/unitcount), '###,##0*;-##,##0*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'BT'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/adj_unitcount), '###,##0.0000*;-##,##0.0000*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'KB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/adj_unitcount div 1024), '###,##0.0000*;-##,##0.0000*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'MB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/adj_unitcount div (1024 * 1024)), '###,##0.0000*;-##,##0.0000*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'GB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/adj_unitcount div (1024 * 1024 * 1024)), '###,##0.0000*;-##,##0.0000*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/unitcount and current-group()[cldi = $cldi]/dqtytp = 'EA'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - current-group()[cldi = $cldi]/unitcount, '###,##0;-##,##0')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'BT'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - current-group()[cldi = $cldi]/adj_unitcount, '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'KB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - (current-group()[cldi = $cldi]/adj_unitcount div 1024), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'MB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - (current-group()[cldi = $cldi]/adj_unitcount div (1024 * 1024)), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'GB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - (current-group()[cldi = $cldi]/adj_unitcount div (1024 * 1024 * 1024)), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="outremain">
							<xsl:choose>
								<xsl:when test="$dtadirout = '0'">
									<xsl:value-of select="' '" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'EA'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/unitcount), '###,##0*;-##,##0*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'BT'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/adj_unitcount), '###,##0.0000*;-##,##0.0000*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'KB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - (sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/adj_unitcount) div 1024), '###,##0.0000*;-##,##0.0000*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'MB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - (sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/adj_unitcount) div (1024 * 1024)), '###,##0.0000*;-##,##0.0000*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper = 'C' and current-group()[cldi = $cldi]/dqtytp = 'GB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - (sum(/all_results/results[@name = 'datasum']/row[dataft = $dataft and cldi = $cldi]/adj_unitcount) div (1024 * 1024 * 1024)), '###,##0.0000*;-##,##0.0000*')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/unitcount and current-group()[cldi = $cldi]/dqtytp = 'EA'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - current-group()[cldi = $cldi]/unitcount, '###,##0;-##,##0')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'BT'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - current-group()[cldi = $cldi]/adj_unitcount, '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'KB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - (current-group()[cldi = $cldi]/adj_unitcount div 1024), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'MB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - (current-group()[cldi = $cldi]/adj_unitcount div (1024 * 1024)), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="current-group()[cldi = $cldi]/cmbper != 'C' and current-group()[cldi = $cldi]/adj_unitcount and current-group()[cldi = $cldi]/dqtytp = 'GB'">
									<xsl:value-of select="format-number(current-group()[cldi = $cldi]/dbno1 - (current-group()[cldi = $cldi]/adj_unitcount div (1024 * 1024 * 1024)), '###,###,###,##0.0000;-##,###,###,##0.0000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<tr>
							<td class="table-cells-smaller" align="center">
								<xsl:value-of select="./itmdsc" />
								<xsl:if test="$datartid = '' or $datartid = '0'">
									<xsl:value-of select="' *'" />
								</xsl:if>								
							</td>
							<td class="table-cells-smaller" align="center">
								<xsl:value-of select="./c1rapd" />
							</td>
							<td class="table-cells-smaller" align="center">
								<xsl:value-of select="./chargedesc" />
							</td>
							<td class="table-cells-smaller" align="center">
								<xsl:value-of select="./cldi" />
							</td>
							<td class="table-cells-smaller" align="center">
								<xsl:value-of select="./apnni" />
							</td>
							<td class="table-cells-smaller" align="center">
								<xsl:choose>
									<xsl:when test="exists(./dqtytp)">
										<xsl:value-of select="./dqtytp" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="'EA'" />
									</xsl:otherwise>
								</xsl:choose>
							</td>
							<td class="table-cells-smaller" align="right">
								<xsl:value-of select="$inunitcount" />
							</td>
							<td class="table-cells-smaller" align="right">
								<xsl:value-of select="$inremain" />
							</td>
							<td class="table-cells-smaller" align="right">
								<xsl:value-of select="$outunitcount" />
							</td>
							<td class="table-cells-smaller" align="right">
								<xsl:value-of select="$outremain" />
							</td>
							<td class="table-cells-smaller" align="right">
								<xsl:value-of select="format-number(sum(current-group()/c1cg), '###,##0.00;-##,##0.00')" />
							</td>
						</tr>
					</xsl:for-each-group>
				</xsl:for-each-group>
			</tbody>
		</table>
	</xsl:if>
</xsl:template>

</xsl:stylesheet>






