<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: callsummary.xsl,v 1.54 2017-11-09 22:53:35 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:util="java:com.psasoft.util.DelegateUtilities"
				exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
   <xsl:import href="subtemplates.xsl"/> 
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Call and Data Summary Report'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		<xsl:call-template name="make-layout-master-set-landscape" />
		<xsl:call-template name="make-body-landscape" />
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account_service">
		<xsl:with-param name="row" select="/all_results/results[@name = 'acctservice']/row" />
	</xsl:call-template>
	<xsl:variable name="rating" select="util:getDataAreaString('RATING')" />
	<xsl:if test="$rating != 'N'">
		<fo:block xsl:use-attribute-sets="component-1" color="red">
			** NOTE ** - Rating is in progress.  Information subject to change
		</fo:block>
	</xsl:if>
	<xsl:if test="$customerCode = 'NWMC' or $customerCode = 'nwmc'">
		<fo:block xsl:use-attribute-sets="component-1" color="red">
			** NOTE ** - This report does not reflect real time customer usage. Only usage records that have been processed will be displayed.  Therefore, you may have outstanding usage that could affect your plan.
		</fo:block>
	</xsl:if>
	
	<xsl:choose>
		<xsl:when test="exists(/all_results/results[@name = 'calldetail']/row) or exists(/all_results/results[@name = 'aircert']/row) or exists(/all_results/results[@name = 'datasum']/row) or exists(/all_results/results[@name = 'datacert']/row) or exists(/all_results/results[@name = 'datacert-acct']/row)">
			<xsl:call-template name="minsummary">
				<xsl:with-param name="from-web" select="'N'" />
			</xsl:call-template>
			<xsl:call-template name="aircert" />
			<xsl:call-template name="roamsummary">
				<xsl:with-param name="from-web" select="'N'" />
			</xsl:call-template>
			<xsl:call-template name="datasum-new" />
		</xsl:when>
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="summary-cells" space-before="12px"> No Information Found
			</fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="minsummary">
	<xsl:param name="from-web" />
	
	<xsl:if test="exists(/all_results/results[@name = 'calldetail']/row[rated = '1'])">
		<xsl:variable name="ratedmin" select="sum(/all_results/results[@name = 'calldetail']/row[rated = '1']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[rated = '1']/suchss) div 60)" />
		<xsl:variable name="unratedmin" select="sum(/all_results/results[@name = 'calldetail']/row[rated != '1']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[rated != '1']/suchss) div 60)" />
		<xsl:variable name="ratedchg" select="sum(/all_results/results[@name = 'calldetail']/row[rated = '1']/ttchtx)" />
		<xsl:variable name="homemin" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and rr != '/LR']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and rr != '/LR']/suchss) div 60)" />
		<xsl:variable name="lrmin" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and rr = '/LR']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and rr = '/LR']/suchss) div 60)" />
		<xsl:variable name="rmin" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '2']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '2']/suchss) div 60)" />
		<xsl:variable name="freeopmin" select="sum(/all_results/results[@name = 'calldetail']/row[ ./freeft &gt; '']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./freeft &gt; '']/suchss) div 60)" />

		<xsl:variable name="pr1min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1']/suchss) div 60)" />
		<xsl:variable name="pr2min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2']/suchss) div 60)" />
		<xsl:variable name="pr3min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3']/suchss) div 60)" />
		<xsl:variable name="pr4min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4']/suchss) div 60)" />
		<xsl:variable name="pr5min" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5']/suchss) div 60)" />

		<xsl:variable name="pr1minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '1' and ./freeft != '']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '1' and ./freeft != '']/suchss) div 60)" />
		<xsl:variable name="pr2minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '2' and ./freeft != '']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '2' and ./freeft != '']/suchss) div 60)" />
		<xsl:variable name="pr3minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '3' and ./freeft != '']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '3' and ./freeft != '']/suchss) div 60)" />
		<xsl:variable name="pr4minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '4' and ./freeft != '']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '4' and ./freeft != '']/suchss) div 60)" />
		<xsl:variable name="pr5minfr" select="sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '5' and ./freeft != '']/suchmn) + (sum(/all_results/results[@name = 'calldetail']/row[./caltyp = '1' and ./rapd = '5' and ./freeft != '']/suchss) div 60)" />

		<xsl:variable name="pr1minrp" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1' and contains(rpc1,'1')]/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1' and contains(rpc2,'1')]/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1' and contains(rpc3,'1')]/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1' and contains(rpc4,'1')]/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1' and contains(rpc5,'1')]/rpm5)" />
		<xsl:variable name="pr2minrp" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2' and contains(rpc1,'2')]/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2' and contains(rpc2,'2')]/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2' and contains(rpc3,'2')]/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2' and contains(rpc4,'2')]/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2' and contains(rpc5,'2')]/rpm5)" />
		<xsl:variable name="pr3minrp" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3' and contains(rpc1,'3')]/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3' and contains(rpc2,'3')]/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3' and contains(rpc3,'3')]/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3' and contains(rpc4,'3')]/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3' and contains(rpc5,'3')]/rpm5)" />
		<xsl:variable name="pr4minrp" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4' and contains(rpc1,'4')]/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4' and contains(rpc2,'4')]/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4' and contains(rpc3,'4')]/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4' and contains(rpc4,'4')]/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4' and contains(rpc5,'4')]/rpm5)" />
		<xsl:variable name="pr5minrp" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5' and contains(rpc1,'5')]/rpm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5' and contains(rpc2,'5')]/rpm2) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5' and contains(rpc3,'5')]/rpm3) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5' and contains(rpc4,'5')]/rpm4) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5' and contains(rpc5,'5')]/rpm5)" />

		<xsl:variable name="pr1minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1']/apm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1']/a2m1)" />
		<xsl:variable name="pr2minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2']/apm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2']/a2m1)" />
		<xsl:variable name="pr3minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3']/apm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3']/a2m1)" />
		<xsl:variable name="pr4minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4']/apm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4']/a2m1)" />
		<xsl:variable name="pr5minat" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5']/apm1) + sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5']/a2m1)" />

		<xsl:variable name="pr1calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '1']/callcnt)" />
		<xsl:variable name="pr2calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '2']/callcnt)" />
		<xsl:variable name="pr3calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '3']/callcnt)" />
		<xsl:variable name="pr4calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '4']/callcnt)" />
		<xsl:variable name="pr5calls" select="sum(/all_results/results[@name = 'calldetail']/row[./rapd = '5']/callcnt)" />
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="1.50in" />
			<fo:table-column column-width="0.50in" />
			<xsl:if test="$from-web = 'N'">
				<fo:table-column column-width="2.00in" />
				<fo:table-column column-width="0.50in" />
				<fo:table-column column-width="1.00in" />
			</xsl:if>
			<xsl:if test="$from-web = 'Y'">
				<fo:table-column column-width="2.50in" />
			</xsl:if>
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.50in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="center">
						<fo:block xsl:use-attribute-sets="summary-cells">
							<xsl:value-of select="'Mins'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell text-align="center">
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="'Mins'" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-cells" margin-right="5px">
							<xsl:value-of select="'Total Min'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-cells" margin-right="5px">
							<xsl:value-of select="'Total Calls'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-cells" margin-right="5px">
							<xsl:value-of select="'Plan Min'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-cells" margin-right="5px">
							<xsl:value-of select="'Free Min'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-cells" margin-right="5px">
							<xsl:value-of select="'Cert Min'" />
						</fo:block>
					</fo:table-cell>															
				</fo:table-row>			
				<fo:table-row>
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells">Rated:</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="right">
							<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
								<xsl:value-of select="format-number($ratedmin, '##,##0.0')" />
							</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">Home:</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($homemin, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">Peak <fo:inline font-size="6">(Period 1)</fo:inline>:</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr1min, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr1calls, '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr1minrp, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr1minfr, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr1minat, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>															
				</fo:table-row>
				<fo:table-row>
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells">Unrated:</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="right">
							<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
								<xsl:value-of select="format-number($unratedmin, '##,##0.0')" />
							</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">Expanded Home:</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($lrmin, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">Off-Peak <fo:inline font-size="6">(Period 2)</fo:inline>:</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr2min, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr2calls, '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr2minrp, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr2minfr, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr2minat, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells">Rated Charges:</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="right">
							<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
								<xsl:value-of select="format-number($ratedchg, '##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">Roam:</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($rmin, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">Weekends <fo:inline font-size="6">(Period 3)</fo:inline>:</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr3min, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr3calls, '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr3minrp, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr3minfr, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr3minat, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell text-align="center">
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="center">
							<fo:block xsl:use-attribute-sets="summary-data">
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">Free Option:</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($freeopmin, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">Mob2Mob <fo:inline font-size="6">(Period 4)</fo:inline>:</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr4min, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr4calls, '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr4minrp, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr4minfr, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr4minat, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell text-align="center">
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="center">
							<fo:block xsl:use-attribute-sets="summary-data">
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="center">
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="center">
							<fo:block xsl:use-attribute-sets="summary-data">
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
					</xsl:if>
					<xsl:if test="$from-web = 'Y'">
						<fo:table-cell text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells">Rated Charges:</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="right">
							<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
								<xsl:value-of select="format-number($ratedchg, '##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">Special <fo:inline font-size="6">(Period 5)</fo:inline>:</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr5min, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr5calls, '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr5minrp, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr5minfr, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block xsl:use-attribute-sets="summary-data" margin-right="5px">
							<xsl:value-of select="format-number($pr5minat, '##,##0.0')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:if>
</xsl:template>

<xsl:template name="aircert">
	<xsl:if test="exists(/all_results/results[@name = 'aircert']/row)">
		<fo:block xsl:use-attribute-sets="summary-cells" keep-with-next="always">Airtime Certificates:</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="2.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cert Level</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cert Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cert Name</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Begin Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>End Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Minutes Used</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Max Minutes</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Minutes Remaining</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'aircert']/row">
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./acct > '0'">
										<xsl:value-of select="'Acct'" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="'Serv'" />
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./crtnam" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
								<xsl:value-of select="./crtdsc" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./fromdate" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./todate" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./mnusct, '##,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./mxmalw">
									<xsl:value-of select="format-number(./mxmalw, '##,##0')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
							    </xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./mxmalw">
									<xsl:value-of select="format-number((./mxmalw - ./mnusct), '##,##0')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
							    </xsl:choose>									
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
		<fo:block space-after="12px" xsl:use-attribute-sets="summary-cells">
		</fo:block>
	</xsl:if>
</xsl:template>

<xsl:template name="roamsummary">
	<xsl:param name="from-web" />

	<xsl:if test="exists(/all_results/results[@name = 'roamsummary']/row)">
		<fo:block xsl:use-attribute-sets="summary-cells" keep-with-next="always">Roaming Summary:</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<xsl:if test="$from-web = 'N'">
				<fo:table-column column-width="0.5in" />
			</xsl:if>
			<fo:table-column column-width="1.5in" />
			<xsl:if test="$from-web = 'N'">
				<fo:table-column column-width="1.5in" />
			</xsl:if>
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Serving SID</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Serving Place</fo:block>
					</fo:table-cell>
					<xsl:if test="$from-web = 'N'">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Roaming Partner</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Minutes</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Charges</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'roamsummary']/row">
					<xsl:variable name="totmin" select="./totmin + (./totsec div 60)" />
					<fo:table-row>
						<xsl:if test="$from-web = 'N'">
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./svsid" />
								</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
								<xsl:value-of select="normalize-space(./svpc)" />
								<xsl:value-of select="', '" />
								<xsl:value-of select="./svst" />
							</fo:block>
						</fo:table-cell>
						<xsl:if test="$from-web = 'N'">
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="./rpname" />
								</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($totmin, '##,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./totchg, '###,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
		<fo:block space-after="12px" xsl:use-attribute-sets="summary-cells">
		</fo:block>
	</xsl:if>
</xsl:template>

<xsl:template name="datacert">
	<xsl:if test="exists(/all_results/results[@name = 'datacert-acct']/row)">
		<fo:block xsl:use-attribute-sets="summary-cells" keep-with-next="always">Shared Data Certificates:</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<xsl:choose>
			<xsl:when test="$customerCode = 'NWMC' or $customerCode = 'nwmc'">
				<fo:table-column column-width="0.60in" />
			</xsl:when>
			<xsl:otherwise>
				<fo:table-column column-width="1.00in" />
			</xsl:otherwise>
			</xsl:choose>
			<fo:table-column column-width="0.40in" />
			<fo:table-column column-width="1.20in" />
			<fo:table-column column-width="0.25in" />
			<fo:table-column column-width="0.30in" />
			<fo:table-column column-width="0.30in" />
			<fo:table-column column-width="0.65in" />
			<fo:table-column column-width="0.65in" />
			<fo:table-column column-width="0.65in" />
			<fo:table-column column-width="0.65in" />
			<fo:table-column column-width="0.65in" />
			<fo:table-column column-width="0.65in" />
			<fo:table-column column-width="0.65in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<xsl:choose>
					<xsl:when test="$customerCode = 'NWMC' or $customerCode = 'nwmc'">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Super Account</fo:block>
						</fo:table-cell>
					</xsl:when>
					<xsl:otherwise>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>MDN</fo:block>
						</fo:table-cell>
					</xsl:otherwise>
					</xsl:choose>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cert Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cert Name</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Sts</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Unit Type</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Shr ?</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Begin Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cert Defined Amount</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Actual Avail on Beg Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Units Used</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Units Used in Cycle</fo:block>
					</fo:table-cell>										
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Units Remain</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>End Date</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'datacert-acct']/row">
					<fo:table-row>
						<xsl:choose>
						<xsl:when test="$customerCode = 'NWMC' or $customerCode = 'nwmc'">
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="./superacct" />
								</fo:block>
							</fo:table-cell>
						</xsl:when>
						<xsl:otherwise>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="'('" />
									<xsl:value-of select="format-number(./cnpa, '000')" />
									<xsl:value-of select="') '" />
									<xsl:value-of select="format-number(./cnxx, '000')" />
									<xsl:value-of select="'-'" />
									<xsl:value-of select="format-number(./cline, '0000')" />
								</fo:block>
							</fo:table-cell>
						</xsl:otherwise>
						</xsl:choose>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="./crtnam" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
							<fo:block>
								<xsl:value-of select="./crtdsc" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="./crtsts" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="./type" />
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="./sharedta" />
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:call-template name="date1parm">
									<xsl:with-param name="date" select="./effective" />
								</xsl:call-template>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./crtunits &lt; 999999999999">
									<xsl:value-of select="format-number(./crtunits, '###,###,##0.00000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' Unlimited '" />
								</xsl:otherwise>
							    </xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./maxunits &lt; 999999999999 and ./crtunits &lt; 999999999999">
									<xsl:value-of select="format-number(./maxunits, '###,###,##0.00000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' Unlimited '" />
								</xsl:otherwise>
							    </xsl:choose>
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./qtyuct, '###,###,##0.00000')" />
							</fo:block>
						</fo:table-cell>		
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./qtyubp, '###,###,##0.00000')" />
							</fo:block>
						</fo:table-cell>										
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./maxunits &lt; 999999999999 and ./crtunits &lt; 999999999999">
									<xsl:value-of select="format-number(./remain, '###,###,##0.00000;-##,###,##0.00000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' Unlimited '" />
								</xsl:otherwise>
							    </xsl:choose>									
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:call-template name="date1parm">
									<xsl:with-param name="date" select="./end" />
								</xsl:call-template>
							</fo:block>
						</fo:table-cell>						
					</fo:table-row>
				</xsl:for-each>
				<fo:table-row>
					<fo:table-cell number-columns-spanned="6">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left" number-columns-spanned="3">
						<fo:block>
							<xsl:value-of select="' Total Data all certs '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'datacert-acct']/row/qtyuct), '###,###,##0.00000')" />					
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'datacert-acct']/row/qtyubp), '###,###,##0.00000')" />					
						</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
						<fo:block>
							<xsl:choose>
							<xsl:when test="sum(/all_results/results[@name = 'datacert-acct']/row/maxunits) &lt; 999999999999 and sum(/all_results/results[@name = 'datacert-acct']/row/crtunits) &lt; 999999999999">
								<xsl:value-of select="format-number(sum(/all_results/results[@name = 'datacert-acct']/row/remain), '###,###,##0.00000')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="' Unlimited '" />
							</xsl:otherwise>
						    </xsl:choose>									
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>					
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
		<fo:block space-after="12px" xsl:use-attribute-sets="summary-cells">
		</fo:block>
	</xsl:if>	
</xsl:template>

<xsl:template name="datasum-new">
	<xsl:call-template name="datacert" />

	<xsl:if test="exists(/all_results/results[@name = 'datasum-full']/row[c1in = '19'])">
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="20px" keep-with-next="always">Data/WAP Usage Summary</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.50in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Super Acct</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>MDN</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Data Feature</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Feature Used</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cert Used</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Initial Free</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Remaining Free</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Overage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Charges</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each-group select="/all_results/results[@name = 'datasum-full']/row[c1in = '19']" group-by="superacct">
					<xsl:variable name="superacct" select="current-grouping-key()" />
					<xsl:for-each select="/all_results/results[@name = 'datasum-full']/row[c1in = '19' and superacct = $superacct]">
						<xsl:call-template name="datasum-row">
							<xsl:with-param name="superacct" select="$superacct" />
							<xsl:with-param name="total" select="'DT'" />
							<xsl:with-param name="outdbno1" select="./outdbno1" />
							<xsl:with-param name="rnduse" select="./rnduse" />
							<xsl:with-param name="adj_outused" select="./adj_outused" />
							<xsl:with-param name="outunitcount" select="./outunitcount" />
							<xsl:with-param name="certtotal" select="'0'" />
							<xsl:with-param name="certind" select="./certind" />
							<xsl:with-param name="datashare" select="./datashare" />
							<xsl:with-param name="cnpa" select="./cnpa" />
							<xsl:with-param name="cnxx" select="./cnxx" />
							<xsl:with-param name="cline" select="./cline" />
							<xsl:with-param name="mdnofrec" select="./mdnofrec" />
							<xsl:with-param name="itmdsc" select="./itmdsc" />
							<xsl:with-param name="dqtytp" select="./dqtytp" />
							<xsl:with-param name="certdqtytp" select="./dqtytp" />
							<xsl:with-param name="c1cg" select="./c1cg" />		
						</xsl:call-template>
					</xsl:for-each>		
					<xsl:if test="/all_results/results[@name = 'datasum-full']/row[c1in = '19' and superacct = $superacct and datashare = 'S' and certind != 'Y']">
						<fo:table-row keep-with-previous="always"  keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="9">					
								<fo:block>
									<xsl:value-of select="' '" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>

						<xsl:for-each-group select="/all_results/results[@name = 'datasum-full']/row[c1in = '19' and superacct = $superacct and datashare = 'S' and certind != 'Y']" group-by="itmdsc">
							<xsl:variable name="itmdsc" select="current-grouping-key()" />
	
							<xsl:variable name="rowtype" select="/all_results/results[@name = 'datasum-full']/row[c1in = '19' and superacct = $superacct and datashare = 'S' and certind != 'Y' and itmdsc = $itmdsc][position() = 1]/dqtytp" />
							<xsl:variable name="datashare" select="/all_results/results[@name = 'datasum-full']/row[c1in = '19' and superacct = $superacct and datashare = 'S' and certind != 'Y'][position() = 1]/datashare" />

							<xsl:call-template name="datasum-row">
								<xsl:with-param name="superacct" select="$superacct" />
								<xsl:with-param name="total" select="'SA'" />
								<xsl:with-param name="outdbno1" select="/all_results/results[@name = 'datasum-full']/row[c1in = '19' and superacct = $superacct and datashare = 'S' and certind != 'Y' and itmdsc = $itmdsc][position() = 1]/outdbno1" />
								<xsl:with-param name="rnduse" select="''" />
								<xsl:with-param name="adj_outused" select="sum(/all_results/results[@name = 'datasum-full']/row[c1in = '19' and superacct = $superacct and datashare = 'S' and certind != 'Y' and itmdsc = $itmdsc]/adj_outused)" />
								<xsl:with-param name="outunitcount" select="sum(/all_results/results[@name = 'datasum-full']/row[c1in = '19' and superacct = $superacct and datashare = 'S' and certind != 'Y' and itmdsc = $itmdsc]/outunitcount)" />
								<xsl:with-param name="certtotal" select="'0'" />
								<xsl:with-param name="certind" select="'N'" />
								<xsl:with-param name="datashare" select="$datashare" />
								<xsl:with-param name="cnpa" select="'0'" />
								<xsl:with-param name="cnxx" select="'0'" />
								<xsl:with-param name="cline" select="'0'" />
								<xsl:with-param name="mdnofrec" select="' '" />
								<xsl:with-param name="itmdsc" select="$itmdsc" />
								<xsl:with-param name="dqtytp" select="$rowtype" />
								<xsl:with-param name="certdqtytp" select="''" />
								<xsl:with-param name="c1cg" select="sum(/all_results/results[@name = 'datasum-full']/row[c1in = '19' and superacct = $superacct]/c1cg)" />		
							</xsl:call-template>
						</xsl:for-each-group>
					</xsl:if>
				</xsl:for-each-group>		
			</fo:table-body>
		</fo:table>
	</xsl:if>	

	<xsl:call-template name="homeroam" />
	<xsl:call-template name="datasum-sms" />	
	<xsl:call-template name="datasum-content" />
	
	<xsl:if test="exists(/all_results/results[@name = 'datasum-full']/row)">
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="20px" keep-with-next="always">Total Charges</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="3.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell border-bottom="solid 1.5px navy" text-align="left">
						<fo:block xsl:use-attribute-sets="summary-cells">
							<xsl:value-of select="'Total of Charges on Overage and Content '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" border-bottom="solid 1.5px navy" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'datasum-full']/row/c1cg), '###,##0.00;-##,##0.00')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:if>		
	
	<xsl:call-template name="billhist" />
</xsl:template>

<xsl:template name="datasum-row">
<xsl:param name="superacct" />
<xsl:param name="total" />
<xsl:param name="outdbno1" />
<xsl:param name="rnduse" />
<xsl:param name="adj_outused" />
<xsl:param name="outunitcount" />
<xsl:param name="certtotal" />
<xsl:param name="certind" />
<xsl:param name="datashare" />
<xsl:param name="cnpa" />
<xsl:param name="cnxx" />
<xsl:param name="cline" />
<xsl:param name="mdnofrec" />
<xsl:param name="itmdsc" />
<xsl:param name="dqtytp" />
<xsl:param name="certdqtytp" />
<xsl:param name="c1cg" />

	<xsl:variable name="initfree">
		<xsl:choose>
		<xsl:when test="$outdbno1 &gt;= 999999999">
			<xsl:value-of select="'Unlimited'" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="format-number(($outdbno1), '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="overage">
		<xsl:choose>
		<xsl:when test="$outdbno1 &gt;= 999999999">
			<xsl:value-of select="'n/a'" />
		</xsl:when>
		<xsl:when test="($rnduse = 'Y' or $total = 'SA') and ($adj_outused - ($outdbno1)) &lt; 0">
			<xsl:value-of select="format-number(0, '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:when>
		<xsl:when test="($rnduse = 'Y' or $total = 'SA')">
			<xsl:value-of select="format-number($adj_outused - ($outdbno1), '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:when>						
		<xsl:when test="($outunitcount - $outdbno1) &lt; 0">
			<xsl:value-of select="format-number(0, '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="format-number($outunitcount - ($outdbno1), '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="remainfree">
		<xsl:choose>
		<xsl:when test="($rnduse = 'Y' or $total = 'SA') and (($outdbno1) - $adj_outused) &lt; 0">
			<xsl:value-of select="format-number(0, '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:when>
		<xsl:when test="$rnduse = 'Y' or $total = 'SA'">
			<xsl:value-of select="format-number(($outdbno1) - $adj_outused, '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:when>
		<xsl:when test="$outdbno1 &gt;= 999999999">
			<xsl:value-of select="'n/a'" />
		</xsl:when>
		<xsl:when test="$adj_outused &gt;= ($outdbno1)">
			<xsl:value-of select="format-number(0, '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:when>						
		<xsl:otherwise>
			<xsl:value-of select="format-number(($outdbno1) - $outunitcount, '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="count">
		<xsl:choose>
		<xsl:when test="$certind = 'Y'">
			<xsl:value-of select="' '" />
		</xsl:when>		
		<xsl:when test="$rnduse = 'Y' or $total = 'SA'">
			<xsl:value-of select="format-number($adj_outused, '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="format-number($outunitcount, '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>										
	<xsl:variable name="count-cert">
		<xsl:choose>
		<xsl:when test="$certind = 'Y'">
			<xsl:value-of select="format-number($adj_outused, '###,###,##0.0000;-##,###,##0.0000')" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="' '" />
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>										
	<fo:table-row>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="format-number($superacct, '0000000')" />
			</fo:block>
		</fo:table-cell>

		<xsl:choose>
		<xsl:when test="$total = 'SA'">
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
				<fo:block>
					<xsl:value-of select="' Share Total '" />
				</fo:block>
			</fo:table-cell>
		</xsl:when>
		<xsl:otherwise>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="'('" />
					<xsl:value-of select="format-number($cnpa, '000')" />
					<xsl:value-of select="')'" />
					<xsl:value-of select="format-number($cnxx, '000')" />
					<xsl:value-of select="'-'" />
					<xsl:value-of select="format-number($cline, '0000')" />
					<xsl:choose>
					<xsl:when test="$mdnofrec = 'Y'">
						<fo:inline vertical-align="super" font-size="6pt">R</fo:inline>
					</xsl:when>
					<xsl:otherwise>
						<fo:inline vertical-align="super" font-size="6pt"><fo:character character="&#0160;" /></fo:inline>
					</xsl:otherwise>
					</xsl:choose>					
				</fo:block>
			</fo:table-cell>
		</xsl:otherwise>
		</xsl:choose>
		
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
			<fo:block>
				<xsl:value-of select="$itmdsc" />
			</fo:block>
		</fo:table-cell>

		<xsl:choose>
		<xsl:when test="$certind = 'Y' or ($datashare = 'S' and $total = 'DT')">
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$count" />
					<xsl:choose>
					<xsl:when test="normalize-space($count) = ''">
						<xsl:value-of select="' '" />
					</xsl:when>
					<xsl:when test="exists($dqtytp)">
						<xsl:value-of select="' '" />
						<xsl:value-of select="$dqtytp" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' EA'" />
					</xsl:otherwise>
					</xsl:choose>														
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$count-cert" />
					<xsl:choose>
					<xsl:when test="normalize-space($count-cert) = ''">
						<xsl:value-of select="' '" />
					</xsl:when>
					<xsl:when test="exists($certdqtytp)">
						<xsl:value-of select="' '" />
						<xsl:value-of select="$certdqtytp" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' EA'" />
					</xsl:otherwise>
					</xsl:choose>														
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right" number-columns-spanned="4">
				<fo:block>
					<xsl:value-of select="' '" />
				</fo:block>
			</fo:table-cell>
		</xsl:when>
		<xsl:when test="$total = 'SA' and $datashare != 'S'">
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$count" />
					<xsl:choose>
					<xsl:when test="normalize-space($count) = ''">
						<xsl:value-of select="' '" />
					</xsl:when>
					<xsl:when test="exists($dqtytp)">
						<xsl:value-of select="' '" />
						<xsl:value-of select="$dqtytp" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' EA'" />
					</xsl:otherwise>
					</xsl:choose>																			
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="' '" />
				</fo:block>
			</fo:table-cell>			
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right" number-columns-spanned="3">
				<fo:block>
					<xsl:value-of select="' '" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($c1cg, '###,##0.00;-##,##0.00')" />
				</fo:block>
			</fo:table-cell>			
		</xsl:when>	
		<xsl:when test="$total = 'SA' and $datashare = 'S'">
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$count" />
					<xsl:choose>
					<xsl:when test="normalize-space($count) = ''">
						<xsl:value-of select="' '" />
					</xsl:when>
					<xsl:when test="exists($dqtytp)">
						<xsl:value-of select="' '" />
						<xsl:value-of select="$dqtytp" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' EA'" />
					</xsl:otherwise>
					</xsl:choose>																			
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="' '" />
				</fo:block>
			</fo:table-cell>			
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$initfree" />
				</fo:block>
			</fo:table-cell>							
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$remainfree" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$overage" />
				</fo:block>		
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($c1cg, '###,##0.00;-##,##0.00')" />
				</fo:block>
			</fo:table-cell>
		</xsl:when>			
		<xsl:otherwise>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$count" />
					<xsl:choose>
					<xsl:when test="normalize-space($count) = ''">
						<xsl:value-of select="' '" />
					</xsl:when>
					<xsl:when test="exists($dqtytp)">
						<xsl:value-of select="' '" />
						<xsl:value-of select="$dqtytp" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' EA'" />
					</xsl:otherwise>
					</xsl:choose>																							
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$count-cert" />
					<xsl:choose>
					<xsl:when test="normalize-space($count-cert) = ''">
						<xsl:value-of select="' '" />
					</xsl:when>
					<xsl:when test="exists($certdqtytp)">
						<xsl:value-of select="' '" />
						<xsl:value-of select="$certdqtytp" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' EA'" />
					</xsl:otherwise>
					</xsl:choose>																								
				</fo:block>
			</fo:table-cell>			
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$initfree" />
				</fo:block>
			</fo:table-cell>							
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$remainfree" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="$overage" />
				</fo:block>		
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($c1cg, '###,##0.00;-##,##0.00')" />
				</fo:block>
			</fo:table-cell>
		</xsl:otherwise>
		</xsl:choose>
	</fo:table-row>
</xsl:template>

<xsl:template name="datasum-sms">
	<xsl:if test="exists(/all_results/results[@name = 'datasum-full']/row[c1in = '12' or c1in = '50'])">
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="20px" keep-with-next="always">SMS/MMS Usage Summary</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="2.00in" />
			<fo:table-column column-width="0.25in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Super Acct</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>MDN</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Data Feature</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Qty Ty</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Incoming</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Outgoing</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Initial Free</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Remaining Free</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Overage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Charges</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each-group select="/all_results/results[@name = 'datasum-full']/row[c1in = '12' or c1in = '50']" group-by="superacct">
					<xsl:variable name="superacct" select="current-grouping-key()" />
					<xsl:for-each select="/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct]">
						<xsl:variable name="initfree">
							<xsl:choose>
							<xsl:when test="./indbno1 = -1 and ./outdbno1 = -1">
								<xsl:value-of select="'Unlimited'" />
							</xsl:when>
							<xsl:when test="./indbno1 = -1 and ./adj_outused = 0">
								<xsl:value-of select="'Unlimited'" />
							</xsl:when>
							<xsl:when test="./outdbno1 = -1 and ./adj_inused = 0">
								<xsl:value-of select="'Unlimited'" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(./indbno1 + ./outdbno1, '###,###,##0     ;-##,###,##0     ')" />
							</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="overage">
							<xsl:choose>
							<xsl:when test="$initfree = 'Unlimited'">
								<xsl:value-of select="'n/a'" />
							</xsl:when>
							<xsl:when test="./dqtytp = 'EA' and ((./adj_inused - ./indbno1) + (./adj_outused - ./outdbno1)) &lt; 0">
								<xsl:value-of select="format-number(0, '###,###,##0    ;-##,###,##0    ')" />
							</xsl:when>
							<xsl:when test="((./adj_inunitcount - ./indbno1) + (./adj_outunitcount - ./outdbno1)) &lt; 0">
								<xsl:value-of select="format-number(0, '###,###,##0.0000;-##,###,##0.0000')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
								<xsl:when test="./dqtytp = 'EA' and (./indbno1 = -1 and ./adj_outused = 0) and ((./adj_inused - ./indbno1) &lt; 0)">
									<xsl:value-of select="format-number(./adj_inused - ./indbno1, '###,###,##0     ;-##,###,##0     ')" />								
								</xsl:when>
								<xsl:when test="./dqtytp = 'EA' and (./outdbno1 = -1 and ./adj_inused = 0 and ((./adj_outused - ./outdbno1)) &lt; 0)">
									<xsl:value-of select="format-number(./adj_outused - ./outdbno1, '###,###,##0     ;-##,###,##0     ')" />							
								</xsl:when>
								<xsl:when test="(./indbno1 = -1 and ./adj_outused = 0) and ((./adj_inused - ./indbno1) &lt; 0)">
									<xsl:value-of select="format-number((./adj_inused - ./indbno1) div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="(./outdbno1 = -1 and ./adj_inused = 0 and ((./adj_outused - ./outdbno1)) &lt; 0)">
									<xsl:value-of select="format-number((./adj_outused - ./outdbno1) div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
								</xsl:when>
								<xsl:when test="./dqtytp = 'EA'">
									<xsl:value-of select="format-number((./adj_inused - ./indbno1) + (./adj_outused - ./outdbno1), '###,###,##0     ;-##,###,##0     ')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number(((./adj_inused - ./indbno1) + (./adj_outused - ./outdbno1)) div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
								</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="remainfree">
							<xsl:choose>
							<xsl:when test="$initfree = 'Unlimited'">
								<xsl:value-of select="'n/a'" />
							</xsl:when>
							<xsl:when test="((./indbno1 - ./adj_inused) + (./outdbno1 - ./adj_outused)) &lt; 1">
								<xsl:value-of select="format-number(0, '###,###,##0')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
								<xsl:when test="./dqtytp = 'EA'">
									<xsl:value-of select="format-number((./indbno1 - ./adj_inused) + (./outdbno1 - ./adj_outused), '###,###,##0     ;-##,###,##0     ')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number(((./indbno1 - ./adj_inused) + (./outdbno1 - ./adj_outused)) div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
								</xsl:otherwise>
								</xsl:choose>						
							</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="incount">
							<xsl:choose>
							<xsl:when test="./dqtytp = 'EA'">
								<xsl:value-of select="format-number(./adj_inused, '###,###,##0     ;-##,###,##0     ')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(./adj_inused, '###,###,##0.0000;-##,###,##0.0000')" />
							</xsl:otherwise>
							</xsl:choose>						
						</xsl:variable>
						<xsl:variable name="outcount">
							<xsl:choose>
							<xsl:when test="./dqtytp = 'EA'">
								<xsl:value-of select="format-number(./adj_outused, '###,###,##0     ;-##,###,##0     ')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(./adj_outused, '###,###,##0.0000;-##,###,##0.0000')" />
							</xsl:otherwise>
							</xsl:choose>						
						</xsl:variable>
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="format-number($superacct, '0000000')" />
								</fo:block>
							</fo:table-cell>					
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="'('" />
									<xsl:value-of select="format-number(./cnpa, '000')" />
									<xsl:value-of select="')'" />
									<xsl:value-of select="format-number(./cnxx, '000')" />
									<xsl:value-of select="'-'" />
									<xsl:value-of select="format-number(./cline, '0000')" />
									<xsl:choose>
									<xsl:when test="./mdnofrec = 'Y'">
										<fo:inline vertical-align="super" font-size="6pt">R</fo:inline>
									</xsl:when>
									<xsl:otherwise>
										<fo:inline vertical-align="super" font-size="6pt"><fo:character character="&#0160;" /></fo:inline>
									</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>					
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="./itmdsc" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:choose>
									<xsl:when test="exists(./dqtytp)">
										<xsl:value-of select="./dqtytp" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="'EA'" />
									</xsl:otherwise>
									</xsl:choose>									
								</fo:block>
							</fo:table-cell>	
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="$incount" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="$outcount" />
								</fo:block>
							</fo:table-cell>
							<xsl:choose>
							<xsl:when test="./datashare = 'S'">
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right" number-columns-spanned="4">
									<fo:block>
										<xsl:value-of select="' '" />
									</fo:block>
								</fo:table-cell>							
							</xsl:when>
							<xsl:otherwise>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="$initfree" />
									</fo:block>
								</fo:table-cell>							
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="$remainfree" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="$overage" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number(./c1cg, '###,##0.00;-##,##0.00')" />
									</fo:block>
								</fo:table-cell>
							</xsl:otherwise>
							</xsl:choose>								
						</fo:table-row>					
					</xsl:for-each>
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="10">					
							<fo:block>
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>					
					<xsl:if test="exists(/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S'])">
						<xsl:for-each-group select="/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S']" group-by="itmdsc">
							<xsl:variable name="itmdsc" select="current-grouping-key()" />

							<xsl:variable name="maxindbno" select="max(/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S' and itmdsc = $itmdsc]/indbno1)" />
							<xsl:variable name="maxoutdbno" select="max(/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S' and itmdsc = $itmdsc]/outdbno1)" />
							<xsl:variable name="suminused" select="sum(/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S' and itmdsc = $itmdsc]/adj_inused)" />
							<xsl:variable name="sumoutused" select="sum(/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S' and itmdsc = $itmdsc]/adj_outused)" />
							<xsl:variable name="maxdttype" select="/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S' and itmdsc = $itmdsc][position() = 1]/dqtytp" />
							<xsl:variable name="suminunitcount" select="sum(/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S' and itmdsc = $itmdsc]/adj_inunitcount)" />						
							<xsl:variable name="sumoutunitcount" select="sum(/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S' and itmdsc = $itmdsc]/adj_outunitcount)" />						
							
							<xsl:variable name="initfree">
								<xsl:choose>
								<xsl:when test="$maxindbno = -1 and $maxoutdbno = -1">
									<xsl:value-of select="'Unlimited'" />
								</xsl:when>
								<xsl:when test="$maxindbno = -1 and $sumoutused = 0">
									<xsl:value-of select="'Unlimited'" />
								</xsl:when>
								<xsl:when test="$maxoutdbno = -1 and $suminused = 0">
									<xsl:value-of select="'Unlimited'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number($maxindbno + $maxoutdbno, '###,###,##0     ;-##,###,##0     ')" />
								</xsl:otherwise>
								</xsl:choose>
							</xsl:variable>
							<xsl:variable name="overage">
								<xsl:choose>
								<xsl:when test="$initfree = 'Unlimited'">
									<xsl:value-of select="'n/a'" />
								</xsl:when>
								<xsl:when test="$maxdttype = 'EA' and ($suminused - $maxindbno) + ($sumoutused - $maxoutdbno) &lt; 0">
									<xsl:value-of select="format-number(0, '###,###,##0    ;-##,###,##0    ')" />
								</xsl:when>
								<xsl:when test="($suminunitcount - $maxindbno + ($sumoutunitcount - $maxoutdbno)) &lt; 0">
									<xsl:value-of select="format-number(0, '###,###,##0.0000;-##,###,##0.0000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
									<xsl:when test="$maxdttype = 'EA' and $maxindbno = -1 and ./adj_outused = 0 and ($suminused - $maxindbno) &lt; 0">
										<xsl:value-of select="format-number(./adj_inused - ./indbno1, '###,###,##0     ;-##,###,##0     ')" />								
									</xsl:when>
									<xsl:when test="$maxdttype = 'EA' and $maxoutdbno = -1 and ./adj_inused = 0 and ($sumoutused - $maxoutdbno) &lt; 0">
										<xsl:value-of select="format-number(./adj_outused - $maxoutdbno, '###,###,##0     ;-##,###,##0     ')" />							
									</xsl:when>
									<xsl:when test="$maxindbno = -1 and $sumoutused = 0 and ($suminused - $maxindbno) &lt; 0">
										<xsl:value-of select="format-number((./adj_inused - ./indbno1) div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
									</xsl:when>
									<xsl:when test="$maxoutdbno = -1 and $suminused = 0 and ($sumoutused - $maxoutdbno) &lt; 0">
										<xsl:value-of select="format-number((./adj_outused - ./outdbno1) div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
									</xsl:when>
									<xsl:when test="$maxdttype = 'EA'">
										<xsl:value-of select="format-number(($suminused - $maxindbno) + ($sumoutused - $maxoutdbno), '###,###,##0     ;-##,###,##0     ')" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="format-number((($suminused - $maxindbno) + ($sumoutused - $maxoutdbno)) div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
									</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
								</xsl:choose>
							</xsl:variable>
							<xsl:variable name="remainfree">
								<xsl:choose>
								<xsl:when test="$initfree = 'Unlimited'">
									<xsl:value-of select="'n/a'" />
								</xsl:when>
								<xsl:when test="(($maxindbno - $suminused) + ($maxoutdbno - $sumoutused)) &lt; 1">
									<xsl:value-of select="format-number(0, '###,###,##0')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
									<xsl:when test="$maxdttype = 'EA'">
										<xsl:value-of select="format-number(($maxindbno - $suminused) + ($maxoutdbno - $sumoutused), '###,###,##0     ;-##,###,##0     ')" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="format-number((($maxindbno - $suminused) + ($maxoutdbno - $sumoutused)) div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
									</xsl:otherwise>
									</xsl:choose>						
								</xsl:otherwise>
								</xsl:choose>
							</xsl:variable>
							<xsl:variable name="incount">
								<xsl:choose>
								<xsl:when test="$maxdttype = 'EA'">
									<xsl:value-of select="format-number($suminused, '###,###,##0     ;-##,###,##0     ')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number($suminused, '###,###,##0.0000;-##,###,##0.0000')" />
								</xsl:otherwise>
								</xsl:choose>						
							</xsl:variable>
							<xsl:variable name="outcount">
								<xsl:choose>
								<xsl:when test="$maxdttype = 'EA'">
									<xsl:value-of select="format-number($sumoutused, '###,###,##0     ;-##,###,##0     ')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number($sumoutused, '###,###,##0.0000;-##,###,##0.0000')" />
								</xsl:otherwise>
								</xsl:choose>						
							</xsl:variable>
							<fo:table-row keep-with-previous="always">
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="format-number($superacct, '0000000')" />
									</fo:block>
								</fo:table-cell>					
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
										<xsl:value-of select="'Share Total'" />
									</fo:block>
								</fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
										<xsl:value-of select="$itmdsc" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:choose>
										<xsl:when test="exists($maxdttype)">
											<xsl:value-of select="$maxdttype" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="'EA'" />
										</xsl:otherwise>
										</xsl:choose>									
									</fo:block>
								</fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="$incount" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="$outcount" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="$initfree" />
									</fo:block>
								</fo:table-cell>							
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="$remainfree" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="$overage" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number(sum(/all_results/results[@name = 'datasum-full']/row[(c1in = '12' or c1in = '50') and superacct = $superacct and datashare = 'S' and itmdsc = $itmdsc]/c1cg), '###,##0.00;-##,##0.00')" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>		
						</xsl:for-each-group>
					</xsl:if>					
				</xsl:for-each-group>
			</fo:table-body>
		</fo:table>
	</xsl:if>	
</xsl:template>

<xsl:template name="datasum-content">
	<xsl:if test="exists(/all_results/results[@name = 'datasum-full']/row[c1in != '12' and c1in != '50' and c1in != '19'])">
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="20px" keep-with-next="always">Content Usage Summary</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Data Feature</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Qty Ty</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Quantity</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block><xsl:value-of select="' '" /></fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block><xsl:value-of select="' '" /></fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block><xsl:value-of select="' '" /></fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block><xsl:value-of select="' '" /></fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Charges</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'datasum-full']/row[c1in != '12' and c1in != '50' and c1in != '19']">
					<xsl:variable name="count">
						<xsl:choose>
						<xsl:when test="./dqtytp = 'EA'">
							<xsl:value-of select="format-number(./aggused, '###,###,##0     ;-##,###,##0     ')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(./aggused, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:otherwise>
						</xsl:choose>						
					</xsl:variable>					
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
								<xsl:value-of select="./itmdsc" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./dqtytp = 'EA'">
										<xsl:value-of select="'Each'" />
									</xsl:when>
									<xsl:when test="./dqtytp = 'BT'">
										<xsl:value-of select="'Byte'" />
									</xsl:when>
									<xsl:when test="./dqtytp = 'KB'">
										<xsl:value-of select="'Kilobyte'" />
									</xsl:when>
									<xsl:when test="./dqtytp = 'MB'">
										<xsl:value-of select="'Megabyte'" />
									</xsl:when>
									<xsl:when test="./dqtytp = 'GB'">
										<xsl:value-of select="'Gigabyte'" />
									</xsl:when>
									<xsl:when test="exists(./dqtytp)">
										<xsl:value-of select="./dqtytp" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="'EA'" />
									</xsl:otherwise>
								</xsl:choose>									
							</fo:block>
						</fo:table-cell>							
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="$count" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./c1cg, '###,##0.00;-##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:if>	
</xsl:template>

<xsl:template name="homeroam">
	<xsl:if test="exists(/all_results/results[@name = 'datasum_homeroam']/row)">
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="20px" keep-with-next="always">Home/Roam Usage Summary</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Super Account</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>MDN</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Usage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Home Usage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Roam Usage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>LTE Home Usage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>LTE Roam Usage</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'datasum_homeroam']/row">
					<xsl:variable name="used">
						<xsl:choose>
						<xsl:when test="./qtytyp = 'GB'">
							<xsl:value-of select="format-number(./used div (1024 * 1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'MB'">
							<xsl:value-of select="format-number(./used div (1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'KB'">
							<xsl:value-of select="format-number(./used div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(./used, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="home">
						<xsl:choose>
						<xsl:when test="./qtytyp = 'GB'">
							<xsl:value-of select="format-number(./home_used div (1024 * 1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'MB'">
							<xsl:value-of select="format-number(./home_used div (1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'KB'">
							<xsl:value-of select="format-number(./home_used div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(./home_used, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>					
					<xsl:variable name="roam">
						<xsl:choose>
						<xsl:when test="./qtytyp = 'GB'">
							<xsl:value-of select="format-number(./roam_used div (1024 * 1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'MB'">
							<xsl:value-of select="format-number(./roam_used div (1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'KB'">
							<xsl:value-of select="format-number(./roam_used div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(./roam_used, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:otherwise>
						</xsl:choose>
					</xsl:variable> 
					<xsl:variable name="ltehome">
						<xsl:choose>
						<xsl:when test="./qtytyp = 'GB'">
							<xsl:value-of select="format-number(./ltehome_used div (1024 * 1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'MB'">
							<xsl:value-of select="format-number(./ltehome_used div (1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'KB'">
							<xsl:value-of select="format-number(./ltehome_used div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(./ltehome_used, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="lteroam">
						<xsl:choose>
						<xsl:when test="./qtytyp = 'GB'">
							<xsl:value-of select="format-number(./lteroam_used div (1024 * 1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'MB'">
							<xsl:value-of select="format-number(./lteroam_used div (1024 * 1024), '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:when test="./qtytyp = 'KB'">
							<xsl:value-of select="format-number(./lteroam_used div 1024, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(./lteroam_used, '###,###,##0.0000;-##,###,##0.0000')" />
						</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="format-number(./superacct, '0000000')" />
							</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="'('" />
								<xsl:value-of select="format-number(./cnpa, '000')" />
								<xsl:value-of select="')'" />
								<xsl:value-of select="format-number(./cnxx, '000')" />
								<xsl:value-of select="'-'" />
								<xsl:value-of select="format-number(./cline, '0000')" />
								<xsl:choose>
								<xsl:when test="./mdnofrec = 'Y'">
									<fo:inline vertical-align="super" font-size="6pt">R</fo:inline>
								</xsl:when>
								<xsl:otherwise>
									<fo:inline vertical-align="super" font-size="6pt"><fo:character character="&#0160;" /></fo:inline>
								</xsl:otherwise>
								</xsl:choose>								
							</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="$used" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="./qtytyp" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="$home" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="./qtytyp" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="$roam" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="./qtytyp" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="$ltehome" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="./qtytyp" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="$lteroam" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="./qtytyp" />
							</fo:block>
						</fo:table-cell>	
					</fo:table-row>				
				</xsl:for-each>
				<fo:table-row keep-with-previous="always">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center" number-columns-spanned="7">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>	
				</fo:table-row>
				<xsl:variable name="totqty" select="/all_results/results[@name = 'datasum_homeroam']/row[position() = 1]/qtytyp" />
				<xsl:variable name="totalused">
					<xsl:choose>
					<xsl:when test="$totqty = 'GB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/used) div (1024 * 1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'MB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/used) div (1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'KB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/used) div 1024" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/used)" />
					</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="totalhome">
					<xsl:choose>
					<xsl:when test="$totqty = 'GB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/home_used) div (1024 * 1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'MB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/home_used) div (1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'KB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/home_used) div 1024" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/home_used)" />
					</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="totalroam">
					<xsl:choose>
					<xsl:when test="$totqty = 'GB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/roam_used) div (1024 * 1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'MB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/roam_used) div (1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'KB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/roam_used) div 1024" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/roam_used)" />
					</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>				
				<xsl:variable name="totalltehome">
					<xsl:choose>
					<xsl:when test="$totqty = 'GB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/ltehome_used) div (1024 * 1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'MB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/ltehome_used) div (1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'KB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/ltehome_used) div 1024" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/ltehome_used)" />
					</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>				
				<xsl:variable name="totallteroam">
					<xsl:choose>
					<xsl:when test="$totqty = 'GB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/lteroam_used) div (1024 * 1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'MB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/lteroam_used) div (1024 * 1024)" />
					</xsl:when>
					<xsl:when test="$totqty = 'KB'">
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/lteroam_used) div 1024" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="sum(/all_results/results[@name = 'datasum_homeroam']/row/lteroam_used)" />
					</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<fo:table-row keep-with-previous="always">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="2">
						<fo:block>
							<xsl:value-of select="'Total All Phones'" />
						</fo:block>
						<fo:block>
							<xsl:value-of select="'(Percentages)'" />
						</fo:block>
					</fo:table-cell>	
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totalused, '###,###,##0.0000;-##,###,##0.0000')" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="$totqty" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totalhome, '###,###,##0.0000;-##,###,##0.0000')" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="$totqty" />
						</fo:block>
						<fo:block>
							<xsl:value-of select="'('" />
							<xsl:value-of select="format-number(($totalhome div $totalused) * 100, '##0.0000')" />
							<xsl:value-of select="'%)'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totalroam, '###,###,##0.0000;-##,###,##0.0000')" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="$totqty" />
						</fo:block>
						<fo:block>
							<xsl:value-of select="'('" />
							<xsl:value-of select="format-number(($totalroam div $totalused) * 100, '##0.0000')" />
							<xsl:value-of select="'%)'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totalltehome, '###,###,##0.0000;-##,###,##0.0000')" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="$totqty" />
						</fo:block>
						<fo:block>
							<xsl:value-of select="'('" />
							<xsl:value-of select="format-number(($totalltehome div $totalused) * 100, '##0.0000')" />
							<xsl:value-of select="'%)'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totallteroam, '###,###,##0.0000;-##,###,##0.0000')" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="$totqty" />
						</fo:block>
						<fo:block>
							<xsl:value-of select="'('" />
							<xsl:value-of select="format-number(($totallteroam div $totalused) * 100, '##0.0000')" />
							<xsl:value-of select="'%)'" />
						</fo:block>						
					</fo:table-cell>	
				</fo:table-row>		
			</fo:table-body>
		</fo:table>
	</xsl:if>
</xsl:template>

<xsl:template name="billhist">
	<xsl:if test="exists(/all_results/results[@name = 'billhist']/row)">
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="20px" keep-with-next="always">Data Usage Billing History</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="0.80in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.20in" />
			<fo:table-column column-width="0.25in" />
			<fo:table-column column-width="1.20in" />
			<fo:table-column column-width="0.50in" />
			<fo:table-column column-width="1.20in" />
			<fo:table-column column-width="0.50in" />
			<fo:table-column column-width="1.20in" />
			<fo:table-column column-width="0.50in" />
			<fo:table-column column-width="1.20in" />
			<fo:table-column column-width="0.50in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Bill Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>MDN</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Usage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Qty Ty</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>3G Home Usage</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>3G Home %</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>3G Roam Usage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>3G Roam %</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>LTE Home Usage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>LTE Home %</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>LTE Roam Usage</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>LTE Roam %</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each-group select="/all_results/results[@name = 'billhist']/row" group-by="billdate">
					<xsl:sort select="billdate" order="descending" />
					<xsl:sort select="areacode" />
					<xsl:sort select="exchange" />
					<xsl:sort select="line" />		
							
					<xsl:variable name="billdate" select="current-grouping-key()" />
					<xsl:for-each select="/all_results/results[@name = 'billhist']/row[billdate = $billdate]">
						<xsl:call-template name="billhist-row">
							<xsl:with-param name="billdate" select="$billdate" />
							<xsl:with-param name="cnpa" select="./areacode" />
							<xsl:with-param name="cnxx" select="./exchange" />
							<xsl:with-param name="cline" select="./line" />
							<xsl:with-param name="dqtytp" select="./qt" />
							<xsl:with-param name="totaluse" select="./bytes" />
							<xsl:with-param name="home" select="./hm" />
							<xsl:with-param name="roam" select="./rm" />
							<xsl:with-param name="ltehome" select="./lte_hm" />
							<xsl:with-param name="lteroam" select="./lte_rm" />
						</xsl:call-template>
					</xsl:for-each>		
					<xsl:call-template name="billhist-row">
							<xsl:with-param name="billdate" select="$billdate" />
							<xsl:with-param name="cnpa" select="'000'" />
							<xsl:with-param name="cnxx" select="'000'" />
							<xsl:with-param name="cline" select="'0000'" />
							<xsl:with-param name="dqtytp" select="/all_results/results[@name = 'billhist']/row[billdate = $billdate][position() = 1]/qt" />
							<xsl:with-param name="totaluse" select="sum(/all_results/results[@name = 'billhist']/row[billdate = $billdate]/bytes)" />
							<xsl:with-param name="home" select="sum(/all_results/results[@name = 'billhist']/row[billdate = $billdate]/hm)" />
							<xsl:with-param name="roam" select="sum(/all_results/results[@name = 'billhist']/row[billdate = $billdate]/rm)" />
							<xsl:with-param name="ltehome" select="sum(/all_results/results[@name = 'billhist']/row[billdate = $billdate]/lte_hm)" />
							<xsl:with-param name="lteroam" select="sum(/all_results/results[@name = 'billhist']/row[billdate = $billdate]/lte_rm)" />
					</xsl:call-template>
				</xsl:for-each-group>						
			</fo:table-body>
		</fo:table>
	</xsl:if>	
</xsl:template>

<xsl:template name="billhist-row">
<xsl:param name="billdate" />
<xsl:param name="cnpa" />
<xsl:param name="cnxx" />
<xsl:param name="cline" />
<xsl:param name="dqtytp" />
<xsl:param name="totaluse" />
<xsl:param name="home" />
<xsl:param name="roam" />
<xsl:param name="ltehome" />
<xsl:param name="lteroam" />

	<fo:table-row>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$billdate" />
			</fo:block>
		</fo:table-cell>
		<xsl:choose>
		<xsl:when test="$cnpa = '000'">
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
				<fo:block>
					<xsl:value-of select="' Cycle Total '" />
				</fo:block>
			</fo:table-cell>
		</xsl:when>
		<xsl:otherwise>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="'('" />
					<xsl:value-of select="format-number($cnpa, '000')" />
					<xsl:value-of select="')'" />
					<xsl:value-of select="format-number($cnxx, '000')" />
					<xsl:value-of select="'-'" />
					<xsl:value-of select="format-number($cline, '0000')" />
				</fo:block>
			</fo:table-cell>
		</xsl:otherwise>
		</xsl:choose>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number($totaluse, '###,###,##0.00000')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="$dqtytp" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number($home, '###,###,##0.00000')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number(($home div $totaluse) * 100, '##0.000')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number($roam, '###,###,##0.00000')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number(($roam div $totaluse) * 100, '##0.000')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number($ltehome, '###,###,##0.00000')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number(($ltehome div $totaluse) * 100, '##0.000')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number($lteroam, '###,###,##0.00000')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number(($lteroam div $totaluse) * 100, '##0.000')" />
			</fo:block>
		</fo:table-cell>
	</fo:table-row>
</xsl:template>

<xsl:template name="aaahist">
	<xsl:if test="exists(/all_results/results[@name = 'aaahist-sum']/row)">
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="20px" keep-with-next="always">Data Usage Daily History</fo:block>
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="3px" color="red" keep-with-previous="always">** NOTE: Totals between daily history and full detail may vary due to rounding of data amounts.</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.20in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>GB Used</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'aaahist-sum']/row">
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./startdate" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./gbytes &gt; ''">
									<xsl:value-of select="./gbytes" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'0.00000000'" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
				<fo:table-row keep-with-previous="always">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="' Total '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'aaahist-sum']/row[gbytes &gt; '']/gbytes), '##,##0.00000000')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:if>	
	<xsl:if test="exists(/all_results/results[@name = 'aaahist-full']/row)">
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="20px" keep-with-next="always">Data Usage Full History</fo:block>
		<fo:block xsl:use-attribute-sets="summary-cells" space-before="3px" color="red" keep-with-previous="always">** NOTE: Totals between daily history and full detail may vary due to rounding of data amounts.</fo:block>
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.20in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Time</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>GB Used</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'aaahist-full']/row">
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./startdate" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./starttime" />
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./gbytes &gt; ''">
									<xsl:value-of select="./gbytes" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'0.00000000'" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>		
				<fo:table-row keep-with-previous="always">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="2">
						<fo:block>
							<xsl:value-of select="' Total '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'aaahist-full']/row[gbytes &gt; '']/gbytes), '##,##0.00000000')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:if>		
</xsl:template>

</xsl:stylesheet>






