<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:exsl="http://exslt.org/functions" 
								xmlns:img="java:com.psasoft.util.ImageUtilities"
								xmlns:util="java:org.apache.commons.lang.StringUtils"
								extension-element-prefixes="exsl" 
								exclude-result-prefixes="java" version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/>  

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
<xsl:variable name="title" select="' '" />

<xsl:template match="/">
		<fo:root>
				<xsl:call-template name="make-layout-master-small-margin" />
				<xsl:call-template name="make-body" />
		</fo:root>
</xsl:template>
<xsl:template name="body_process">
		<xsl:variable name="rowcount" select="'1'" />
		<xsl:variable name="acct" select="/all_results/results[@name = 'acct']/row" />
		<xsl:variable name="serv" select="/all_results/results[@name = 'serv']/row" />
		<xsl:variable name="primaryint" select="/all_results/results[@name = 'internet']/row[primary = 'Y']" />
		<xsl:variable name="secint" select="/all_results/results[@name = 'internet']/row[primary = 'N']" />
		<fo:table keep-together.within-page="always">
				<fo:table-column column-width="3.75in"/>
				<fo:table-column column-width="3.75in" />
				<fo:table-body>
						<fo:table-row height="30px">
								<fo:table-cell number-columns-spanned="2" text-align="center">
									<fo:block xsl:use-attribute-sets="report-title" font-size="20pt" font-weight="bold" font-style="italic">Service Agreement</fo:block>
								</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-headings">Customer Name: 
											<fo:inline>
												<xsl:value-of select="$acct/fname"/>
												<xsl:value-of select="' '"/>
												<xsl:value-of select="$acct/lname"/>
											</fo:inline>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-headings">Service Number: 
										<fo:inline>
											<xsl:call-template name="phone">
												<xsl:with-param name="npa" select="$serv/cnpa"/>
												<xsl:with-param name="nxx" select="$serv/cnxx"/>
												<xsl:with-param name="line" select="$serv/cline"/>
											</xsl:call-template>
										</fo:inline>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>                   		
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-headings">Account Number:	
											<fo:inline>
												<xsl:value-of select="format-number($acct/cycle, '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number($acct/bacct, '0000000')" />
											</fo:inline>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-headings">Effective Date:
										<fo:inline>
											<xsl:call-template name="date1parm">
												<xsl:with-param name="date" select="$acct/crdate"/>
											</xsl:call-template>								
										</fo:inline>
									</fo:block>	
								</fo:table-cell>
						</fo:table-row>                   		
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-headings">Address:
											<xsl:if test="$acct/bdisc">
												<fo:block xsl:use-attribute-sets="summary-headings" margin-left="10px">
													<xsl:value-of select="$serv/bdisc"/>
												</fo:block>
											</xsl:if>
											<xsl:if test="$acct/adln1">
												<fo:block xsl:use-attribute-sets="summary-headings" margin-left="10px">
													<xsl:value-of select="$acct/adln1"/>
												</fo:block>
											</xsl:if>												
											<xsl:if test="$acct/adln2">
												<fo:block xsl:use-attribute-sets="summary-headings" margin-left="10px">
													<xsl:value-of select="$acct/adln2"/>
												</fo:block>
											</xsl:if>												
											<xsl:if test="$acct/adln3">
												<fo:block xsl:use-attribute-sets="summary-headings" margin-left="10px">
													<xsl:value-of select="$acct/adln3"/>
												</fo:block>
											</xsl:if>												
											<fo:block xsl:use-attribute-sets="summary-headings" margin-left="10px">
												<fo:inline>
													<xsl:value-of select="$acct/adcity"/>
													<xsl:value-of select="', '"/>
													<xsl:value-of select="$acct/adst"/>
													<xsl:value-of select="' '"/>
													<xsl:value-of select="substring($acct/adzip, 1, 5)"/>
													<xsl:if test="substring($acct/adzip, 6, 4) != '0000'" >
														<xsl:value-of select="'-'"/>
														<xsl:value-of select="substring($acct/adzip, 6, 4)"/>
													</xsl:if>
												</fo:inline>
											</fo:block>                   		
									</fo:block>
								</fo:table-cell>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-headings">Contact Number: 
										<fo:inline>
											<xsl:call-template name="phone">
												<xsl:with-param name="npa" select="$acct/ctnpa"/>
												<xsl:with-param name="nxx" select="$acct/ctnxx"/>
												<xsl:with-param name="line" select="$acct/ctline"/>
											</xsl:call-template>
										</fo:inline>
									</fo:block>
								</fo:table-cell>								
						</fo:table-row>                            
						<fo:table-row height="15px">
								<fo:table-cell number-columns-spanned="2">
									<fo:block xsl:use-attribute-sets="summary-headings">Plans / Charges:  
									</fo:block>
								</fo:table-cell>
						</fo:table-row>								
						<fo:table-row height="75px">
								<fo:table-cell number-columns-spanned="2" text-align="left">
									<fo:table keep-together="always">
											<fo:table-column column-width="3in"/>
											<fo:table-column column-width="1.25in" />
											<fo:table-body>                    
												<xsl:for-each select="/all_results/results[@name = 'seitems']/row">
													<fo:table-row>
															<fo:table-cell>
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="10px">
																	<xsl:value-of select="./itmdsc"/>
																</fo:block>																	
															</fo:table-cell>														
															<fo:table-cell text-align="right">
																<fo:block xsl:use-attribute-sets="summary-headings">
																	<xsl:value-of select="format-number(./itmrat, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
																</fo:block>																	
															</fo:table-cell>														
													</fo:table-row>
												</xsl:for-each>
												<xsl:for-each select="/all_results/results[@name = 'acitems']/row">
													<fo:table-row>
															<fo:table-cell>
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="10px">
																	<xsl:value-of select="./itmdsc"/>
																</fo:block>																	
															</fo:table-cell>														
															<fo:table-cell text-align="right">
																<fo:block xsl:use-attribute-sets="summary-headings">
																	<xsl:value-of select="format-number(./aitrat, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
																</fo:block>																	
															</fo:table-cell>														
													</fo:table-row>
												</xsl:for-each>														
											</fo:table-body>
									</fo:table>		                  
								</fo:table-cell>
						</fo:table-row>
						<fo:table-row height="30px">
								<fo:table-cell number-columns-spanned="2" border-style="solid" border-width="1px">
										<fo:table keep-together="always">
											<fo:table-column column-width="1.0in" />
											<fo:table-column column-width="3.5in" />
											<fo:table-column column-width="3.5in" />
											<fo:table-body>
													<fo:table-row height="30px">
															<fo:table-cell number-columns-spanned="3">
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="10px">
																	Primary Email Address:
																</fo:block>
															</fo:table-cell>
													</fo:table-row>                
													<fo:table-row height="20px">
															<fo:table-cell>
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="20px">
																	<xsl:value-of select="' '"/>
																</fo:block>
															</fo:table-cell>													
															<fo:table-cell>
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="20px">
																	<fo:inline text-decoration="underline">
																		<xsl:value-of select="util:leftPad($primaryint/emladdr, 15, '_')"/>
																	</fo:inline>
																	@bugnet.net
																</fo:block>
															</fo:table-cell>
															<fo:table-cell>
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="20px">
																	Password:
																	<fo:inline text-decoration="underline">
																		<xsl:value-of select="util:leftPad($primaryint/emlpass, 15, '_')"/>
																	</fo:inline>
																</fo:block>
															</fo:table-cell>
													</fo:table-row>  
													<fo:table-row height="30px">
															<fo:table-cell number-columns-spanned="3">
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="10px">
																	Additional Email Accounts:
																</fo:block>
															</fo:table-cell>
													</fo:table-row>        
													        
													<xsl:for-each select="$secint">
														<fo:table-row height="20px">
															<fo:table-cell>
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="20px">
																	<xsl:value-of select="' '"/>
																</fo:block>
															</fo:table-cell>													
															<fo:table-cell>
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="20px">
																	<fo:inline text-decoration="underline">
																		<xsl:value-of select="util:leftPad(./emladdr, 15, '_')"/>
																	</fo:inline>
																	@bugnet.net
																</fo:block>
															</fo:table-cell>
															<fo:table-cell>
																<fo:block xsl:use-attribute-sets="summary-headings" margin-left="20px">
																	Password:
																	<fo:inline text-decoration="underline">
																		<xsl:value-of select="util:leftPad(./emlpass, 15, '_')"/>
																	</fo:inline>
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</xsl:for-each>													
											</fo:table-body>
										</fo:table>
								</fo:table-cell>
						</fo:table-row>
						<fo:table-row height="30px">
								<fo:table-cell number-columns-spanned="2" >
									<fo:block xsl:use-attribute-sets="summary-cells" space-before="15px">Please keep this document in a safe location.  Never give your password to anyone.  Your account is now active.  Information on this document is case sensitive.  Please contact Technical Support at Bug Tussel Wireless, LLC 1-800-580-9567 with any connectivity questions or concerns.
									</fo:block>
								</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
								<fo:table-cell number-rows-spanned="3" text-align="center" margin-top="2%">
									<xsl:variable name="logo" select="img:getImageBase64Encoded('/images/BTLogo.jpg')"/>
									<fo:block xsl:use-attribute-sets="summary-headings">
											<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="2.0in"/>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell height="65px">
									<fo:block xsl:use-attribute-sets="summary-cells">Customer Signature:
									</fo:block>
									<fo:block xsl:use-attribute-sets="summary-headings" border-bottom-style="solid" border-bottom-width="1px">
										<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="175px" content-height="50px"/>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>                
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">Date:
									</fo:block>
									<fo:block xsl:use-attribute-sets="summary-headings" border-bottom-style="solid" border-bottom-width="1px">
										<fo:inline><xsl:value-of select="format-dateTime(current-dateTime(), '[MNn] [D], [Y]')" /></fo:inline>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>                
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">My signature verifies that I understand and agree to the terms and conditions provided to me and indicated above for the agreed upon length of the contract.
									</fo:block>
								</fo:table-cell>
						</fo:table-row>                
				</fo:table-body>
		</fo:table>

		<fo:block break-before="page" />
		<xsl:call-template name="backpage"/> 		
</xsl:template>

<xsl:template name="backpage">
	<!-- keep-together="always" -->
		<fo:block xsl:use-attribute-sets="component-1" text-align="center" font-size="12pt" font-weight="bold" space-before="0px" space-after="0px">Terms and Conditions of Agreement</fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt"><fo:inline color="black" font-weight="bold">Bug Tussel Wireless, LLC (hereinafter “Bug Tussel Wireless”) does not assert or claim wireless internet service is available at all locations.  Service will be provided on a best effort basis.  Installation includes a wired connection from equipment to one qualified computer or to one router.  Multiple computers may be used on the connection; however, Service does not include network configuration, management or support.  Additional networking equipment may be required and is not included in Service.  Individual agreements are required for each connection.</fo:inline></fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Equipment <fo:character character="&#8210;" /></fo:inline> Ownership of Equipment.  For purposes of this agreement, wireless internet equipment, includes all equipment installed in or on Customer<fo:character character="&#8217;" />s premises by Bug Tussel Wireless used in delivery of wireless internet.  All equipment shall remain the sole and exclusive property of Bug Tussel Wireless. Under no circumstances shall Customer alter, misuse, abuse, remove, or in any manner tamper with Bug Tussel Wireless equipment placed in or on Customer<fo:character character="&#8217;" />s premises. Customer is responsible for safeguarding such equipment from damage and will not permit anyone other than a Bug Tussel Wireless representative or agent to perform any work on the equipment. In the event the equipment is destroyed, damaged, lost, or stolen while in Customer<fo:character character="&#8217;" />s possession, Customer shall be liable for the cost of repair or replacement of the equipment. The Customer may be held responsible for installation repairs.</fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Termination <fo:character character="&#8210;" /></fo:inline> Upon termination or disconnection of wireless internet service for any reason, Customers<fo:character character="&#8217;" /> right to possession of the equipment shall likewise terminate.  Customer agrees to immediately return or schedule the removal of all equipment in the same operating condition as when received (reasonable wear and tear is expected), directly to Bug Tussel Wireless at one of its retail offices.  If Customer fails or refuses to promptly return or schedule the removal of equipment within 30 days of termination or disconnection,  Customer shall, pay Bug Tussel Wireless the replacement cost up to $400 for each piece of equipment without any deduction for depreciation, wear and tear, or the physical condition of the unreturned equipment. </fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Access to Premises <fo:character character="&#8210;" /></fo:inline> Bug Tussel Wireless may enter into and over Customer<fo:character character="&#8217;" />s premises periodically during the term of this agreement to install, connect, inspect, maintain, repair or alter its wireless internet equipment.</fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Customer as Renter <fo:character character="&#8210;" /></fo:inline> In the event Customer is not the owner of the premises upon which Bug Tussel Wireless<fo:character character="&#8217;" />s equipment is installed, Customer warrants to Bug Tussel Wireless he/she has obtained the consent of the owner of the premises for Bug Tussel Wireless to make installation and maintenance contemplated by this agreement.  If the Customer is not the owner of such premises, Customer agrees to indemnify and hold Bug Tussel Wireless harmless from and against any claims of the owner arising out of the performance of this agreement, including but not limited to the operation, installation, connection, inspection, modification, maintenance or repair of the wireless internet equipment.</fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Customer<fo:character character="&#8217;" />s Equipment <fo:character character="&#8210;" /></fo:inline> Bug Tussel Wireless shall not have any responsibility for the operation, maintenance or repair of any customer equipment, including but not limited to personal computers, monitors, cables, wireless routers and other devices.</fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Service Interruptions <fo:character character="&#8210;" /></fo:inline> Bug Tussel Wireless shall assume no liability for interruption of wireless internet service due to circumstances beyond its control, including without limitation, acts of God, natural disaster, fire, flood, civil disturbance, strike or weather.  In no event shall Bug Tussel Wireless be liable for any incidental, special, consequential, or punitive damages, including, but not limited to, loss of profits, loss of business, or business opportunity, loss of use, etc.  The liability of Bug Tussel Wireless for actual proven damages for any cause, (including but not limited to any failure of or disruption of service), regardless of the form of action, whether in contract or in tort or otherwise, including negligence, shall be limited to an amount equivalent to charges payable by Customer under this agreement for the service during the period such damages occurred.</fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Rates/Charges/Payment <fo:character character="&#8210;" /></fo:inline> Customer agrees to pay for all services provided by Bug Tussel Wireless including charges for installation, equipment, wireless internet, services, and all applicable local, state, or general fees, or taxes.  Monthly wireless internet service charges are billed in advance and are due by due date specified on the billing statement. Failure to remit payment by the specified due date may result in late fees and disconnection of service.  If service is disconnected for non-payment, Customer shall pay Bug Tussel Wireless a disconnection fee of $200.00 in addition to any other amounts owed for the services provided hereunder, a reconnect charge and/or security deposit, in additional to any outstanding balance, including collection processing before service is restored.  A $35 fee will be assessed for all checks returned for non-sufficient funds.</fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Changes in Service and Service Charges <fo:character character="&#8210;" /></fo:inline> Customer understands, from time to time, Bug Tussel Wireless may change its service and other charges.  Bug Tussel Wireless will give Customer reasonable, prior written notice of price increase or other changes in its rate structure for its wireless internet service.</fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Early Termination <fo:character character="&#8210;" /></fo:inline> The term of this agreement is the length chosen by the Customer at the time the order for Service is placed.  Bug Tussel Wireless will impose a $200 early termination fee onto those Customers who may chose to disconnect during the agreed upon contract length as per the Customer Service Agreement.</fo:block>
		<fo:block text-align="justify" font-size="9pt" space-before="10pt" font-weight="normal"><fo:inline color="black" font-weight="bold">Miscellaneous <fo:character character="&#8210;" /></fo:inline> Compliance with Policies, Terms, and Conditions.  Acceptance of service implies acceptance of the terms and conditions herein.  Bug Tussel Wireless specifically reserves the right to disconnect service for the breach of any of the policies, term, and conditions of the agreement.  It is mutually agreed and understood that should any provision of this agreement be ruled invalid by a court of competent jurisdiction, all remaining provisions shall remain in full force and effect as if the judicially declared invalid provision was originally deleted here from.</fo:block>
</xsl:template>
</xsl:stylesheet>
