<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:exsl="http://exslt.org/functions" 
								xmlns:img="java:com.psasoft.util.ImageUtilities"
								extension-element-prefixes="exsl" 
								exclude-result-prefixes="java" version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/>  

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
<xsl:variable name="title" select="' '" />

	<xsl:template match="/">
		<fo:root>
				<xsl:call-template name="make-layout-master-small-margin" />
				<xsl:call-template name="make-body" />
		</fo:root>
	</xsl:template>
	
	<xsl:template name="body_process">
		<xsl:variable name="rowcount" select="'1'" />
		<xsl:variable name="logo-wireless" select="img:getImageBase64Encoded('/images/indigo-trans.png')"/>

 <!-- -->
		<xsl:call-template name="page1">
			<xsl:with-param name="acct" select="/all_results/results[@name = 'acct']/row" />
			<xsl:with-param name="serv" select="/all_results/results[@name = 'serv']/row" />
			<xsl:with-param name="purchase" select="/all_results/results[@name = 'purchase']/row"/>			
			<xsl:with-param name="logo" select="$logo-wireless" />
		</xsl:call-template>	

<!-- 		<fo:block break-before="page" />
		<xsl:call-template name="backpage">
			<xsl:with-param name="acct" select="/all_results/results[@name = 'acct']/row" />
			<xsl:with-param name="serv" select="/all_results/results[@name = 'serv']/row" />
		</xsl:call-template> -->
		
 <!--  -->				
	</xsl:template>
	
	<xsl:template name="page1">
		<xsl:param name="acct" />
		<xsl:param name="serv" />
		<xsl:param name="purchase" />
		<xsl:param name="logo" />

		<xsl:variable name="checkbox" select="img:getImageBase64Encoded('/images/checkbox.png')"/>
		<xsl:variable name="box" select="img:getImageBase64Encoded('/images/box.gif')"/>
		
		<fo:block-container absolute-position="fixed" left="3.25in" top=".25in">
			<fo:block>
				<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="2.0in"/>
			</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="6in" start-indent="2.5in" top="1.5in" text-align="center">
			<fo:block xsl:use-attribute-sets="report-title" font-size="16pt" font-weight="bold">Service Agreement</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" left=".5in" top="1.75in" text-align="justify" border-top-style="solid" border-top-width="1px">
			<fo:block font-size="8pt">The following is a Service Agreement to be entered into between you and Indigo Wireless.  This Agreement should be read in conjunction with, and incorporates herein by reference, the contents of the General Terms and Conditions and any written rate plan or other sales literature you have been provided by us simultaneously herewith.</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height=".5in" left=".5in" top="2.25in"  border-style="solid" border-width="2px">
			<fo:table table-layout="fixed" keep-together="always">
				<fo:table-column column-width="2.0in"/>
				<fo:table-column column-width="2.0in"/>
				<fo:table-column column-width="2.0in"/>
				<fo:table-column column-width="1.5in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">
								Service Start
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/ctcstrdte"/>
								</fo:inline>
							</fo:block>

						</fo:table-cell>

						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Mobile Number</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:call-template name="phone">
									<xsl:with-param name="npa" select="$serv/cnpa"/>
									<xsl:with-param name="nxx" select="$serv/cnxx"/>
									<xsl:with-param name="line" select="$serv/cline"/>
								</xsl:call-template>
							</fo:block>							
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Date</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="$serv/ctcstrdte"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Account Number</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="format-number($acct/cycle, '000')" />
								<xsl:value-of select="'-'" />
								<xsl:value-of select="format-number($acct/bacct, '0000000')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height="6.95in" left=".5in" top="2.75in"  border-style="solid" border-width="2px">
			<fo:table>
				<fo:table-column column-width="3.75in"/>
				<fo:table-column column-width="3.75in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Billing Address</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/fname"/>
									<xsl:value-of select="' '"/>
									<xsl:value-of select="$acct/lname"/>
								</fo:inline>							
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/bdisc"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Address
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/adln1"/>
								</fo:inline>
							</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="25px">
									<xsl:value-of select="$acct/adln2"/>
								</fo:inline>
							</fo:block>							
							<xsl:if test="$acct/adln3">
								<fo:block xsl:use-attribute-sets="summary-cells" color="black">
									<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="25px">
										<xsl:value-of select="$acct/adln3"/>
									</fo:inline>
								</fo:block>
							</xsl:if>																			
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Type of Account
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="25px">
									<xsl:choose>
									<xsl:when test="$acct/typser = 'R'">
										<xsl:value-of select="'Residential'"/>
									</xsl:when>
									<xsl:when test="$acct/typser = 'B'">
										<xsl:value-of select="'Business'"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$acct/typser"/>
									</xsl:otherwise>
									</xsl:choose>
								</fo:inline>
							</fo:block>	
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">City/State/Zip
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/adcity"/>
									<xsl:value-of select="', '"/>
									<xsl:value-of select="$acct/adst"/>
									<xsl:value-of select="' '"/>
									<xsl:value-of select="substring($acct/adzip, 1, 5)"/>
									<xsl:if test="substring($acct/adzip, 6, 4) != '0000'" >
										<xsl:value-of select="'-'"/>
										<xsl:value-of select="substring($acct/adzip, 6, 4)"/>
									</xsl:if>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Date of Birth
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="$acct/btcc"/>
										<xsl:with-param name="yy" select="$acct/btyy"/>
										<xsl:with-param name="mm" select="$acct/btmm"/>
										<xsl:with-param name="dd" select="$acct/btdd"/>
									</xsl:call-template>	
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Home Phone
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="$acct/ctnpa"/>
										<xsl:with-param name="nxx" select="$acct/ctnxx"/>
										<xsl:with-param name="line" select="$acct/ctline"/>
									</xsl:call-template>
								</fo:inline>
								<fo:inline padding-left="5px">Work Phone</fo:inline>
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="$acct/ctnpa2"/>
										<xsl:with-param name="nxx" select="$acct/ctnxx2"/>
										<xsl:with-param name="line" select="$acct/ctlin2"/>
									</xsl:call-template>								
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">...</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center" number-columns-spanned="2">
							<fo:block>Rate Plan / Features</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style-top="solid" border-width-top="1px" padding="5px" text-align="left" number-columns-spanned="2">
						    <xsl:if test="/all_results/results[@name = 'seitems']/row">
								<fo:table table-layout="fixed" keep-together="always">
									<fo:table-column column-width="4.5in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-header>
										<fo:table-row>
											<fo:table-cell>
												<fo:block xsl:use-attribute-sets="summary-cells" color="black">
													<xsl:value-of select="'Plan/Feature'" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="right">
												<fo:block xsl:use-attribute-sets="summary-cells" color="black">
													<xsl:value-of select="'Rate'" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
									</fo:table-header>
									<fo:table-body>
										<xsl:for-each select="/all_results/results[@name = 'seitems']/row">
											<fo:table-row>
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="./itmdsc" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right">
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="format-number(./itmrat, '$ ##,###,##0.00;$ -#,###,##0.00')" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:for-each>
										<xsl:for-each select="/all_results/results[@name = 'acitems']/row">
											<fo:table-row>
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="./itmdsc" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right">
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="format-number(./aitrat, '$ ##,###,##0.00;$ -#,###,##0.00')" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:for-each>
									</fo:table-body>
								</fo:table>
							</xsl:if>							
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height="1.75in" left=".5in" top="7.25in">
			<fo:table>
				<fo:table-column column-width="3.75in"/>
				<fo:table-column column-width="3.75in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Equipment</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Auto Pay Options</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Manufacturer
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/mfgmdl" />											
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" number-rows-spanned="5">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="8pt">I authorize Indigo Wireless to</fo:block>
							<fo:table>
								<fo:table-column column-width="0.35in" />
								<fo:table-column column-width="3.00in" />
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell>
											<fo:block>
												<xsl:choose>
												<xsl:when test="$acct/btccfg = 'Y'">
													<fo:external-graphic src="data:image/jpeg;base64,{$checkbox}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:when>
												<xsl:otherwise>
													<fo:external-graphic src="data:image/jpeg;base64,{$box}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:otherwise>
												</xsl:choose>											
											</fo:block>
										</fo:table-cell>
										<fo:table-cell text-align="justify" padding-right="5px">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="6pt">Charge my credit card on file.</fo:block>
										</fo:table-cell>
									</fo:table-row>
									<fo:table-row>
										<fo:table-cell>
											<fo:block>
												<xsl:choose>
												<xsl:when test="$acct/paybyach = 'Y'">
													<fo:external-graphic src="data:image/jpeg;base64,{$checkbox}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:when>
												<xsl:otherwise>
													<fo:external-graphic src="data:image/jpeg;base64,{$box}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:otherwise>
												</xsl:choose>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell text-align="justify" padding-right="5px">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="6pt">Electronically debit my bank account on file, </fo:block>
										</fo:table-cell>
									</fo:table-row>
									<fo:table-row>
										<fo:table-cell text-align="justify" padding-right="5px" padding-top="10px" number-columns-spanned="2">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="6pt">for this account every month for for all fees incurred during use of the wireless device listed on this CSA.</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-body>
							</fo:table>							
						</fo:table-cell>
					</fo:table-row>		
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Model
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/eqpdsc" />											
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<xsl:if test="$serv/imei &gt; 0">
								<fo:block xsl:use-attribute-sets="summary-cells" color="black">IMEI
									<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
										<xsl:value-of select="format-number($serv/imei, '000000000000000')" />
									</fo:inline>											
								</fo:block>		
							</xsl:if>						
						</fo:table-cell>
					</fo:table-row>															
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">SIM
								<xsl:if test="$serv/imnumb &gt; 0">
									<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
										<xsl:value-of select="format-number($serv/imctry, '000')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number($serv/imcomp, '00')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number($serv/imnumb, '0000000000')" />
									</fo:inline>											
								</xsl:if>	
							</fo:block>
						</fo:table-cell>
					</fo:table-row>															
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Credit Level
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/crdrat" />											
									<xsl:value-of select="' - '" />											
									<xsl:value-of select="$acct/lvldesc" />											
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>															
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Authorized Users</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Sales Information</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/aunam1"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Representative / Agent
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/agfsnm"/>
									<xsl:value-of select="' '"/>
									<xsl:value-of select="$serv/aglsnm"/>
									<xsl:value-of select="' ('"/>
									<xsl:value-of select="$serv/agcd1"/>
									<xsl:value-of select="')'"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>	
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/aunam2"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black"><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
					</fo:table-row>	
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/aunam3"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black"><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
					</fo:table-row>	
				</fo:table-body>
			</fo:table>
		</fo:block-container>

	</xsl:template>
		
	<!--  
	<xsl:template name="backpage">
		<xsl:param name="acct" />
		<xsl:param name="serv" />

		<fo:block-container absolute-position="fixed" left=".5in" top=".5in" width="7.5in">
				<fo:block xsl:use-attribute-sets="summary-cells" text-align="center" color="black" font-weight="bold" border-style="solid" border-width="1px">General Terms and Conditions</fo:block>							
				<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">This General Terms and Conditions (<fo:character character="&#8220;" />Agreement<fo:character character="&#8221;" />) is for wireless telephone service and other services (<fo:character character="&#8220;" />Service<fo:character character="&#8221;" />) between you and Americell PA-3, LP d/b/a Indigo Wireless (<fo:character character="&#8220;" />Indigo<fo:character character="&#8221;" />), the Federal Communications Commission<fo:character character="&#8217;" />s licensee to provide Service in the area associated with your assigned telephone number (<fo:character character="&#8220;" />Number<fo:character character="&#8221;" />).  The term <fo:character character="&#8220;" />Phone<fo:character character="&#8221;" /> means the SIM (Subscriber Identity Module) card and/or wireless receiving and transmitting equipment that Indigo has authorized to be programmed with the Number and any accessories.  By using your Phone, giving us a written or electronic signature, accepting a benefit in exchange for committing to these Terms and Conditions, or by paying any amount billed to your account, you consent to these Terms and Conditions.  If you do not disagree with these Terms and Conditions do not do any of the above.  You warrant that you are at least 18 years old and have the legal capacity and authority to execute this Agreement.  If you are ordering the service for a company you are representing that you have the power to bind that company.</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" left=".5in" top="1.75in" width="3.65in">
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Pricing for Services</fo:inline> - Indigo will provide pricing for monthly service access and additional features per your selected service plan for the term of your Agreement as stated on the first page. Indigo reserves the right to change pricing for enhanced services, features or optional packages at any time upon thirty (30) days notice written notice. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Term of Service / Trial Period</fo:inline> - You have contracted to have Indigo provide you service for the term specified on the front of this Contract under the heading <fo:character character="&#8220;" />Contract Length<fo:character character="&#8221;" />. You agree to maintain service with us for your minimum term (the <fo:character character="&#8220;" />Term<fo:character character="&#8221;" />). The Term begins on the date when your Phone is activated.   At the end of your Term this contract will automatically renew on the same terms and conditions contained herein on a month-to-month basis and shall continue until terminated by either party. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Termination of Service</fo:inline> - Indigo has the right to discontinue temporarily or terminate your Service without notice to you if: (a) you fail to pay any amounts due by the due date, (b) we believe you have breached any part of this Agreement, (c) we cease to furnish the Service, (d) we believe your Service is being misused or used by anyone for unlawful activity, (e) your use of the Service adversely affects service to other customers, (f) you provided inaccurate or false information to us, (g) we believe your credit has deteriorated and you refuse to pay any requested advance payment or deposit, (h) if a majority of minutes in any three consecutive monthly periods are used off the portion of our network that we own and operate or (i) if your principle residence is not within our Indigo owned and operated area (j) verbally or physically abuse an employee or agent of Indigo. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Early Termination Fee</fo:inline> - If we terminate your Services for nonpayment or other default before the end of your Service Commitment, or if you terminate your Services you agree to pay us with respect to each device or telephone number assigned to you, in addition to all other amounts owed, an Early Termination Fee in the amount specified below (<fo:character character="&#8220;" />Early Termination Fee<fo:character character="&#8221;" />). If your Service Commitment includes the purchase of an Advanced Devise Phone, the Early Termination Fee will be $325 minus $10 for each full month of your Service Commitment that you complete. Otherwise your Early Termination Fee will be $150 minus $5 for each full month of your Service Commitment that you complete. The Early Termination Fee is not a penalty, but rather a charge to compensate us for your failure to satisfy the Service Commitment on which your rate plan is based.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Credit Check Consent and Reporting Authorization</fo:inline> - You authorize Indigo to ask credit-reporting agencies for credit information about you and to share credit information about you with credit reporting agencies. You have the right to dispute the accuracy and completeness of any credit report we receive. Upon written request, we will provide you the name and address of the credit agency that gives us a credit report about you. You authorize us to disclose information related to your account(s), including confidential information and payment history, to credit reporting agencies, private credit reporting associations and otherwise as required by applicable law. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Billing and Payment</fo:inline> - You will be billed on a monthly basis and are responsible for paying all charges for or resulting from the Service provided under this Agreement. You are responsible for all authorized and unauthorized use of each wireless phone associated with this Agreement.  Payment is due upon receipt of the invoice. Billing cycles may change from time to time. You are responsible for paying your monthly service fee if your service is suspended for nonpayment. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Rates and Charges</fo:inline> - Charges include, without limitation, international roamer, recurring monthly service, administrative and late payment charges; optional feature charges; directory assistance charges; international calls billed to your wireless telephone number and applicable taxes and government fees.	</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Taxes and Other Charges</fo:inline> - You agree to pay all applicable federal, state and local government taxes, fees and surcharges including but not limited to, charges relating to Universal Service (USF), Call Assistance for Law Enforcement Act (CALEA), Telecommunications Relay Service Charges (TRS), implementation of Local Number Portability (LNP) and E911 Phase 1 and Phase 2 emergency services. Indigo agrees to give you reasonable prior written notice if any such costs and/or charges are implemented or changed after your service activation date.</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" left="4.35in" top="1.75in" width="3.65in" text-align="justify">
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Deposits</fo:inline> – At any time Indigo may require you to make a suitable deposit to be held by Indigo to secure the payment of all sums due hereunder and on other account # for which you are responsible for payment. Security deposits must be cash, credit card or certified funds. Indigo reserves the right to apply any security deposit to any sums due from you. Funds received by Indigo as a security deposit will not accrue interest. Security deposits will be held in your account until you have completed one-year of payments without being late or any interruptions of service for non-payment. If you successfully meet payment history requirements, the amount of your deposit will be credited to your active account. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Dispute Resolution</fo:inline> - YOU MUST, WITHIN 90 DAYS OF THE DATE OF THE BILL, NOTIFY US OF ANY DISPUTE YOU HAVE WITH RESPECT TO THE BILL, INCLUDING ANY CHARGES ON THE BILL AND ANY SERVICE PROVIDED FOR WHICH YOU WERE BILLED, OR YOU WILL HAVE WAIVED THE RIGHT TO DISPUTE THE BILL.  If you have an issue that cannot be resolved through our customer service department and want to obtain third party intervention, you agree that Indigo will arbitrate with you before the American Arbitration Association using the Wireless Industry Arbitration rules. All customer disputes will be resolved through arbitration, not with a judge or jury. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Non Payment/Breach</fo:inline> - If you fail to pay any amounts due under this Agreement, whether voluntary or involuntary, Indigo reserves the right to immediately terminate your service without prior notice, and receive from you all amounts due under this Agreement plus all costs of collection, attorney<fo:character character="&#8217;" />s fees, collection charges and applicable termination fees. Indigo may also pursue any other remedy at law or in equity.  A charge of no less than $25.00 will be made by Indigo for any check or other negotiable instrument tendered by you and returned unpaid by a financial institution for any reason and Indigo may demand payment by money order, cashier<fo:character character="&#8217;" />s check or similarity secure for of payment.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Bankruptcy</fo:inline> - If a petition for bankruptcy relief is filed by or against you, you agree to pay all post-petition charges. If at any time prior to assumption of this Agreement by you, you default in making payment when due for post-petition charges, Indigo can immediately terminate this Agreement or require a security deposit. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Misuse of Service</fo:inline> - Service may be immediately discontinued in the event of any misuse or fraudulent use of service; or any use which Indigo determines, in its reasonable judgment negatively affects its wireless systems or other subscribers<fo:character character="&#8217;" /> use of service. Misuse shall include but is not limited to toll fraud, toll bypass, unauthorized voicemail box access and unauthorized or excessive data usage deemed by Indigo. You will be responsible to Indigo for any expenses incurred as a result of misuse or fraudulent use of service. You agree to operate the wireless equipment in accordance with all FCC Rules. FCC Rules prohibit the transfer; alteration or emulation of the Subscriber Identity Module (SIM)/(MEID) Mobile Equipment Identifier, encoded in your wireless phone. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Phone Numbers</fo:inline> - Any wireless unit used by you in connection with the Service must be technically and operationally compatible with our wireless system and must comply with the rules and regulations of the Federal Communications Commission. We will provide you with a telephone number for your Service. Only one wireless telephone unit may use any particular assigned telephone number. Except for any rights granted to you by federal law, you have no property right or other proprietary interest to your assigned number, and we reserve the right to change your assigned number or assign that number to someone else.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Local Number Portability</fo:inline> - You may choose to send all of your landline calls to your new Service and discontinue your landline service.  You may also choose to send your current wireless number to a new service provider, in which case, we will send that number to the new service provider.  These arrangements are known as <fo:character character="&#8220;" />porting<fo:character character="&#8221;" />.  If you choose to have your number ported to a new service provider, we will interpret that request as a notice from you to terminate our service for that number once the porting has been completed.  You will then remain responsible for all fees and charges through the current billing cycle just as in any other termination. Indigo is entitled to charge a Fifty Dollar ($50.00) processing fee to effect the porting of your Number to another carrier.  Only currently active numbers may be ported.</fo:block>
		</fo:block-container>
		<fo:block break-before="page" />
		<fo:block-container absolute-position="fixed" left=".5in" top=".5in" width="3.65in">
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Delinquent Payment</fo:inline> - Late payment fee will be charged at a rate of 1.5% of balance per month.  Indigo reserves the right to immediately suspend and/or disconnect service without notice on accounts more than ten (10) days past due. If a suspended account is reactivated, a service fee and any applicable taxes will be charged. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Privacy</fo:inline> - We have a duty under federal law to protect the confidentiality of information about the quantity, type and destination of your use of our service. We won<fo:character character="&#8217;" />t share information about you without your permission unless required by law or by legal process or to protect our rights or property. You consent to our sharing such information with our affiliates to develop or bring to your attention new products and services or in the event of a merger, sale of assets or acquisition in which your confidential information would be transferred as a business asset. This consent is valid until revoked by you and will survive the termination of this Agreement. You acknowledge that our systems use radio signals to transmit voice and data communications and that the Service may not be completely private. You acknowledge through our implementation of federally mandated E911 services, we will have the ability to track your location while you are using your wireless phone. We may also share your account information to initiate, render, bill and collect for the Service or to protect users of those Services from fraudulent, abusive or unlawful use of the Service, or if we reasonably believe that an emergency involving death or serious bodily injury requires disclosure of such information without delay.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Disclaimer of Warranties</fo:inline> - Indigo makes no warranties, express or implied, with respect to service or equipment, including any implied warranty of merchantability or fitness for a particular purpose. You acknowledge that all equipment has been determined solely by you to be suitable for its purpose, you have selected the equipment supplier, and Indigo has made no representation or warranty with respect to the suitability or durability of the equipment. This Agreement does not deprive you of any rights you may have against any manufacturer or vendor of the equipment. Your sole recourse shall be against the manufacturer or vendor if equipment fails to operate to your satisfaction, or if any other damage is claimed. You agree to hold Indigo harmless from any claims, loss or damage resulting from the use of the equipment and/or damage caused by such equipment. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Miscellaneous</fo:inline> - You agree that this Agreement and the Indigo Calling Plan Schedule make up the complete and exclusive Agreement between us. This Agreement supersedes any proposal or prior oral or written agreement. It may not be amended, altered or changed except by written consent of both parties. You acknowledge that no Indigo supplier, employee or agent is authorized to make any representation or warranty with respect to this Agreement, or to waive or alter any provision of this Agreement. If Indigo waives or fails to uphold any provision of this Agreement, it shall not be construed as waiving any other provision. If either party concerning this Agreement initiates legal action, the most prevailing party shall be entitled to recover all costs and reasonable attorney<fo:character character="&#8217;" />s fees, including costs and fees on appeal. Indigo may assign all or part of this Agreement by giving you written notice and you agree to make all subsequent payments as instructed in such notice. You may not assign your rights or obligations under this Agreement without prior written approval from Indigo. You certify that the information that is provided on the reverse side of this Agreement is correct to the best of your knowledge. Indigo reserves the right to immediately terminate this agreement and charge you the early termination fee if you knowingly provided false information. Indigo has assumed that you have the legal capacity to enter into this Agreement, but expressly reserves the right to declare this Agreement void in the event you are below the age of eighteen (18). </fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" left="4.35in" top=".5in" width="3.65in" text-align="justify">
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Stolen or Lost Phone</fo:inline> - If your phone is stolen or lost, you must immediately notify us and provide any documentation (such as a police report) we request. After receipt of your notification, we will suspend service for up to 30 days, or until you replace or recover your phone, whichever comes first. The time of any suspension counts towards satisfying the initial term of this agreement under your price plan. Until you notify us, you<fo:character character="&#8217;" />re still responsible for all charges to your telephone number.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Limitation of Liability</fo:inline> - You understand that the ability to place a wireless call, including a 911 call, may be subject to limitations of coverage and network capacity and that you should not rely on Indigo service as your only means of communication in emergency situations. Indigo can not be held liable for interruptions in service due to equipment failure, equipment or facilities shortages, strikes, acts of God or other causes beyond Indigo<fo:character character="&#8217;" />s reasonable control. Indigo<fo:character character="&#8217;" />s liability, if any, in its operation of service or equipment shall not exceed the amount of Indigo<fo:character character="&#8217;" />s prorated monthly charge for the service during the period affected. You assume all risk of use of equipment, including the risk of traffic accidents while using the equipment. Indigo will not be liable for any other costs, delays, special incidental or consequential damages, physical harm or any other damage that may be alleged to result from the use of the equipment or service. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Notices</fo:inline> - Service of all notices under this Agreement shall be sufficient if given personally or mailed to the party involved at its respective address or any other address as either party may provide in writing. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Emergency Services</fo:inline> - When you call 911 or other emergency service numbers you may need to tell them your location. In some instances, we may be able to give the 911-service information about where your call was placed. It is important that you know we cannot complete calls to 911 from telecommunication devices for the deaf (TTY/TDD). If you choose to port your number, you may experience temporary disruption of services during the porting process that may affect the completion of calls to and from your wireless phone, including calls to emergency services. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Our Rights to Make Changes</fo:inline> - All services we provide to you are subject to our business policies, practices, and procedures, which we can change without notice. Such changes can include but are not limited to over-the-air modification of the software in your wireless phone. We can also change prices and any other terms in this agreement at any time after the initial term of your Service Agreement, by giving you written notice prior to the billing period in which the changes would go into effect. If the changes adversely affect your monthly rate or service in a material way, your right to end this agreement without any early termination fee is your only remedy. If you choose to continue to use our service after receiving notice of any changes, those changes will apply to you. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Return policy/Trial Period</fo:inline> - If you are not completely satisfied with the performance of our services, or products, you may cancel the extended service agreement and receive a refund. To qualify, you must notify us and return all purchased items including accessories and user manuals in the original box within 30 days of your service activation date. Returned products must be in excellent working condition and free of cosmetic defects. You will be billed for airtime, a pro- rated monthly fee, and other costs incurred during the time you used our product and/ or services. We reserve the right to charge you to recover the cost for damaged products while in your possession. You will remain responsible for your Activation Fee unless you terminate service within three days of activation. Other restrictions may apply. </fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" left=".5in" top="8.5in" width="7.5in">
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">I ACKNOWLEDGE THAT I HAVE READ AND UNDERSTAND ALL OF THE CUSTOMER SERVICE AGREEMENT INCLUDING THE GENERAL TERMS AND CONDITIONS ON THIS CONTRACT AND I AGREE TO BE BOUND THEREBY. BY SIGNING THIS FORM YOU ARE ACCEPTING PERSONAL FINANCIAL RESPONSIBILITY FOR PAYMENT OF ALL CHARGES ASSOCIATED WITH THIS ACCOUNT.  YOU ALSO AGREE TO ALLOW INDIGO WIRELESS TO OBTAIN A CREDIT REPORT FROM EQUIFAX.</fo:block>
			
			<fo:table keep-together="always">
				<fo:table-column column-width="2.25in" />
				<fo:table-column column-width="5.25in" />
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">Printed Name:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="$acct/fname" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="$acct/lname" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row height="20px">
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">
								Date:
								<fo:inline>
									<xsl:value-of select="format-dateTime(current-dateTime(), '[MNn] [D], [Y]')" />
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row height="75px">
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">Signature:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings" border-bottom-style="solid" border-bottom-width="1px">
								<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="1.5in" content-height="auto" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" left=".5in" top="10.5in" width="7.5in">
				<fo:block text-align="center" color="black" font-size="7pt">10/2011</fo:block>							
		</fo:block-container>

	</xsl:template>
	-->
</xsl:stylesheet>
