<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" xmlns:exsl="http://exslt.org/functions"
	xmlns:img="java:com.psasoft.util.ImageUtilities" extension-element-prefixes="exsl" exclude-result-prefixes="java" version="2.0">
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	<xsl:variable name="title" select="' '" />
	<xsl:variable name="acct" select="/all_results/results[@name = 'acct']/row" />
	<xsl:variable name="serv" select="/all_results/results[@name = 'serv']/row" />
	<xsl:variable name="box" select="img:getImageBase64Encoded('/images/box.gif')"/>

	<xsl:template match="/">
		<fo:root>
			<xsl:call-template name="make-layout-master-small-margin" />
			<xsl:call-template name="make-body" />
		</fo:root>
	</xsl:template>
	<xsl:template name="body_process">
		<xsl:variable name="logo-internet" select="img:getImageBase64Encoded('/images/indigo-internet.png')" />

 <!-- -->
		<xsl:call-template name="page1">
			<xsl:with-param name="acct" select="/all_results/results[@name = 'acct']/row" />
			<xsl:with-param name="serv" select="/all_results/results[@name = 'serv']/row" />
			<xsl:with-param name="purchase" select="/all_results/results[@name = 'purchase']/row"/>			
			<xsl:with-param name="logo" select="$logo-internet" />
		</xsl:call-template>	

  		<fo:block break-before="page" />  
		<xsl:call-template name="backpage" />

		<fo:block break-before="page" />
		<xsl:call-template name="internetorder" />

	</xsl:template>
	
	<xsl:template name="page1">
		<xsl:param name="acct" />
		<xsl:param name="serv" />
		<xsl:param name="purchase" />
		<xsl:param name="logo" />

		<xsl:variable name="checkbox" select="img:getImageBase64Encoded('/images/checkbox.png')"/>
		<xsl:variable name="box" select="img:getImageBase64Encoded('/images/box.gif')"/>
		
		<fo:block-container absolute-position="fixed" left="3.25in" top=".25in">
			<fo:block>
				<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="1.75in"/>
			</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="6in" start-indent="2.5in" top="1.5in" text-align="center">
			<fo:block xsl:use-attribute-sets="report-title" font-size="16pt" font-weight="bold">Indigo Xtreme Internet</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" left=".5in" top="1.75in" text-align="justify" border-top-style="solid" border-top-width="1px">
			<fo:block font-size="8pt">The following is a Customer Service Agreement to be entered into between you and Indigo Wireless.  This Agreement should be read in conjunction with, and incorporates herein by reference, the contents of the General Terms and Conditions and any written rate plan or other sales literature you have been provided by us simultaneously herewith.</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height=".5in" left=".5in" top="2.25in"  border-style="solid" border-width="2px">
			<fo:table table-layout="fixed" keep-together="always">
				<fo:table-column column-width="2.0in"/>
				<fo:table-column column-width="1.0in"/>
				<fo:table-column column-width="1.5in"/>
				<fo:table-column column-width="1.5in"/>
				<fo:table-column column-width="1.5in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">
								Contract Start
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/ctcstrdte"/>
								</fo:inline>
							</fo:block>
							<fo:block font-size="8pt">
								Contract End
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="$serv/scexcc"/>
										<xsl:with-param name="yy" select="$serv/scexyy"/>
										<xsl:with-param name="mm" select="$serv/scexmm"/>
										<xsl:with-param name="dd" select="$serv/scexdd"/>
									</xsl:call-template>	
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Contract Length</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="$serv/ctclen"/>
								<xsl:choose>
								<xsl:when test="$serv/ctclen &lt; 2">
									<xsl:value-of select="' Month'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' Months'" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Mobile Number</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:call-template name="phone">
									<xsl:with-param name="npa" select="$serv/cnpa"/>
									<xsl:with-param name="nxx" select="$serv/cnxx"/>
									<xsl:with-param name="line" select="$serv/cline"/>
								</xsl:call-template>
							</fo:block>							
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Date</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="$serv/ctcstrdte"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Account Number</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="format-number($acct/cycle, '000')" />
								<xsl:value-of select="'-'" />
								<xsl:value-of select="format-number($acct/bacct, '0000000')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height="6.95in" left=".5in" top="2.75in"  border-style="solid" border-width="2px">
			<fo:table>
				<fo:table-column column-width="3.75in"/>
				<fo:table-column column-width="3.75in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Billing Address</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/fname"/>
									<xsl:value-of select="' '"/>
									<xsl:value-of select="$acct/lname"/>
								</fo:inline>							
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/bdisc"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Address
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/adln1"/>
								</fo:inline>
							</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="25px">
									<xsl:value-of select="$acct/adln2"/>
								</fo:inline>
							</fo:block>							
							<xsl:if test="$acct/adln3">
								<fo:block xsl:use-attribute-sets="summary-cells" color="black">
									<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="25px">
										<xsl:value-of select="$acct/adln3"/>
									</fo:inline>
								</fo:block>
							</xsl:if>																			
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Type of Account
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="25px">
									<xsl:choose>
									<xsl:when test="$acct/typser = 'R'">
										<xsl:value-of select="'Residential'"/>
									</xsl:when>
									<xsl:when test="$acct/typser = 'B'">
										<xsl:value-of select="'Business'"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$acct/typser"/>
									</xsl:otherwise>
									</xsl:choose>
								</fo:inline>
							</fo:block>	
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">City/State/Zip
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/adcity"/>
									<xsl:value-of select="', '"/>
									<xsl:value-of select="$acct/adst"/>
									<xsl:value-of select="' '"/>
									<xsl:value-of select="substring($acct/adzip, 1, 5)"/>
									<xsl:if test="substring($acct/adzip, 6, 4) != '0000'" >
										<xsl:value-of select="'-'"/>
										<xsl:value-of select="substring($acct/adzip, 6, 4)"/>
									</xsl:if>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Date of Birth
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="$acct/btcc"/>
										<xsl:with-param name="yy" select="$acct/btyy"/>
										<xsl:with-param name="mm" select="$acct/btmm"/>
										<xsl:with-param name="dd" select="$acct/btdd"/>
									</xsl:call-template>	
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Home Phone
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="$acct/ctnpa"/>
										<xsl:with-param name="nxx" select="$acct/ctnxx"/>
										<xsl:with-param name="line" select="$acct/ctline"/>
									</xsl:call-template>
								</fo:inline>
								<fo:inline padding-left="5px">Work Phone</fo:inline>
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="$acct/ctnpa2"/>
										<xsl:with-param name="nxx" select="$acct/ctnxx2"/>
										<xsl:with-param name="line" select="$acct/ctlin2"/>
									</xsl:call-template>								
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">...</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center" number-columns-spanned="2">
							<fo:block>Rate Plan / Features</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style-top="solid" border-width-top="1px" padding="5px" text-align="left" number-columns-spanned="2">
						    <xsl:if test="/all_results/results[@name = 'seitems']/row">
								<fo:table table-layout="fixed" keep-together="always">
									<fo:table-column column-width="4.5in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-header>
										<fo:table-row>
											<fo:table-cell>
												<fo:block xsl:use-attribute-sets="summary-cells" color="black">
													<xsl:value-of select="'Plan/Feature'" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="right">
												<fo:block xsl:use-attribute-sets="summary-cells" color="black">
													<xsl:value-of select="'Rate'" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
									</fo:table-header>
									<fo:table-body>
										<xsl:for-each select="/all_results/results[@name = 'seitems']/row">
											<fo:table-row>
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="./itmdsc" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right">
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="format-number(./itmrat, '$ ##,###,##0.00;$ -#,###,##0.00')" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:for-each>
										<xsl:for-each select="/all_results/results[@name = 'acitems']/row">
											<fo:table-row>
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="./itmdsc" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right">
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="format-number(./aitrat, '$ ##,###,##0.00;$ -#,###,##0.00')" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:for-each>
									</fo:table-body>
								</fo:table>
							</xsl:if>							
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height="1.75in" left=".5in" top="7.25in">
			<fo:table>
				<fo:table-column column-width="3.75in"/>
				<fo:table-column column-width="3.75in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Equipment</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Auto Pay Options</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Manufacturer
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/mfgmdl" />											
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" number-rows-spanned="4">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="8pt">I authorize Indigo Wireless to</fo:block>
							<fo:table>
								<fo:table-column column-width="0.35in" />
								<fo:table-column column-width="3.00in" />
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell>
											<fo:block>
												<xsl:choose>
												<xsl:when test="$acct/btccfg = 'Y'">
													<fo:external-graphic src="data:image/jpeg;base64,{$checkbox}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:when>
												<xsl:otherwise>
													<fo:external-graphic src="data:image/jpeg;base64,{$box}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:otherwise>
												</xsl:choose>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell text-align="justify" padding-right="5px">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="6pt">Charge my credit card on file,</fo:block>
										</fo:table-cell>
									</fo:table-row>
									<fo:table-row>
										<fo:table-cell>
											<fo:block>
												<xsl:choose>
												<xsl:when test="$acct/paybyach = 'Y'">
													<fo:external-graphic src="data:image/jpeg;base64,{$checkbox}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:when>
												<xsl:otherwise>
													<fo:external-graphic src="data:image/jpeg;base64,{$box}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:otherwise>
												</xsl:choose>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell text-align="justify" padding-right="5px">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="6pt">Electronically debit my bank account on file, </fo:block>
										</fo:table-cell>
									</fo:table-row>
									<fo:table-row>
										<fo:table-cell text-align="justify" padding-right="5px"  padding-top="10px" number-columns-spanned="2">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="6pt">for this account every month for for all fees incurred during use of the wireless device listed on this CSA.</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-body>
							</fo:table>							
						</fo:table-cell>
					</fo:table-row>		
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Model
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/eqpdsc" />											
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<xsl:if test="$serv/imei &gt; 0">
								<fo:block xsl:use-attribute-sets="summary-cells" color="black">Serial #
									<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
										<xsl:value-of select="$serv/serialno" />
									</fo:inline>											
								</fo:block>		
							</xsl:if>						
						</fo:table-cell>
					</fo:table-row>															
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Credit Level
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/crdrat" />											
									<xsl:value-of select="' - '" />											
									<xsl:value-of select="$acct/lvldesc" />											
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>															
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Authorized Users</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Sales Information</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/aunam1"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Representative / Agent
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/agfsnm"/>
									<xsl:value-of select="' '"/>
									<xsl:value-of select="$serv/aglsnm"/>
									<xsl:value-of select="' ('"/>
									<xsl:value-of select="$serv/agcd1"/>
									<xsl:value-of select="')'"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>	
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/aunam2"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black"><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
					</fo:table-row>	
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/aunam3"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black"><xsl:value-of select="' '" /></fo:block>
						</fo:table-cell>
					</fo:table-row>	
				</fo:table-body>
			</fo:table>
		</fo:block-container>

	</xsl:template>	
	
	<xsl:template name="internetorder">
		<fo:table keep-together="always">
			<fo:table-column column-width="2.25in" />
			<fo:table-column column-width="5.25in" />
			<fo:table-body>
				<fo:table-row height="30px">
					<fo:table-cell>
						<xsl:variable name="logo" select="img:getImageBase64Encoded('/images/indigo-internet.png')" />
						<fo:block xsl:use-attribute-sets="report-title">
							<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="2.25in" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="report-title" font-size="20pt" font-weight="bold">Broadband Internet Work Order</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Account Number:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($acct/cycle, '000')" />
							<xsl:value-of select="'-'" />
							<xsl:value-of select="format-number($acct/bacct, '0000000')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Account Name:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="$acct/fname" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="$acct/lname" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Address:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<xsl:if test="$acct/adln1">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="$acct/adln1" />
							</fo:block>
						</xsl:if>
						<xsl:if test="$acct/adln2">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="$acct/adln2" />
							</fo:block>
						</xsl:if>
						<xsl:if test="$acct/adln3">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="$acct/adln3" />
							</fo:block>
						</xsl:if>
						<fo:block xsl:use-attribute-sets="summary-headings">
							<fo:inline>
								<xsl:value-of select="$acct/adcity" />
								<xsl:value-of select="', '" />
								<xsl:value-of select="$acct/adst" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="substring($acct/adzip, 1, 5)" />
								<xsl:if test="substring($acct/adzip, 6, 4) != '0000'">
									<xsl:value-of select="'-'" />
									<xsl:value-of select="substring($acct/adzip, 6, 4)" />
								</xsl:if>
							</fo:inline>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Phone:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:call-template name="phone">
								<xsl:with-param name="npa" select="$acct/ctnpa" />
								<xsl:with-param name="nxx" select="$acct/ctnxx" />
								<xsl:with-param name="line" select="$acct/ctline" />
							</xsl:call-template>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row height="50px">
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Plans / Features:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:table keep-together="always">
							<fo:table-column column-width="4in" />
							<fo:table-column column-width="1.25in" />
							<fo:table-body>
								<xsl:for-each select="/all_results/results[@name = 'seitems']/row">
									<fo:table-row>
										<fo:table-cell>
											<fo:block xsl:use-attribute-sets="summary-headings">
												<xsl:value-of select="./itmdsc" />
											</fo:block>
										</fo:table-cell>
										<fo:table-cell text-align="right">
											<fo:block xsl:use-attribute-sets="summary-headings">
												<xsl:value-of select="format-number(./itmrat, '$ ##,###,##0.00;$ -#,###,##0.00')" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</xsl:for-each>
								<xsl:for-each select="/all_results/results[@name = 'acitems']/row">
									<fo:table-row>
										<fo:table-cell>
											<fo:block xsl:use-attribute-sets="summary-headings">
												<xsl:value-of select="./itmdsc" />
											</fo:block>
										</fo:table-cell>
										<fo:table-cell text-align="right">
											<fo:block xsl:use-attribute-sets="summary-headings">
												<xsl:value-of select="format-number(./aitrat, '$ ##,###,##0.00;$ -#,###,##0.00')" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</xsl:for-each>
							</fo:table-body>
						</fo:table>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Start Date:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="$serv/ctcstrdte" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Duration:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:choose>
								<xsl:when test="$serv/ctclen = 0">
									<xsl:value-of select="' Month-to-Month'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$serv/ctclen" />
									<xsl:value-of select="' Months'" />
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Install Date:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings"> ____/____/
							<fo:inline>
								<xsl:value-of select="format-dateTime(current-dateTime(), '[Y]')" />
							</fo:inline>
							(Tuesday)
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row height="30px">
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Install Time:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">
							<fo:external-graphic src="data:image/jpeg;base64,{$box}"
								 width="7px" height="7px"
								 padding-top="0px"
								 padding-bottom="0px"
								 padding-left="15px"
								 padding-right="10px"/> Morning (8:30 am - Noon)								 
						</fo:block>
						<fo:block xsl:use-attribute-sets="summary-headings">
							<fo:external-graphic src="data:image/jpeg;base64,{$box}"
								 width="7px" height="7px"
								 padding-top="0px"
								 padding-bottom="0px"
								 padding-left="15px"
								 padding-right="10px"/> Afternoon (1:00 pm - 5:00 pm)								 
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
		<fo:table>
			<fo:table-column column-width="0.35in" />
			<fo:table-column column-width="6.65in" />
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="summary-cells" number-columns-spanned="2">
						<fo:block>I understand that:</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block>
							<fo:character character="&#8226;" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="justify"  padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-cells" wrap-option="wrap">I am requesting Indigo Wireless to install broadband Internet access at the address listed above at the date and time listed, and am agreeing to
							maintain service for the duration specified above.</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block>
							<fo:character character="&#8226;" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="justify"  padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-cells" wrap-option="wrap">A technician or contractor will need access to my residence or business to complete the install and may need access to my roof.</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block>
							<fo:character character="&#8226;" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="justify"  padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-cells" wrap-option="wrap">I, or an authorized individual must be home for the install and that if someone is not home Indigo Wireless will not install service.</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<fo:block>
							<fo:character character="&#8226;" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="justify"  padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-cells" wrap-option="wrap">If due to unavoidable and unchangable circumstance (e.g. tree, hill, building) acceptable service levels can not be obtained Indigo Wireless may choose,
							at their discretion, to not perform an install of service.</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
		<fo:table keep-together="always">
			<fo:table-column column-width="2.25in" />
			<fo:table-column column-width="5.25in" />
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Printed Name:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="$acct/fname" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="$acct/lname" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row height="20px">
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">
							Date:
							<fo:inline>
								<xsl:value-of select="format-dateTime(current-dateTime(), '[MNn] [D], [Y]')" />
							</fo:inline>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row height="55px">
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings">Signature:</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="summary-headings" border-bottom-style="solid" border-bottom-width="1px">
							<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="1.5in" content-height="auto" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
		<fo:table keep-together="always" border-style="solid" border-width="1px">
			<fo:table-column column-width="3.75in" />
			<fo:table-column column-width="3.75in" />
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="summary-cells" number-columns-spanned="2" text-align="center" padding-top="10px" padding-bottom="10px" padding-right="10px">
						<fo:block text-decoration="underline">Internal Use</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding-left="10px">
						<fo:block xsl:use-attribute-sets="summary-cells">Received Date:  ____/____/
							<fo:inline>
								<xsl:value-of select="format-dateTime(current-dateTime(), '[Y]')" />
							</fo:inline>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-cells">CPE RSL: - ____dB          AP RSL: - ____dB</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding-left="10px">
						<fo:block xsl:use-attribute-sets="summary-cells">Install Date:  ____/____/
							<fo:inline>
								<xsl:value-of select="format-dateTime(current-dateTime(), '[Y]')" />
							</fo:inline>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-cells">CPE Download Speed: - ________Mb/second</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding-left="10px" padding-bottom="10px">
						<fo:block xsl:use-attribute-sets="summary-cells"><xsl:value-of select="' '" /></fo:block>
					</fo:table-cell>
					<fo:table-cell padding-right="10px" padding-bottom="10px">
						<fo:block xsl:use-attribute-sets="summary-cells">CPE Upload Speed: - ________Mb/second</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="summary-cells" number-columns-spanned="2" padding-left="10px">
						<fo:table>
							<fo:table-column column-width=".5in"/>
							<fo:table-column column-width="1in"/>
							<fo:table-column column-width="1in"/>
							<fo:table-column column-width="1in"/>
							<fo:table-column column-width="1in"/>
							<fo:table-column column-width="1in"/>
							<fo:table-column column-width="1in"/>
							<fo:table-body>
								<fo:table-row>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="summary-cells">CPE Type:
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:external-graphic src="data:image/jpeg;base64,{$box}"
												 width="7px" height="7px"
												 padding-top="0px"
												 padding-bottom="0px"
												 padding-left="15px"
												 padding-right="10px"/> N900
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:external-graphic src="data:image/jpeg;base64,{$box}"
												 width="7px" height="7px"
												 padding-top="0px"
												 padding-bottom="0px"
												 padding-left="15px"
												 padding-right="10px"/> NS2
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:external-graphic src="data:image/jpeg;base64,{$box}"
												 width="7px" height="7px"
												 padding-top="0px"
												 padding-bottom="0px"
												 padding-left="15px"
												 padding-right="10px"/> NB2
										</fo:block>
									</fo:table-cell>
									<fo:table-cell number-columns-spanned="2">
										<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:external-graphic src="data:image/jpeg;base64,{$box}"
												 width="7px" height="7px"
												 padding-top="0px"
												 padding-bottom="0px"
												 padding-left="15px"
												 padding-right="10px"/> Other _______________________________________
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
								<fo:table-row>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="summary-cells">Outcome:
										</fo:block>
									</fo:table-cell>								
									<fo:table-cell padding-bottom="10px">
										<fo:block xsl:use-attribute-sets="summary-cells"> 
											<fo:external-graphic src="data:image/jpeg;base64,{$box}"
												 width="7px" height="7px"
												 padding-top="0px"
												 padding-bottom="0px"
												 padding-left="15px"
												 padding-right="10px"/> Passed
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell padding-bottom="10px">
										<fo:block xsl:use-attribute-sets="summary-cells"> 
											<fo:external-graphic src="data:image/jpeg;base64,{$box}"
												 width="7px" height="7px"
												 padding-top="0px"
												 padding-bottom="0px"
												 padding-left="15px"
												 padding-right="10px"/> Failed
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell padding-bottom="10px">
										<fo:block xsl:use-attribute-sets="summary-cells"> 
											<xsl:value-of select="' '" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell padding-bottom="10px">
										<fo:block xsl:use-attribute-sets="summary-cells"> 
											<fo:external-graphic src="data:image/jpeg;base64,{$box}"
												 width="7px" height="7px"
												 padding-top="0px"
												 padding-bottom="0px"
												 padding-left="15px"
												 padding-right="10px"/> Monitored
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell padding-bottom="10px">
										<fo:block xsl:use-attribute-sets="summary-cells"> 
											<fo:external-graphic src="data:image/jpeg;base64,{$box}"
												 width="7px" height="7px"
												 padding-top="0px"
												 padding-bottom="0px"
												 padding-left="15px"
												 padding-right="10px"/> Graphed
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell padding-bottom="10px">
										<fo:block xsl:use-attribute-sets="summary-cells"> 
											 <fo:external-graphic src="data:image/jpeg;base64,{$box}"
												 width="7px" height="7px"
												 padding-top="0px"
												 padding-bottom="0px"
												 padding-left="15px"
												 padding-right="10px"/> Billing
										</fo:block>
									</fo:table-cell>	
								</fo:table-row>							
							</fo:table-body>
						</fo:table>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	
	<xsl:template name="backpage">
		<fo:block-container absolute-position="fixed" width="7.8in" height="10.5in" left=".3in" top=".35in">
			<fo:block font-size="12pt" font-family="sans-serif" font-weight="bold" space-before="0px" space-after="4px" text-align="center">Indigo Xtreme Internet Terms of Service</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">What is this document?</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">This document contains your Terms of Service (TOS).  It is an agreement between you and Indigo Wireless explaining the rights and responsibilities of Indigo Wireless and you as an Indigo Wireless customer.</fo:block>
			
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">By ordering a service from Indigo Wireless, or by using equipment provided by Indigo Wireless, you accept the terms and conditions contained in this agreement and agree to comply with its requirements.  Indigo Wireless is also bound by this agreement, although Indigo Wireless has the right to update the terms of service and other policies with conditions.</fo:block>
			
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">We have done our best to make this document and other Indigo Wireless policies understandable.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Definitions</fo:block>
			
			<fo:table padding-left=".25in">
				<fo:table-column column-width="2in" />
				<fo:table-column column-width="4in" />
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell>
							<fo:block font-family="sans-serif" font-weight="normal" font-size="8pt" padding="6pt">Customer, I, you, your:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" padding="6pt">means a person, a company, or legal entity who subscribers to a service provided by Internet Wireless.</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell>
							<fo:block font-family="sans-serif" font-weight="normal" font-size="8pt" padding="6pt">User:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" padding="6pt">Also refers to a person, company, or legal entity who subscribes to a service provided by Indigo Wireless, but also includes someone who also uses the same service.</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell>
							<fo:block font-family="sans-serif" font-weight="normal" font-size="8pt" padding="6pt">Service:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" padding="6pt">Any service provided by Indigo Wireless</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell>
							<fo:block font-family="sans-serif" font-weight="normal" font-size="8pt" padding="6pt">Equipment:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" padding="6pt">Means any hardware or device provided by Indigo Wireless for us by a customer.</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell>
							<fo:block font-family="sans-serif" font-weight="normal" font-size="8pt" padding="6pt">Indigo Wireless, we, us:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" padding="6pt">Indigo Wireless, 64 Main St, Wellsboro, PA.</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Scope of this Agreement</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">This Agreement shall be governed by, construed under, and enforced in accordance with the laws of the United States of America and the state of Pennsylvania.  In the event of a conflict between this Agreement and any applicable tariff, the tariff shall prevail.  If any provision of this Agreement shall be held to be invalid or unenforceable, the validity and enforceability of the remaining provisions of this Agreement shall not be affected thereby.  The Agreement, which incorporates by reference the Indigo Wireless Acceptable Use Policy embodies the entire agreement between the parties with respect to the subject matter hereof and supersedes all prior agreements and understandings, whether written or oral, and all contemporaneous oral agreements and understandings relating to the subject matter hereof.  Indigo Wireless may amend the terms and conditions of this Agreement by giving you thirty (30) days notice.  This notice may be in writing or may appear online or by email to the e-mail address you provided when you started service with us.  This Agreement is subject to modification by any authorized regulatory agency.  This Agreement shall be binding on the parties hereto and their respective personal and legal representatives, successors, and permitted assigns.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Your Responsibilities</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">You agree to purchase Internet Services from Indigo Wireless, in accordance with the terms and conditions of this Agreement.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Customer Responsibility</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">You have certain responsibilities as a party to this agreement.  Another section describes Indigo Wireless<fo:character character="&#8217;" /> responsibilities.  You acknowledge that you accept this Agreement on behalf of yourself, your users and all persons who use the equipment and/or service through this equipment.  You have the sole responsibility for ensuring that all other users understand and comply with the terms and conditions of this agreement, whether such breach is the result of the use of the Service and/or Equipment by you or another user.  You agree to use your Indigo Wireless supplied service from your own premises.  You agree to provide Indigo Wireless with accurate and complete billing information, including your legal name, address and telephone number.  If your address, phone number, name or other billing information changes, you will notify us within 30 days.  By ordering and paying for an Indigo Wireless service, you affirm that you are 18 years of age or older.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">What happens if I break this agreement</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">If you default or break this agreement, Indigo Wireless may temporarily suspend or permanently close some or all of your service.  Indigo Wireless alone makes this decision.  Suspending or closing your service does not limit Indigo Wireless<fo:character character="&#8217;" /> remedies or incur any liability to you (that is you don<fo:character character="&#8217;" />t have to be credited down time as a result of you defaulting).  <fo:character character="&#8220;" />Default<fo:character character="&#8221;" /> means failure on your part to comply with this agreement.  This includes getting behind on your payments and breaking the provisions of this agreement or associated policies, but is not limited to these situations.  If you use your own equipment with service provided by Indigo Wireless in violation of any of the provisions of this agreement, Indigo Wireless will notify you and take such action as is necessary for the protection of the service for user by its other customers.  This may include disconnecting your service.  Indigo Wireless reserves the right to charge a disconnect and/or reconnect fee for any discontinued service.</fo:block>

			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Indigo Wireless<fo:character character="&#8217;" /> Responsibilities</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">Indigo Wireless has certain responsibilities as a party to this agreement.  Another section describes your responsibilities.  Indigo Wireless agrees to provide you with the service and required special equipment, provided that you comply with all the terms and conditions of this agreement.  Indigo Wireless also agrees to maintain the equipment provided by us.  Another section details the terms over equipment.  We will do our best to provide uninterrupted service.  However, like any other telecommunications service provided, the service may experience temporary slowdowns or interruptions caused by: overload, abuse, equipment modifications, upgrades, relocations, or repairs, and similar activities necessary for the proper operation and supply of the service, or disasters (see <fo:character character="&#8220;" />force majeure<fo:character character="&#8221;" /> in another section).  Indigo Wireless will provide basic instructions on how to use the service.  These instructions will be provided during the time of your installation by our installer.  You are also entitled to technical support for the Indigo Wireless provided equipment or service via phone or e-mail.  We cannot provide technical support for any hardware, software or operating systems not provided by Indigo Wireless.  If an Indigo Wireless technician or representative is asked to provide support or repair for software or hardware that is not supplied by Indigo Wireless, a callout charge and labor charge may apply.  If Indigo Wireless cannot be made to work at your location because of distance, hills, trees, or any other cause, you will be refunded 100% of any payments you have made to us, subject to this agreement.  You must return the equipment in good condition.  Indigo Wireless has no other liability if your location proves impossible to provide the service for.</fo:block>
			
		</fo:block-container>
		<fo:block break-before="page" />
		<fo:block-container absolute-position="fixed" width="7.8in" height="10.5in" left=".3in" top=".35in">
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Force Majeure (Disasters, Etc)</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">Neither you or Indigo Wireless is liable for any delay or failure in performance of any part of this agreement caused by any force majeure event even beyond your, or our, control and without your, or our, fault or negligence.  These events include, but are not limited to, the events known legally as <fo:character character="&#8220;" />Force Majeure<fo:character character="&#8221;" />.  Force Majeure refers to a number of situations that could affect you and Indigo Wireless in performing your, or our, obligations: acts of civil or military authority, terrorist acts, nuclear accidents, government regulations, riots, strikes, embargoes, insurrections, extended power blackouts, natural disasters, epidemics, fires, severe weather conditions, environmental disturbances, war, explosions, legal and/or regulatory constraints.  </fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">If a Force Majeure condition occurs, the party injured by the other party<fo:character character="&#8217;" />s inability to perform has two options (detailed below).  The injured party has 30 days to choose which one.  If the injured party does not inform the other within 30 days of being notified of a Force Majeure situation, the second option goes into effect.  </fo:block>
			
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="2px">Option One:  The injured party may terminate the agreement if such Force Majeure condition results in a delay or failure to perform which continues for more than 30 calendar days.</fo:block>
			
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">Option Two: The injured party may suspend the service for a duration of the delaying cause and buy a similar service.  After the emergency is over, this agreement and service will continue.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Paying for your Indigo Wireless service</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">The price you will pay Indigo Wireless is the monthly rate and other fees and charges such as equipment leases and applicable taxes as established from time to time by Indigo Wireless.  Indigo Wireless reserves the right to modify the rates, fees and charges at any time.  You have the right to be notified of price changes at least 30 days before the new rate takes effect.  You acknowledge that you may incur additional charges while using the service.  If you make purchases over the Internet, those transactions are between you and the seller, and have nothing to do with your relationship with Indigo Wireless.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Payment</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">Indigo Wireless will charge your credit card periodically as agreed when you signed up for service.  You will be sent a statement by postal mail, or to the e-mail address provided when you signed up for service before payment is due.  Payment will be deemed made when received by Indigo Wireless.  If a credit card payment is declined by the payment service, it will be retried in 2 days time.</fo:block>
			
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">Payment may also be made by check.   Checks may be made out to:  Indigo Wireless and sent to: 64 Main St, Wellsboro, PA 16901.</fo:block>
			
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">If your account becomes overdue, you will receive a notice by email or postal service.  At this time, Indigo Wireless may take steps to reduce the service supplied or temporarily suspend the service and apply any applicable disconnection and /or reconnection fee.  If your account becomes more than 30 days overdue, Indigo Wireless may apply 4.5% interest per month to the account.  A service charge of up to $20 will be assessed for each check that is returned to Indigo Wireless for insufficient funds.  You will get your statement by postal mail or to the e-mail address supplied when you began service.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Term</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">This agreement becomes effective on the date on which you order your Indigo Wireless service.  Your first payment is due at the moment your service is connected.  This is also your start-of-service date.  Your payments are due on the 25th day of every month.  This agreement remains in effect for 24 months from your start-of-service date for all two (2) year agreements.   At the end of the 24 month period, you must give 30 days notice that you wish to discontinue service, or change to a month-to-month service plan.  If no notice is given, the agreement will automatically renew for an additional 24 month period at the then active rate for such service.</fo:block>

			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Credit for Down Time</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">Although we intend to maintain your service at all times, you have the right to be credited if through our negligence you lose service via Indigo Wireless for more than 24 hours.  In such a case, we will credit you 1/30 of the monthly base charge for each 24 hour period from the time of notice of interruption until the service restoration.  The 24 hours must be continuous.  You cannot add up shorter periods.  To receive credit, you must notify the Indigo Wireless office that your service is not working.  Most types of outages do not qualify for credit.  Please read the next section for your information.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Events that don<fo:character character="&#8217;" />t qualify for credit</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">Most temporary service outages do not qualify for credit.  You will not get credit for problems in the Service caused by your own or other<fo:character character="&#8217;" />s negligence or willful act (except as provided above) or for problems caused by weather or disaster-like situations.  Please see Force Majeure.  <fo:character character="&#8220;" />Willful acts<fo:character character="&#8221;" /> include system failures caused by viruses, <fo:character character="&#8220;" />hacking<fo:character character="&#8221;" />, <fo:character character="&#8220;" />cracking<fo:character character="&#8221;" />, and other forms of remote malice.  You will not get credit for loss of connectivity caused by technicians working to modify or repair Indigo Wireless<fo:character character="&#8217;" /> equipment.  You will not get credit for loss of connectivity less than 24 hours long.  Indigo Wireless may, however, issue credit on a case-by-cause basis at Indigo Wireless<fo:character character="&#8217;" /> discretion.  If you believe that Indigo Wireless has billed you in error, you must contact us or call within 30 days of the invoice or statement date.  Refunds or adjustments will not be given for any charges more than 60 days old.</fo:block>

			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Deposit</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">Indigo Wireless may require a deposit to commence the supply of service.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Closing your Account</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">To close your account, you must notify Indigo Wireless.  To add or remove services, or close an account, you must identify yourself to Indigo Wireless<fo:character character="&#8217;" /> satisfaction.  This is to protect unauthorized changes by other persons to your account.  If you wish to cancel or close your account and terminate this agreement before it expires, an early termination fee of $240 may be charged.  This fee will reduce by $10 each month of the term, for 24 month terms.  If you wish to cancel a month-to-month service, you must provide 30 days notice to the closure of your account.  Services will still be charged during this time.</fo:block>

			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Upon Termination of this Agreement or your account</fo:block>
			<fo:block font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt">You agree that upon termination of this Agreement:  </fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt">You will pay Indigo Wireless in full for your use of the Equipment and the Service up to the effective date of termination of this Agreement or the date on which the Service and Equipment have been disconnected and returned to Indigo Wireless, whichever is later.  You will not receive a refund if you terminate service part-way through a month.  You will allow Indigo Wireless employees or contractors to access your premises to remove the Equipment.  This may mean coming in your house and climbing on your roof.  We agree to arrange a time that is convenient for you and an Indigo Wireless technician.</fo:block>			
			
		</fo:block-container>
		<fo:block break-before="page" />
		<fo:block-container absolute-position="fixed" width="7.8in" height="10.5in" left=".3in" top=".35in">			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Credit for closed accounts</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">If you cancel your Indigo Wireless service, we will refund that part of your latest payment which covers service up until your next invoice date excluding the 30 day notice period.  Your setup and installation fees are non-refundable.  You will always be refunded at the rate you paid.  That is, if you got a discount, you will be refunded at the discount level, not at the standard level.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Computer Equipment</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">You are responsible for your own equipment that you use with the Indigo Wireless service.  For this agreement to be valid, your computer must meet minimum requirements (as determined solely by Indigo Wireless).  It must be technically and operationally compatible with the Service.  Indigo Wireless<fo:character character="&#8217;" /> responsibility for your Internet connectivity stops at the downstream end of the Equipment.  You are responsible for providing equipment capable of received and transmitting electronic data through a standard port.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Home networks</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">You may access the Internet via Indigo Wireless from secondary computers on a home network within the limits of the Acceptable Use Policy.  Your home network is not part of your Internet Wireless service or Equipment.  By accepting this agreement, you explicitly acknowledge that Indigo Wireless will not provide technical support for equipment or software that is not part of the Indigo Wireless Service or Equipment.  Allowing someone to connect to your home network from outside your premises and use your Indigo Wireless service is strictly prohibited.  If you do this, we may close your account.  Giving someone outside your household or business your Indigo Wireless login name and password is strictly prohibited.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Equipment supplied by Indigo Wireless</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">Indigo Wireless agrees to maintain the Equipment in working condition for the lifetime of this agreement.  In case of Equipment failure, Indigo Wireless will troubleshoot, diagnose, repair, or replace the Equipment within 48 hours.  All Equipment supplied by Indigo Wireless, except for any item that you buy and pay for in full, remains the property of Indigo Wireless.  You may not mortgage, sell, transfer, lease, encumber, or assign all or part of the Equipment.  If you lose or break the Equipment, or turn it over to someone else as described in the previous paragraph, you must pay Indigo Wireless the full retail cost of the repair or replacement.  If Indigo Wireless spends money in the effort to get the equipment back, you must also pay those costs.  You will not modify, tamper with, or move the Equipment.  If you need the Equipment moved, you must contact Indigo Wireless and ask to have an Indigo Wireless technician or contractor move the Equipment for you.  You may be charged for the callout, labor and materials required to move the Equipment.  If Equipment, including network components, is moved or modified by anyone other than Indigo Wireless personnel (employed or contracted), and damage to the equipment results so that Indigo Wireless personnel or contractors are called out to your location to repair or replace it, you will be charged $150.00 for the visit in addition to any other charges specified in the Terms of Service.  You authorized Indigo Wireless and its employees, agents, contractors and representatives to enter your premises in order to install, maintain, inspect, repair, and remove the Equipment.  Indigo Wireless agrees to arrange a mutually convenient time with you for these activities.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Limitation of Liability</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">We will not be liable for interruptions in Services caused by failure of your hardware or software, failure of communications services, power outages, or other interruptions not within the complete control of Indigo, including, but not limited to: acts of God; acts of the public enemy; acts of the United States, a state or other political subdivision; fire, floods or other natural disasters; accidents; wars; labor disputes or shortages; and inability to obtain material, power, equipment or transportation.</fo:block>
			
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">INDIGO'S LIABILITY REGARDING YOUR USE OF SERVICES OR EQUIPMENT, OR THE FAILURE OF OR INABILITY TO USE THE SERVICES OR EQUIPMENT, IS LIMITED TO THE CHARGES YOU INCUR FOR SERVICES DURING THE AFFECTED PERIOD. THIS MEANS WE ARE NOT LIABLE FOR ANY INCIDENTAL OR CONSEQUENTIAL DAMAGES (SUCH AS LOST PROFITS OR LOST BUSINESS OPPORTUNITIES), PUNITIVE OR EXEMPLARY DAMAGES, OR ATTORNEY'S FEES.</fo:block>
			
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">You agree that Indigo will not be liable or responsible for any third-party claims or damages that arise from your use or another person's use of the Services or Internet access, further, You agree to indemnify and reimburse us for all costs and expenses related to the defense of any such claims, including attorney's fees. This provision will continue to apply after the Agreement ends.</fo:block>
			
			<fo:block font-size="8pt" font-family="sans-serif" font-weight="bold" space-before="8px" space-after="4px">Entire Agreement</fo:block>
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="4px">These terms and conditions together with the acceptable use policy and work order are the entire agreement between you and Indigo Wireless, which may only be amended as described above. These terms and conditions supersede any inconsistent or additional promises made to you by any of our employees or agents.</fo:block>
			
			<fo:block space-before="2px" font-family="sans-serif" text-align="justify" font-weight="normal" font-size="8pt" space-after="14px">By signing below You: (1) Acknowledge that you have read and understand the terms and conditions; (2) Agree to be bound by the terms and conditions; and (3) Are entering into a binding contract with Indigo Wireless for the purchase of Services that may have a term commitment and early termination charge.</fo:block>
					
			<fo:table keep-together="always">
				<fo:table-column column-width="2.25in" />
				<fo:table-column column-width="5.25in" />
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">Printed Name:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="$acct/fname" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="$acct/lname" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row height="20px">
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">
								Date:
								<fo:inline>
									<xsl:value-of select="format-dateTime(current-dateTime(), '[MNn] [D], [Y]')" />
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row height="75px">
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">Signature:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings" border-bottom-style="solid" border-bottom-width="1px">
								<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="1.5in" content-height="auto" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
								
			<fo:block space-before="4px" text-align="center" font-size="6pt" >(10/11)</fo:block>
		</fo:block-container>
	</xsl:template>	
</xsl:stylesheet>