<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:exsl="http://exslt.org/functions" 
								xmlns:img="java:com.psasoft.util.ImageUtilities"
								xmlns:util="java:org.apache.commons.lang.StringUtils"
								extension-element-prefixes="exsl" 
								exclude-result-prefixes="java" version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/>  

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
<xsl:variable name="title" select="' '" />

	<xsl:template match="/">
		<fo:root>
				<xsl:call-template name="make-layout-master-small-margin" />
				<xsl:call-template name="make-body" />
		</fo:root>
	</xsl:template>
	
	<xsl:template name="body_process">
		<xsl:variable name="rowcount" select="'1'" />
		<xsl:variable name="logo-wireless" select="img:getImageBase64Encoded('/images/anywhere-wireless.jpg')"/>

 <!-- -->
		<xsl:call-template name="page1">
			<xsl:with-param name="acct" select="/all_results/results[@name = 'acct']/row" />
			<xsl:with-param name="serv" select="/all_results/results[@name = 'serv']/row" />
			<xsl:with-param name="purchase" select="/all_results/results[@name = 'purchase']/row"/>			
			<xsl:with-param name="logo" select="$logo-wireless" />
		</xsl:call-template>	

		<fo:block break-before="page" />
		<xsl:call-template name="backpage">
			<xsl:with-param name="acct" select="/all_results/results[@name = 'acct']/row" />
			<xsl:with-param name="serv" select="/all_results/results[@name = 'serv']/row" />
			<xsl:with-param name="logo" select="$logo-wireless" />
		</xsl:call-template>
		
 <!--  -->				
	</xsl:template>
	
	<xsl:template name="page1">
		<xsl:param name="acct" />
		<xsl:param name="serv" />
		<xsl:param name="purchase" />
		<xsl:param name="logo" />

		<xsl:variable name="primaryint" select="/all_results/results[@name = 'internet']/row[primary = 'Y']" />
		<xsl:variable name="secint" select="/all_results/results[@name = 'internet']/row[primary = 'N']" />

		<xsl:variable name="checkbox" select="img:getImageBase64Encoded('/images/checkbox.png')"/>
		<xsl:variable name="box" select="img:getImageBase64Encoded('/images/box.gif')"/>
		
		<fo:block-container absolute-position="fixed" left="0.5in" top=".27in" height="1.3in" width="7.5in" border-style="solid" border-width="1px" padding="2px">
			<fo:block-container absolute-position="fixed" left="0.5in" top=".27in">
				<fo:block>
					<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="1.3in" content-width="4.0in"/>
				</fo:block>
			</fo:block-container>
			<fo:block-container absolute-position="fixed" width="3in" left="5in" top="0.5in" text-align="center">
				<fo:block xsl:use-attribute-sets="report-title" font-size="14pt" font-weight="bold" border-style="solid" border-width="1px" color="white" background-color="black" padding="2px" text-align="center">Customer Service Agreement</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" padding="5px" text-align="center">Anywhere Wireless</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" padding="5px" text-align="center">800.333.1234</fo:block>
			</fo:block-container>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.4in" left=".55in" top="1.75in" text-align="justify">
			<fo:block font-size="8pt">The following is a Customer Service Agreement to be entered into between you and Anywhere Wireless. This agreement should be read in conjunction with, and incorporates herein by reference, the contents of the Terms and Conditions and any written rate plan or other sales literature you have been provided by Anywhere Wireless simultaneously herewith.</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height=".5in" left=".5in" top="2.25in"  border-style="solid" border-width="2px">
			<fo:table table-layout="fixed" keep-together="always">
				<fo:table-column column-width="2.5in"/>
				<fo:table-column column-width="2.5in"/>
				<fo:table-column column-width="2.5in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Mobile Number</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:call-template name="phone">
									<xsl:with-param name="npa" select="$serv/cnpa"/>
									<xsl:with-param name="nxx" select="$serv/cnxx"/>
									<xsl:with-param name="line" select="$serv/cline"/>
								</xsl:call-template>
							</fo:block>							
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Account Number</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="format-number($acct/cycle, '000')" />
								<xsl:value-of select="'-'" />
								<xsl:value-of select="format-number($acct/bacct, '0000000')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Date</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="$serv/ctcstrdte"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height="7.75in" left=".5in" top="2.75in"  border-style="solid" border-width="2px">
			<fo:table>
				<fo:table-column column-width="3.75in"/>
				<fo:table-column column-width="3.75in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center" number-columns-spanned="2">
							<fo:block>Billing Address</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Name
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/fname"/>
									<xsl:value-of select="' '"/>
									<xsl:value-of select="$acct/lname"/>
								</fo:inline>							
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Type of Account
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/typedesc"/>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left" number-columns-spanned="2">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Address
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/adln1"/>
								</fo:inline>
							</fo:block>
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="25px">
									<xsl:value-of select="$acct/adln2"/>
								</fo:inline>
							</fo:block>							
							<xsl:if test="$acct/adln3">
								<fo:block xsl:use-attribute-sets="summary-cells" color="black">
									<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="25px">
										<xsl:value-of select="$acct/adln3"/>
									</fo:inline>
								</fo:block>
							</xsl:if>																			
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left" number-columns-spanned="2">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">City/State/Zip
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$acct/adcity"/>
									<xsl:value-of select="', '"/>
									<xsl:value-of select="$acct/adst"/>
									<xsl:value-of select="' '"/>
									<xsl:value-of select="substring($acct/adzip, 1, 5)"/>
									<xsl:if test="substring($acct/adzip, 6, 4) != '0000'" >
										<xsl:value-of select="'-'"/>
										<xsl:value-of select="substring($acct/adzip, 6, 4)"/>
									</xsl:if>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Home Phone
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="$acct/ctnpa"/>
										<xsl:with-param name="nxx" select="$acct/ctnxx"/>
										<xsl:with-param name="line" select="$acct/ctline"/>
									</xsl:call-template>
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Other Phone
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="$acct/ctnpa2"/>
										<xsl:with-param name="nxx" select="$acct/ctnxx2"/>
										<xsl:with-param name="line" select="$acct/ctlin2"/>
									</xsl:call-template>								
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center" number-columns-spanned="2">
							<fo:block>Rate Plan / Features</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<xsl:if test="normalize-space($serv/prmcod) > ''" >
						<fo:table-row>
							<fo:table-cell padding-left="5px" text-align="left" number-columns-spanned="2">
								<fo:block xsl:use-attribute-sets="summary-cells" color="black">Promotions:
									<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
										<xsl:value-of select="$serv/prodsc"/>
									</fo:inline>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:if>
					<fo:table-row>
						<fo:table-cell border-style-top="solid" border-width-top="1px" padding="5px" text-align="left" number-columns-spanned="2">
						    <xsl:if test="/all_results/results[@name = 'seitems']/row[itmtyp != 'K']">
								<fo:table table-layout="fixed" keep-together="always">
									<fo:table-column column-width="4.5in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-header>
										<fo:table-row>
											<fo:table-cell>
												<fo:block xsl:use-attribute-sets="summary-cells" color="black">
													<xsl:value-of select="'Plan/Feature'" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="right">
												<fo:block xsl:use-attribute-sets="summary-cells" color="black">
													<xsl:value-of select="'Rate'" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
									</fo:table-header>
									<fo:table-body>
										<xsl:for-each select="/all_results/results[@name = 'seitems']/row[itmtyp != 'K']">
											<fo:table-row>
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="./itmdsc" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right">
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="format-number(./itmrat, '$ ##,###,##0.00;$ -#,###,##0.00')" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:for-each>
										<xsl:for-each select="/all_results/results[@name = 'acitems']/row">
											<fo:table-row>
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="./itmdsc" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right">
													<fo:block xsl:use-attribute-sets="summary-cells">
														<xsl:value-of select="format-number(./aitrat, '$ ##,###,##0.00;$ -#,###,##0.00')" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:for-each>
										<fo:table-row>
											<fo:table-cell>
												<fo:block xsl:use-attribute-sets="summary-cells" height="20px">
													<xsl:value-of select="'Total'"  />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="right" border-top-style="double" border-top-width="2px">
												<fo:block xsl:use-attribute-sets="summary-cells" height="20px">
													<xsl:value-of select="format-number(sum(/all_results/results[@name = 'seitems']/row/itmrat) + sum(/all_results/results[@name = 'acitems']/row/aitrat), '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
										<fo:table-row>
											<fo:table-cell text-align="right" number-columns-spanned="2">
												<fo:block xsl:use-attribute-sets="summary-cells" color="black">
													<xsl:value-of select="'Tax Not Included'"  />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
									</fo:table-body>
								</fo:table>
							</xsl:if>							
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height="3.45in" left=".5in" top="7.25in">
			<fo:table>
				<fo:table-column column-width="3.75in"/>
				<fo:table-column column-width="3.75in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Equipment</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Auto Pay Options</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Manufacturer
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/mfgmdl" />											
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell padding="5px" number-rows-spanned="4" border-style="solid" border-width="1px">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="8pt">I authorize Anywhere Wireless, LLC to</fo:block>
							<fo:table>
								<fo:table-column column-width="0.35in" />
								<fo:table-column column-width="3.00in" />
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell>
											<fo:block padding-left="2px">
												<xsl:choose>
												<xsl:when test="$acct/btccfg = 'Y'">
													<fo:external-graphic src="data:image/jpeg;base64,{$checkbox}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:when>
												<xsl:otherwise>
													<fo:external-graphic src="data:image/jpeg;base64,{$box}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:otherwise>
												</xsl:choose>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell text-align="justify" padding-right="5px">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="6pt">Charge my credit card on file.</fo:block>
										</fo:table-cell>
									</fo:table-row>
									<fo:table-row>
										<fo:table-cell>
											<fo:block padding-left="2px">
												<xsl:choose>
												<xsl:when test="$acct/paybyach = 'Y'">
													<fo:external-graphic src="data:image/jpeg;base64,{$checkbox}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:when>
												<xsl:otherwise>
													<fo:external-graphic src="data:image/jpeg;base64,{$box}"
														 width="7px" height="7px"
														 padding-top="0px"
														 padding-bottom="0px"/>
												</xsl:otherwise>
												</xsl:choose>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell text-align="justify" padding-right="5px">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="6pt">Electronically debit my bank account on file, </fo:block>
										</fo:table-cell>
									</fo:table-row>
									<fo:table-row>
										<fo:table-cell text-align="justify" padding-right="5px" padding-top="10px" number-columns-spanned="2">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black" font-size="6pt">for this account every month for all fees incurred during use of the wireless device listed on this CSA, not to exceed the maximum amount of: <fo:inline>
												<xsl:choose>
												<xsl:when test="$acct/btccfg = 'Y'">
													<xsl:value-of select="format-number($acct/mxccam, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</xsl:when>
												<xsl:when test="$acct/paybyach = 'Y'">
													<xsl:value-of select="format-number($acct/achmaxamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="'______________________'" />
												</xsl:otherwise>
												</xsl:choose>
											</fo:inline></fo:block>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-body>
							</fo:table>							
						</fo:table-cell>
					</fo:table-row>		
					<fo:table-row>
						<fo:table-cell padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Model
								<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
									<xsl:value-of select="$serv/eqpdsc" />											
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell padding-left="5px" text-align="left">
							<xsl:if test="$serv/imei &gt; 0">
								<fo:block xsl:use-attribute-sets="summary-cells" color="black">IMEI
									<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
										<xsl:value-of select="format-number($serv/imei, '000000000000000')" />
									</fo:inline>											
								</fo:block>		
							</xsl:if>	
							<xsl:value-of select="' '" />					
						</fo:table-cell>
					</fo:table-row>															
					<fo:table-row>
						<fo:table-cell padding-left="5px" text-align="left">
							<xsl:if test="$serv/imnumb &gt; 0">
								<fo:block xsl:use-attribute-sets="summary-cells" color="black">IMSI
									<fo:inline xsl:use-attribute-sets="summary-cells" padding-left="5px">
										<xsl:value-of select="format-number($serv/imctry, '000')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number($serv/imcomp, '00')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number($serv/imnumb, '0000000000')" />
									</fo:inline>											
								</fo:block> 
							</xsl:if>	
							<xsl:value-of select="' '" />					
						</fo:table-cell>
					</fo:table-row>															
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Anywhere EMail</fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Authorized Users</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding-left="5px" text-align="left" height="1.4in" number-rows-spanned="3">
							<fo:table keep-together="always">
								<fo:table-column column-width="0.25in" />
								<fo:table-column column-width="2.75in" />
								<fo:table-body>
										<fo:table-row>
												<fo:table-cell number-columns-spanned="2">
													<fo:block xsl:use-attribute-sets="summary-cells" margin-left="2px" color="black">
														Primary Email Address:
													</fo:block>
												</fo:table-cell>
										</fo:table-row>                
										<fo:table-row>
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells" margin-left="5px">
														<xsl:value-of select="' '"/>
													</fo:block>
												</fo:table-cell>													
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells" margin-left="2px">
														<xsl:value-of select="$primaryint/emladdr"/>
														@anywherewireless.com
													</fo:block>
												</fo:table-cell>
										</fo:table-row>  
										<fo:table-row>
												<fo:table-cell number-columns-spanned="2">
													<fo:block xsl:use-attribute-sets="summary-cells" margin-left="2px" color="black">
														Additional Email Accounts:
													</fo:block>
												</fo:table-cell>
										</fo:table-row>        													        
										<xsl:for-each select="$secint">
											<fo:table-row>
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells" margin-left="5px">
														<xsl:value-of select="' '"/>
													</fo:block>
												</fo:table-cell>													
												<fo:table-cell>
													<fo:block xsl:use-attribute-sets="summary-cells" margin-left="2px">
														<xsl:value-of select="./emladdr"/>
														@anywherewireless.com
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:for-each>													
								</fo:table-body>
							</fo:table>
						</fo:table-cell>
						<fo:table-cell padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black" padding-left="5px">
								<xsl:value-of select="$acct/aunam1"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>	
					<fo:table-row>
						<fo:table-cell padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black" padding-left="5px">
								<xsl:value-of select="$acct/aunam2"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>	
					<fo:table-row>
						<fo:table-cell padding-left="5px" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-cells" color="black" padding-left="5px">
								<xsl:value-of select="$acct/aunam3"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>	
				</fo:table-body>
			</fo:table>
		</fo:block-container>

	</xsl:template>
		
	<xsl:template name="backpage">
		<xsl:param name="acct" />
		<xsl:param name="serv" />
		<xsl:param name="logo" />

		<fo:block-container absolute-position="fixed" left="0.5in" top=".27in" height="1.3in" width="7.5in" border-style="solid" border-width="1px" padding="2px">
			<fo:block-container absolute-position="fixed" left="0.5in" top=".25in">
				<fo:block>
					<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="4.25in"/>
				</fo:block>
			</fo:block-container>
			<fo:block-container absolute-position="fixed" width="3in" left="5in" top="0.5in" text-align="center">
				<fo:block xsl:use-attribute-sets="report-title" font-size="14pt" font-weight="bold" border-style="solid" border-width="1px" color="white" background-color="black" padding="2px" text-align="center">TERMS &amp; CONDITIONS</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" padding="5px" text-align="center">anywherewireless.com</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" padding="5px" text-align="center">800.333.1234</fo:block>
			</fo:block-container>
		</fo:block-container>

		<fo:block-container absolute-position="fixed" left=".5in" top="1.65in" width="7.5in">
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">This Agreement for  Service (<fo:character character="&#x201C;" />Agreement<fo:character character="&#x201D;" />)  and/or  Equipment is between Anywhere Wireless, LLC , 130 E. Walnut Street, Green Bay Wisconsin, 54301 (d/b/a and hereinafter referred to as <fo:character character="&#x201C;" />Anywhere<fo:character character="&#x201D;" />), and the party whose name(s) appear on the Customer Service Agreement hereof (the <fo:character character="&#x201C;" />Customer<fo:character character="&#x201D;" />). Service(s) shall mean the wireless mobility or wireless internet service provided by Anywhere or its authorized roaming partners.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">EQUIPMENT AND SERVICES</fo:inline></fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">A. Service(s) hereunder shall only be available to Equipment properly configured and installed to accept  the Service. The Service(s) will only be available when the Equipment is within range of the antenna sites located in the Anywhere and its roaming partners service areas.  The Service(s) is subject to transmission limitations caused by atmospheric or geographic conditions or government regulations. The Service may be temporarily refused or limited because of the network<fo:character character="&#x2019;" />s capacity limitations. Service to the Customer may be temporarily interrupted or curtailed, without notice, due to Equipment modifications, upgrades, relocations, repairs or similar activities necessary for the proper or improved operation of Anywhere<fo:character character="&#x2019;" />s network. Representations of service by Anywhere, its sales representatives or roaming partners are not guarantees.  Neither the Equipment nor the Services shall be used by Customer for any purpose that is in violation of federal, state or local law.  </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">B. Anywhere Wireless shall assume no liability for interruption of the Service due to circumstances beyond its control, including without limitation, acts of God, natural disaster, fire, flood, civil disturbance, strike or weather. In no event shall Anywhere Wireless be liable for any incidental, special, consequential, or punitive damages, including, but not limited to, loss of profits, personal injury, loss of business, or business opportunity, loss of use, etc. related to a malfunction of either the Service or the Equipment. The liability of Anywhere Wireless for actual proven damages for any cause, (including but not limited to any failure of or disruption of Service), regardless of the form of action, whether in contract or in tort or otherwise, including negligence, shall be limited to an amount equivalent to charges payable by Customer under this agreement for the service during the period such damages occurred.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">C. Customer acknowledges that Anywhere is neither the manufacturer nor the agent of the manufacturer of the Equipment provided hereunder. Customer acknowledges and agrees that Anywhere makes no warranty or representation of any kind regarding the Equipment and that Anywhere disclaims any warranty, express or implied, including the implied warranties of merchantability and of fitness for a particular purpose. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">D. Customer acknowledges that Anywhere is under no duty or obligation to perform any service, maintenance, or repair (collectively <fo:character character="&#x201C;" />repairs<fo:character character="&#x201D;" />) of the Equipment provided hereunder, nor does this agreement create such a duty or obligation to perform repairs. Notwithstanding, Anywhere may perform such repairs upon the Customer<fo:character character="&#x2019;" />s request and pursuant to the terms and conditions of an agreement for such repairs. Anywhere will not be liable for any damages to the Equipment, or expenses related thereto, resulting from Customer<fo:character character="&#x2019;" />s negligence, whether deemed active or passive. Anywhere shall not be responsible for the cost of repairing or replacing any Equipment that has been repaired or altered by anyone other than Anywhere or the manufacturer of such Equipment, or to any Equipment not operated in accordance with the manufacturer<fo:character character="&#x2019;" />s or Anywhere<fo:character character="&#x2019;" />s directions regarding such use.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">TERMINATION OF SERVICE </fo:inline></fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">A. Anywhere may, after giving prior written notice to Customer, terminate or temporarily discontinue or restrict Customer<fo:character character="&#x2019;" />s Service if: (1) Customer fails to pay any charge due or otherwise violates any term of this Agreement, or (2) Customer fails to maintain a billing address within Anywhere<fo:character character="&#x2019;" />s  service area, or (3)  Customer utilizes less than fifty percent (50%) of Customer<fo:character character="&#x2019;" />s overall system usage within Anywhere<fo:character character="&#x2019;" />s  service area during any three (3) month period. In addition, Anywhere may discontinue Customer<fo:character character="&#x2019;" />s Service without prior notice if Customer<fo:character character="&#x2019;" />s Service is reasonably suspected of being used in an illegal or other manner that causes or is likely to cause any form of harm to Anywhere or any other person. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">B. In the event Anywhere, in its sole discretion, undertakes litigation or collection efforts against Customer to enforce the terms of this Agreement, and Anywhere prevails in such efforts, Customer shall be responsible to reimburse Anywhere for all costs and expenses, including actual attorney<fo:character character="&#x2019;" />s fees, incurred by Anywhere relative to such efforts, unless otherwise precluded by law. In the event such litigation or collection effort arises from, or results in, the termination of this Agreement, Customer shall be liable for all outstanding charges on Customer<fo:character character="&#x2019;" />s account at the time of termination.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">MOBILE NUMBER</fo:inline></fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">A. Anywhere reserves the right, in its sole discretion, to change Customer<fo:character character="&#x2019;" />s mobile number upon notice to the Customer. Customer acknowledges that Customer has no proprietary or ownership rights or interest in or to Customer<fo:character character="&#x2019;" />s number(s), except as allowed for by law, and cannot acquire such rights or interest through usage, publication or otherwise.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">B. Customer may request that Customer<fo:character character="&#x2019;" />s mobile number(s) be transferred (ported) to or from another service provider within the same telecommunications LATAs (local area transport areas)  If Customer transfers the mobile number(s) to Anywhere, all activation requirements and charges apply. Customer shall remain liable for charges (including cancellation fees) incurred with a former service provider. If a transfer is unsuccessful and the request is cancelled  and Customer does not ask Anywhere to assign a new number, Customer shall be required to return to Anywhere all Equipment and/or goods supplied hereunder at which time Anywhere will refund the  initial payment. Porting of numbers may take up to 30 days.  In order for Anywhere to port a mobile number, the customer must provide their social security number.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">RATES &amp; CHARGES</fo:inline></fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">A. Customer acknowledges that it shall pay to Anywhere for the use of the Services either within or outside of Anywhere<fo:character character="&#x2019;" />s service area per Customer<fo:character character="&#x2019;" />s selected Service plan. Anywhere will bill Customer on a monthly basis for the use of the Service. Payment of the bill for the Service is due on the date indicated on said bill. A balance which remains unpaid as of the next billing date shall accrue interest at the monthly rate 1%, or the highest amount allowable by law, whichever is lower, from the original due date until such balance is paid in full.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">B. This Agreement can be cancelled at any time by either party per the terms of the Customer<fo:character character="&#x2019;" />s rate plan. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">C. There may be added to any charges incurred by Customer amounts equal to any industry-wide surcharges and/or fees and any surcharge, duty, levy, tax, or withholding, including, but not limited to, sales, property, ad valorem, excise and use taxes, or any tax in lieu thereof or in addition thereto, imposed by any local, state, or federal government or governmental agency with respect to the Services, or with respect to services provided to Customer. Also, there may be additional charges billed to Customer to reimburse Anywhere for its reasonable and necessary costs and expenses incurred in maintaining compliance with regulatory requirements imposed by any local, state, or federal government or governmental agency having jurisdiction over Anywhere.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">FOR WIRELESS INTERNET SERVICE CUSTOMERS ONLY </fo:inline></fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">A. Anywhere  does not represent or warrant that its wireless internet service is available at all locations.  The Service will be provided on a best effort basis as determined by Anywhere.  Depending on the Equipment used and Service provided, installation shall include a wired connection from the Equipment to one working computer.  Multiple computers may be used on the wireless internet connection; however, installation of the Service does not include network configuration, management or support.  Additional networking equipment may be required and is not included with the Service.  </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">B. The WiMax wireless internet equipment installed by Anywhere, with the exception of cable, wiring and mounts, shall at all times remain the sole and exclusive property of Anywhere . Under no circumstances shall Customer alter, misuse, abuse, remove, or in any manner tamper with the Anywhere WiMax equipment placed in or on Customer<fo:character character="&#x2019;" />s premises. Customer is responsible for safeguarding such equipment from damage and will not permit anyone other than a Anywhere representative or agent to perform any work on the equipment. In the event the equipment is destroyed, damaged, lost, or stolen while in Customer<fo:character character="&#x2019;" />s possession, including but limited to damage due to lightning strikes, Customer shall be liable for the cost of repair or replacement of the equipment. The Customer may be held responsible for installation repairs.  The Surfer unit and related equipment shall also remain the property of Anywhere unless Customer elects to purchase the Surfer unit. Under no circumstances shall Customer alter, misuse, abuse, remove or in any manner tamper with the Surfer units owned by Anywhere. </fo:block>

		</fo:block-container>


		<fo:block break-before="page" />
		<fo:block-container absolute-position="fixed" left="0.5in" top=".27in" height="1.3in" width="7.5in" border-style="solid" border-width="1px" padding="2px">
			<fo:block-container absolute-position="fixed" left="0.5in" top=".25in">
				<fo:block>
					<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="4.25in"/>
				</fo:block>
			</fo:block-container>
			<fo:block-container absolute-position="fixed" width="3in" left="5in" top="0.5in" text-align="center">
				<fo:block xsl:use-attribute-sets="report-title" font-size="14pt" font-weight="bold" border-style="solid" border-width="1px" color="white" background-color="black" padding="2px" text-align="center">TERMS &amp; CONDITIONS</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" padding="5px" text-align="center">anywherewireless.com</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" padding="5px" text-align="center">800.333.1234</fo:block>
			</fo:block-container>
		</fo:block-container>

		<fo:block-container absolute-position="fixed" left=".5in" top="1.65in" width="7.5in" text-align="justify">		
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">C. Upon termination or disconnection of the wireless internet service, Customers<fo:character character="&#x2019;" /> right to possession of either the WiMax or Surfer equipment, with the exception of cables, wiring, mounts, shall likewise terminate unless Customer has purchased same.  Customer agrees to immediately return or schedule the removal of the Anywhere Equipment.  The Equipment shall be returned in the same operating condition as it was when installed except for reasonable wear and tear.  Should Customer fail to either return the Equipment or schedule the removal of Equipment within 30 days of the termination or disconnection of the wireless internet service, Customer shall pay Anywhere Wireless the replacement cost for same. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">D. Anywhere  may enter into and over Customer<fo:character character="&#x2019;" />s premises periodically during the term of this agreement to install, connect, inspect, maintain, repair or alter the Equipment. Anywhere will obtain Customer<fo:character character="&#x2019;" />s permission prior to entering Customer<fo:character character="&#x2019;" />s premises. In the event Customer is not the owner of the premises upon which the Equipment is installed, Customer warrants to Anywhere  he/she has obtained the consent of the owner of the premises for Anywhere  to perform the installation and maintenance contemplated by this Agreement.  If the Customer is not the owner of such premises, Customer agrees to indemnify and hold Anywhere  harmless from and against any claims of the owner of the premises arising out of the performance of this Agreement, including but not limited to the operation, installation, connection, inspection, modification, maintenance or repair of the Equipment.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">E. Anywhere  shall not have any responsibility for the operation, maintenance or repair of  Customer<fo:character character="&#x2019;" />s personal computer, monitors, cables, wireless routers and other devices.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">F. Use of the wireless internet service on networks other than the Anywhere network is dependent upon that network<fo:character character="&#x2019;" />s technology and functionality.  Anywhere  does not represent or warrant that the Surfer unit will have the same functionality at all locations or on other networks.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">G. For Residential WiMax Customers Only/Seasonal Status – Customer may elect Seasonal Status for a minimum of 1 month and a maximum of 6 months.  Customer will be billed current monthly seasonal rate for the months Customer elects to be on Seasonal Status.  Seasonal Status Customers will have remote access to their Anywhere e-mail accounts and no additional Services.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">H. If Customer is disconnected from service for any reason other than non-payment, and want to keep existing Anywhere email account, Customer may do so for an annual fee.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">MISCELLANEOUS PROVISIONS</fo:inline></fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">A. This instrument, together with all attachments and any other documents referenced herein, shall constitute the entire agreement between the parties; and no term of condition contained herein or therein may be modified or waived, except in writing signed by an authorized representative of Anywhere. The acceptance by Anywhere of any payment after it shall become due shall not constitute or be construed as a waiver of any or all of Anywhere<fo:character character="&#x2019;" />s right hereunder.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">B. Anywhere Wireless reserves the right to run a credit check on individuals and/or businesses prior to providing Equipment or Service(s). </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">C. Anywhere may assign this Agreement without notice to Customer. Customer may assign this Agreement only with Anywhere<fo:character character="&#x2019;" />s consent.  The interpretation of this Agreement shall be subject to the laws of the State of Wisconsin.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">D. The invalidity of any portion of any provision of this instrument shall not affect the validity of the remainder of the provisions hereof.</fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">E. Anywhere may require a deposit from Customer to guarantee payment of charges for Service and may increase the deposit based on usage and payment history. Deposits will only be returned to Customer after a minimum of 12 consecutive months of satisfactory payment history. Anywhere may apply deposits or payments to any charges owed by Customer on any account. Upon termination of this Agreement, Anywhere shall return any remaining deposit to Customer at such time as all charges for Services have been paid. </fo:block>
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">F. Customer is responsible for all authorized charges for Services on Customer<fo:character character="&#x2019;" />s Equipment. If  Customer claims unauthorized charges on account of a lost or stolen Equipment, Customer must report the Equipment as lost or stolen immediately so that Anywhere may investigate said claims. Anywhere will investigate any claims of unauthorized charges within 60 days. Customer agrees to cooperate with any investigation and will submit any relevant documentation regarding the loss or theft of Equipment. Customer will not be required to pay any disputed charges while the investigation is pending.  If Anywhere determines that the charges for Services are unauthorized; Anywhere will credit Customer<fo:character character="&#x2019;" />s account.</fo:block>
			<fo:block-container absolute-position="relative" border-style="solid" border-width="1px" padding="2px">
				<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt"><fo:inline font-weight="bold">Customer Proprietary Network Information (CPNI) -  <fo:character character="&#x201C;" />Opt Out<fo:character character="&#x201D;" /> Notice - </fo:inline></fo:block> 
				<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">Anywhere <fo:character character="&#x2122;" />  (<fo:character character="&#x201C;" />Anywhere<fo:character character="&#x201D;" />) provides certain telecommunications services to you. In doing so, we may each collect certain information that is made available to us solely  by virtue of our relationship with you, such as quantity, technical configuration, type, destination, location and usage of the telecommunications services you purchase.  This information and related billing information is known as Customer Proprietary Network Information (CPNI). You have a right to the protection of your CPNI and it is Anywhere<fo:character character="&#x2019;" />s responsibility to protect it.  CPNI does not include your published directory information or any information that is in the public domain such as your name, address or telephone number. Use of CPNI is subject to federal laws and regulations with which Anywhere is required to comply. The Federal Communications Commission (FCC) requires Anywhere to notify its customers of their additional rights to restrict the use of their CPNI. CPNI can be used for certain purposes without the customer<fo:character character="&#x2019;" />s permission.  CPNI may be used by Anywhere to offer you additional services that are related to the services you currently subscribe to or to respond to your inquiry regarding services you purchase from Anywhere. CPNI may also be used for functions related to billing and collection, repair, maintenance and to prevent fraud. Anywhere is providing this notification regarding your CPNI rights because we need your consent to use this information to provide you with marketing information for additional communications services that we or our affiliates may offer you in the future. You need to respond to Anywhere only if you wish to <fo:character character="&#x201C;" />opt out<fo:character character="&#x201D;" /> of granting us permission to use your CPNI by sending notice to us at billing@anywherewireless.com. If you have not notified us in writing within 30 days of the date set forth in this Agreement of your desire to <fo:character character="&#x201C;" />opt out<fo:character character="&#x201D;" />, Anywhere and its affiliates will be authorized to use your CPNI for additional marketing purposes.  You may withdraw this consent and <fo:character character="&#x201C;" />opt out<fo:character character="&#x201D;" /> at any time by notifying us in writing at the same email address as noted above.  <fo:character character="&#x201C;" />Opting out<fo:character character="&#x201D;" /> will not affect the services you currently receive from Anywhere.</fo:block>

			</fo:block-container>
		</fo:block-container>
		
		<fo:block-container absolute-position="fixed" left=".5in" top="8.5in" width="7.5in">
			<fo:block text-align="justify" space-before="3px" color="black" font-size="7pt">The undersigned being duly authorized accepts the Terms &amp; Conditions of the Agreement and the service and equipment as specified on the Customer Service Agreement.  </fo:block>
			
			<fo:table keep-together="always">
				<fo:table-column column-width="2.25in" />
				<fo:table-column column-width="5.25in" />
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">Printed Name:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="$acct/fname" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="$acct/lname" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row height="20px">
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings" number-columns-spanned="2">
								Date:
								<fo:inline>
									<xsl:value-of select="format-dateTime(current-dateTime(), '[MNn] [D], [Y]')" />
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row height="50px">
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings">Signature:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-headings" border-bottom-style="solid" border-bottom-width="1px">
								<xsl:choose>
								<xsl:when test="$sigpng > ''">
									<fo:external-graphic src="data:image/png;base64,{$sigpng}" content-width="1.5in" content-height="auto" />
								</xsl:when>
								<xsl:otherwise>
									<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="1.5in" content-height="auto" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row height="50px">
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-cells" color="black">Representative / Agent</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block xsl:use-attribute-sets="summary-cells">
								<xsl:value-of select="$serv/agfsnm"/>
								<xsl:value-of select="' '"/>
								<xsl:value-of select="$serv/aglsnm"/>
								<xsl:value-of select="' ('"/>
								<xsl:value-of select="$serv/agcd1"/>
								<xsl:value-of select="')'"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>					
				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height="0.25in" left=".5in" top="10.65in">
			<fo:block xsl:use-attribute-sets="summary-cells" font-size="7pt" font-weight="bold" padding="5px" text-align="center">
				Anywhere Wireless, LLC, presently does not transmit wireless emergency alerts.  Notice required by FCC Rule 47 C.F.R. 10.240 (Commercial Mobile Alert Service)
			</fo:block>
		</fo:block-container>		
		<fo:block-container absolute-position="fixed" left=".5in" top="10.5in" width="7.5in">
				<fo:block text-align="center" color="black" font-size="7pt">05/2012</fo:block>							
		</fo:block-container>

	</xsl:template>
</xsl:stylesheet>
