<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: creditlvl-dep.xsl,v 1.1 2017-03-28 15:50:39 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:util="java:com.psasoft.util.ConversionUtilities"
				exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
   <xsl:import href="subtemplates.xsl"/> 
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
	<xsl:variable name="title" select="concat('Credit Level/Deposit Report ', $connect_date_range[1], ' to ', $connect_date_range[2])" />

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		<xsl:call-template name="make-layout-master-set-landscape" />
		<xsl:call-template name="make-body-landscape" />
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'data']/row)">
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="2.00in" />
			<fo:table-column column-width="0.50in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Connect Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Account</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>MDN</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Disconnect Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Customer Name</fo:block>
					</fo:table-cell>								
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cr Lvl</fo:block>
					</fo:table-cell>								
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Deposit Amount</fo:block>
					</fo:table-cell>								
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Created By</fo:block>
					</fo:table-cell>													
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'data']/row">
					<xsl:call-template name="detail">
						<xsl:with-param name="row" select="." />
					</xsl:call-template>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>									
	</xsl:when>
	<xsl:otherwise>
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			No Information Found
		</fo:block>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="detail">
	<xsl:param name="row" />
	<fo:table-row>
		<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
			<fo:block>
				<xsl:call-template name="date4parm">
					<xsl:with-param name="cc" select="./cncc" />
					<xsl:with-param name="yy" select="./cnyy" />
					<xsl:with-param name="mm" select="./cnmm" />
					<xsl:with-param name="dd" select="./cndd" />
				</xsl:call-template>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
			<fo:block>
				<xsl:value-of select="format-number(./cycle, '000')" />
				<xsl:value-of select="'-'" />
				<xsl:value-of select="format-number(./account, '0000000')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
			<fo:block>
				<xsl:call-template name="phone">
					<xsl:with-param name="npa" select="./cnpa" />
					<xsl:with-param name="nxx" select="./cnxx" />
					<xsl:with-param name="line" select="./cline" />
				</xsl:call-template>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
			<fo:block>
				<xsl:choose>
					<xsl:when test="./dcmm = 99">
						<xsl:value-of select="'Suspend Nonpay'" />
					</xsl:when>
					<xsl:when test="./dcmm > 0">
						<xsl:call-template name="date4parm">
							<xsl:with-param name="cc" select="./dccc" />
							<xsl:with-param name="yy" select="./dcyy" />
							<xsl:with-param name="mm" select="./dcmm" />
							<xsl:with-param name="dd" select="./dcdd" />
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
				<xsl:value-of select="' '" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
			<fo:block>
				<xsl:value-of select="./fname" />
				<xsl:value-of select="' '" />
				<xsl:value-of select="./lname" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
			<fo:block>
				<xsl:value-of select="./crdrat" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="right">
			<fo:block>
				<xsl:choose>
					<xsl:when test="./depamt != ''">
						<xsl:value-of select="format-number(./itmrat, '$ #,##0.00')" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="''" />
					</xsl:otherwise>
				</xsl:choose>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
			<fo:block>
				<xsl:value-of select="./bruser" />
			</fo:block>
		</fo:table-cell>
	</fo:table-row>
</xsl:template>

</xsl:stylesheet>






