<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: creditreport_full.xsl,v 1.12 2017-03-03 17:16:03 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
							  xmlns:fo="http://www.w3.org/1999/XSL/Format" 
							  xmlns:java="http://xml.apache.org/xslt/java" 
							  xmlns:ar="http://www.experian.com/ARFResponse"
							  xmlns:nc="http://www.experian.com/NetConnectResponse"
							  exclude-result-prefixes="java" version="2.0">
							  
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
    <xsl:import href="subtemplates.xsl"/>

	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="'Credit Report'" />
	<xsl:template match="/">
		<fo:root>
			<xsl:call-template name="make-layout-master-set" />
			<xsl:call-template name="make-body" />
		</fo:root>
	</xsl:template>
	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="exists(/EfxTransmit)">
				<xsl:call-template name="equifax" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="experian" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="equifax">
		<xsl:variable name="rpt" select="/EfxTransmit/EfxReport/USConsumerCreditReports/USConsumerCreditReport" />
		<xsl:if test="exists(/EfxTransmit/EfxReport/USConsumerCreditReports/USConsumerCreditReport/USErrorMessages)">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Errors: '" />
			</fo:block>
			<xsl:for-each select="/EfxTransmit/EfxReport/USConsumerCreditReports/USConsumerCreditReport/USErrorMessages/USErrorMessage">
				<fo:block xsl:use-attribute-sets="data-plain">
					<xsl:value-of select="'Error Code: '" />
					<xsl:value-of select="./Error/@code" />
				</fo:block>
				<fo:block xsl:use-attribute-sets="data-plain">
					<xsl:value-of select="'Error Description: '" />
					<xsl:value-of select="./Error/@description" />
				</fo:block>				  
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="$rpt/USHeader/USConsumerSubject/PersonName">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Report Subject: '" />
					<fo:inline xsl:use-attribute-sets="data-plain">
						<xsl:if test="$rpt/USHeader/USConsumerSubject/PersonName/NamePrefix">
							<xsl:value-of select="$rpt/USHeader/USConsumerSubject/PersonName/NamePrefix" />
							<xsl:value-of select="' '" />				
						</xsl:if>
						<xsl:value-of select="$rpt/USHeader/USConsumerSubject/PersonName/FirstName" />
						<xsl:value-of select="' '" />
						<xsl:if test="$rpt/USHeader/USConsumerSubject/PersonName/MiddleName">
							<xsl:value-of select="$rpt/USHeader/USConsumerSubject/PersonName/MiddleName" />
							<xsl:value-of select="' '" />				
						</xsl:if>
						<xsl:value-of select="$rpt/USHeader/USConsumerSubject/PersonName/LastName" />
						<xsl:if test="$rpt/USHeader/USConsumerSubject/PersonName/NameSuffix">
							<xsl:value-of select="' '" />				
							<xsl:value-of select="$rpt/USHeader/USConsumerSubject/PersonName/NameSuffix" />
						</xsl:if>
					</fo:inline>
			</fo:block>
		</xsl:if>		
		<xsl:if test="$rpt/USOtherNames">
			<fo:block xsl:use-attribute-sets="category-label" margin-left="15px">
				<xsl:value-of select="'Other Names: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USOtherNames/USOtherName">
				<fo:block xsl:use-attribute-sets="category-label" margin-left="25px">
					<fo:inline xsl:use-attribute-sets="data-plain">
						<xsl:if test="./NamePrefix">
							<xsl:value-of select="./NamePrefix" />
							<xsl:value-of select="' '" />				
						</xsl:if>
						<xsl:value-of select="./FirstName" />
						<xsl:value-of select="' '" />
						<xsl:if test="./MiddleName">
							<xsl:value-of select="./MiddleName" />
							<xsl:value-of select="' '" />				
						</xsl:if>
						<xsl:value-of select="./LastName" />
						<xsl:if test="./NameSuffix">
							<xsl:value-of select="' '" />				
							<xsl:value-of select="./NameSuffix" />
						</xsl:if>
					</fo:inline>
				</fo:block>
			</xsl:for-each>
		</xsl:if>		
		<xsl:if test="$rpt/USHeader/USConsumerSubject/DateOfBirth">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="' Date of Birth:  '" />
				<fo:inline xsl:use-attribute-sets="data-plain">
					<xsl:value-of select="$rpt/USHeader/USConsumerSubject/DateOfBirth" />
				</fo:inline>
			</fo:block>
		</xsl:if>
		<xsl:if test="$rpt/USSubjectDeath/DateOfDeath">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="' Date of Death:  '" />
				<fo:inline xsl:use-attribute-sets="data-plain">
					<xsl:value-of select="$rpt/USSubjectDeath/DateOfDeath" />
				</fo:inline>
			</fo:block>
		</xsl:if>
		<xsl:if test="$rpt/USIdentificationSSN/InquirySubjectSSN">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="' SSN:  '" />
				<fo:inline xsl:use-attribute-sets="data-plain">
					<xsl:value-of select="substring($rpt/USIdentificationSSN/InquirySubjectSSN, 1, 3)" />
					<xsl:value-of select="'-'" />
					<xsl:value-of select="substring($rpt/USIdentificationSSN/InquirySubjectSSN, 4, 2)" />
					<xsl:value-of select="'-'" />
					<xsl:value-of select="substring($rpt/USIdentificationSSN/InquirySubjectSSN, 6, 4)" />
				</fo:inline>
			</fo:block>
		</xsl:if>		
		<xsl:if test="$rpt/USHeader/USCreditFile/HitCode">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Report Status: '" />
				<fo:inline xsl:use-attribute-sets="data-plain">
					<xsl:choose>
					<xsl:when test="$rpt/USHeader/USCreditFile/HitCode/@code = '1'">
						<xsl:value-of select="' Information Returned'" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' '" />
						<xsl:value-of select="$rpt/USHeader/USCreditFile/HitCode/@code" />
						<xsl:value-of select="' - '" />
						<xsl:value-of select="$rpt/USHeader/USCreditFile/HitCode/@description" />
					</xsl:otherwise>
					</xsl:choose>
				</fo:inline>
			</fo:block>
		</xsl:if>
		<xsl:if test="$rpt/USModelScores">
			<xsl:for-each select="$rpt/USModelScores/USModelScore">
				<fo:block xsl:use-attribute-sets="category-label" margin-left="15px">
					<xsl:value-of select="'Score: '" />				
					<fo:inline xsl:use-attribute-sets="data-plain">
						<xsl:if test="./ScoreResult">
							<xsl:value-of select="format-number(./ScoreResult, '##,##0;-##,##0')" />
						</xsl:if>
						<fo:inline font-size="5pt" padding-left="20px">
							<xsl:value-of select="' (Score Model: '" />				
							<xsl:value-of select="./ModelNumber" />
							<xsl:value-of select="')'" />				
						</fo:inline>
					</fo:inline>
				</fo:block>
				<xsl:if test="./RejectCode">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px">
						<xsl:value-of select="'Reject Code: '" />										
						<fo:inline xsl:use-attribute-sets="data-plain" margin-left="35px">
							<xsl:value-of select="./RejectCode/@code" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="./RejectCode/@description" />
						</fo:inline>
					</fo:block>
				</xsl:if>				
				<xsl:if test="./ScoreReasons">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px">
						<xsl:value-of select="'Score Reasons: '" />										
						<xsl:for-each select="./ScoreReasons/ScoreReason">
							<fo:block xsl:use-attribute-sets="data-plain" margin-left="35px">
								<xsl:value-of select="./@description" />
							</fo:block>
						</xsl:for-each>
					</fo:block>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="$rpt/IdentityScan/AlertCodes">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Identity Scan Codes: '" />
			</fo:block>
			<xsl:for-each select="$rpt/IdentityScan/AlertCodes/AlertCode">
				<fo:block xsl:use-attribute-sets="data-plain" margin-left="15px">
					<xsl:value-of select="'Alert Code: '" />				
					<fo:inline xsl:use-attribute-sets="data-plain">
						<xsl:value-of select="@code" />
						<xsl:value-of select="' - '" />				
						<xsl:value-of select="@description" />
					</fo:inline>
				</fo:block>
			</xsl:for-each>
		</xsl:if>		
		<xsl:if test="$rpt/USConsumerStatements">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Consumer Statements: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USConsumerStatements/USConsumerStatement">
				<fo:block xsl:use-attribute-sets="category-label" margin-left="25px">
					<xsl:value-of select="'Date Reported: '" />				
					<fo:inline xsl:use-attribute-sets="data-plain">
						<xsl:value-of select="./DateReported" />
					</fo:inline>
					<xsl:value-of select="' Date To Be Purged: '" />				
					<fo:inline xsl:use-attribute-sets="data-plain">
						<xsl:value-of select="./DateToBePurged" />
					</fo:inline>
				</fo:block>
				<fo:block xsl:use-attribute-sets="category-label" margin-left="35px">
					<fo:inline xsl:use-attribute-sets="data-plain">
						<xsl:value-of select="./Statement" />
					</fo:inline>
				</fo:block>
			</xsl:for-each>
		</xsl:if>		
		<xsl:if test="$rpt/USAddresses">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Report Addresses: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USAddresses/USAddress">
				<fo:block-container keep-together="always">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="15px">
						<xsl:value-of select="'Address Designation: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="@description" />
						</fo:inline>
					</fo:block>
					<fo:block xsl:use-attribute-sets="data-plain" margin-left="25px">
						<xsl:value-of select="./StreetNumber" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./StreetName" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./StreetType" />
					</fo:block>
					<fo:block xsl:use-attribute-sets="data-plain" margin-left="25px">
						<xsl:value-of select="./City" />
						<xsl:value-of select="', '" />
						<xsl:value-of select="./State" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="substring(./PostalCode, 1, 5)" />
						<xsl:if test="substring(./PostalCode, 6, 4) != ''">
							<fo:character character="&#8210;" />
							<xsl:value-of select="substring(./PostalCode, 6, 4)" />
						</xsl:if>
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-before="10px">
						<xsl:value-of select="'Date Reported: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./DateAddressFirstReported" />
						</fo:inline>
						<xsl:value-of select="' - Source: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./AddressSource/@description" />
						</fo:inline>
					</fo:block>
				</fo:block-container>
			</xsl:for-each>
		</xsl:if>	
		<xsl:if test="$rpt/USEmployments">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Employment History: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USEmployments/USEmployment">
				<fo:block-container keep-together="always">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="15px" keep-with-next="always" space-before="15px">
						<xsl:value-of select="'Employment Designation: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="@description" />
						</fo:inline>
					</fo:block>
					<fo:block xsl:use-attribute-sets="data-plain" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Employer: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./Employer" />
						</fo:inline>
					</fo:block>
					<xsl:if test="./Occupation">
						<fo:block xsl:use-attribute-sets="data-plain" margin-left="25px" space-after="2px">
							<xsl:value-of select="'Occupation: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./Occupation" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./City">
						<fo:block xsl:use-attribute-sets="data-plain" margin-left="25px" space-after="2px">
							<xsl:value-of select="'City: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./City" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./DateEmployed or ./DateEmployed or ./DateEmploymentEnded">
						<fo:block xsl:use-attribute-sets="data-plain" margin-left="25px" space-after="2px">
							<xsl:if test="./DateEmployed">
								<xsl:value-of select="'Date Employed: '" />
								<fo:inline xsl:use-attribute-sets="data-plain">
									<xsl:value-of select="./DateEmployed" />
								</fo:inline>
							</xsl:if>
							<xsl:if test="./VerificationDate">
								<xsl:value-of select="'Verification Date: '" />
								<fo:inline xsl:use-attribute-sets="data-plain">
									<xsl:value-of select="./VerificationDate" />
								</fo:inline>
							</xsl:if>
							<xsl:if test="./DateEmploymentEnded">
								<xsl:value-of select="'Date Employment Ended: '" />
								<fo:inline xsl:use-attribute-sets="data-plain">
									<xsl:value-of select="./DateEmploymentEnded" />
								</fo:inline>
							</xsl:if>
						</fo:block>
					</xsl:if>
				</fo:block-container>
			</xsl:for-each>
		</xsl:if>			
		<xsl:if test="$rpt/USTrades">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Trades: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USTrades/USTrade">
				<fo:block-container keep-together="always">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="15px" space-after="5px">
						<xsl:value-of select="'Account: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./CreditorId/CustomerNumber" />
						</fo:inline>
						<xsl:if test="./CreditorId/Name">
							<xsl:value-of select="' Name: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CreditorId/Name" />
							</fo:inline>
						</xsl:if>
						<xsl:value-of select="'  Industry: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./CreditorId/Industry/@description" />
						</fo:inline>
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Type: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./AccountType/@description" />
							<xsl:value-of select="' - '" />
							<xsl:value-of select="./AccountDesignator/@description" />
						</fo:inline>
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:if test="./DateOpened">
							<xsl:value-of select="'Date Opened: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./DateOpened" />
							</fo:inline>
						</xsl:if>
						<xsl:value-of select="' Date Reported: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./DateReported" />
						</fo:inline>
					</fo:block>
					<xsl:if test="./DateOfLastActivity or ./DateClosed">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:if test="./DateOfLastActivity">
								<xsl:value-of select="'Date of Last Activity: '" />
								<fo:inline xsl:use-attribute-sets="data-plain">
									<xsl:value-of select="./DateOfLastActivity" />
								</fo:inline>
							</xsl:if>
							<xsl:if test="./DateClosed">
								<xsl:value-of select="' Date Closed: '" />
								<fo:inline xsl:use-attribute-sets="data-plain">
									<xsl:value-of select="./DateClosed" />
								</fo:inline>
							</xsl:if>
						</fo:block>
					</xsl:if>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Status: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./PortfolioType/@description" />
							<xsl:value-of select="' - '" />
							<xsl:value-of select="./Status/@description" />
						</fo:inline>
					</fo:block>
					<xsl:if test="./ActivityDesignator">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:value-of select="'Activity: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./ActivityDesignator/@description" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Balance: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="format-number(./BalanceAmount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</fo:inline>
						<xsl:if test="./PastDueAmount">
							<xsl:value-of select="'  Past Due: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="format-number(./PastDueAmount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:inline>
						</xsl:if>
					</fo:block>
					<xsl:if test="./DateOfFirstDelinquency">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:value-of select="'Date of First Delinquency: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./DateOfFirstDelinquency" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./PaymentHistory">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="5px">
							<xsl:value-of select="'Payment History: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./PaymentHistory" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./ScheduledPaymentAmount">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="5px">
							<xsl:value-of select="'Scheduled Payment: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="format-number(./ScheduledPaymentAmount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./TermsFrequency">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="5px">
							<xsl:value-of select="'Terms Frequency: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./TermsFrequency/@description" />
							</fo:inline>
							<xsl:value-of select="' Terms Duration '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./TermsDuration" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./Narratives/Narrative">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="5px">
							<xsl:value-of select="'Narrative: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:for-each select="./Narratives/Narrative">
									<xsl:value-of select="./@description" />
									<xsl:value-of select="' '" />
								</xsl:for-each>
							</fo:inline>
						</fo:block>
					</xsl:if>
				</fo:block-container>
			</xsl:for-each>
		</xsl:if>	
		<xsl:if test="$rpt/USLegalItems">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Legal Items: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USLegalItems/USLegalItem">
				<fo:block-container keep-together="always">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="15px" space-after="5px">
						<xsl:value-of select="'Item: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./@description" />
						</fo:inline>
					</fo:block>				
					<fo:block xsl:use-attribute-sets="category-label" margin-left="15px" space-after="5px">
						<xsl:value-of select="'Date Filed: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./DateFiled" />
						</fo:inline>
						<xsl:if test="./DateReported">
							<xsl:value-of select="' Date Reported: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./DateReported" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./VerificationDate">
							<xsl:value-of select="' Date Verified: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./VerificationDate" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./DateSatisfied">
							<xsl:value-of select="' Date Satisfied: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./DateSatisfied" />
							</fo:inline>
						</xsl:if>						
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:if test="./CCourtId/CustomerNumber">
							<xsl:value-of select="'Account: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CCourtId/CustomerNumber" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./CaseNumber">
							<xsl:value-of select="' Case Number: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CaseNumber" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./CourtId/Name">
							<xsl:value-of select="' Name: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CourtId/Name" />
							</fo:inline>
						</xsl:if>
						<xsl:value-of select="'  Industry: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./CourtId/Industry/@description" />
						</fo:inline>
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Status: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./Status/@description" />
						</fo:inline>
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Amount: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:choose>
							<xsl:when test="contains(./Amount, 'K')">
								<xsl:value-of select="replace(./Amount, '0', ' ')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(./Amount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</xsl:otherwise>
							</xsl:choose>
						</fo:inline>
					</fo:block>
				</fo:block-container>		
			</xsl:for-each>
		</xsl:if>	
		<xsl:if test="$rpt/USTaxLiens">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Tax Liens: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USTaxLiens/USTaxLien">
				<fo:block-container keep-together="always">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="15px" space-after="5px">
						<xsl:value-of select="'Date Filed: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./DateFiled" />
						</fo:inline>
						<xsl:if test="./DateReported">
							<xsl:value-of select="' Date Reported: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./DateReported" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./VerificationDate">
							<xsl:value-of select="' Date Verified: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./VerificationDate" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./ReleaseDate">
							<xsl:value-of select="' Release Date: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./ReleaseDate" />
							</fo:inline>
						</xsl:if>						
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:if test="./CCourtId/CustomerNumber">
							<xsl:value-of select="'Account: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CCourtId/CustomerNumber" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./CaseNumber">
							<xsl:value-of select="' Case Number: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CaseNumber" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./CourtId/Name">
							<xsl:value-of select="' Name: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CourtId/Name" />
							</fo:inline>
						</xsl:if>
						<xsl:value-of select="'  Industry: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./CourtId/Industry/@description" />
						</fo:inline>
					</fo:block>
					<xsl:if test="./LienClass or ./LienStatus">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:if test="./LienClass">
								<xsl:value-of select="'Lien Class: '" />
								<fo:inline xsl:use-attribute-sets="data-plain">
									<xsl:value-of select="./LienClass/@description" />
								</fo:inline>
							</xsl:if>
							<xsl:if test="./LienStatus">
								<xsl:value-of select="' Status: '" />
								<fo:inline xsl:use-attribute-sets="data-plain">
									<xsl:value-of select="./LienStatus/@description" />
								</fo:inline>
							</xsl:if>
						</fo:block>
					</xsl:if>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Amount: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:choose>
							<xsl:when test="contains(./Amount, 'K')">
								<xsl:value-of select="replace(./Amount, '0', ' ')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(./Amount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</xsl:otherwise>
							</xsl:choose>
						</fo:inline>
					</fo:block>
					<xsl:if test="./Narratives/Narrative">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="5px">
							<xsl:value-of select="'Narrative: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:for-each select="./Narratives/Narrative">
									<xsl:value-of select="./@description" />
									<xsl:value-of select="' '" />
								</xsl:for-each>
							</fo:inline>
						</fo:block>
					</xsl:if>					
				</fo:block-container>		
			</xsl:for-each>
		</xsl:if>			
		<xsl:if test="$rpt/USBankruptcies">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Bankruptcies: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USBankruptcies/USBankruptcy">
				<fo:block-container keep-together="always">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="15px" space-after="5px">
						<xsl:value-of select="'Date Filed: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./DateFiled" />
						</fo:inline>
						<xsl:if test="./DateReported">
							<xsl:value-of select="' Date Reported: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./DateReported" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./VerificationDate">
							<xsl:value-of select="' Date Verified: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./VerificationDate" />
							</fo:inline>
						</xsl:if>
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:if test="./CCourtId/CustomerNumber">
							<xsl:value-of select="'Account: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CCourtId/CustomerNumber" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./CourtId/Name">
							<xsl:value-of select="' Name: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CourtId/Name" />
							</fo:inline>
						</xsl:if>
						<xsl:value-of select="'  Industry: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./CourtId/Industry/@description" />
						</fo:inline>
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Type: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./Type/@description" />
						</fo:inline>
						<xsl:value-of select="' Filer: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./Filer/@description" />
						</fo:inline>
					</fo:block>
					<xsl:if test="./Disposition">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:value-of select="'Disposition: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./Disposition/@description" />
							</fo:inline>
							<xsl:value-of select="' Date: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./Disposition/Date" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./PriorIntentCode">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:value-of select="'Prior Intent: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./PriorIntentCode/@description" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./Narratives/Narrative">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="5px">
							<xsl:value-of select="'Narrative: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:for-each select="./Narratives/Narrative">
									<xsl:value-of select="./@description" />
									<xsl:value-of select="' '" />
								</xsl:for-each>
							</fo:inline>
						</fo:block>
					</xsl:if>
				</fo:block-container>		
			</xsl:for-each>
		</xsl:if>		
		<xsl:if test="$rpt/USCollections">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Collections: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USCollections/USCollection">
				<fo:block-container keep-together="always">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="15px" space-after="5px">
						<xsl:value-of select="'Account: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./CustomerId/CustomerNumber" />
						</fo:inline>
						<xsl:if test="./CustomerId/Name or ./ClientNameNumber">
							<xsl:value-of select="' Name: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CustomerId/Name" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="./ClientNameNumber" />
							</fo:inline>
						</xsl:if>
						<xsl:value-of select="'  Industry: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./CustomerId/Industry/@description" />
						</fo:inline>
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:if test="./DateReported">
							<xsl:value-of select="'Date Reported: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./DateReported" />
							</fo:inline>
						</xsl:if>
						<xsl:if test="./AssignedDate">
							<xsl:value-of select="' Date Assigned: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./AssignedDate" />
							</fo:inline>
						</xsl:if>
					</fo:block>
					<xsl:if test="./AccountDesignator">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:value-of select="'Account Designation: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./AccountDesignator/@description" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./CreditorClassification">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:value-of select="' Creditor Classification: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CreditorClassification/@description" />
							</fo:inline>
						</fo:block>				
					</xsl:if>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Original Amount: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="format-number(./OriginalAmount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</fo:inline>
						<xsl:if test="./BalanceAmount">
							<xsl:value-of select="'  Balance Due: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="format-number(./BalanceAmount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:inline>
						</xsl:if>
					</fo:block>
					<xsl:if test="./UpdateIndicator">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:value-of select="'Update: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./UpdateIndicator/@description" />
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:if test="./DateOfFirstDelinquency or ./DateOfLastPayment">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
							<xsl:if test="./DateOfFirstDelinquency">
								<xsl:value-of select="'Date of First Delinquency: '" />
								<fo:inline xsl:use-attribute-sets="data-plain">
									<xsl:value-of select="./DateOfFirstDelinquency" />
								</fo:inline>
							</xsl:if>
							<xsl:if test="./DateOfLastPayment">
								<xsl:value-of select="' Date of Last Payment: '" />
								<fo:inline xsl:use-attribute-sets="data-plain">
									<xsl:value-of select="./DateOfLastPayment" />
								</fo:inline>
							</xsl:if>
						</fo:block>
					</xsl:if>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="2px">
						<xsl:value-of select="'Status: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./Status/@description" />
						</fo:inline>
						<xsl:if test="./StatusDate">
							<xsl:value-of select="' Status Date: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./StatusDate" />
							</fo:inline>
						</xsl:if>
					</fo:block>
					<xsl:if test="./Narratives/Narrative">
						<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="5px">
							<xsl:value-of select="'Narrative: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:for-each select="./Narratives/Narrative">
									<xsl:value-of select="./@description" />
									<xsl:value-of select="' '" />
								</xsl:for-each>
							</fo:inline>
						</fo:block>
					</xsl:if>
				</fo:block-container>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="$rpt/USInquiries">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				<xsl:value-of select="'Credit Inquiries: '" />
			</fo:block>
			<xsl:for-each select="$rpt/USInquiries/USInquiry">
				<fo:block-container keep-together="always">
					<fo:block xsl:use-attribute-sets="category-label" margin-left="15px">
						<xsl:value-of select="'Date of Inquiry: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./DateOfInquiry" />
						</fo:inline>
						<xsl:value-of select="' Type: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./InquiryAbbreviation/@description" />
						</fo:inline>
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="25px" space-after="5px">
						<xsl:value-of select="'Account: '" />
					</fo:block>
					<fo:block xsl:use-attribute-sets="category-label" margin-left="30px" space-after="5px">
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./CreditorId/CustomerNumber" />
						</fo:inline>
						<xsl:if test="./CustomerId/Name">
							<xsl:value-of select="' Name: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CustomerId/Name" />
							</fo:inline>
							<xsl:value-of select="' Number: '" />
							<fo:inline xsl:use-attribute-sets="data-plain">
								<xsl:value-of select="./CustomerId/CustomerNumber" />
							</fo:inline>
						</xsl:if>
						<xsl:value-of select="'  Industry: '" />
						<fo:inline xsl:use-attribute-sets="data-plain">
							<xsl:value-of select="./CustomerId/Industry/@description" />
						</fo:inline>
					</fo:block>
				</fo:block-container>
			</xsl:for-each>
		</xsl:if>			
	</xsl:template>
	
	<xsl:template name="experian">
		<xsl:variable name="rpt" select="/nc:NetConnectResponse/ar:Products/ar:CreditProfile" />
		<xsl:if test="exists(/nc:NetConnectResponse/nc:CompletionCode)">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Completion Code:  '" />
			</fo:block>
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:choose>
				<xsl:when test="/nc:NetConnectResponse/nc:CompletionCode = '0000'">
					<xsl:value-of select="'Request Completed Normally'" />
				</xsl:when>
				<xsl:when test="/nc:NetConnectResponse/nc:CompletionCode = '1000'">
					<xsl:value-of select="'Invalid request format'" />
				</xsl:when>
				<xsl:when test="/nc:NetConnectResponse/nc:CompletionCode = '1001'">
					<xsl:value-of select="'Invalid length'" />
				</xsl:when>
				<xsl:when test="/nc:NetConnectResponse/nc:CompletionCode = '1002'">
					<xsl:value-of select="'Invalid length'" />
				</xsl:when>
				<xsl:when test="/nc:NetConnectResponse/nc:CompletionCode = '1003'">
					<xsl:value-of select="'No XML request'" />
				</xsl:when>
				<xsl:when test="/nc:NetConnectResponse/nc:CompletionCode = '1004'">
					<xsl:value-of select="'Invalid request parameter'" />
				</xsl:when>
				<xsl:when test="/nc:NetConnectResponse/nc:CompletionCode = '2000'">
					<xsl:value-of select="'Authorization failure'" />
					<xsl:value-of select="' Call Experian Technical Support at 1-800-854-7201.'" />
				</xsl:when>
				<xsl:when test="/nc:NetConnectResponse/nc:CompletionCode = '4000'">
					<xsl:value-of select="'System error. Call Experian Technical Support at 1-800-854-7201.'" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'Request Completed - Unknown Reason: '" />
					<xsl:value-of select="/nc:NetConnectRespons/nc:CompletionCode" />
					<xsl:value-of select="' Call Experian Technical Support at 1-800-854-7201.'" />
				</xsl:otherwise>
				</xsl:choose>
			</fo:block>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:Error)">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Error:  '" />
			</fo:block>
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Name:  '" />
				<fo:inline>
					<xsl:value-of select="$rpt/ar:Error/ar:FirstName" />
					<xsl:value-of select="' '" />
					<xsl:value-of select="$rpt/ar:Error/ar:Surname" />
				</fo:inline>
			</fo:block>
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Report Date:  '" />
				<xsl:call-template name="date1parmcr">
					<xsl:with-param name="date" select="$rpt/ar:Error/ar:ReportDate" />
				</xsl:call-template>
			</fo:block>
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Action:  '" />
				<fo:inline>
					<xsl:value-of select="$rpt/ar:Error/ar:ActionIndicator" />
				</fo:inline>
			</fo:block>
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Cause:  '" />
				<fo:inline>
					<xsl:value-of select="$rpt/ar:Error/ar:ErrorCode" />
				</fo:inline>
			</fo:block>
		</xsl:if>
		<xsl:if test="exists(/nc:NetConnectResponse/nc:ErrorMessage)">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Error Message:  '" />
			</fo:block>
			<fo:block xsl:use-attribute-sets="category-label">
				<fo:inline>
					<xsl:value-of select="/nc:NetConnectResponse/nc:CompletionCode" />
					<xsl:value-of select="' - '" />
					<xsl:value-of select="/nc:NetConnectResponse/nc:ErrorMessage" />
				</fo:inline>
			</fo:block>
		</xsl:if>					
		<xsl:if test="exists($rpt/ar:InformationalMessage)">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Informational Message:  '" />
			</fo:block>
			<fo:block xsl:use-attribute-sets="category-label">
				<fo:inline>
					<xsl:value-of select="$rpt/ar:InformationalMessage/ar:MessageText" />
				</fo:inline>
			</fo:block>
		</xsl:if>	
		<xsl:if test="$rpt/ar:Header/ar:ReportDate">
			<fo:block xsl:use-attribute-sets="category-label">
				<xsl:value-of select="'Report Date:  '" />
				<xsl:call-template name="date1parmcr">
					<xsl:with-param name="date" select="$rpt/ar:Header/ar:ReportDate" />
				</xsl:call-template>
			</fo:block>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:SSN/ar:Number)">
			<xsl:for-each select="$rpt/ar:SSN">
				<fo:block xsl:use-attribute-sets="category-label">
					<xsl:value-of select="'Identity: SSN:  '" />
					<fo:inline>
						<xsl:value-of select="substring(ar:Number, 1, 3)" />
						<xsl:value-of select="'-'" />
						<xsl:value-of select="substring(ar:Number, 4, 2)" />
						<xsl:value-of select="'-'" />
						<xsl:value-of select="substring(ar:Number, 6, 4)" />
					</fo:inline>
					<xsl:if test="ar:VariationIndicator">
						<fo:inline>
							<xsl:value-of select="'  - Variation '" />
							<xsl:value-of select="ar:VariationIndicator" />
						</fo:inline>
					</xsl:if>
				</fo:block>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:ConsumerIdentity)">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px">
				<xsl:value-of select="'Identity Information:  '" />
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="3.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Type</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Name</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Birth Year</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="$rpt/ar:ConsumerIdentity">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="ar:Name/ar:Type" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:if test="ar:Name/ar:First">
										<xsl:value-of select="ar:Name/ar:First" />
									</xsl:if>
									<xsl:if test="ar:Name/ar:Middle">
										<xsl:value-of select="' '" />
										<xsl:value-of select="ar:Name/ar:Middle" />
									</xsl:if>
									<xsl:if test="ar:Name/ar:Surname">
										<xsl:value-of select="' '" />
										<xsl:value-of select="ar:Name/ar:Surname" />
									</xsl:if>
									<xsl:if test="ar:Name/ar:SecondSurname">
										<xsl:value-of select="'-'" />
										<xsl:value-of select="ar:Name/ar:SecondSurname" />
									</xsl:if>
									<xsl:if test="ar:Name/ar:Gen">
										<xsl:value-of select="' '" />
										<xsl:value-of select="ar:Name/ar:Gen" />
									</xsl:if>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="ar:YOB" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:PublicRecord)">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px">
				<xsl:value-of select="'Public Record Information:  '" />
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="5.5in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Status Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Filing Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Description</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="$rpt/ar:PublicRecord">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:StatusDate" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:FilingDate" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block xsl:use-attribute-sets="category-label">
									<xsl:value-of select="ar:Status" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="3">
								<xsl:if test="ar:ReferenceNumber > ''">
									<fo:block>
										<xsl:value-of select="'Reference Number: '" />
										<xsl:value-of select="ar:ReferenceNumber" />
									</fo:block>
								</xsl:if>
								<xsl:if test="normalize-space(ar:Amount) > ''">
									<fo:block>
										<xsl:value-of select="'Amount: '" />
										<xsl:value-of select="format-number(ar:Amount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
									</fo:block>
								</xsl:if>
								<xsl:if test="ar:ECOA > ''">
									<fo:block>
										<xsl:value-of select="'ECOA: '" />
										<xsl:value-of select="ar:ECOA" />
									</fo:block>
								</xsl:if>
								<xsl:if test="ar:Evaluation > ''">
									<fo:block>
										<xsl:value-of select="'Evaluation: '" />
										<xsl:value-of select="ar:Evaluation" />
									</fo:block>
								</xsl:if>
								<xsl:if test="ar:ConsumerComment > ''">
									<fo:block>
										<xsl:value-of select="'Consumer Comment: '" />
										<xsl:value-of select="ar:ConsumerComment" />
									</fo:block>
								</xsl:if>
								<xsl:if test="ar:Court/@code > ''">
									<fo:block>
										<xsl:value-of select="'Court Code: '" />
										<xsl:value-of select="ar:Court/@code" />
									</fo:block>
								</xsl:if>
								<xsl:if test="ar:Court/@name > ''">
									<fo:block>
										<xsl:value-of select="'Court: '" />
										<xsl:value-of select="ar:Court/@name" />
									</fo:block>
								</xsl:if>
								<xsl:if test="ar:PlaintiffName > ''">
									<fo:block>
										<xsl:value-of select="'Plaintiff Name: '" />
										<xsl:value-of select="ar:PlaintiffName" />
									</fo:block>
								</xsl:if>

							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:Statement)">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px">
				<xsl:value-of select="'Experian Statement Information:  '" />
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="6.5in" />
				<fo:table-body>
					<xsl:for-each select="$rpt/ar:Statement">
						<fo:table-row>
							<fo:table-cell text-align="center">
								<fo:block xsl:use-attribute-sets="category-label">
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:DateReported" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell text-align="left">
								<xsl:if test="normalize-space(ar:Type) > ''">
									<fo:block xsl:use-attribute-sets="category-label">
										<xsl:value-of select="ar:Type" />
									</fo:block>
								</xsl:if>
								<fo:block xsl:use-attribute-sets="category-label">
									<xsl:value-of select="ar:StatementText" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:FraudServices)">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px">
				<xsl:value-of select="'Fraud Service Information:  '" />
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="7.5in" />
				<fo:table-body>
					<xsl:for-each select="$rpt/ar:FraudServices">
						<xsl:if test="normalize-space(ar:Text) > '' ">
							<fo:table-row>
								<fo:table-cell text-align="left">
									<xsl:if test="normalize-space(ar:Type) > ''">
										<fo:block xsl:use-attribute-sets="category-label">
											<xsl:value-of select="ar:Type" />
										</fo:block>
									</xsl:if>
									<fo:block xsl:use-attribute-sets="category-label">
										<xsl:value-of select="ar:Text" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</xsl:if>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:RiskModel)">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px">
				<xsl:value-of select="'Score Information:  '" />
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="3.0in" />
				<fo:table-column column-width="2.0in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Score</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Score Type</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Factors</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="$rpt/ar:RiskModel">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:if test="ar:Evaluation/@code = 'N'">
										<xsl:value-of select="'-'" />
									</xsl:if>
									<xsl:value-of select="ar:Score" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:ModelIndicator" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:ScoreFactorCodeOne" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="ar:ScoreFactorCodeTwo" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="ar:ScoreFactorCodeThree" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="ar:ScoreFactorCodeFour" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:AddressInformation)">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px">
				<xsl:value-of select="'Address Information:  '" />
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="3.0in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>First Rpt Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Last Upd Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Type</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Ownership</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Address</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="$rpt/ar:AddressInformation">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:FirstReportedDate" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:LastUpdatedDate" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:DwellingType" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:HomeOwnership" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:StreetPrefix" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="ar:StreetName" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="ar:StreetSuffix" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="ar:UnitType" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="ar:UnitID" />
								</fo:block>
								<fo:block>
									<xsl:value-of select="ar:City" />
									<xsl:value-of select="', '" />
									<xsl:value-of select="ar:State" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="substring(ar:Zip, 1, 5)" />
									<xsl:if test="substring(ar:Zip, 6, 4) != ''">
										<xsl:value-of select="'-'" />
										<xsl:value-of select="substring(ar:Zip, 6, 4)" />
									</xsl:if>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:EmploymentInformation)">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px">
				<xsl:value-of select="'Employment Information:  '" />
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="3.0in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>First Rpt Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Last Upd Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Name</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Address</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="$rpt/ar:EmploymentInformation">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:FirstReportedDate" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:LastUpdatedDate" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:Name" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:AddressFirstLine" />
								</fo:block>
								<xsl:if test="ar:AddressSecondLine != ''">
									<fo:block>
										<xsl:value-of select="ar:AddressSecondLine" />
									</fo:block>
								</xsl:if>
								<xsl:if test="ar:AddressExtraLine != ''">
									<fo:block>
										<xsl:value-of select="ar:AddressExtraLine" />
									</fo:block>
								</xsl:if>
								<xsl:if test="ar:Zip != ''">
									<fo:block>
										<xsl:value-of select="substring(ar:Zip, 1, 5)" />
										<xsl:if test="substring(ar:Zip, 6, 4) != ''">
											<xsl:value-of select="'-'" />
											<xsl:value-of select="substring(ar:Zip, 6, 4)" />
										</xsl:if>
									</fo:block>
								</xsl:if>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:Inquiry)">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px">
				<xsl:value-of select="'Inquiry Information:  '" />
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="2.5in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Type of Inquiry</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Type of Business</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Business Name</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Amount</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="$rpt/ar:Inquiry">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:Date" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:Type" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:KOB" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:SubscriberDisplayName" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="ar:Amount" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
		<xsl:if test="exists($rpt/ar:TradeLine)">
			<fo:block xsl:use-attribute-sets="category-label" break-before="page">
				<xsl:value-of select="'Account Information:  '" />
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="2.25in" />
				<fo:table-column column-width="2.25in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-header>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Open Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Business Name</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Account Type</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Status</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Balance Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Balance Amount</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="$rpt/ar:TradeLine">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:OpenDate" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:SubscriberDisplayName" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:AccountType" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="ar:OpenOrClosed" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:call-template name="date1parmcr">
										<xsl:with-param name="date" select="ar:BalanceDate" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:choose>
										<xsl:when test="exists(ar:BalanceAmount) and normalize-space(ar:BalanceAmount) > ''">
											<xsl:value-of select="format-number(ar:BalanceAmount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number(0, '$ ##,###,##0.00')" />
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row keep-with-previous="always">
							<fo:table-cell xsl:use-attribute-sets="table-cells" keep-with-previous="always" text-align="left" number-columns-spanned="6">
								<fo:table table-layout="fixed" width="100%">
									<fo:table-column column-width="1.25in" />
									<fo:table-column column-width="2.5in" />
									<fo:table-column column-width="1.25in" />
									<fo:table-column column-width="2.0in" />
									<fo:table-body>
										<fo:table-row keep-with-previous="always">
											<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="'Account Number:'" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="left">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="ar:AccountNumber" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="'Type of Business: '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="left">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="ar:KOB" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
										<fo:table-row keep-with-previous="always">
											<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="'Status:'" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="left">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="ar:Status" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="'ECOA: '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="left">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="ar:ECOA" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
										<fo:table-row keep-with-previous="always">
											<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="'Status Date:'" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="left">
												<fo:block keep-with-previous="always">
													<xsl:call-template name="date1parmcr">
														<xsl:with-param name="date" select="ar:StatusDate" />
													</xsl:call-template>
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
												<fo:block keep-with-previous="always">
													<xsl:value-of select="'Maximum Delinquency Date: '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell text-align="left">
												<fo:block keep-with-previous="always">
													<xsl:if test="ar:MaxDelinquencyDate > ''">
														<xsl:call-template name="date1parmcr">
															<xsl:with-param name="date" select="ar:MaxDelinquencyDate" />
														</xsl:call-template>
													</xsl:if>
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
										<xsl:if test="ar:RevolvingOrInstallment > '' or ar:TermsDuration > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Revolving or Installment:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:RevolvingOrInstallment" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Terms / Duration: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:TermsDuration" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:for-each select="ar:Amount">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Amount Type:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:Qualifier" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Amount: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right">
													<fo:block keep-with-previous="always">
														<xsl:choose>
															<xsl:when test="ar:value = 'UNKNOWN'">
																<xsl:value-of select="ar:value" />
															</xsl:when>
															<xsl:when test="ar:Value > '' and ar:value != 'UNKNOWN'">
																<xsl:value-of select="format-number(ar:Value, '$ ##,###,##0.00;$ -#,###,##0.00')" />
															</xsl:when>
															<xsl:otherwise>
																<xsl:value-of select="format-number(0, '$ ##,###,##0.00')" />
															</xsl:otherwise>
														</xsl:choose>
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:for-each>
										<xsl:if test="ar:MonthlyPaymentType > '' or ar:MonthlyPaymentAmount > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Monthly Payment Type:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:MonthlyPaymentType" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Montlhly Payment: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:choose>
															<xsl:when test="ar:Value > ''">
																<xsl:value-of select="format-number(ar:MonthlyPaymentAmount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
															</xsl:when>
															<xsl:otherwise>
																<xsl:value-of select="format-number(0, '$ ##,###,##0.00')" />
															</xsl:otherwise>
														</xsl:choose>
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:LastPaymentDate > '' or ar:PaymentProfile > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Last Payment Date: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:if test="ar:LastPaymentDate > ''">
															<xsl:call-template name="date1parmcr">
																<xsl:with-param name="date" select="ar:LastPaymentDate" />
															</xsl:call-template>
														</xsl:if>
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Payment Profile:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:PaymentProfile" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:PaymentStatus > '' or ar:Evaluation > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Payment Status: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:PaymentStatus" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Evaluation :'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:Evaluation " />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:SpecialComment > '' or ar:MonthsHistory > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Special Comment: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:SpecialComment" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Months History :'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:MonthsHistory " />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:DelinquenciesOver30Days > 0 or ar:DelinquenciesOver60Days > 0">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Delinquencies > 30: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="format-number(ar:DelinquenciesOver30Days, '##0')" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Delinquencies > 60:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="format-number(ar:DelinquenciesOver60Days, '##0')" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="normalize-space(ar:DelinquenciesOver90Days) > '' and normalize-space(ar:DerogCounter) > '' ">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Delinquencies > 90: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="format-number(ar:DelinquenciesOver90Days, '##0')" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Months Seriously Derogatory:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="format-number(ar:DerogCounter, '##0')" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:AmountPastDue > '' or ar:DisputeFlag > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Amount Past Due: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:choose>
															<xsl:when test="ar:Value > ''">
																<xsl:value-of select="format-number(ar:AmountPastDue, '$ ##,###,##0.00;$ -#,###,##0.00')" />
															</xsl:when>
															<xsl:otherwise>
																<xsl:value-of select="format-number(0, '$ ##,###,##0.00')" />
															</xsl:otherwise>
														</xsl:choose>
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Dispute:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:DisputeFlag" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:FirstDelinquencyDate > '' or ar:SecondDelinquencyDate > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'First Delinquency Date: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:if test="ar:FirstDelinquencyDate > ''">
															<xsl:call-template name="date1parmcr">
																<xsl:with-param name="date" select="ar:FirstDelinquencyDate" />
															</xsl:call-template>
														</xsl:if>
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Second Delinquency Date:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:if test="ar:SecondDelinquencyDate > ''">
															<xsl:call-template name="date1parmcr">
																<xsl:with-param name="date" select="ar:SecondDelinquencyDate" />
															</xsl:call-template>
														</xsl:if>
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:MaxPayment > '' or ar:Collateral > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Max Payment: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:choose>
															<xsl:when test="ar:Value > ''">
																<xsl:value-of select="format-number(ar:MaxPayment, '$ ##,###,##0.00;$ -#,###,##0.00')" />
															</xsl:when>
															<xsl:otherwise>
																<xsl:value-of select="format-number(0, '$ ##,###,##0.00')" />
															</xsl:otherwise>
														</xsl:choose>
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Collateral:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:Collateral" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:SoldToName > '' or ar:OriginalCreditorName > '' ">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Sold To: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:SoldToName" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Original Creditor:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:OriginalCreditorName" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:EnhancedPaymentData/ar:InitialPaymentLevelDate > '' or ar:EnhancedPaymentData/ar:AccountCondition > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Intial Payment Level Date: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:if test="ar:EnhancedPaymentData/ar:InitialPaymentLevelDate > ''">
															<xsl:call-template name="date1parmcr">
																<xsl:with-param name="date" select="ar:EnhancedPaymentData/ar:InitialPaymentLevelDate" />
															</xsl:call-template>
														</xsl:if>
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Account Condition:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:EnhancedPaymentData/ar:AccountCondition" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:EnhancedPaymentData/ar:AccountType > '' or ar:EnhancedPaymentData/ar:PaymentStatus > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Account Type: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:EnhancedPaymentData/ar:AccountType" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Payment Status:'" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:EnhancedPaymentData/ar:PaymentStatus" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:EnhancedPaymentData/ar:SpecialComment > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Special Payment Comment: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left" number-columns-spanned="2">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:EnhancedPaymentData/ar:SpecialComment" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
										<xsl:if test="ar:ConsumerComment > ''">
											<fo:table-row keep-with-previous="always">
												<fo:table-cell text-align="right" xsl:use-attribute-sets="table-cells-minimal">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="'Consumer Comment: '" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell text-align="left" number-columns-spanned="2">
													<fo:block keep-with-previous="always">
														<xsl:value-of select="ar:ConsumerComment" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</xsl:if>
									</fo:table-body>
								</fo:table>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
