<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:java="http://xml.apache.org/xslt/java" 
				xmlns:exsl="http://exslt.org/functions" 
                xmlns:credit="java:com.psasoft.customer.data.CreditReport"
				xmlns:img="java:com.psasoft.util.ImageUtilities"
                xmlns:integer="java:java.lang.Integer"
                xmlns:textutil="java:com.psasoft.util.TextUtilities"								
				xmlns:util="java:org.apache.commons.lang.StringUtils"
				extension-element-prefixes="exsl" 
				exclude-result-prefixes="java" version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/>  

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
<xsl:variable name="title" select="' '" />

	<xsl:template match="/">
		<fo:root>
				<xsl:call-template name="make-layout-master-small-margin" />
				<xsl:call-template name="make-body" />
		</fo:root>
	</xsl:template>
	
	<xsl:template name="body_process">
		<xsl:variable name="rowcount" select="'1'" />
		<xsl:variable name="logo-wireless" select="img:getImageBase64Encoded('/images/BTLogo.jpg')"/>

 <!-- -->
		<xsl:call-template name="page1">
			<xsl:with-param name="logo" select="$logo-wireless" />
		</xsl:call-template>	
		
 <!--  -->				
	</xsl:template>
	
	<xsl:template name="page1">
		<xsl:param name="logo" />

		<fo:block-container absolute-position="fixed" left="0.5in" top=".27in" height="1.3in" width="7.5in" border-style="solid" border-width="1px">
			<fo:block-container absolute-position="fixed" left="0.5in" top=".27in" padding="2px">
				<fo:block>
					<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="4.25in"/>
				</fo:block>
			</fo:block-container>
			<fo:block-container absolute-position="fixed" width="3in" left="5in" top="0.3in" text-align="center">
				<fo:block font-size="14pt" font-weight="bold" border-style="solid" border-width="1px" color="white" background-color="black" text-align="center">Credit Check Agreement</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="8pt" font-weight="bold" padding="5px" text-align="center">130 E. Walnut Street</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="8pt" font-weight="bold" padding="5px" text-align="center">P.O. Box 1060</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="8pt" font-weight="bold" padding="5px" text-align="center">Green Bay, WI  54305-1060</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="8pt" font-weight="bold" padding="5px" text-align="center">bugtusselwireless.com</fo:block>
				<fo:block xsl:use-attribute-sets="summary-cells" font-size="8pt" font-weight="bold" padding="5px" text-align="center">877.227.0924</fo:block>
			</fo:block-container>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height=".5in" left=".5in" top="2.00in">
			<fo:table table-layout="fixed" keep-together="always">
				<fo:table-column column-width="2.5in"/>
				<fo:table-column column-width="2.5in"/>
				<fo:table-column column-width="2.5in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="left">
							<fo:block font-size="8pt">Date:
								<fo:inline xsl:use-attribute-sets="summary-cells">
									<xsl:value-of select="format-date(current-date(), '[MNn] [D], [Y] ')" />
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height="7.75in" left=".5in" top="2.75in">
			<fo:table>
				<fo:table-column column-width="3.625in"/>
				<fo:table-column column-width="0.25in"/>
				<fo:table-column column-width="3.625in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center" number-columns-spanned="3">
							<fo:block>Billing Information</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell text-align="left" padding="5px" >
							<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" color="black">Name:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><fo:character character="&#x2002;" /></fo:block>
						</fo:table-cell>						
						<fo:table-cell text-align="left" padding="5px" >
							<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" color="black">Drivers License:</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" height="30px">
							<fo:block font-size="10pt" color="black">
								<xsl:value-of select="credit:getFirstName($credit_report)"/>
								<xsl:if test="normalize-space(credit:getMiddleName($credit_report))">
										<xsl:value-of select="' '"/>
										<xsl:value-of select="credit:getMiddleName($credit_report)"/>
								</xsl:if>
								<xsl:value-of select="' '"/>
								<xsl:value-of select="credit:getLastName($credit_report)"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><fo:character character="&#x2002;" /></fo:block>
						</fo:table-cell>						
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" height="30px">
							<fo:block font-size="10pt" color="black">
								<xsl:value-of select="credit:getDriversLicense($credit_report)"/>
								<xsl:if test="normalize-space(credit:getDriversLicenseState($credit_report))">
									<xsl:value-of select="' | '"/>
									<xsl:value-of select="credit:getDriversLicenseState($credit_report)"/>
								</xsl:if>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					
					<fo:table-row>
						<fo:table-cell text-align="left" padding="5px" >
							<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" color="black">Address:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><fo:character character="&#x2002;" /></fo:block>
						</fo:table-cell>						
						<fo:table-cell text-align="left" padding="5px" >
							<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" color="black">Social Security Number:</fo:block>
						</fo:table-cell>						
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" height="70px">
							<fo:block font-size="10pt">
								<xsl:value-of select="credit:getAddressLine1($credit_report)"/>
							</fo:block>						
							<fo:block font-size="10pt">
								<xsl:value-of select="credit:getAddressLine2($credit_report)"/>
							</fo:block>
							<fo:block font-size="10pt">
								<xsl:value-of select="credit:getAddressLine3($credit_report)"/>
							</fo:block>			
							<fo:block font-size="10pt">
								<xsl:value-of select="credit:getCity($credit_report)" />
								<xsl:value-of select="', '" />
								<xsl:value-of select="credit:getState($credit_report)" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="substring(integer:toString(credit:getZip($credit_report)), 1, 5)" />
								<xsl:if test="substring(integer:toString(credit:getZip($credit_report)), 6, 4) != '0000'">
									<xsl:value-of select="'-'" />
									<xsl:value-of select="substring(integer:toString(credit:getZip($credit_report)), 6, 4)" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell>
							<fo:block><fo:character character="&#x2002;" /></fo:block>
						</fo:table-cell>						
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" height="70px">
							<fo:block font-size="10pt" color="black">
								<fo:block>
									<xsl:value-of select="substring(integer:toString(credit:getSocialSecurityNumber($credit_report)), 1, 3)"/>
									<xsl:value-of select="'-'"/>
									<xsl:value-of select="substring(integer:toString(credit:getSocialSecurityNumber($credit_report)), 4, 2)"/>
									<xsl:value-of select="'-'"/>
									<xsl:value-of select="substring(integer:toString(credit:getSocialSecurityNumber($credit_report)), 6, 4)"/>
								</fo:block>
							</fo:block>
						</fo:table-cell>						
					</fo:table-row>
					
					<fo:table-row>
						<fo:table-cell text-align="left" padding="5px" >
							<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" color="black">Contact Number:</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><fo:character character="&#x2002;" /></fo:block>
						</fo:table-cell>						
						<fo:table-cell text-align="left" padding="5px" >
							<fo:block xsl:use-attribute-sets="summary-cells" font-size="10pt" font-weight="bold" color="black">Date of Birth:</fo:block>
						</fo:table-cell>						
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" height="30px">
							<fo:block font-size="10pt" color="black">
								<xsl:if test="credit:getAreaCode($credit_report) and integer:intValue(credit:getAreaCode($credit_report)) > 0">
									<xsl:value-of select="'('" />
									<xsl:value-of select="credit:getAreaCode($credit_report)"/>
									<xsl:value-of select="') '" />
									<xsl:value-of select="credit:getExchange($credit_report)"/>
									<xsl:value-of select="'-'" />
									<xsl:value-of select="credit:getLine($credit_report)"/>
								</xsl:if>
								<fo:character character="&#x2002;" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><fo:character character="&#x2002;" /></fo:block>
						</fo:table-cell>						
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" height="30px">
							<fo:block font-size="10pt" color="black">
								<xsl:value-of select="credit:getBirthDate($credit_report)" />
							</fo:block>
						</fo:table-cell>						
					</fo:table-row>

				</fo:table-body>
			</fo:table>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" height="2.00in" left=".5in" top="6.75in">
			<fo:table>
				<fo:table-column column-width="7.50in"/>
				<fo:table-body>					
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" color="white" background-color="black" padding="5px" text-align="center">
							<fo:block>Notes / Comments</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" height="70px">
							<fo:block font-size="10pt">
								<xsl:value-of select="credit:getComment($credit_report)"/>
								<fo:character character="&#x2002;" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block-container>

		<fo:block-container absolute-position="fixed" width="7.4in" left=".55in" top="8.50in" text-align="justify">
			<fo:block font-size="8pt">I agree and consent to the obtainment by Bug Tussel Wireless<fo:character character="&#x2122;" /> of any and all personal credit and/or financial information.  This personal credit and/or financial information is to be used by Bug Tussel Wireless<fo:character character="&#x2122;" /> for the sole purpose of waiving any service deposit or determining whether or not service should be initiated or continued.  I understand that Bug Tussel Wireless<fo:character character="&#x2122;" /> may require a security deposit based on my financial information.  I certify and warrant that the information provided is complete and correct.</fo:block>
		</fo:block-container>
		
		<fo:block-container absolute-position="fixed" width="7.5in" height="3.45in" left=".5in" top="9.25in">
			<fo:table>
				<fo:table-column column-width="3.625in"/>
				<fo:table-column column-width="0.25in"/>
				<fo:table-column column-width="3.625in"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" height="50px">
							<fo:block>
								<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="3.25in" content-height="auto" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><fo:character character="&#x2002;" /></fo:block>
						</fo:table-cell>
						<fo:table-cell border-style="solid" border-width="1px" padding="5px" height="50px">
							<fo:block>
								<xsl:value-of select="format-date(current-date(), '[MNn] [D], [Y] ')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell padding="5px" text-align="top">
							<fo:block>Customer Signature</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block><fo:character character="&#x2002;" /></fo:block>
						</fo:table-cell>
						<fo:table-cell padding="5px" text-align="top">
							<fo:block>Date</fo:block>
						</fo:table-cell>
					</fo:table-row>														
				</fo:table-body>
			</fo:table>
		</fo:block-container>

	</xsl:template>
		
</xsl:stylesheet>
