<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" exclude-result-prefixes="java"
	version="2.0">
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="'Comments Report'" />

	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	<xsl:template name="body_process">
		<xsl:call-template name="account_service">
			<xsl:with-param name="row" select="/all_results/results[@name = 'acctservice']/row" />
		</xsl:call-template>

		<xsl:choose>
			<xsl:when test="exists(/all_results/results[@name = 'data']/row)">
				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<fo:table-column column-width="1.5in" />
					<fo:table-column column-width="2in" />
					<fo:table-column column-width="2in" />
					<fo:table-column column-width="4.5in" />
					<fo:table-header>
						<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
									Comment Date
											</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
									Comment Type
											</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
									Comment By
											</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
									Comment
											</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-header>
					<fo:table-footer>
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="4" text-align="left">
							<fo:block>
								<fo:character character="&#x25A1;" font-size="14pt" background-color="#CCCCFF" />
								Indicates account level comment.
							</fo:block>
						</fo:table-cell>
					</fo:table-footer>
					<fo:table-body>
						<xsl:for-each-group select="/all_results/results[@name = 'data']/row"
							group-by="concat(format-number(./cycle, '000'), format-number(./account, '000000'), format-number(./cnpa, '000'), format-number(./cnxx, '000'), format-number(./cline, '0000'), format-number(./dccc, '00'), format-number(./dcyy, '00'), format-number(./dcmm, '00'), format-number(./dcdd, '00'), format-number(./grpid, '0000000'), ./cmdate, ./cmtime) ">
							<xsl:call-template name="commentrow">
								<xsl:with-param name="cycle" select="./cycle" />
								<xsl:with-param name="acct" select="./account" />
								<xsl:with-param name="npa" select="./cnpa" />
								<xsl:with-param name="nxx" select="./cnxx" />
								<xsl:with-param name="line" select="./cline" />
								<xsl:with-param name="dccc" select="./dccc" />
								<xsl:with-param name="dcyy" select="./dcyy" />
								<xsl:with-param name="dcmm" select="./dcmm" />
								<xsl:with-param name="dcdd" select="./dcdd" />
								<xsl:with-param name="group" select="./grpid" />
								<xsl:with-param name="cmdate" select="./cmdate" />
								<xsl:with-param name="cmtime" select="./cmtime" />
							</xsl:call-template>
						</xsl:for-each-group>
					</fo:table-body>
				</fo:table>
			</xsl:when>
			<xsl:otherwise>
				<fo:block>No comments found.</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="commentrow">
		<xsl:param name="cycle" />
		<xsl:param name="acct" />
		<xsl:param name="npa" />
		<xsl:param name="nxx" />
		<xsl:param name="line" />
		<xsl:param name="dccc" />
		<xsl:param name="dcyy" />
		<xsl:param name="dcmm" />
		<xsl:param name="dcdd" />
		<xsl:param name="group" />
		<xsl:param name="cmdate" />
		<xsl:param name="cmtime" />

		<xsl:variable name="color">
			<xsl:choose>
				<xsl:when test="$npa = 0">
					<xsl:value-of select="'#CCCCFF'" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'#FFFFFF'" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<fo:table-row keep-together="always" background-color="{$color}">
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="./cmdate" />
					<xsl:value-of select="' '" />
					<xsl:value-of select="./cmtime" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="./cmttypdsc" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:choose>
						<xsl:when test="./updatedby &gt; 0">
							<xsl:value-of select="./name" />
						</xsl:when>
						<xsl:when test="contains(./userid, 'JBOSS')">
							<xsl:value-of select="'System Generated'" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="./userid" />
						</xsl:otherwise>
					</xsl:choose>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
				<xsl:for-each
					select="/all_results/results[@name = 'data']/row[cycle = $cycle and account = $acct and cnpa = $npa and cnxx = $nxx and cline = $line and dccc = $dccc and dcyy = $dcyy and dcmm = $dcmm and dcdd = $dcdd and grpid = $group and cmdate = $cmdate and cmtime = $cmtime]">
					<fo:block white-space-collapse="false" white-space-treatment="preserve">
						<xsl:value-of select="./rline" />
					</fo:block>
				</xsl:for-each>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
</xsl:stylesheet>
