<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/> 
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Customers Deposits ', $deposit_date_range[1], ' to ', $deposit_date_range[2])" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'cust']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'cust']/row" group-by="./status">
						<xsl:variable name="status" select="./status"/>
						<xsl:variable name="statusdesc" select="./mstatdsc"/>
						<fo:table table-layout="fixed" width="100%" space-before="16px">
								<xsl:call-template name="header">
									<xsl:with-param name="status" select="$status"/>
									<xsl:with-param name="statusdesc" select="$statusdesc" />
								</xsl:call-template>
								<fo:table-body>
									<xsl:call-template name="detailrow">
										<xsl:with-param name="status" select="$status"/>
									</xsl:call-template>									
								</fo:table-body>
						</fo:table>

				</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
				<fo:block>No Accounts Found for selected status(s)</fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
    
<xsl:template name="header">
		<xsl:param name="status" />   
		<xsl:param name="statusdesc" />   
		<xsl:variable name="cols">
				<xsl:choose>
				<xsl:when test="normalize-space($status) = 'W'" >
						<xsl:value-of select="9"/>
				</xsl:when>											
				<xsl:otherwise>
						<xsl:value-of select="6"/>
				</xsl:otherwise>
				</xsl:choose>
		</xsl:variable>

		<xsl:choose>
		<xsl:when test="normalize-space($status) = 'W'" >
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />		
				<fo:table-column column-width="0.75in" />		
		</xsl:when>											
		<xsl:otherwise>
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />		
		</xsl:otherwise>
		</xsl:choose>
		
		<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="{$cols}" text-align="left">
								<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px">
									<xsl:value-of select="$statusdesc" />
								</fo:block>	
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
										Total
								</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="right">
								<fo:block>
										<xsl:value-of select="format-number(count(/all_results/results[@name = 'cust']/row[status = $status]), '###,###,##0')"/>
								</fo:block>
						</fo:table-cell>						
				</fo:table-row>		
				<xsl:choose>
				<xsl:when test="normalize-space($status) = 'W'" >			
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Account
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Service Number
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Disconnect Date
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Account Name
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										SSN
										</fo:block>
								</fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Service Name
										</fo:block>
								</fo:table-cell>									
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Deposit Date
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Deposit Amount
										</fo:block>
								</fo:table-cell>										
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Connect Date
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Write Off Date
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Write Off Amount
										</fo:block>
								</fo:table-cell>						
						</fo:table-row>
				</xsl:when>											
				<xsl:otherwise>						
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Account
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Service Number
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Disconnect Date
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Account Name
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										SSN
										</fo:block>
								</fo:table-cell>									
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Service Name
										</fo:block>
								</fo:table-cell>									
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Deposit Date
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Deposit Amount
										</fo:block>
								</fo:table-cell>															
						</fo:table-row>
				</xsl:otherwise>
				</xsl:choose>						
		</fo:table-header>
</xsl:template>

<xsl:template name="detailrow">
		<xsl:param name="status" />    
  	
		<xsl:for-each select="/all_results/results[@name = 'cust']/row[status = $status]">
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:value-of select="format-number(./cycle, '000')"/>
									<xsl:value-of select="'-'"/>
									<xsl:value-of select="format-number(./account, '0000000')"/>
							</fo:block>															
					</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:if test="./cnpa &gt; 0 and ./cnxx &gt; 0">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="./cnpa"/>
										<xsl:with-param name="nxx" select="./cnxx"/>
										<xsl:with-param name="line" select="./cline"/>
									</xsl:call-template>	
								</xsl:if>
								<xsl:value-of select="' '"/>
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:if test="./dcmm &gt; 0 and ./dcmm != 99">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./dccc"/>
											<xsl:with-param name="yy" select="./dcyy"/>
											<xsl:with-param name="mm" select="./dcmm"/>
											<xsl:with-param name="dd" select="./dcdd"/>
										</xsl:call-template>	
									</xsl:if>
									<xsl:value-of select="' '"/>
								</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
									<xsl:value-of select="./fname"/>
									<xsl:value-of select="' '"/>
									<xsl:value-of select="./lname"/>
							</fo:block>
							<xsl:if test="normalize-space(./adln1)">
									<fo:block>
											<xsl:value-of select="./adln1" />
									</fo:block>
							</xsl:if>
							<xsl:if test="normalize-space(./adln2)">
									<fo:block>
											<xsl:value-of select="./adln2" />
									</fo:block>
							</xsl:if>
							<xsl:if test="normalize-space(./adln3)">
									<fo:block>
											<xsl:value-of select="./adln3" />
									</fo:block>
							</xsl:if>
							<fo:block>
									<xsl:value-of select="./adcity" />
									<xsl:value-of select="', '" />
									<xsl:value-of select="./adst" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="substring(./adzip, 1, 5)" />
									<xsl:if test="substring(./adzip, 6, 4) != '0000'">
											<xsl:value-of select="'-'" />
											<xsl:value-of select="substring(./adzip, 6, 4)" />
									</xsl:if>
							</fo:block>							
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:choose>
									<xsl:when test="string-length(./ssn) = 9">
											<xsl:value-of select="substring(./ssn, 1, 3)" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="substring(./ssn, 4, 2)" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="substring(./ssn, 6, 4)" />
									</xsl:when>
									<xsl:otherwise>
											<xsl:value-of select="./ssn" />
									</xsl:otherwise>
									</xsl:choose>
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:value-of select="./bdisc" />
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:if test="./dpmm &gt; 0">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./dpcc"/>
											<xsl:with-param name="yy" select="./dpyy"/>
											<xsl:with-param name="mm" select="./dpmm"/>
											<xsl:with-param name="dd" select="./dpdd"/>
										</xsl:call-template>	
									</xsl:if>
									<xsl:value-of select="' '"/>
								</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number(./depamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
							</fo:block>
						</fo:table-cell>							
						<xsl:if test="normalize-space($status) = 'W'" >		
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
											<xsl:if test="./wtomm != '' and ./wtomm &gt; 0">
												<xsl:call-template name="date4parm">
													<xsl:with-param name="cc" select="./wtocc"/>
													<xsl:with-param name="yy" select="./wtoyy"/>
													<xsl:with-param name="mm" select="./wtomm"/>
													<xsl:with-param name="dd" select="./wtodd"/>
												</xsl:call-template>	
											</xsl:if>
											<xsl:value-of select="' '"/>
										</fo:block>
								</fo:table-cell>		
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
											<xsl:choose>
											<xsl:when test="./wtoamt &gt; 0">
													<xsl:value-of select="format-number(./wtoamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
											</xsl:when>
											<xsl:otherwise>
													<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
											</xsl:otherwise>
											</xsl:choose>
									</fo:block>
								</fo:table-cell>								
						</xsl:if>
																	
			  </fo:table-row>
		</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
