<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: customers_payments.xsl,v 1.7 2014-08-21 15:53:27 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
				exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="concat('Payments ', $payment_date[1], ' to ', $payment_date[2])"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'payments']/row">
			<xsl:variable name="pmtcnt">
				<xsl:choose>
					<xsl:when test="$report_type = 'wo'">
						<xsl:value-of select="count(/all_results/results[@name = 'payments']/row[wrtoff = 'W'])" />
					</xsl:when>
					<xsl:when test="$report_type = 'nonwo'">
						<xsl:value-of select="count(/all_results/results[@name = 'payments']/row[wrtoff != 'W'])" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="count(/all_results/results[@name = 'payments']/row)" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:variable name="pmtamt">
				<xsl:choose>
					<xsl:when test="$report_type = 'wo'">
						<xsl:value-of select="sum(/all_results/results[@name = 'payments']/row[wrtoff = 'W']/pmtamt)" />
					</xsl:when>
					<xsl:when test="$report_type = 'nonwo'">
						<xsl:value-of select="sum(/all_results/results[@name = 'payments']/row[wrtoff != 'W']/pmtamt)" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="sum(/all_results/results[@name = 'payments']/row/pmtamt)" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<fo:table table-layout="fixed" width="100%" space-before="8px">
				<fo:table-column column-width="5.0in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell>
							<fo:block>
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="'Total'" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block>
								<xsl:value-of select="format-number(number($pmtcnt), '###,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block>
								<xsl:value-of select="format-number(number($pmtamt), '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
			<fo:table table-layout="fixed" space-before="8px">
				<fo:table-column column-width="1.00in" />
				<fo:table-column column-width="1.65in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.50in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.50in" />
				<fo:table-column column-width="0.50in" />
				<fo:table-column column-width="0.25in" />
				<fo:table-column column-width="1.75in" />
				<fo:table-column column-width="0.50in" />
				<fo:table-column column-width="0.65in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Account</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Name</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Payment Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Payment Amount</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Ref</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Billing Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Batch</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Seq</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Mkt</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Originating Place</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Ent By</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Status</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:choose>
						<xsl:when test="$report_type = 'wo'">
							<xsl:for-each select="/all_results/results[@name = 'payments']/row[wrtoff = 'W']">
								<xsl:choose>
									<xsl:when test="btchsts = 'O'">
										<fo:table-row background-color="#CCCC66">
											<xsl:call-template name="payrow">
												<xsl:with-param name="row" select="." />
											</xsl:call-template>
										</fo:table-row>
									</xsl:when>
									<xsl:otherwise>
										<fo:table-row background-color="#FFFFFF">
											<xsl:call-template name="payrow">
												<xsl:with-param name="row" select="." />
											</xsl:call-template>
										</fo:table-row>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
						</xsl:when>
						<xsl:when test="$report_type = 'nonwo'">
							<xsl:for-each select="/all_results/results[@name = 'payments']/row[wrtoff != 'W']">
								<xsl:choose>
									<xsl:when test="btchsts = 'O'">
										<fo:table-row background-color="#CCCC66">
											<xsl:call-template name="payrow">
												<xsl:with-param name="row" select="." />
											</xsl:call-template>
										</fo:table-row>
									</xsl:when>
									<xsl:otherwise>
										<fo:table-row background-color="#FFFFFF">
											<xsl:call-template name="payrow">
												<xsl:with-param name="row" select="." />
											</xsl:call-template>
										</fo:table-row>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:for-each select="/all_results/results[@name = 'payments']/row">
								<xsl:choose>
									<xsl:when test="btchsts = 'O'">
										<fo:table-row background-color="#CCCC66">
											<xsl:call-template name="payrow">
												<xsl:with-param name="row" select="." />
											</xsl:call-template>
										</fo:table-row>
									</xsl:when>
									<xsl:otherwise>
										<fo:table-row background-color="#FFFFFF">
											<xsl:call-template name="payrow">
												<xsl:with-param name="row" select="." />
											</xsl:call-template>
										</fo:table-row>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-body>
			</fo:table>
		</xsl:when>
		<xsl:otherwise>
			<fo:block>No Payments Found in selected date range</fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="payrow">
		<xsl:param name="row" />

		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="format-number($row/cycle, '000')" />
				<xsl:value-of select="'-'" />
				<xsl:value-of select="format-number($row/account, '0000000')" />
			</fo:block>
		</fo:table-cell>	
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/fname" />
				<xsl:value-of select="$row/lname" />				
			</fo:block>
		</fo:table-cell>																			
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/paydate"/>
			</fo:block>
		</fo:table-cell>										
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number($row/pmtamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
			</fo:block>
		</fo:table-cell>				
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/refno"/>
			</fo:block>
		</fo:table-cell>								
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:call-template name="date4parm">
					<xsl:with-param name="cc" select="$row/blcc"/>
					<xsl:with-param name="yy" select="$row/blyy"/>
					<xsl:with-param name="mm" select="$row/blmm"/>
					<xsl:with-param name="dd" select="$row/bldd"/>
				</xsl:call-template>										
			</fo:block>
		</fo:table-cell>		
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/btchid"/>
			</fo:block>
		</fo:table-cell>			
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/seq"/>
			</fo:block>
		</fo:table-cell>						
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/market"/>
			</fo:block>
		</fo:table-cell>						
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/orgplc"/>
			</fo:block>
		</fo:table-cell>	
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/payuser"/>
			</fo:block>
		</fo:table-cell>				
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:choose>
					<xsl:when test="wrtoff = 'W' and btchsts = 'O'">
						<xsl:value-of select="'Write Off '"/>
						<xsl:value-of select="'Not Posted'"/>
					</xsl:when>
					<xsl:when test="wrtoff = 'W'">
						<xsl:value-of select="'Write Off '"/>
						<xsl:value-of select="'Posted'"/>
					</xsl:when>
					<xsl:when test="btchsts = 'O'">
						<xsl:value-of select="'Not Posted'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'Posted'"/>
					</xsl:otherwise>
				</xsl:choose>
			</fo:block>
		</fo:table-cell>				
</xsl:template>		

</xsl:stylesheet>






