<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">
  <xsl:import href="Literal.xsl" />
  <xsl:import href="Format.xsl" />
  <xsl:import href="subtemplates.xsl"/>
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
  <xsl:variable name="title" select="'Sales Report'" />
    
  <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
  </xsl:template>
  
	<xsl:template name="body_process">
		<xsl:call-template name="account_service">
			<xsl:with-param name="row" select="/all_results/results[@name = 'acctservice']/row" />
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="/all_results/results[@name = 'data']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="./locationid">
					<fo:block xsl:use-attribute-sets="summary-headings">
						<xsl:value-of select="'Company:  '" />
						<xsl:value-of select="current-group()[position() = 1]/company" />
					</fo:block>
					<fo:block xsl:use-attribute-sets="summary-headings">
						<xsl:value-of select="'Location:  '" />
						<xsl:value-of select="current-group()[position() = 1]/location" />
					</fo:block>
					<xsl:call-template name="location">
						<xsl:with-param name="locaid" select="current-group()[position() = 1]/locationid" />
					</xsl:call-template>
					<xsl:if test="position() != last()">
						<fo:block break-after="page" />
					</xsl:if>
				</xsl:for-each-group>
			</xsl:when>
			<xsl:otherwise>
				<fo:block>No Sold Information Found</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
    
  <xsl:template name="location">
    		<xsl:param name="locaid" />
				<fo:table table-layout="fixed" width="100%" space-before="16px">
						<fo:table-column column-width="0.7in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="0.7in" />
						<fo:table-column column-width="1.5in" />
						<fo:table-column column-width="1.3in" />
						<fo:table-column column-width="0.7in" />
						<fo:table-column column-width="2.0in" />
						<fo:table-header>
								<fo:table-row keep-with-next="always">
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Sale Date
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Transaction Number
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Item Code
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Item Desc
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Serial / IMEI
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Sale Price
												</fo:block>
										</fo:table-cell>										
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Status
												</fo:block>
										</fo:table-cell>
								</fo:table-row>
					  </fo:table-header>
					  <fo:table-body>
						<xsl:for-each select="/all_results/results[@name = 'data']/row[locationid = $locaid]">
							<fo:table-row keep-together="always">
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
												<xsl:value-of select="./saledate" />
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
												<xsl:value-of select="./salerefno" />
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
												<xsl:choose>
														<xsl:when test="./externalcd != ''">
																<fo:block>
																		<xsl:value-of select="./externalcd" />
																</fo:block>
														</xsl:when>
														<xsl:otherwise>
																<fo:block>
																		<xsl:value-of select="./unitcode" />
																</fo:block>
														</xsl:otherwise>
												</xsl:choose>										
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
												<xsl:value-of select="./itemdesc" />
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
											<fo:inline space-end="0.2in" space-start.precedence="force">
													<xsl:value-of select="./serialno2" />
													<xsl:if test="normalize-space(./serialno)">
															<xsl:value-of select="' (S#: '" />
															<xsl:value-of select="./serialno" />
															<xsl:value-of select="')'" />
													</xsl:if>
											</fo:inline>												
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
												<xsl:value-of select="format-number(./saleprice, '##,##0.00')" />
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
												<xsl:choose>
														<xsl:when test="./status = '2' and ./unitqty &lt; 0">
																<fo:block>
																		<xsl:value-of select="'Sale (Exception)'" />
																</fo:block>
														</xsl:when>
														<xsl:when test="./status = '2' and ./unitqty = 0">
																<fo:block>
																		<xsl:value-of select="'Sale'" />
																</fo:block>
														</xsl:when>
														<xsl:when test="./status = '7' or ./status = '8'">
																<fo:block>
																		<xsl:value-of select="'Returned'" />
																</fo:block>
														</xsl:when>
														<xsl:when test="./status = '9'">
																<fo:block>
																		<xsl:value-of select="'Sale (Exception Resolved)'" />
																</fo:block>
														</xsl:when>														
														<xsl:otherwise>
																<fo:block>
																		<xsl:value-of select="./status" />
																</fo:block>
														</xsl:otherwise>
												</xsl:choose>	
										</fo:block>
									</fo:table-cell>												
								</fo:table-row>
							</xsl:for-each>
						</fo:table-body>
				</fo:table>
  </xsl:template>
</xsl:stylesheet>
