<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: installment_nwmc.xsl,v 1.4 2015-09-16 19:33:32 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:img="java:com.psasoft.util.ImageUtilities"
				xmlns:pos="java:com.psasoft.pos.util.POSUtil"
				exclude-result-prefixes="java" version="2.0">
  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="''"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		<xsl:call-template name="make-layout-master-set"/>
		<xsl:call-template name="make-body-web"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'install']/row)">
		<xsl:call-template name="pageone" />
	</xsl:when>
	<xsl:otherwise>
		<fo:block>No installment information found</fo:block>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="pageone"> 
	<xsl:variable name="cust" select="/all_results/results[@name = 'cust']/row"/>
	<xsl:variable name="install" select="/all_results/results[@name = 'install']/row"/>
	<xsl:variable name="logo" select="img:getImageBase64Encoded('/images/northwest_logo_new.jpg')"/>
	<xsl:variable name="seriallbl">
        <xsl:call-template name="getserialname">
            <xsl:with-param name="serial2typ" select="$install/serial2typ" />
            <xsl:with-param name="s2typlabel" select="$install/s2typlabel" />
        </xsl:call-template>
	</xsl:variable>
	<xsl:variable name="calcpay" select="pos:calculateInstallmentsPaymentReport(number($install/beginbal), number($install/origterm), number($install/instintrt), 10)"/>
	<xsl:variable name="lastpay">
		<xsl:choose>
		<xsl:when test="($install/itmrat * $install/origterm) = ($calcpay * $install/origterm)">
			<xsl:value-of select="$install/itmrat" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="($calcpay * $install/origterm) - ($install/itmrat * ($install/origterm - 1))" />
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<fo:block-container absolute-position="fixed" left=".5in" top=".25in">
			<fo:block>
				<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="1.75in"/>
			</fo:block>
	</fo:block-container>
	<fo:block-container  absolute-position="fixed" width="6in" start-indent="2.5in" top=".25in" text-align="center">
			<fo:block xsl:use-attribute-sets="report-title" font-size="16pt" font-weight="bold">Wireless Device Financing Agreement</fo:block>
	</fo:block-container>
	<fo:block-container absolute-position="fixed" left="3cm" top="1.25in" width="7in" padding="5pt">
		<fo:block xsl:use-attribute-sets="category-label">
			Seller/Creditor: 
		</fo:block>	
		<fo:block start-indent="1.0in">
			<xsl:value-of select="'Northwest Missouri Cellular Limited Partnership'" />
		</fo:block>
		<fo:block start-indent="1.0in">
			<xsl:value-of select="'1218 South Main, Maryville, MO 64468'" />
		</fo:block>
	</fo:block-container>
	<fo:block-container absolute-position="fixed" left="3cm" top="2.25in" width="2.9in" padding="5pt">
		<fo:block space-before=".25in">
			<fo:inline xsl:use-attribute-sets="category-label">Date: </fo:inline>		                        
			<xsl:value-of select="$install/effdate" />
		</fo:block>
		<fo:block space-before=".25in">
			<fo:inline xsl:use-attribute-sets="category-label">Buyer's Account: </fo:inline>		                        
			<xsl:value-of select="format-number($cust/ptcyc, '000')" />
			<xsl:value-of select="'-'" />
			<xsl:value-of select="format-number($cust/ptacct, '0000000')" />
		</fo:block>
		<fo:block>
			<fo:inline xsl:use-attribute-sets="category-label">Buyer's Name: </fo:inline>		                        
			<xsl:value-of select="$cust/fname" />
			<xsl:value-of select="$cust/lname" />
		</fo:block>
		<fo:block>
			<fo:inline xsl:use-attribute-sets="category-label">Buyer's Phone # : </fo:inline>		                        
			<xsl:value-of select="format-number($cust/cnpa, '000')" />
			-
			<xsl:value-of select="format-number($cust/cnxx, '000')" />
			-
			<xsl:value-of select="format-number($cust/cline, '0000')" />
		</fo:block>		
		<fo:block>
			<fo:inline xsl:use-attribute-sets="category-label">Buyer's Address: </fo:inline>		                        
		</fo:block>
		<xsl:if test="normalize-space($cust/adln1)">
			<fo:block margin-left=".5in">
				<xsl:value-of select="$cust/adln1" />
			</fo:block>
		</xsl:if>
		<xsl:if test="normalize-space($cust/adln2)">
			<fo:block margin-left=".5in">
				<xsl:value-of select="$cust/adln2" />
			</fo:block>
		</xsl:if>
		<xsl:if test="normalize-space($cust/adln3)">
			<fo:block margin-left=".5in">
				<xsl:value-of select="$cust/adln3" />
			</fo:block>
		</xsl:if>
		<fo:block margin-left=".5in">
			<xsl:value-of select="$cust/adcity" />
			<xsl:value-of select="', '" />
			<xsl:value-of select="$cust/adst" />
			<xsl:value-of select="' '" />
			<xsl:value-of select="substring($cust/adzip, 1, 5)"/>
			<xsl:if test="substring($cust/adzip, 6, 4) != '0000' and substring($cust/adzip, 6, 4) != ''" >
				<xsl:value-of select="'-'"/>
				<xsl:value-of select="substring($cust/adzip, 6, 4)"/>
			</xsl:if>
		</fo:block>
	</fo:block-container>
	
	<fo:block-container absolute-position="fixed" left="4.25in" top="2.25in" width="2.5in" padding="5pt">
		<fo:block>
			<fo:inline xsl:use-attribute-sets="category-label">CSR: </fo:inline>		                        
			<xsl:value-of select="$install/username" />
		</fo:block>
		<fo:block>
			<fo:inline xsl:use-attribute-sets="category-label">Manufacturer / Model : </fo:inline>		                        
			<xsl:value-of select="$install/manu" />
			<xsl:value-of select="$install/model" />
		</fo:block>
		<fo:block space-before="10pt">
			<fo:inline xsl:use-attribute-sets="category-label"><xsl:value-of select="$seriallbl" /> : </fo:inline>		                        
			<xsl:value-of select="$install/invssn" />
		</fo:block>		
	</fo:block-container>
	
	<fo:block-container absolute-position="fixed" left="3cm" top="4.0in" width="6.25in">
		<fo:table table-layout="fixed">
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="6" color="black" text-align="center">
						<fo:block font-size="12pt">Federal Truth-In-Lending Disclosures</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block font-size="10pt" font-weight="bold" text-decoration="underline">Annual Percentage Rate</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block font-size="10pt" font-weight="bold" text-decoration="underline">Finance Charge</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block font-size="10pt">Amount Financed</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block font-size="10pt">Total of Payments</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block font-size="10pt">Total Down Payment</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block font-size="10pt">Total Sale Price</fo:block>
					</fo:table-cell>					
				</fo:table-row>
			</fo:table-header>						
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="10pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($install/instintrt, '##0.00 %')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="10pt" xsl:use-attribute-sets="summary-headings">
							<xsl:choose>
							<xsl:when test="(($calcpay * $install/origterm) - $install/beginbal) > 0.00">
								<xsl:value-of select="format-number((($calcpay * $install/origterm) - $install/beginbal), '$ ##,##0.00')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(0, '$ ##,##0.00')" />
							</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="10pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($install/beginbal, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="10pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($calcpay * $install/origterm, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="10pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($install/pitamt, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="10pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($install/beginbal + $install/pitamt, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="7pt">
							The cost of Buyer<fo:character character="&#8217;" />s credit as a yearly rate.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="7pt">
							The dollar amount the credit will cost Buyer.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell  color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="7pt">
							The amount of credit provided to Buyer or on Buyer<fo:character character="&#8217;" />s behalf.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell  color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="7pt">
							The amount Buyer will have paid after all payments have been made as scheduled.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell  color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="7pt">
							The Buyer<fo:character character="&#8217;" />s down payment.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell  color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="7pt">
							The total cost of Buyer<fo:character character="&#8217;" />s purchase on credit, including Buyer<fo:character character="&#8217;" />s down payment.
						</fo:block>
					</fo:table-cell>
				</fo:table-row>	
				<fo:table-row>
					<fo:table-cell color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings" number-columns-spanned="6">
						<fo:block space-before=".25in">
							YOUR PAYMENT SCHEDULE WILL BE:
						</fo:block>		
						<fo:block space-before=".10in">
							NUMBER OF PAYMENTS: 	                        
							<xsl:value-of select="format-number($install/origterm, '##0')" />
						</fo:block>		
						<xsl:choose>
							<xsl:when test="$install/itmrat = $lastpay">
								<fo:block>
									AMOUNT OF PAYMENT:                         
									<xsl:value-of select="format-number($install/itmrat, '$ ##,##0.00;$ -##,##0.00')" />
								</fo:block>		
							</xsl:when>
							<xsl:otherwise>
								<fo:block>
									AMOUNT OF PAYMENT: 	                        
									<xsl:value-of select="format-number($install/origterm - 1, '##0')" />
									MONTHS AT 	                        
									<xsl:value-of select="format-number($install/itmrat, '$ ##,##0.00;$ -##,##0.00')" />
								</fo:block>
								<fo:block>
									AMOUNT OF PAYMENT: 1 MONTH AT 	
									<xsl:value-of select="format-number(number($lastpay), '$ ##,##0.00;$ -##,##0.00')" /> 
								</fo:block>				
							</xsl:otherwise>
						</xsl:choose>
						<fo:block space-before="7pt">
							When Payments Are Due: 
							Payments are due monthly on the same day that payments for your wireless service are due.                        
						</fo:block>		
						<fo:block space-before="7pt">
							Late Charge: 
							Any payment not paid within ten days of when due, will be assessed a late charge of one and one half percent (1 <fo:character character="&#x00BD;" />%) of the amount of payment due up to a maximum of ten dollars (or five dollars if the payment due was less than twenty-five dollars)                       
						</fo:block>		
						<fo:block space-before="7pt">
							Prepayment: 
							If you pay off your debt early, you will not have to pay a penalty.  
						</fo:block>		
						<fo:block space-before="7pt">
							Additional information: 
							See this agreement for additional information about nonpayment, default, any required repayment in full before the scheduled date, and prepayment refunds and penalties.  
						</fo:block>									
					</fo:table-cell>
				</fo:table-row>								
				<fo:table-row>
					<fo:table-cell number-columns-spanned="6" border-width="0px">
						<fo:block space-before="15pt"><xsl:value-of select="' '" /></fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings" number-columns-spanned="6">
						<fo:block space-before=".25in">
							ITEMIZATION OF AMOUNT FINANCED:
						</fo:block>	
						<fo:block space-before=".10in">
							Purchase Price / Cash Sale Price:         
							<xsl:value-of select="format-number($install/beginbal + $install/pitamt, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>		
						<fo:block>
							Down Payment:
							<xsl:value-of select="format-number($install/pitamt, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>		
						<fo:block>
							Amount Financed / Difference: 	                        
							<xsl:value-of select="format-number($install/beginbal, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>		
					</fo:table-cell>				
				</fo:table-row>
			</fo:table-body>
		</fo:table>

	</fo:block-container>
	
	<fo:block break-before="page" />
	<fo:block-container absolute-position="fixed" width="8in" start-indent=".25in" top=".25in" >
		<fo:block xsl:use-attribute-sets="smallprint-8" space-before="15pt" font-size="10pt">By signing this Wireless Device Financing Agreement (the <fo:character character="&#8220;" />Agreement<fo:character character="&#8221;" />), you, the Buyer, choose to buy they Device identified above (the <fo:character character="&#8220;" />Device<fo:character character="&#8221;" />) on credit under the terms and conditions disclosed in this Agreement.  You agree to pay Northwest Missouri Cellular Limited Partnership (also, <fo:character character="&#8220;" />NorthwestCell,<fo:character character="&#8221;" /> <fo:character character="&#8220;" />We<fo:character character="&#8221;" /> or <fo:character character="&#8220;" />Us<fo:character character="&#8221;" />) the Amount Financed and any Finance Charge in U.S. funds according to the payment schedule above (the <fo:character character="&#8220;" />Monthly Device Charge<fo:character character="&#8221;" />).  The Truth-in-Lending Disclosures above are part of this Agreement, and by signing below you acknowledge receipt of these disclosures.</fo:block>		
		<fo:block xsl:use-attribute-sets="report-title" space-before="15pt" font-size="12pt" font-weight="bold" text-align="center">Important Terms - Please Read This</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">RESPONSIBLE PARTY.</fo:inline> As used herein, <fo:character character="&#8220;" />you<fo:character character="&#8221;" /> or <fo:character character="&#8220;" />Buyer<fo:character character="&#8221;" /> means an individual or a business entity that is the customer of record.  If you are an individual signing on behalf of an entity, you represent that you are authorized to sign on its behalf and, if it is determined that you are not so authorized, you understand and agree to be personally responsible for and guarantee payment of any sums that become due under this Agreement.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">SALES TAX.</fo:inline> Depending on the Device, you may be required to pay all applicable sales tax or similar taxes, fees or surcharges on the Device at time of purchase rather than financing these items.  </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">PAYMENTS.</fo:inline> Payments of the Monthly Device Charge are due as stated in the payment schedule disclosed above on the day that payment for your wireless service is due under the Terms and Conditions of your wireless service or, if applicable, your business agreement (the <fo:character character="&#8220;" />Service Agreement<fo:character character="&#8221;" />).  The Monthly Device Charge will appear on your monthly bill that you receive for service under your applicable service agreement with NorthwestCell for wireless voice and/or data service for the Device (the <fo:character character="&#8220;" />Service Agreement<fo:character character="&#8221;" />).  Payments that you make will be applied first to outstanding balances due under your Service Agreement, then to balances due under this Agreement, with any excess credited toward your next month<fo:character character="&#8217;" />s wireless service.  Once you have made all payments due under this Agreement, the Monthly Device Charge will no longer appear on your bill.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">LATE CHARGES.</fo:inline>  Any payment not paid within ten days of when due, will be assessed a late charge of one and one half percent (1 <fo:character character="&#x00BD;" />%) of the amount of payment due up to a maximum of ten dollars (or five dollars if the payment due was less than twenty-five dollars). </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">PREPAYMENT.</fo:inline> You may make early payments or you may pay the total amount due under this Agreement, without penalty, at any time before the final scheduled payment is due. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">BUYER ELIGIBILITY.</fo:inline> Device financing pursuant to this Agreement is available only to: (1) existing NorthwestCell consumer customers with a history of timely payments for at least six (6) months prior to entering into this Agreement; or, (2) new consumer customers with an acceptable credit history pursuant to NorthwestCell policies, as such policies may change from time-to-time.  Device financing is available only to customers with a postpaid service agreement with NorthwestCell. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">ELIGIBLE DEVICES.</fo:inline> All wireless handsets and devices may not be eligible for purchase through this Agreement.  For a list of eligible devices, please contact NorthwestCell. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">DEVICE FINANCING LIMIT PER ACCOUNT.</fo:inline> You may finance up to four (4) devices for each post-paid, consumer wireless account. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">RISK OF LOSS: INSURANCE.</fo:inline> You bear the entire risk of loss, theft, or damage to the Device from any cause during the entire term of this Agreement.  Even if the Device is lost, stolen, or damaged, you remain obligated for any outstanding payments due under this Agreement.  We recommend that you obtain property coverage on the Device.  You may obtain this property coverage from anyone you want.  NorthwestCell also offers handset coverage.  Please contact NorthwestCell for information about this protection. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">INDEMNITY.</fo:inline> You are responsible for any and all liabilities, losses, or damages, whether imposed on you or Us, which are directly attributable to you or any of your acts or omissions during the time the Device is in your possession.  This provision shall survive the termination of this Agreement.  To the extent permitted by law, you will reimburse Us for any expenses We incur in connection with the defense of any claim or action you are responsible for under this Agreement.  This includes, but is not limited to, actual and reasonable attorney<fo:character character="&#8217;" />s fees not to exceed fifteen percent (15%) of the amount of the loss, liability, or damage. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">DEFAULT.</fo:inline> You will be in default of this Agreement if any one of the following events (referred to as an <fo:character character="&#8220;" />event of default<fo:character character="&#8221;" />) occurs: (a) you fail to make any required payment when due or within ten (10) days of the due date; (b) you breach any covenant, representation, or warranty in this Agreement; (c) you default in the performance of any other obligation in this Agreement and such default continues for ten (10) days after We provide you with written notice of the default; (d) you are not eligible to finance a Device under this Agreement; or (e) you fail to maintain voice and/or data service (voice and data are both required for smartphone Devices) under a Service Agreement for the wireless Device covered by this Agreement, unless the Device is an iPad and you maintain another mobile service from Us that is billed on a monthly basis. </fo:block>
	</fo:block-container>
	<fo:block break-before="page" />
	<fo:block-container absolute-position="fixed" width="8in" start-indent=".25in" top=".25in" >
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">REMEDIES IN THE EVENT OF DEFAULT.</fo:inline> If you are in default of this Agreement and to the extent permitted by applicable law after We provide you notice and an opportunity to cure, We have the right to exercise any one or more of the following remedies: </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:character character="&#x2022;" /> Disable the Device<fo:character character="&#8217;" />s wireless network connectivity capabilities;</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:character character="&#x2022;" />	Require you to immediately pay the sum of the remaining unpaid Amount Financed; and</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:character character="&#x2022;" /> Require you to pay Us attorney and court cost fees if We file a suit for collection.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">ASSIGNMENT.</fo:inline> NorthwestCell may, without your consent and without notice to you, assign this Agreement.  You may not assign this Agreement or any interest in this Agreement without NorthwestCell<fo:character character="&#8217;" />s prior written consent. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">GOVERNING LAW.</fo:inline> The law of the state of Missouri shall govern this Agreement except to the extent that such law is preempted by or inconsistent with applicable federal law. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">ENGLISH LANGUAGE.</fo:inline> The original version of this Agreement is in the English language.  Any discrepancy or conflicts between the English version and any other language version will be resolved with reference to and by interpreting the English version. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">DISCLAIMER OF WARRANTIES/RETURN POLICY.</fo:inline> NorthwestCell makes no warranties of any kind, statutory, express or implied on the Device, and there will be no implied warranties of merchantability or of fitness for a particular purpose.  NorthwestCell has a limited return policy.  For information about our return policy and manufacturer's warranties, please contact NorthwestCell<fo:character character="&#8217;" />s customer service department or ask a sales representative for details. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt"><fo:inline color="black" font-weight="bold">NOTICE TO THE BUYER:</fo:inline></fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt">(1) DO NOT SIGN THIS CONTRACT BEFORE YOU READ IT OR IF IT CONTAINS ANY BLANK SPACES. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt">(2) YOU ARE ENTITLED TO AN EXACT COPY OF THE CONTRACT YOU SIGN.  </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="10pt" space-before="7.5pt">(3) UNDER THE LAW YOU HAVE THE RIGHT TO PAY OFF IN ADVANCE THE FULL AMOUNT DUE AND UNDER CERTAIN CIRCUMSTANCES TO OBTAIN A PARTIAL REFUND OF THE TIME CHARGE.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="12pt" space-before="15pt"><fo:inline color="black" font-weight="bold">I acknowledge that I have read this Agreement and have received a copy of this Agreement from NorthwestCell.</fo:inline></fo:block>	
	</fo:block-container>
	<fo:block-container absolute-position="fixed" left="2.8cm" top="10in" width="4in">
		<fo:block height="1.5in" space-before="0.5in">
			<xsl:value-of select="' Signature: '" />
			<fo:inline xsl:use-attribute-sets="summary-headings" border-bottom-style="solid" border-bottom-width="1px">
				<xsl:choose>
					<xsl:when test="$sigpng > ''">
						<fo:external-graphic src="data:image/png;base64,{$sigpng}" content-width="1.5in" content-height="auto" />
					</xsl:when>
					<xsl:when test="$sigimg > ''">
						<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="3.0in" content-height="auto" />
					</xsl:when>
					<xsl:otherwise>
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
					</xsl:otherwise>
				</xsl:choose>
			</fo:inline>
		</fo:block>
	</fo:block-container>
	<fo:block-container absolute-position="fixed" left="5in" top="10in" width="3in">
		<fo:block space-before="50px">
			<xsl:value-of select="' Date: '" /> 
			<xsl:value-of select="$install/schedate" />
		</fo:block>
	</fo:block-container> 
	
</xsl:template>

</xsl:stylesheet>






