<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:java="http://xml.apache.org/xslt/java" 
				exclude-result-prefixes="java" version="2.0">

    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
    <xsl:import href="subtemplates.xsl" />
    
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="concat('Catalog Item Changes ', $change_date[1], ' to ', $change_date[2])" />
	
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>
    
    <xsl:template name="body_process">
				<xsl:choose>
				<xsl:when test="/all_results/results[@name = 'data']/row">    
					<xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="unitid">
						<xsl:variable name="unitid" select="current-grouping-key()" />
						
						<fo:block xsl:use-attribute-sets="component-2" space-before="10px">
							<xsl:value-of select="'Item Description: '" />
							<xsl:value-of select="current-group()[position() = 1]/descr" />
						</fo:block>
						<fo:block xsl:use-attribute-sets="component-2">
							<xsl:value-of select="'Unit Code: '" />
							<xsl:value-of select="current-group()[position() = 1]/unitcode" />
						</fo:block>
						<fo:block xsl:use-attribute-sets="component-2">
							<xsl:value-of select="'Billing Id: '" />
							<xsl:value-of select="current-group()[position() = 1]/externalcd" />
						</fo:block>				
						
						<fo:table table-layout="fixed" width="100%" space-before="16px">
								<fo:table-column column-width="2in" />
								<fo:table-column column-width="2in" />
								<fo:table-column column-width="2in" />
								<fo:table-column column-width="2in" />
								<fo:table-column column-width="2in" />
								<fo:table-header>
										<fo:table-row keep-with-next="always">
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>Audit Time</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>Field</fo:block>
												</fo:table-cell>												
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>Before</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>After</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>Change By</fo:block>
												</fo:table-cell>
										</fo:table-row>
								</fo:table-header>
								<fo:table-body>
									<xsl:for-each select="/all_results/results[@name = 'data']/row[unitid = $unitid]">
										<fo:table-row keep-together="always">
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
												<fo:block>
													<xsl:value-of select="./audittime" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
												<fo:block wrap-option="wrap">
													<xsl:value-of select="./auditfield" />
												</fo:block>
												<xsl:if test="./audittname = 'IVPBOOK'" >
													<fo:block wrap-option="wrap" margin-left="5px">
														<xsl:value-of select="./pricetype" />
													</fo:block>
												</xsl:if>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
												<fo:block>
													<xsl:value-of select="./audbefore" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
												<fo:block wrap-option="wrap">
													<xsl:value-of select="./audafter" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
												<fo:block>
													<xsl:value-of select="./name" />
													<xsl:value-of select="' ('" />
													<xsl:value-of select="./uname" />
													<xsl:value-of select="')'" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
									</xsl:for-each>
								</fo:table-body>
						</fo:table>
					</xsl:for-each-group>
				</xsl:when>
				<xsl:otherwise>
						<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
							No Information Found
						</fo:block>		
				</xsl:otherwise>
				</xsl:choose>						
    </xsl:template>
</xsl:stylesheet>
