<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
			    xmlns:fo="http://www.w3.org/1999/XSL/Format" 
			    xmlns:date="http://exslt.org/dates-and-times" 
			    xmlns:saxon="http://saxon.sf.net/"
			    xmlns:java="http://xml.apache.org/xslt/java" 
			    xmlns:pos="java:com.psasoft.pos.util.POSUtil" 
			    extension-element-prefixes="date" 
			    exclude-result-prefixes="java" 
			    version="2.0">
	<!-- ====================================================================== Sales Invoice Templates ======================================================================= -->
	<xsl:template name="invoice_header">
		<xsl:param name="company" />
		<xsl:param name="cust" />
		<xsl:param name="poshdr" />
		<xsl:param name="logo" />
		<xsl:param name="location" />
		<xsl:param name="udf" />
		<xsl:choose>
			<xsl:when test="not($company)">
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px"> No Company Information Found
				</fo:block>
			</xsl:when>
			<xsl:when test="not($cust)">
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px"> No Customer Information Found
				</fo:block>
			</xsl:when>
			<xsl:when test="not($poshdr)">
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px"> No Invoice Information Found
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:table font-size="8pt">
					<fo:table-column column-width="2.5in" />
					<fo:table-column column-width="2.5in" />
					<fo:table-column column-width="2.5in" />
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="report-title">
									<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="2.0in" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<!--  
								<fo:block xsl:use-attribute-sets="summary-headings" space-before="-5px">
									<xsl:value-of select="$company/coname" />
								</fo:block>
								-->
								<fo:block xsl:use-attribute-sets="summary-headings" space-before="-5px">
									<xsl:value-of select="$company/addr1" />
								</fo:block>
								<xsl:if test="normalize-space($company/addr2) > ''">
									<fo:block xsl:use-attribute-sets="summary-headings" space-before="-5px">
										<xsl:value-of select="$company/addr2" />
									</fo:block>
								</xsl:if>
								<xsl:if test="normalize-space($company/addr3) > ''">
									<fo:block xsl:use-attribute-sets="summary-headings" space-before="-5px">
										<xsl:value-of select="$company/addr3" />
									</fo:block>
								</xsl:if>
								<fo:block xsl:use-attribute-sets="summary-headings" space-before="-5px" space-after="12px">
									<xsl:value-of select="normalize-space($company/adcity)" />
									<xsl:if test="normalize-space($company/adcity) &gt; '' ">
										<xsl:value-of select="', '" />
									</xsl:if>
									<xsl:value-of select="$company/adst" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="substring($company/adzip, 1, 5)" />
									<xsl:if test="substring($company/adzip, 6, 4) != '0000' and substring($company/adzip, 6, 4) != ''">
										<xsl:value-of select="'-'" />
										<xsl:value-of select="substring($company/adzip, 6, 4)" />
									</xsl:if>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="category-label">Invoice :</fo:block>
								<fo:block xsl:use-attribute-sets="summary-headings">
									<xsl:choose>
										<xsl:when test="$poshdr/billrecordid &gt; 0">
											<xsl:value-of select="$poshdr/billrecordid" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="$poshdr/invid" />
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<xsl:if test="$customerCode != 'broad'">						
							<fo:table-row>
								<fo:table-cell number-columns-spanned="2">
									<fo:block xsl:use-attribute-sets="category-label">Sold At :</fo:block>
									<fo:block>
										<xsl:value-of select="$location" />
									</fo:block>
									<xsl:if test="normalize-space($company/line1)">
										<fo:block>
											<xsl:value-of select="$company/line1" />
										</fo:block>
									</xsl:if>
									<xsl:if test="normalize-space($company/line2)">
										<fo:block>
											<xsl:value-of select="$company/line2" />
										</fo:block>
									</xsl:if>
									<xsl:if test="normalize-space($company/line3)">
										<fo:block>
											<xsl:value-of select="$company/line3" />
										</fo:block>
									</xsl:if>
									<xsl:if test="normalize-space($company/city) or normalize-space($company/state) or normalize-space($company/zip) != '0'">
										<fo:block>
											<xsl:value-of select="$company/city" />
											<xsl:if test="normalize-space($company/adcity) &gt; '' ">
												<xsl:value-of select="', '" />
											</xsl:if>
											<xsl:value-of select="$company/state" />
											<xsl:value-of select="' '" />
											<xsl:value-of select="$company/zip" />
										</fo:block>
									</xsl:if>
								</fo:table-cell>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="category-label">
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</xsl:if>
						<fo:table-row height="14px">
							<fo:table-cell number-columns-spanned="3">
								<fo:block>
									<xsl:value-of select="' '" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell number-columns-spanned="2">
								<fo:block xsl:use-attribute-sets="category-label">Sold To :</fo:block>
								<xsl:choose>
									<xsl:when test="$poshdr/ptcyc = 0 and $poshdr/ptacct = 0">
										<fo:block>
											<xsl:value-of select="$poshdr/fullnm" />
										</fo:block>
										<xsl:if test="normalize-space($poshdr/altadr1)">
											<fo:block>
												<xsl:value-of select="$poshdr/altadr1" />
											</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($poshdr/altadr2)">
											<fo:block>
												<xsl:value-of select="$poshdr/altadr2" />
											</fo:block>
										</xsl:if>
										<fo:block>
											<xsl:value-of select="$poshdr/altadct" />
											<xsl:value-of select="', '" />
											<xsl:value-of select="$poshdr/altadst" />
											<xsl:value-of select="' '" />
											<xsl:value-of select="substring($poshdr/altadzp, 1, 5)" />
											<xsl:if test="substring($poshdr/altadzp, 6, 4) != '0000' and substring($poshdr/altadzp, 6, 4) != ''">
												<xsl:value-of select="'-'" />
												<xsl:value-of select="substring($poshdr/altadzp, 6, 4)" />
											</xsl:if>
											<xsl:if test="$poshdr/altadcu != ''">
												<xsl:value-of select="' '" />
												<xsl:value-of select="$poshdr/altadcu" />
											</xsl:if>
										</fo:block>
									</xsl:when>
									<xsl:otherwise>
										<fo:block>
											<xsl:value-of select="format-number($poshdr/ptcyc, '000')" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number($poshdr/ptacct, '0000000')" />
										</fo:block>
										<fo:block>
											<xsl:value-of select="normalize-space($cust/fname)" />
											<xsl:value-of select="' '" />
											<xsl:value-of select="normalize-space($cust/lname)" />
										</fo:block>
										<xsl:if test="normalize-space($cust/adln1)">
											<fo:block>
												<xsl:value-of select="$cust/adln1" />
											</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($cust/adln2)">
											<fo:block>
												<xsl:value-of select="$cust/adln2" />
											</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($cust/adln3)">
											<fo:block>
												<xsl:value-of select="$cust/adln3" />
											</fo:block>
										</xsl:if>
										<fo:block>
											<xsl:value-of select="normalize-space($cust/adcity)" />
											<xsl:value-of select="', '" />
											<xsl:value-of select="$cust/adst" />
											<xsl:value-of select="' '" />
											<xsl:value-of select="substring($cust/adzip, 1, 5)" />
											<xsl:if test="substring($cust/adzip, 6, 4) != '0000' and substring($cust/adzip, 6, 4) != ''">
												<xsl:value-of select="'-'" />
												<xsl:value-of select="substring($cust/adzip, 6, 4)" />
											</xsl:if>
										</fo:block>
									</xsl:otherwise>
								</xsl:choose>
							</fo:table-cell>
							<fo:table-cell>
								<xsl:choose>
									<xsl:when test="$poshdr/ptcyc = 0 and $poshdr/ptacct = 0">
										<xsl:if test="$poshdr/altph1 > 0">
											<fo:block>
												<fo:inline xsl:use-attribute-sets="category-label">Phone # : </fo:inline>
												<xsl:value-of select="format-number(number(substring($poshdr/altph1, 1, 3)), '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(number(substring($poshdr/altph1, 4, 3)), '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(number(substring($poshdr/altph1, 7, 4)), '0000')" />
											</fo:block>
										</xsl:if>
										<xsl:if test="$poshdr/altph2 > 0">
											<fo:block>
												<fo:inline xsl:use-attribute-sets="category-label">Alternate Phone # : </fo:inline>
												<xsl:value-of select="format-number(number(substring($poshdr/altph2, 1, 3)), '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(number(substring($poshdr/altph2, 4, 3)), '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(number(substring($poshdr/altph2, 7, 4)), '0000')" />
											</fo:block>
										</xsl:if>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="normalize-space($cust/esn) != '0'">
											<fo:block>
												<fo:inline xsl:use-attribute-sets="category-label">ESN : </fo:inline>
												<xsl:value-of select="$cust/esn" />
											</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($cust/meid) != ''">
											<fo:block>
												<fo:inline xsl:use-attribute-sets="category-label">MEID : </fo:inline>
												<xsl:value-of select="$cust/meid" />
											</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($cust/srno)">
											<fo:block>
												<fo:inline xsl:use-attribute-sets="category-label">Serial # : </fo:inline>
												<xsl:value-of select="$cust/srno" />
											</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($cust/sim) != '0 0 0'">
											<fo:block>
												<fo:inline xsl:use-attribute-sets="category-label">SIM : </fo:inline>
												<xsl:value-of select="$cust/sim" />
											</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($cust/imei) != '0'">
											<fo:block>
												<fo:inline xsl:use-attribute-sets="category-label">IMEI : </fo:inline>
												<xsl:value-of select="$cust/imei" />
											</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($cust/ip) != ''">
											<fo:block>
												<fo:inline xsl:use-attribute-sets="category-label">IP : </fo:inline>
												<xsl:value-of select="$cust/ip" />
											</fo:block>
										</xsl:if>
										<fo:block>
											<fo:inline xsl:use-attribute-sets="category-label">Phone # : </fo:inline>
											<xsl:value-of select="format-number($cust/cnpa, '000')" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number($cust/cnxx, '000')" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number($cust/cline, '0000')" />
										</fo:block>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:if test="normalize-space($cust/ppacct) = 'Y'">
									<fo:block>
										<fo:inline xsl:use-attribute-sets="category-label">Due Date : </fo:inline>
										<xsl:value-of select="$cust/pduedt" />
									</fo:block>
								</xsl:if>
								<xsl:if test="$customerCode = 'broad'">
									<fo:block>
										<fo:inline xsl:use-attribute-sets="category-label">Terms : </fo:inline>
										<xsl:value-of select="$cust/terms" />
										<fo:inline> Days</fo:inline>
									</fo:block>
									<fo:block>
										<fo:inline xsl:use-attribute-sets="category-label">Invoice Due Date : </fo:inline>
										<xsl:value-of select="$cust/duedate" />
									</fo:block>
									<fo:block space-before="10px">
										<fo:inline xsl:use-attribute-sets="category-label">Job No : </fo:inline>
										<xsl:value-of select="$poshdr/altadr1" />
									</fo:block>
									<fo:block>
										<fo:inline xsl:use-attribute-sets="category-label">FWT No : </fo:inline>
										<xsl:value-of select="$poshdr/altadr2" />
									</fo:block>			
									<fo:block space-before="10px" space-after="5px">
										<fo:inline xsl:use-attribute-sets="category-label">Site Information : </fo:inline>
									</fo:block>
									<xsl:for-each select="$udf">
										<fo:block>
											<fo:inline xsl:use-attribute-sets="category-label"><xsl:value-of select="./udftext" /> : </fo:inline>
											<xsl:value-of select="./udfentry" />
										</fo:block>			
									</xsl:for-each>
								</xsl:if>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row height="14px">
							<fo:table-cell number-columns-spanned="3">
								<fo:block>
									<xsl:value-of select="' '" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="category-label">Date :</fo:block>
								<fo:block>
									<xsl:value-of select="format-number($poshdr/ptrmm, '00')" />
									<xsl:value-of select="'/'" />
									<xsl:value-of select="format-number($poshdr/ptrdd, '00')" />
									<xsl:value-of select="'/'" />
									<xsl:value-of select="format-number($poshdr/ptrcc, '00')" />
									<xsl:value-of select="format-number($poshdr/ptryy, '00')" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="category-label">Salesperson :</fo:block>
								<fo:block>
									<xsl:value-of select="$poshdr/ptrusr" />
									<fo:inline>
										<xsl:value-of select="' ('" />
										<xsl:value-of select="normalize-space($poshdr/drwnam)" />
										<xsl:value-of select="')'" />
									</fo:inline>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block>
									<xsl:value-of select="' '" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="invoice_body">
		<xsl:param name="poshdr" />
		<xsl:param name="posdtl" />
		<xsl:param name="posdtlsum" />
		<xsl:param name="footer" />
		<xsl:choose>
			<xsl:when test="not($poshdr)">
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px"> No Invoice Information Found
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$posdtlsum[bill != 'Y']">
					<xsl:call-template name="invoice_body_sub">
						<xsl:with-param name="poshdr" select="$poshdr" />
						<xsl:with-param name="posdtl" select="$posdtl[bill != 'Y']" />
						<xsl:with-param name="posdtlsum" select="$posdtlsum[bill != 'Y']" />
						<xsl:with-param name="bill" select="'N'" />
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="exists(/all_results/results[@name = 'taxsum']/row[bill != 'Y'])">
					<xsl:call-template name="tax_summary">
						<xsl:with-param name="heading" select="'Tax Summary'" />
						<xsl:with-param name="taxsum" select="/all_results/results[@name = 'taxsum']/row[bill != 'Y']" />
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="$posdtlsum[bill = 'Y']">
					<fo:block xsl:use-attribute-sets="category-label" space-before="14px" keep-with-next="always">Bill on Account :</fo:block>
					<xsl:call-template name="invoice_body_sub">
						<xsl:with-param name="poshdr" select="$poshdr" />
						<xsl:with-param name="posdtl" select="$posdtl[bill = 'Y']" />
						<xsl:with-param name="posdtlsum" select="$posdtlsum[bill = 'Y']" />
						<xsl:with-param name="bill" select="'Y'" />
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="exists(/all_results/results[@name = 'install']/row)">
					<xsl:call-template name="installment">
						<xsl:with-param name="heading" select="'Installment'" />
						<xsl:with-param name="install" select="/all_results/results[@name = 'install']/row" />
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="exists(/all_results/results[@name = 'taxsum']/row[bill = 'Y'])">
					<xsl:call-template name="tax_summary">
						<xsl:with-param name="heading" select="'Billed Tax Summary'" />
						<xsl:with-param name="taxsum" select="/all_results/results[@name = 'taxsum']/row[bill = 'Y']" />
					</xsl:call-template>
				</xsl:if>
				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<fo:table-column column-width="4in" />
					<fo:table-column column-width="4in" />
					<fo:table-body>
						<fo:table-row keep-with-previous="always">
							<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="left">
								<fo:block space-before="50px">
									<xsl:value-of select="'  '" />
									<!-- <xsl:value-of select="' Date: _______________________________________________ '" /> -->
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="left">
								<xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CREDT']/totamt != 0">
									<fo:block space-before="100px">
										<xsl:value-of select="' I agree to pay above total amount according to '" />
									</fo:block>
									<fo:block space-after="50px">
										<xsl:value-of select="' card issuer agreement. '" />
									</fo:block>
								</xsl:if>
								<fo:block height="1.5in">
									<xsl:value-of select="' Signature: '" />
									<fo:inline xsl:use-attribute-sets="summary-headings" border-bottom-style="solid" border-bottom-width="1px">
										<xsl:choose>
											<xsl:when test="$sigpng > ''">
												<fo:external-graphic src="data:image/png;base64,{$sigpng}" content-width="1.5in" content-height="auto" />
											</xsl:when>
											<xsl:when test="$sigimg > ''">
												<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="3.0in" content-height="1.00in" />
											</xsl:when>
											<xsl:otherwise>
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<fo:character character="&#x2000;" />
												<!-- xsl:value-of select="' _______________________________________________ '" / -->
											</xsl:otherwise>
										</xsl:choose>
									</fo:inline>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
				<xsl:if test="$customerCode = 'broad'">
					<fo:block xsl:use-attribute-sets="table-cells-black" border-style="none" wrap-option="wrap" space-before="1in">
						Remittance: PO Box 677988, Dallas TX 75267-7988
					</fo:block>
					<fo:block xsl:use-attribute-sets="table-cells-black" border-style="none" wrap-option="wrap" space-before="3px">
						Inquiries: 866-621-5289 or customercare@tampnet.com
					</fo:block>
					<fo:block xsl:use-attribute-sets="table-cells-black" border-style="none" wrap-option="wrap" space-before="3px">
						Thank you for your business.
					</fo:block>
				</xsl:if>
				<xsl:if test="normalize-space($footer) &gt; ''">
					<fo:block xsl:use-attribute-sets="table-cells-black" border-style="none" wrap-option="wrap" space-before="1in">
						<xsl:copy-of select="$footer" />
					</fo:block>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="installment">
		<xsl:param name="heading" />
		<xsl:param name="install" />
		<xsl:variable name="calcpay" select="pos:calculateInstallmentsPaymentReport(number($install/beginbal), number($install/origterm), number($install/instintrt), 10)" />
		<xsl:variable name="lastpay">
			<xsl:choose>
				<xsl:when test="$install/itmrat &lt;= ''">
					<xsl:value-of select="0" />
				</xsl:when>
				<xsl:when test="($install/itmrat * $install/origterm) = ($calcpay * $install/origterm)">
					<xsl:value-of select="$install/itmrat" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="($calcpay * $install/origterm) - ($install/itmrat * ($install/origterm - 1))" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<fo:block xsl:use-attribute-sets="category-label" space-before="14px">
			<xsl:value-of select="$heading" />
			<xsl:value-of select="': '" />
		</fo:block>
		<fo:table table-layout="fixed" width="60%" space-before="8px">
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Equipment Serial</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Initial Paid</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Amount on Installment</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Payments</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Last Payment</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="$install">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="left">
							<fo:block>
								<xsl:value-of select="$install/invssn" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./pitamt, '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./beginbal, '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./origterm - 1, '##0')" />
								<xsl:value-of select="' @ ' " />
								<xsl:choose>
									<xsl:when test="$install/itmrat &lt;= ''">
										<xsl:value-of select="'n/a'" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="format-number(./itmrat, '$ ##,##0.00;$ -##,##0.00')" />
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="'1 @ ' " />
								<xsl:value-of select="format-number(number($lastpay), '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<xsl:template name="tax_summary">
		<xsl:param name="heading" />
		<xsl:param name="taxsum" />
		<fo:block xsl:use-attribute-sets="category-label" space-before="14px">
			<xsl:value-of select="$heading" />
			<xsl:value-of select="': '" />
		</fo:block>
		<fo:table table-layout="fixed" width="60%" space-before="8px">
			<fo:table-column column-width="2in" />
			<fo:table-column column-width="1in" />
			<fo:table-body>
				<xsl:for-each select="$taxsum">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" text-align="left">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./taxcode = '$$FD'">
										<xsl:value-of select="'Federal Tax'" />
									</xsl:when>
									<xsl:when test="./taxcode = '$$ST'">
										<xsl:value-of select="'State Tax'" />
									</xsl:when>
									<xsl:when test="./taxcode = '$$CN'">
										<xsl:value-of select="'County Tax'" />
									</xsl:when>
									<xsl:when test="./taxcode = '$$CT'">
										<xsl:value-of select="'City Tax'" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:variable name="taxcd" select="./taxcode" />
										<xsl:variable name="county" select="/all_results/results[@name = 'cust']/row/cncd" />
										<xsl:choose>
											<xsl:when test="/all_results/results[@name = 'taxmst']/row[mtaxcd = $taxcd and mtcncd = $county]/mtaxds">
												<xsl:value-of select="/all_results/results[@name = 'taxmst']/row[mtaxcd = $taxcd and mtcncd = $county]/mtaxds" />
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="/all_results/results[@name = 'taxmst']/row[mtaxcd = $taxcd]/mtaxds" />
											</xsl:otherwise>
										</xsl:choose>
										<xsl:value-of select="' ('" />
										<xsl:value-of select="$taxcd" />
										<xsl:value-of select="')'" />
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./totaltax, '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
				<fo:table-row keep-with-previous="always">
					<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" text-align="left">
						<fo:block>
							<xsl:value-of select="'Total Tax'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum($taxsum/totaltax), '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<xsl:template name="invoice_body_sub">
		<xsl:param name="poshdr" />
		<xsl:param name="posdtl" />
		<xsl:param name="posdtlsum" />
		<xsl:param name="bill" />
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="1.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.80in" />
			<fo:table-column column-width="0.80in" />
			<fo:table-column column-width="0.80in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Source</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Description</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Quantity</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Amount</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Tax Amount</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Cost</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="$posdtlsum[ptrtyp != 'TENDERED']">
					<xsl:variable name="itemid" select="./itemid" />
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="left">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./ptrtyp = 'PURCHASE'">
										<xsl:value-of select="'Purchase'" />
									</xsl:when>
									<xsl:when test="./ptrtyp = 'ACCOUNT'">
										<xsl:value-of select="'Account Item'" />
									</xsl:when>
									<xsl:when test="./ptrtyp = 'SERVICE'">
										<xsl:value-of select="'Service Item'" />
									</xsl:when>
									<xsl:when test="./ptrtyp = 'MISC'">
										<xsl:value-of select="'Adjustment'" />
									</xsl:when>
									<xsl:when test="./ptrtyp = 'RETURN'">
										<xsl:value-of select="'Return'" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="./ptrtyp" />
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="center">
							<fo:block>
								<xsl:value-of select="./itemid" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="left">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./itemdesc &gt; ''">
										<xsl:value-of select="./itemdesc" />
									</xsl:when>
									<xsl:when test="./ptrtyp = 'PAYMENT' and ./pitamt &lt; 0">
										Return on Account
									</xsl:when>
									<xsl:when test="./ptrtyp = 'PAYMENT'">
										Payment on Account
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="./itemid" />
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
							<xsl:if test="./spdesc != ''">
								<fo:block>
									<xsl:value-of select="./spdesc" />
								</fo:block>
							</xsl:if>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./serial2typ = '51'">
										<xsl:value-of select="format-number(./totqty, '##,##0.00')" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="format-number(./totqty, '##,##0')" />
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./pitamt, '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./itemtax, '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number((./totamt + ./totaltax), '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<xsl:variable name="serialno">
						<xsl:for-each select="$posdtl[itemid = $itemid]">
							<fo:inline space-end="0.2in" space-start.precedence="force">
								<xsl:call-template name="formatserial">
									<xsl:with-param name="serial" select="./invssn" />
									<xsl:with-param name="serial0" select="./serialno" />
									<xsl:with-param name="serial2typ" select="./serial2typ" />
									<xsl:with-param name="unitid" select="./unitid" />
									<xsl:with-param name="actpin" select="./actpin" />
									<xsl:with-param name="npa" select="./npa" />
									<xsl:with-param name="nxx" select="./nxx" />
									<xsl:with-param name="line" select="./line" />
								</xsl:call-template>
								<xsl:value-of select="' '" />
							</fo:inline>
						</xsl:for-each>
					</xsl:variable>
					<xsl:if test="normalize-space($serialno)">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells-black">
								<fo:block>
									<xsl:value-of select="' '" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-black" keep-with-previous="always" text-align="left" number-columns-spanned="6">
								<fo:block>
									<fo:inline>
										<xsl:value-of select="' '" />
									</fo:inline>
									<fo:block space-start="auto" space-start.precedence="force">
										<xsl:value-of select="$serialno" />
									</fo:block>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:if>
				</xsl:for-each>
				<xsl:if test="$bill = 'N'">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="6">
							<fo:block>
								<xsl:value-of select="' Amount Due '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(sum($posdtlsum[ptrtyp != 'TENDERED' and bill != 'Y']/totamt) + sum($posdtlsum[ptrtyp != 'TENDERED' and bill != 'Y']/totaltax), '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
				<!-- <xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CASH']/totamt != 0"> <fo:table-row keep-with-previous="always"> <fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" 
					font-weight="bold" text-align="right" number-columns-spanned="6"> <fo:block> <xsl:choose> <xsl:when test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CREDT']/totamt &lt; 0"> <xsl:value-of select="' Returned 
					Cash '" /> </xsl:when> <xsl:otherwise> <xsl:value-of select="' Paid Cash '" /> </xsl:otherwise> </xsl:choose> </fo:block> <xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CASH']/spdesc != ''"> 
					<fo:block> <xsl:value-of select="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CASH']/spdesc" /> </fo:block> </xsl:if> </fo:table-cell> <fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right"> 
					<fo:block> <xsl:value-of select="format-number($posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CASH']/totamt, '$ ##,##0.00;$ -##,##0.00')" /> </fo:block> </fo:table-cell> </fo:table-row> </xsl:if> <xsl:if 
					test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHECK']/totamt != 0"> <fo:table-row keep-with-previous="always"> <fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" 
					text-align="right" number-columns-spanned="6"> <fo:block> <xsl:value-of select="' Paid Check #'" /> <xsl:value-of select="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHECK']/payref" /> <xsl:value-of select="' 
					'" /> </fo:block> <xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHECK']/spdesc != ''"> <fo:block> <xsl:value-of select="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHECK']/spdesc" /> </fo:block> 
					</xsl:if> </fo:table-cell> <fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right"> <fo:block> <xsl:value-of select="format-number($posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHECK']/totamt, 
					'$ ##,##0.00;$ -##,##0.00')" /> </fo:block> </fo:table-cell> </fo:table-row> </xsl:if> -->
				<xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CREDT']/totamt != 0">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="6">
							<fo:block>
								<xsl:choose>
									<xsl:when test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CREDT']/totamt &lt; 0">
										<xsl:value-of select="' Returned To Credit Card '" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="' Paid Credit Card '" />
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
							<xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CREDT']/spdesc != ''">
								<fo:block>
									<xsl:value-of select="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CREDT']/spdesc" />
								</fo:block>
							</xsl:if>
							<xsl:if test="$poshdr/cctype != ''">
								<fo:block>
									<xsl:value-of select="$poshdr/cctype" />
									<xsl:value-of select="', '" />
									<xsl:choose>
										<xsl:when test="$poshdr/cctype = 'AMER'">
											<xsl:value-of select="'****-******-*'" />
											<xsl:value-of select="$poshdr/ccnumb" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="'****-****-****-'" />
											<xsl:value-of select="$poshdr/ccnumb" />
										</xsl:otherwise>
									</xsl:choose>
									<xsl:value-of select="', exp '" />
									<xsl:value-of select="format-number($poshdr/ccexpmm, '00')" />
									<xsl:value-of select="'/'" />
									<xsl:value-of select="format-number($poshdr/ccexpyy, '0000')" />
								</fo:block>
								<fo:block>
									<xsl:value-of select="$poshdr/rsptext" />
									<xsl:value-of select="' '" />
								</fo:block>
								<fo:block>
									<xsl:if test="normalize-space($poshdr/transid)">
										<xsl:value-of select="'Trans ID# '" />
										<xsl:value-of select="$poshdr/transid" />
										<xsl:value-of select="' '" />
									</xsl:if>
									<xsl:if test="normalize-space($poshdr/authcode)">
										<xsl:value-of select="'Auth# '" />
										<xsl:value-of select="$poshdr/authcode" />
										<xsl:value-of select="' '" />
									</xsl:if>
									<xsl:if test="normalize-space($poshdr/rsptrace)">
										<xsl:value-of select="'Ref# '" />
										<xsl:value-of select="$poshdr/rsptrace" />
										<xsl:value-of select="' '" />
									</xsl:if>
								</fo:block>
							</xsl:if>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CREDT']/totamt, '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
				<xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid != 'CREDT']">
					<xsl:for-each select="$posdtlsum[ptrtyp = 'TENDERED' and itemid != 'CREDT' and itemid != 'CHNGE']">
						<fo:table-row keep-with-previous="always">
							<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="6">
								<fo:block>
									<xsl:choose>
										<xsl:when test="./totamt &lt; 0">
											<xsl:value-of select="' Returned '" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="' Paid '" />
										</xsl:otherwise>
									</xsl:choose>
									<xsl:value-of select="./tendereddesc" />
								</fo:block>
								<xsl:if test="./payref != ''">
									<fo:block>
										<xsl:value-of select="' Reference: '" />
										<xsl:value-of select="./payref" />
									</fo:block>
								</xsl:if>
								<xsl:if test="./spdesc != ''">
									<fo:block>
										<xsl:value-of select="./spdesc" />
									</fo:block>
								</xsl:if>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./totamt, '$ ##,##0.00;$ -##,##0.00')" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</xsl:if>
				<xsl:if test="sum($posdtlsum[ptrtyp = 'MISC' and bill = 'Y']/totamt) != 0">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="6">
							<fo:block>
								<xsl:value-of select="'Adjustment On Account '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(sum($posdtlsum[ptrtyp = 'MISC' and bill = 'Y']/totamt) + sum($posdtlsum[ptrtyp = 'MISC' and bill = 'Y']/totaltax), '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
				<xsl:if test="sum($posdtlsum[ptrtyp = 'PURCHASE' and bill = 'Y']/totamt) &gt; 0">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="6">
							<fo:block>
								<xsl:value-of select="'Purchase On Account '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(sum($posdtlsum[ptrtyp = 'PURCHASE' and bill = 'Y']/totamt) + sum($posdtlsum[ptrtyp = 'PURCHASE' and bill = 'Y']/totaltax), '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
				<xsl:if test="sum($posdtlsum[ptrtyp = 'PURCHASE' and bill = 'Y']/totamt) &lt; 0">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="6">
							<fo:block>
								<xsl:value-of select="'Return On Account '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(sum($posdtlsum[ptrtyp = 'PURCHASE' and bill = 'Y']/totamt) + sum($posdtlsum[ptrtyp = 'PURCHASE' and bill = 'Y']/totaltax), '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
				<xsl:if test="sum($posdtlsum[ptrtyp = 'RETURN' and bill = 'Y']/totamt) != 0">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="6">
							<fo:block>
								<xsl:value-of select="'Return On Account '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(sum($posdtlsum[ptrtyp = 'RETURN' and bill = 'Y']/totamt) + sum($posdtlsum[ptrtyp != 'TENDERED' and bill = 'Y']/totaltax), '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
				<!-- <xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'MISC']/totamt != 0"> <fo:table-row keep-with-previous="always"> <fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" 
					font-weight="bold" text-align="right" number-columns-spanned="6"> <fo:block> <xsl:value-of select="' Miscellaneous Tendered '" /> </fo:block> <xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'MISC']/spdesc 
					!= ''"> <fo:block> <xsl:value-of select="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'MISC']/spdesc" /> </fo:block> </xsl:if> </fo:table-cell> <fo:table-cell xsl:use-attribute-sets="table-cells-black" 
					text-align="right"> <fo:block> <xsl:value-of select="format-number($posdtlsum[ptrtyp = 'TENDERED' and itemid = 'MISC']/totamt, '$ ##,##0.00;$ -##,##0.00')" /> </fo:block> </fo:table-cell> </fo:table-row> 
					</xsl:if> -->
				<xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHNGE']/totamt != 0">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="6">
							<fo:block>
								<xsl:value-of select="' Change '" />
							</fo:block>
							<xsl:if test="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHNGE']/spdesc != ''">
								<fo:block>
									<xsl:value-of select="$posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHNGE']/spdesc" />
								</fo:block>
							</xsl:if>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHNGE']/totamt, '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
				<xsl:variable name="remaining"
					select="format-number(sum($posdtlsum[ptrtyp != 'TENDERED' and bill != 'Y']/totamt) + sum($posdtlsum[ptrtyp != 'TENDERED' and bill != 'Y']/totaltax) - sum($posdtlsum[ptrtyp = 'TENDERED' and itemid != 'CHNGE']/totamt) + sum($posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHNGE']/totamt), '####0.00')" />
				<xsl:if test="$remaining != '0.00' and $remaining != '-0.00'">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="6">
							<fo:block>
								<xsl:value-of select="' Remaining Amount Due '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="right">
							<fo:block>
								<xsl:value-of
									select="format-number(sum($posdtlsum[ptrtyp != 'TENDERED' and bill != 'Y']/totamt) + sum($posdtlsum[ptrtyp != 'TENDERED' and bill != 'Y']/totaltax) - sum($posdtlsum[ptrtyp = 'TENDERED' and itemid != 'CHNGE']/totamt) + sum($posdtlsum[ptrtyp = 'TENDERED' and itemid = 'CHNGE']/totamt), '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
				<xsl:if test="not(exists(/all_results/results[@name = 'taxsum']/row)) and sum($posdtlsum/totaltax) != 0">
					<fo:table-row keep-with-previous="always">
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right">
							<fo:block>
								<xsl:value-of select="' Total Tax '" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(sum($posdtlsum/totaltax), '$ ##,##0.00;$ -##,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-black" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="5">
							<fo:block>
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
			</fo:table-body>
		</fo:table>
	</xsl:template>
</xsl:stylesheet>