<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:exsl="http://exslt.org/functions" 
								xmlns:set="http://exslt.org/sets" 
								extension-element-prefixes="exsl" 
								version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="'Invoice'" />
    <xsl:variable name="name" select="/all_results/results[@name = 'company']/row/addr1" />
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set" />
            <xsl:call-template name="make-body" />
        </fo:root>
    </xsl:template>
    <xsl:template name="body_process">
        <xsl:variable name="invid" select="." />
        <xsl:variable name="rcvname" select="''" />
        <xsl:variable name="rowcount" select="'1'" />
        <xsl:if test="position() &gt; 1">
            <fo:block break-after="page" />
        </xsl:if>
        <fo:table font-size="8pt">
        		<fo:table-column column-width="2.5in" />
            <fo:table-column column-width="2.5in" />
            <fo:table-column column-width="2.5in" />
            <fo:table-body>
                <fo:table-row>
                    <fo:table-cell>
                   		<fo:block xsl:use-attribute-sets="report-title">
                   				<fo:external-graphic src="url(companylogo.gif)" content-height="auto" content-width="2.0in" />
                   		</fo:block>
                    </fo:table-cell>                
                    <fo:table-cell>
                        <fo:block xsl:use-attribute-sets="category-label">Main Office : </fo:block>
                        <fo:block xsl:use-attribute-sets="summary-headings">
                            <xsl:value-of select="/all_results/results[@name = 'company']/row/addr1" />
                        </fo:block>
                        <fo:block xsl:use-attribute-sets="summary-headings">
                            <xsl:value-of select="/all_results/results[@name = 'company']/row/addr2" />
                        </fo:block>
                        <fo:block xsl:use-attribute-sets="summary-headings" space-after="12px">
                            <xsl:value-of select="/all_results/results[@name = 'company']/row/addr3" />
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell>
                        <fo:block xsl:use-attribute-sets="category-label">Invoice : </fo:block>
                        <fo:block xsl:use-attribute-sets="summary-headings">
                            <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/invid, '00000000000000')" />
                        </fo:block>
                    </fo:table-cell>
                </fo:table-row>
                <fo:table-row>
                    <fo:table-cell>
                        <fo:block xsl:use-attribute-sets="category-label">Sold At : </fo:block>
                        <fo:block xsl:use-attribute-sets="summary-headings">
                            <xsl:value-of select="/all_results/results[@name = 'company']/row/subloc1" />
                        </fo:block>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'company']/row/locadr)">
                            <fo:block xsl:use-attribute-sets="summary-headings">
                                <xsl:value-of select="/all_results/results[@name = 'company']/row/locadr" />
                            </fo:block>
                        </xsl:if>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'company']/row/loccty) or normalize-space(/all_results/results[@name = 'company']/row/locst) or normalize-space(/all_results/results[@name = 'company']/row/loczip) != '0'">
                            <fo:block xsl:use-attribute-sets="summary-headings" space-after="12px">
                                <xsl:value-of select="/all_results/results[@name = 'company']/row/loccty" />
                                <xsl:value-of select="', '" />
                                <xsl:value-of select="/all_results/results[@name = 'company']/row/locst" />
                                <xsl:value-of select="' '" />
                                <xsl:value-of select="/all_results/results[@name = 'company']/row/loczip" />
                            </fo:block>
                        </xsl:if>
                    </fo:table-cell>
                    <fo:table-cell>
                        <fo:block xsl:use-attribute-sets="category-label">
                        </fo:block>
                    </fo:table-cell>                    
                </fo:table-row>
                <fo:table-row>
                    <fo:table-cell>
                        <fo:block xsl:use-attribute-sets="category-label" space-before="12px">Sold To : </fo:block>
                        <fo:block xsl:use-attribute-sets="summary-headings">
                            <xsl:value-of select="/all_results/results[@name = 'poshdr']/row/ptacct" />
                        </fo:block>
                        <fo:block xsl:use-attribute-sets="summary-headings">
                            <xsl:value-of select="/all_results/results[@name = 'cust']/row/fname" />
                            <xsl:value-of select="/all_results/results[@name = 'cust']/row/lname" />
                        </fo:block>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'cust']/row/adln1)">
                            <fo:block xsl:use-attribute-sets="summary-headings">
                                <xsl:value-of select="/all_results/results[@name = 'cust']/row/adln1" />
                            </fo:block>
                        </xsl:if>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'cust']/row/adln2)">
                            <fo:block xsl:use-attribute-sets="summary-headings">
                                <xsl:value-of select="/all_results/results[@name = 'cust']/row/adln2" />
                            </fo:block>
                        </xsl:if>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'cust']/row/adln3)">
                            <fo:block xsl:use-attribute-sets="summary-headings">
                                <xsl:value-of select="/all_results/results[@name = 'cust']/row/adln3" />
                            </fo:block>
                        </xsl:if>
                        <fo:block xsl:use-attribute-sets="summary-headings" space-after="12px">
                            <xsl:value-of select="/all_results/results[@name = 'cust']/row/adcity" />
                            <xsl:value-of select="', '" />
                            <xsl:value-of select="/all_results/results[@name = 'cust']/row/adst" />
                            <xsl:value-of select="' '" />
                            <xsl:value-of select="substring(/all_results/results[@name = 'cust']/row/adzip, 1, 5)"/>
																<xsl:if test="substring(/all_results/results[@name = 'cust']/row/adzip, 6, 4) != '0000'" >
														  	<xsl:value-of select="'-'"/>
														    <xsl:value-of select="substring(/all_results/results[@name = 'cust']/row/adzip, 6, 4)"/>
                   				</xsl:if>
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'cust']/row/esn) != '0'">
                            <fo:block xsl:use-attribute-sets="summary-headings">
                                <fo:inline xsl:use-attribute-sets="category-label">ESN : </fo:inline>
                                <xsl:value-of select="/all_results/results[@name = 'cust']/row/esn" />
                            </fo:block>
                        </xsl:if>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'cust']/row/srno)">
                            <fo:block xsl:use-attribute-sets="summary-headings">
                                <fo:inline xsl:use-attribute-sets="category-label">Serial # : </fo:inline>
                                <xsl:value-of select="/all_results/results[@name = 'cust']/row/srno" />
                            </fo:block>
                        </xsl:if>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'cust']/row/sim) != '0 0 0'">
                            <fo:block xsl:use-attribute-sets="summary-headings">
                                <fo:inline xsl:use-attribute-sets="category-label">SIM : </fo:inline>
                                <xsl:value-of select="/all_results/results[@name = 'cust']/row/sim" />
                            </fo:block>
                        </xsl:if>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'cust']/row/imei) != '0'">
                            <fo:block xsl:use-attribute-sets="summary-headings">
                                <fo:inline xsl:use-attribute-sets="category-label">IMEI : </fo:inline>
                                <xsl:value-of select="/all_results/results[@name = 'cust']/row/imei" />
                            </fo:block>
                        </xsl:if>
                        <fo:block xsl:use-attribute-sets="summary-headings">
                        <fo:inline xsl:use-attribute-sets="category-label">Phone # : </fo:inline>
                        <xsl:value-of select="format-number(/all_results/results[@name = 'cust']/row/cnpa, '000')" />
                        -
                        <xsl:value-of select="format-number(/all_results/results[@name = 'cust']/row/cnxx, '000')" />
                        -
                        <xsl:value-of select="format-number(/all_results/results[@name = 'cust']/row/cline, '0000')" />
                        </fo:block>
                        <xsl:if test="normalize-space(/all_results/results[@name = 'cust']/row/ppacct) = 'Y'">
                            <fo:block xsl:use-attribute-sets="summary-headings">
                                <fo:inline xsl:use-attribute-sets="category-label">Due Date : </fo:inline>
                                <xsl:value-of select="/all_results/results[@name = 'cust']/row/pduedt" />
                            </fo:block>
                        </xsl:if>
                    </fo:table-cell>
                </fo:table-row>
                <fo:table-row>
                    <fo:table-cell>
                        <fo:block xsl:use-attribute-sets="category-label">Date : </fo:block>
                        <fo:block xsl:use-attribute-sets="summary-headings">
                        <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/ptrmm, '00')" />
                        / 
                        <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/ptrdd, '00')" />
                        / 
                        <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/ptrcc, '00')" />
                        <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/ptryy, '00')" />
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell>
                        <fo:block xsl:use-attribute-sets="category-label">Salesperson : </fo:block>
                        <fo:block xsl:use-attribute-sets="summary-headings">
                            <xsl:value-of select="/all_results/results[@name = 'poshdr']/row/ptrusr" />
                        </fo:block>
                    </fo:table-cell>
                </fo:table-row>
            </fo:table-body>
        </fo:table>
        <fo:table table-layout="fixed" width="100%" space-before="16px">
            <fo:table-column column-width="1.0in" />
            <fo:table-column column-width="2.0in" />
            <fo:table-column column-width="1.0in" />
            <fo:table-column column-width="1.0in" />
            <fo:table-column column-width="1.0in" />
            <fo:table-column column-width="1.0in" />
            <fo:table-header>
                <fo:table-row keep-with-next="always">
                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                        <fo:block>Item Code</fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                        <fo:block>Item Description</fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                        <fo:block>Quantity</fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                        <fo:block>Item Amount</fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                        <fo:block>Tax Amount</fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                        <fo:block>Total Cost</fo:block>
                    </fo:table-cell>
                </fo:table-row>
           </fo:table-header>
           <fo:table-body>
                <xsl:for-each select="/all_results/results[@name = 'posdtlsum']/row">
                    <xsl:variable name="itemid" select="./itemid" />
                    <xsl:variable name="origqty" select="/all_results/results[@name = 'posdtl']/row[itemid = $itemid]/pitqty" />
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
                            <fo:block>
                                <xsl:value-of select="./itemid" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
                            <fo:block>
                                <xsl:choose>
                                    <xsl:when test="./itemdesc &gt; ''">
                                        <xsl:value-of select="./itemdesc" />
                                    </xsl:when>
                                    <xsl:when test="normalize-space(./ptrtyp) = 'PAYMENT'">Payment on Account</xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="./itemid" />
                                    </xsl:otherwise>
                                </xsl:choose>
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(./totqty, '##,##0')" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(./pitamt div $origqty, '##,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(./totaltax, '##,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(./totamt, '##,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <xsl:variable name="serialno">
                        <xsl:for-each select="/all_results/results[@name = 'posdtl']/row[itemid = $itemid]">
                            <fo:inline space-end="0.2in" space-start.precedence="force">
                                <xsl:value-of select="./invssn" />
                                <xsl:if test="normalize-space(./invsn)">
                                    <xsl:value-of select="' (S#: '" />
                                    <xsl:value-of select="./invsn" />
                                    <xsl:value-of select="')'" />
                                </xsl:if>
                                <xsl:value-of select="' '" />
                            </fo:inline>
                        </xsl:for-each>
                    </xsl:variable>
                    <xsl:if test="normalize-space($serialno)">
                        <fo:table-row>
                            <fo:table-cell xsl:use-attribute-sets="table-cells">
                            	<fo:block>
                            		<xsl:value-of select="' '"/>
                            	</fo:block>
                            </fo:table-cell>
                            <fo:table-cell xsl:use-attribute-sets="table-cells" keep-with-previous="always" text-align="left" number-columns-spanned="5">
                                <fo:block>
                                    <fo:inline>
                                        <xsl:value-of select="' '" />
                                    </fo:inline>
                                    <fo:block space-start="auto" space-start.precedence="force">
                                        <xsl:value-of select="$serialno" />
                                    </fo:block>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </xsl:if>
                </xsl:for-each>
                <fo:table-row keep-with-previous="always">
                    <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="2">
                        <fo:block>
                            <xsl:value-of select="' Total Amounts '" />
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                        <fo:block>
                            <xsl:value-of select="format-number(sum(/all_results/results[@name = 'posdtlsum']//row/totqty), '##,##0')" />
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                        <fo:block>
                            <xsl:value-of select="' '" />
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                        <fo:block>
                            <xsl:value-of select="format-number(sum(/all_results/results[@name = 'posdtlsum']//row/totaltax), '##,##0.00')" />
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                        <fo:block>
                            <xsl:value-of select="format-number(sum(/all_results/results[@name = 'posdtlsum']//row/totamt), '##,##0.00')" />
                        </fo:block>
                    </fo:table-cell>
                </fo:table-row>
                <fo:table-row keep-with-previous="always">
                    <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="5">
                        <fo:block>
                            <xsl:value-of select="' Amount Due '" />
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                        <fo:block>
                            <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/ptramt, '##,##0.00')" />
                        </fo:block>
                    </fo:table-cell>
                </fo:table-row>
                <xsl:if test="/all_results/results[@name = 'poshdr']/row/pcash &gt; 0">
                    <fo:table-row keep-with-previous="always">
                        <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="5">
                            <fo:block>
                                <xsl:value-of select="' Paid Cash '" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/pcash, '##,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </xsl:if>
                <xsl:if test="/all_results/results[@name = 'poshdr']/row/pcheck &gt; 0">
                    <fo:table-row keep-with-previous="always">
                        <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="5">
                            <fo:block>
                                <xsl:value-of select="' Paid Check #'" />
                                <xsl:value-of select="/all_results/results[@name = 'poshdr']/row/tchkno" />
                                <xsl:value-of select="' '" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/pcheck, '##,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </xsl:if>
                <xsl:if test="/all_results/results[@name = 'poshdr']/row/pccard &gt; 0">
                    <fo:table-row keep-with-previous="always">
                        <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="5">
                            <fo:block>
                                <xsl:value-of select="' Paid Credit Card '" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/pccard, '##,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </xsl:if>
                <xsl:if test="/all_results/results[@name = 'poshdr']/row/pdcard &gt; 0">
                    <fo:table-row keep-with-previous="always">
                        <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="5">
                            <fo:block>
                                <xsl:value-of select="' Paid Debit Card '" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/pdcard, '##,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </xsl:if>
                <xsl:if test="/all_results/results[@name = 'poshdr']/row/ptoacc &gt; 0">
                    <fo:table-row keep-with-previous="always">
                        <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="5">
                            <fo:block>
                                <xsl:value-of select="' On Account '" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/ptoacc, '##,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </xsl:if>
                <xsl:if test="/all_results/results[@name = 'poshdr']/row/ptmisc &gt; 0">
                    <fo:table-row keep-with-previous="always">
                        <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="5">
                            <fo:block>
                                <xsl:value-of select="' Miscellaneous Tendered '" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/ptmisc, '##,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </xsl:if>
                <fo:table-row keep-with-previous="always">
                    <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="right" number-columns-spanned="5">
                        <fo:block>
                            <xsl:value-of select="' Change '" />
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                        <fo:block>
                            <xsl:value-of select="format-number(/all_results/results[@name = 'poshdr']/row/pcgamt, '##,##0.00')" />
                        </fo:block>
                    </fo:table-cell>
                </fo:table-row>
                <fo:table-row keep-with-previous="always">
                    <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="left" number-columns-spanned="2">
                        <fo:block space-before="50px">
                            <xsl:value-of select="' Date: _______________________________________________ '" />
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell xsl:use-attribute-sets="table-cells" border-style="none" font-weight="bold" text-align="left" number-columns-spanned="5">
			               		<xsl:if test="/all_results/results[@name = 'poshdr']/row/pccard &gt; 0">
														<fo:block space-before="100px" space-after="50px">
																<xsl:value-of select="' I agree to pay above total amount according to card issuer agreement. '" />
														</fo:block>
                    		</xsl:if>                    
                        <fo:block space-before="50px">
                            <xsl:value-of select="' Signature: '" />
														<xsl:choose>
														<xsl:when test="$sigimg > ''">
																<fo:external-graphic src="{$sigimg}" width="175px" height="50px"/>
														</xsl:when>
														<xsl:otherwise>
																<xsl:value-of select="' _______________________________________________ '" />
														</xsl:otherwise>
														</xsl:choose>
                        </fo:block>
                    </fo:table-cell>
                </fo:table-row>
            </fo:table-body>
        </fo:table>
    </xsl:template>
</xsl:stylesheet>
