<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Item Change Report ', $change_date_range[1], ' to ', $change_date_range[2])" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
		<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'data']/row">
				<fo:table table-layout="fixed" width="100%" space-before="16px">
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="2.0in" />
						<fo:table-header>
								<fo:table-row keep-with-next="always">
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Account
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												MDN
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Change Date
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Account Item Remove Count
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Account Item Install Count
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Service Item Remove Count
												</fo:block>
										</fo:table-cell>			
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Service Item Install Count
												</fo:block>
										</fo:table-cell>													
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Change By
												</fo:block>
										</fo:table-cell>													
								</fo:table-row>
						</fo:table-header>

						<fo:table-body>
							<xsl:call-template name="detailrow">
									<xsl:with-param name="name" select="$name"/>
							</xsl:call-template>									
					</fo:table-body>
				</fo:table>
		</xsl:when>
		<xsl:otherwise>
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
					No Information Found
				</fo:block>		
		</xsl:otherwise>
		</xsl:choose>
</xsl:template>

<xsl:template name="detailrow">
		<xsl:param name="name" />    
  	
		<xsl:for-each select="/all_results/results[@name = 'data']/row">
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
										<xsl:if test="./cycle != 0 and ./account != 0">
												<xsl:value-of select="format-number(./cycle, '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(./account, '0000000')" />																
										</xsl:if>
										<xsl:value-of select="' '"/>
								</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:if test="./cnpa != 0 and ./cnxx != 0">
											<xsl:call-template name="phone">
												<xsl:with-param name="npa" select="./cnpa"/>
												<xsl:with-param name="nxx" select="./cnxx"/>
												<xsl:with-param name="line" select="./cline"/>
											</xsl:call-template>															
									</xsl:if>							
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:value-of select="./auditdate" />		
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number(./acctrmv, '###,##0')" />																
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number(./acctinst, '###,##0')" />																
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number(./servrmv, '###,##0')" />																
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number(./servinst, '###,##0')" />																
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
									<xsl:value-of select="./uname" />					
									<xsl:value-of select="' - '" />					
									<xsl:value-of select="./name" />					
							</fo:block>
						</fo:table-cell>							
			  </fo:table-row>
		</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
