<?xml version="1.0" encoding="utf-8"?>
	<!-- $Id: itemperform.xsl,v 1.2 2018-09-04 18:03:03 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:java="http://xml.apache.org/xslt/java" 
				xmlns:saxon="http://saxon.sf.net/"
				xmlns:util="java:com.psasoft.reports.util.ReportUtilities" 
				exclude-result-prefixes="java" 
				extension-element-prefixes="saxon" 
				version="2.0">
				
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="'Item Performance'" />

	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>

	<xsl:template name="body_process">
		<xsl:choose>
		<xsl:when test="/all_results/results[@name='detail']/row">
			<xsl:for-each-group select="/all_results/results[@name='detail']/row" group-by="unitid">
				<xsl:variable name="unitid" select="current-group()[position() = 1]/unitid" />
				<xsl:variable name="row" select="current-group()[position() = 1]" />
				
				<fo:table table-layout="fixed" width="100%" space-before="8px" page-break-after="always">
					<fo:table-column column-width="1.5in" /> 
					<fo:table-column column-width="2.0in" />
					<fo:table-column column-width="1.5in" />
					<fo:table-column column-width="6.0in" />
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell text-align="right" padding="10px" padding-bottom="0px">
								<fo:block xsl:use-attribute-sets="summary-headings">
									<xsl:value-of select="'Item'" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell number-columns-spanned="3" padding="12px" padding-bottom="0px">
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$row/item" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell text-align="right" padding="10px" padding-bottom="0px">
								<fo:block xsl:use-attribute-sets="summary-headings">
									<xsl:value-of select="'Item Code'" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell padding="12px" padding-bottom="0px">
								<fo:block>
									<xsl:choose>
										<xsl:when test="$row/externalcd != ''">
											<fo:block xsl:use-attribute-sets="component-2">
												<xsl:value-of select="$row/externalcd" />
											</fo:block>
										</xsl:when>
										<xsl:otherwise>
											<fo:block xsl:use-attribute-sets="component-2">
												<xsl:value-of select="$row/unitcode" />
											</fo:block>
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell text-align="right" padding="10px" padding-bottom="0px">
								<fo:block xsl:use-attribute-sets="summary-headings">
									<xsl:value-of select="'Manuf/Model'" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell padding="12px" padding-bottom="0px">
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$row/manu" />
									<xsl:value-of select="' - '" />
									<xsl:value-of select="$row/model" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>

						<xsl:for-each-group select="/all_results/results[@name='detail']/row[unitid = $unitid]" group-by="concat(company, location)">
							<xsl:variable name="company" select="current-group()[position() = 1]/company" />
							<xsl:variable name="location" select="current-group()[position() = 1]/location" />
						
							<fo:table-row>
								<fo:table-cell text-align="right" padding="10px">
									<fo:block xsl:use-attribute-sets="summary-headings">
										<xsl:value-of select="'Company'" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell padding="12px">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$company" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell text-align="right" padding="10px">
									<fo:block xsl:use-attribute-sets="summary-headings">
										<xsl:value-of select="'Location'" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell padding="12px">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$location" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<fo:table-row>
								<fo:table-cell number-columns-spanned="4" padding="10px">
									<xsl:call-template name="detail">
										<xsl:with-param name="unitid" select="$unitid" />
										<xsl:with-param name="company" select="$company" />
										<xsl:with-param name="location" select="$location" />
									</xsl:call-template>
								</fo:table-cell>
							</fo:table-row>
						
						</xsl:for-each-group>	
						<fo:table-row>
							<fo:table-cell number-columns-spanned="4" padding="10px">
						
								<xsl:variable name="serialized" select="/all_results/results[@name = 'detail']/row[unitid = $unitid][1]/serialized" />
		
								<fo:table table-layout="fixed" width="100%" space-before="8px">
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.75in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.75in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.75in" />
									<fo:table-header>
										<fo:table-row keep-with-next="always">
											<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="13" text-align="left">
												<fo:block>
													<xsl:value-of select="'Overall Totals for Item '" />
													<xsl:value-of select="$row/item" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
									</fo:table-header>
									<fo:table-body>
										<fo:table-row>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="'Totals'" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid]/onhandcount), '##,##0')" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid]/soldcount), '##,##0')" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid]/returncount), '##,##0')" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid]/usedcount), '##,##0')" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid]/totdaysonhand), '##,##0')" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid]/daystoret), '##,##0')" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>	
										<fo:table-row>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="'Averages'" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
												<fo:block>
													<xsl:value-of select="format-number(avg(/all_results/results[@name = 'detail']/row[unitid = $unitid and avgrcvprice != '']/avgrcvprice), '$ ##,##0.00;$ -#,##0.00')" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
												<fo:block>
													<xsl:variable name="avgsale" select="avg(/all_results/results[@name = 'detail']/row[unitid = $unitid and avgsaleprice != '']/avgsaleprice)" />
													<xsl:choose>
													<xsl:when test="$avgsale != 0" >
														<xsl:value-of select="format-number($avgsale, '$ ##,##0.00;$ -#,##0.00')" />
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="' '" />
													</xsl:otherwise>
													</xsl:choose>
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
												<fo:block>
													<xsl:variable name="avgreturn" select="avg(/all_results/results[@name = 'detail']/row[unitid = $unitid and avgrtnprice != '']/avgrtnprice)" />
													<xsl:choose>
													<xsl:when test="$avgreturn != 0" >
														<xsl:value-of select="format-number($avgreturn, '$ ##,##0.00;$ -#,##0.00')" />
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="' '" />
													</xsl:otherwise>
													</xsl:choose>
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
												<fo:block>
													<xsl:value-of select="' '" />
												</fo:block>
											</fo:table-cell>
										</fo:table-row>							
									</fo:table-body>
								</fo:table>		
							</fo:table-cell>
						</fo:table-row>			
					</fo:table-body>
				</fo:table>
			</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
				<fo:block>No item information found for selections.</fo:block>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="detail">
		<xsl:param name="unitid" />
		<xsl:param name="company" />
		<xsl:param name="location" />
		
		<xsl:variable name="serialized" select="/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location][1]/serialized" />

		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<xsl:choose>
					<xsl:when test="$serialized = '1'" >
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Serial</fo:block>
						</fo:table-cell>
					</xsl:when>
					<xsl:otherwise>
						<fo:table-cell>
							<fo:block>
								<xsl:value-of select="' '" />
							</fo:block>
						</fo:table-cell>
					</xsl:otherwise>
					</xsl:choose>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>On Hand</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Sold</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Rtn</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Used</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Rcv Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Avg Rcv Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Days On Hand</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Avg Sale Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Sale Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Days to Rtn</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Avg Rtn Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Rtn Date</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location]">
					<fo:table-row>
						<xsl:choose>
						<xsl:when test="$serialized = '1'" >
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="./serialno2" />
								</fo:block>
							</fo:table-cell>
						</xsl:when>
						<xsl:otherwise>
							<fo:table-cell>
								<fo:block>
									<xsl:value-of select="' '" />
								</fo:block>
							</fo:table-cell>
						</xsl:otherwise>
						</xsl:choose>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="format-number(./onhandcount, '##,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="format-number(./soldcount, '##,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="format-number(./returncount, '##,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="format-number(./usedcount, '##,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="./rcvdate" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./avgrcvprice, '$ ##,##0.00;$ -#,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:value-of select="format-number(./totdaysonhand, '##,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./avgsaleprice &gt; ''" >
									<xsl:value-of select="format-number(./avgsaleprice, '$ ##,##0.00;$ -#,##0.00')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./firstsaledate &gt; ''" >
									<xsl:value-of select="./firstsaledate" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
							<xsl:if test="./firstsaledate &gt; '' and ./firstsaledate != ./lastsaledate">
								<fo:block>
									<xsl:value-of select="./lastsaledate" />
								</fo:block>
							</xsl:if>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./daystoret &gt; ''" >
									<xsl:value-of select="format-number(./daystoret, '##,##0')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./avgrtnprice &gt; ''" >
									<xsl:value-of select="format-number(./avgrtnprice, '$ ##,##0.00;$ -#,##0.00')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./firstreturndate &gt; ''" >
										<xsl:value-of select="./firstreturndate" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
							<xsl:if test="./firstreturndate &gt; '' and ./firstreturndate != ./lastreturndate">
								<fo:block>
									<xsl:value-of select="./lastreturndate" />
								</fo:block>
							</xsl:if>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="'Totals'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location]/onhandcount), '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location]/soldcount), '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location]/returncount), '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location]/usedcount), '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location]/totdaysonhand), '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location]/daystoret), '##,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>	
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="'Averages'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(avg(/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location and avgrcvprice != '']/avgrcvprice), '$ ##,##0.00;$ -#,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
						<fo:block>
							<xsl:variable name="avgsale" select="avg(/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location and avgsaleprice != '']/avgsaleprice)" />
							<xsl:choose>
							<xsl:when test="$avgsale != 0" >
								<xsl:value-of select="format-number($avgsale, '$ ##,##0.00;$ -#,##0.00')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="' '" />
							</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
						<fo:block>
							<xsl:variable name="avgreturn" select="avg(/all_results/results[@name = 'detail']/row[unitid = $unitid and company = $company and location = $location and avgrtnprice != '']/avgrtnprice)" />
							<xsl:choose>
							<xsl:when test="$avgreturn != 0" >
								<xsl:value-of select="format-number($avgreturn, '$ ##,##0.00;$ -#,##0.00')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="' '" />
							</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>							
			</fo:table-body>
		</fo:table>
	</xsl:template>
</xsl:stylesheet>