<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: itemsumm.xsl,v 1.4 2014-08-12 19:18:19 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
								exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Account / Service Item Summary'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account_service">
		<xsl:with-param name="row" select="/all_results/results[@name = 'acctservice']/row"/>
	</xsl:call-template>
	
	<xsl:variable name="totalinst" select="sum(/all_results/results[@name = 'acctdetail']/row/ainamt) +
																	 sum(/all_results/results[@name = 'servdetail']/row/inamt)"/>
	<xsl:variable name="totalonhand" select="sum(/all_results/results[@name = 'acctdetail']/row/aitamt) +
																	 sum(/all_results/results[@name = 'servdetail']/row/itmamt)"/>
	<xsl:variable name="totalrmv" select="sum(/all_results/results[@name = 'acctdetail']/row/armamt) +
																	 sum(/all_results/results[@name = 'servdetail']/row/rmamt)"/>
	<xsl:variable name="totaltax" select="sum(/all_results/results[@name = 'acctdetail']/row/totaltax) + 
																	 sum(/all_results/results[@name = 'servdetail']/row/totaltax)"/>
	<xsl:variable name="totalall" select="$totalinst + $totalonhand + $totalrmv + $totaltax" />

	<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
		Totals
	</fo:block>	
	<fo:table table-layout="fixed" width="100%" 
							space-before="8px">
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" /> 		
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-header>
		<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Install / Prorate</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Recurring Charges</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Remove / Prorate</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Taxes</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</fo:table-header>					
		<fo:table-body>
			<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totalinst, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>
					</fo:table-cell>		
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totalonhand, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>
					</fo:table-cell>	
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totalrmv, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>
					</fo:table-cell>	
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>
					</fo:table-cell>	
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totalall, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</fo:block>
					</fo:table-cell>						
				</fo:table-row>		
		</fo:table-body>
	</fo:table>
		
	<xsl:if test="/all_results/results[@name = 'acctdetail']/row[itmtyp != 'A']">
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px" keep-with-next="always">
				Account Items
			</fo:block>	
			<xsl:call-template name="accitemtable">
				<xsl:with-param name="row" select="/all_results/results[@name = 'acctdetail']/row[itmtyp != 'A']"/>
			</xsl:call-template>
	</xsl:if>
	<xsl:if test="/all_results/results[@name = 'acctdetail']/row[itmtyp = 'A']">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px" keep-with-next="always">
				Account Adjustments
			</fo:block>	
			<xsl:call-template name="accitemtable">
				<xsl:with-param name="row" select="/all_results/results[@name = 'acctdetail']/row[itmtyp = 'A']"/>
			</xsl:call-template>			
	</xsl:if>
	<xsl:if test="/all_results/results[@name = 'servdetail']/row[itmtyp = 'K']">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px" keep-with-next="always">
				Packages
			</fo:block>	
			<xsl:call-template name="packagetable">
				<xsl:with-param name="row" select="/all_results/results[@name = 'servdetail']/row[itmtyp = 'K']"/>
			</xsl:call-template>
	</xsl:if>
	<xsl:if test="/all_results/results[@name = 'servdetail']/row[itmtyp = 'P' and substring(item, 1, 3) = 'PLN' and packrecid = 0]">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px" keep-with-next="always">
				Plans
			</fo:block>	
			<xsl:call-template name="srvitemtable">
				<xsl:with-param name="row" select="/all_results/results[@name = 'servdetail']/row[itmtyp = 'P' and substring(item, 1, 3) = 'PLN' and packrecid = 0]"/>
			</xsl:call-template>			
	</xsl:if>
	<xsl:if test="/all_results/results[@name = 'servdetail']/row[itmtyp != 'A' and substring(item, 1, 3) != 'PLN' and packrecid = 0]">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px" keep-with-next="always">
				Service Features
			</fo:block>	
			<xsl:call-template name="srvitemtable">
				<xsl:with-param name="row" select="/all_results/results[@name = 'servdetail']/row[itmtyp != 'A' and substring(item, 1, 3) != 'PLN' and packrecid = 0]"/>
			</xsl:call-template>				
	</xsl:if>
	<xsl:if test="/all_results/results[@name = 'servdetail']/row[itmtyp = 'A' and substring(item, 1, 3) != 'PLN']">
			<fo:block xsl:use-attribute-sets="category-label" space-before="16px" keep-with-next="always">
				Service Adjustments
			</fo:block>	
			<xsl:call-template name="srvitemtable">
				<xsl:with-param name="row" select="/all_results/results[@name = 'servdetail']/row[itmtyp = 'A' and substring(item, 1, 3) != 'PLN']"/>
			</xsl:call-template>	
	</xsl:if>
</xsl:template>

<xsl:template name="accitemtable">
	<xsl:param name="row" />
	<fo:table table-layout="fixed" width="100%" space-before="8px">
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="1.5in" />
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="1.0in" /> 		
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Item</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Item Description</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Status</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Install Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Prorate</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Recurring Charges</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Remove Date</fo:block>
						</fo:table-cell> 			 						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Remove Amount</fo:block>
						</fo:table-cell> 	
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Taxes</fo:block>
						</fo:table-cell>				
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Total</fo:block>
						</fo:table-cell>						
					</fo:table-row>
			</fo:table-header>					
			<fo:table-body>
				<xsl:for-each select="$row"> 
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./item"/>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="./itmdsc"/>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:choose>
										<xsl:when test="./abillin = 'Y'">
												<xsl:value-of select="'Install'"/>
										</xsl:when>										
										<xsl:when test="./armiyy > 0">
												<xsl:value-of select="'Remove'"/>
										</xsl:when>
										<xsl:otherwise>
												<xsl:value-of select="'On Hand'"/>
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:if test="./aityy > 0">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./aitcc"/>
											<xsl:with-param name="yy" select="./aityy"/>
											<xsl:with-param name="mm" select="./aitmm"/>
											<xsl:with-param name="dd" select="./aitdd"/>
										</xsl:call-template>
									</xsl:if>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./ainamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./aitamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:if test="./armiyy > 0">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./armicc"/>
											<xsl:with-param name="yy" select="./armiyy"/>
											<xsl:with-param name="mm" select="./armimm"/>
											<xsl:with-param name="dd" select="./armidd"/>
										</xsl:call-template>
									</xsl:if>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./armamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>	
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number((./ainamt + ./aitamt + ./armamt + ./totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>								
					</fo:table-row>		
				</xsl:for-each>
			</fo:table-body>
		</fo:table>		
</xsl:template>

<xsl:template name="srvitemtable">
	<xsl:param name="row" />
	<fo:table table-layout="fixed" width="100%" space-before="8px">
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="1.5in" />
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="1.0in" /> 		
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Item</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Item Description</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Status</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Install Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Prorate</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Recurring Charges</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Remove Date</fo:block>
						</fo:table-cell> 			 						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Remove Amount</fo:block>
						</fo:table-cell> 	
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Taxes</fo:block>
						</fo:table-cell>				
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Total</fo:block>
						</fo:table-cell>						
					</fo:table-row>
			</fo:table-header>					
			<fo:table-body>
				<xsl:for-each select="$row"> 
					<xsl:variable name="item" select="./item"/>
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./item"/>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="./itmdsc"/>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:choose>
										<xsl:when test="./billin = 'Y'">
												<xsl:value-of select="'Install'"/>
										</xsl:when>										
										<xsl:when test="./rmiyy > 0">
												<xsl:value-of select="'Remove'"/>
										</xsl:when>
										<xsl:otherwise>
												<xsl:value-of select="'On Hand'"/>
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:if test="./ityy > 0">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./itcc"/>
											<xsl:with-param name="yy" select="./ityy"/>
											<xsl:with-param name="mm" select="./itmm"/>
											<xsl:with-param name="dd" select="./itdd"/>
										</xsl:call-template>
									</xsl:if>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./inamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./itmamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:if test="./rmiyy > 0">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./rmicc"/>
											<xsl:with-param name="yy" select="./rmiyy"/>
											<xsl:with-param name="mm" select="./rmimm"/>
											<xsl:with-param name="dd" select="./rmidd"/>
										</xsl:call-template>
									</xsl:if>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./rmamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>	
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number((./inamt + ./itmamt + ./rmamt + ./totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>								
					</fo:table-row>		
					<xsl:if test="/all_results/results[@name = 'ratefeat']/row[item = $item]">
						<xsl:for-each select="/all_results/results[@name = 'ratefeat']/row[item = $item]">
							<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
											<xsl:value-of select="./rfeat"/>
										</fo:block>
									</fo:table-cell>			
									<fo:table-cell xsl:use-attribute-sets="table-cells" 
																 number-columns-spanned="8"
																 text-align="left">
										<fo:block>
											<fo:inline>
												<xsl:value-of select="./rpfdsc"/>
												<xsl:value-of select="' - Value: '"/>
												<xsl:value-of select="./listdesc"/>
											</fo:inline>
										</fo:block>
									</fo:table-cell>								
							</fo:table-row>		
						</xsl:for-each>
					</xsl:if>					
				</xsl:for-each>
			</fo:table-body>
		</fo:table>		
</xsl:template>

<xsl:template name="packagetable">
	<xsl:param name="row" />
	<fo:table table-layout="fixed" width="100%" space-before="8px">
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="1.5in" />
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="1.0in" /> 	
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Item</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Item Description</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Status</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Install Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Prorate</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Recurring Charges</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Remove Date</fo:block>
						</fo:table-cell> 			 						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Remove Amount</fo:block>
						</fo:table-cell> 			 		
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Taxes</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Total</fo:block>
						</fo:table-cell>							
					</fo:table-row>
			</fo:table-header>					
			<fo:table-body>
				<xsl:for-each select="$row"> 
					<xsl:variable name="packid" select="./serecid"/>
					<xsl:variable name="item" select="./item"/>
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./item"/>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="./itmdsc"/>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:choose>
										<xsl:when test="./billin = 'Y'">
												<xsl:value-of select="'Install'"/>
										</xsl:when>										
										<xsl:when test="./rmityy > 0">
												<xsl:value-of select="'Remove'"/>
										</xsl:when>
										<xsl:otherwise>
												<xsl:value-of select="'On Hand'"/>
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:if test="./ityy > 0">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./itcc"/>
											<xsl:with-param name="yy" select="./ityy"/>
											<xsl:with-param name="mm" select="./itmm"/>
											<xsl:with-param name="dd" select="./itdd"/>
										</xsl:call-template>
									</xsl:if>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./inamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./itmamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:if test="./armiyy > 0">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./rmitcc"/>
											<xsl:with-param name="yy" select="./rmityy"/>
											<xsl:with-param name="mm" select="./rmitmm"/>
											<xsl:with-param name="dd" select="./rmitdd"/>
										</xsl:call-template>
									</xsl:if>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./rmamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>	
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number((./inamt + ./itmamt + ./rmamt + ./totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>								
					</fo:table-row>		
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="'Package Contents'"/>
								</fo:block>
							</fo:table-cell>								
							<fo:table-cell xsl:use-attribute-sets="table-cells" 
														 text-align="left" 
														 padding-top="10px" 
														 padding-left="20px" 
														 padding-bottom="10px" 
														 padding-right="10px" 
														 number-columns-spanned="9">
								<xsl:if test="/all_results/results[@name = 'servdetail']/row[packrecid = $packid and itmtyp = 'P' and substring(item, 1, 3) = 'PLN']">
										<fo:block xsl:use-attribute-sets="category-label" keep-with-next="always">
											Plans
										</fo:block>	
										<xsl:call-template name="packitemtable">
											<xsl:with-param name="row" select="/all_results/results[@name = 'servdetail']/row[packrecid = $packid and itmtyp = 'P' and substring(item, 1, 3) = 'PLN']"/>
											<xsl:with-param name="packitem" select="' '"/>
										</xsl:call-template>				
								</xsl:if>					
								<xsl:if test="/all_results/results[@name = 'servdetail']/row[packrecid = $packid and itmtyp != 'A'and itmtyp != 'K' and substring(item, 1, 3) != 'PLN']">
										<fo:block xsl:use-attribute-sets="category-label" space-before="10px" keep-with-next="always">
											Service Features
										</fo:block>	
										<xsl:call-template name="packitemtable">
											<xsl:with-param name="row" select="/all_results/results[@name = 'servdetail']/row[packrecid = $packid and itmtyp != 'A' and itmtyp != 'K' and substring(item, 1, 3) != 'PLN']"/>
											<xsl:with-param name="packitem" select="$item"/>
										</xsl:call-template>					
								</xsl:if>																			
							</fo:table-cell>								
					</fo:table-row>		
				</xsl:for-each>
			</fo:table-body>
		</fo:table>		
</xsl:template>

<xsl:template name="packitemtable">
	<xsl:param name="row" />
	<xsl:param name="packitem" />
	<fo:table table-layout="fixed" width="90%" space-before="6px">
		<fo:table-column column-width=".75in" />
		<fo:table-column column-width="2.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" /> 		
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Item</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Item Description</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Prorate</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Recurring Charges</fo:block>
						</fo:table-cell> 			 						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Remove Amount</fo:block>
						</fo:table-cell> 			
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Taxes</fo:block>
						</fo:table-cell>		
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Total</fo:block>
						</fo:table-cell>						
					</fo:table-row>
			</fo:table-header>					
			<fo:table-body>
				<xsl:for-each select="$row[packrecid != 0]"> 
				<xsl:variable name="item" select="./item"/>
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./item"/>
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
									<xsl:value-of select="./itmdsc"/>
								</fo:block>
							</fo:table-cell>								
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./inamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
								</fo:block>
							</fo:table-cell>			
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./itmamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
								</fo:block>
							</fo:table-cell>					
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./rmamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>		
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>		
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number((./inamt + ./itmamt + ./rmamt + ./totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')"/>		
								</fo:block>
							</fo:table-cell>								
					</fo:table-row>		
				</xsl:for-each>
				<xsl:if test="/all_results/results[@name = 'ratefeat']/row[item = $packitem]">
					<xsl:for-each select="/all_results/results[@name = 'ratefeat']/row[item = $packitem]">
						<fo:table-row keep-with-previous="always">
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./rfeat"/>
									</fo:block>
								</fo:table-cell>			
								<fo:table-cell xsl:use-attribute-sets="table-cells" 
															 number-columns-spanned="6"
															 text-align="left">
									<fo:block>
										<fo:inline>
											<xsl:value-of select="./rpfdsc"/>
											<xsl:value-of select="' - Value: '"/>
											<xsl:value-of select="./listdesc"/>
										</fo:inline>
									</fo:block>
								</fo:table-cell>								
						</fo:table-row>		
					</xsl:for-each>
				</xsl:if>						
			</fo:table-body>
		</fo:table>	
</xsl:template>

</xsl:stylesheet>






