<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: mansuspend.xsl,v 1.2 2010-05-05 17:32:47 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
								exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
   <xsl:import href="subtemplates.xsl"/> 
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
	<xsl:variable name="title" select="concat('Manual Suspend Report ', $change_date_range[1], ' to ', $change_date_range[2])" />

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		<xsl:call-template name="make-layout-master-set-landscape" />
		<xsl:call-template name="make-body-landscape" />
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'data']/row)">
		<xsl:for-each-group select="/all_results/results[@name='data']/row" group-by="./cumrkt">
			<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt" />
			<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />

				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<xsl:call-template name="header">
							<xsl:with-param name="market" select="$market"/>
							<xsl:with-param name="marketname" select="$marketname"/>
					</xsl:call-template>										
					<fo:table-body>
							<xsl:for-each select="/all_results/results[@name = 'data']/row[cumrkt = $market]">
									<xsl:call-template name="detail">
										<xsl:with-param name="row" select="."/>
									</xsl:call-template>							
						 </xsl:for-each>
						</fo:table-body>
				</fo:table>										
	    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="0px" space-after="10px">
	    				<xsl:value-of select="'Total Suspensions for Market ( '"/>
	    				<xsl:value-of select="$market"/>
	    				<xsl:value-of select="' - '"/>
	    				<xsl:value-of select="$marketname"/>
	    				<xsl:value-of select="' ): '"/>
	    				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cumrkt = $market]), '###,##0')"/>
	    		</fo:block>	

			</xsl:for-each-group>	
    										
			<fo:block xsl:use-attribute-sets="summary-headings">
					<xsl:value-of select="'Total Suspensions:  '"/>
					<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row), '###,##0')"/>
			</fo:block>								
		</xsl:when>
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
				No Information Found
			</fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="header">
	<xsl:param name="market" />
	<xsl:param name="marketname" />
	
	<fo:table-column column-width="1.00in" />
	<fo:table-column column-width="1.00in" />
	<fo:table-column column-width="1.00in" />
	<fo:table-column column-width="0.75in" />
	<fo:table-column column-width="2.50in" />
	<fo:table-column column-width="1.50in" />
	<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell number-columns-spanned="6">
						<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always">
								<xsl:value-of select="'Market:  '"/>
								<xsl:value-of select="$market"/>
								<xsl:value-of select="' - '"/>
								<xsl:value-of select="$marketname"/>
						</fo:block>			
					</fo:table-cell>
			</fo:table-row>
			<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Account</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>MDN</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Disconnect Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Suspend Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Customer Name</fo:block>
					</fo:table-cell>								
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Current Status</fo:block>
					</fo:table-cell>
			</fo:table-row>
	</fo:table-header>
</xsl:template>

<xsl:template name="detail">
		<xsl:param name="row" />
		
		<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:value-of select="format-number(./cycle, '000')" />
						<xsl:value-of select="'-'" />
						<xsl:value-of select="format-number(./account, '0000000')" />
					</fo:block>
				</fo:table-cell>																		
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:call-template name="phone">
							<xsl:with-param name="npa" select="./cnpa"/>
							<xsl:with-param name="nxx" select="./cnxx"/>
							<xsl:with-param name="line" select="./cline"/>
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:choose>
						<xsl:when test="exists(./dcmm) and ./dcmm > '' and ./dcmm = 99">
								<xsl:value-of select="'Suspend Nonpay'"/>
						</xsl:when>
						<xsl:when test="exists(./dcmm) and ./dcmm > '' and ./dcmm > 0">
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./dccc"/>
								<xsl:with-param name="yy" select="./dcyy"/>
								<xsl:with-param name="mm" select="./dcmm"/>
								<xsl:with-param name="dd" select="./dcdd"/>
							</xsl:call-template>
						</xsl:when>
						</xsl:choose>
						<xsl:value-of select="' '"/>
					</fo:block>
				</fo:table-cell>										
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:value-of select="./suspenddate" />
					</fo:block>
				</fo:table-cell>										
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
							<xsl:value-of select="./fname" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="./lname" />									
					</fo:block>
				</fo:table-cell>	
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:choose>
							<xsl:when test="exists(./dcmm) and ./dcmm > '' and ./dcmm = 99">
								<xsl:value-of select="'Suspend Nonpay'"/>
							</xsl:when>
							<xsl:when test="exists(./dcmm) and ./dcmm > '' and ./dcmm &gt; 0">
								<xsl:value-of select="'Disconnected'"/>
							</xsl:when>
							<xsl:when test="./mstat = 'S'">
								<xsl:value-of select="'Manual Suspend'"/>
							</xsl:when>
							<xsl:when test="exists(./dcmm) and ./dcmm > '' and ./dcmm = 0">
								<xsl:value-of select="'Active'"/>
							</xsl:when>							
							<xsl:otherwise>
								<xsl:value-of select="./mstat"/>							
							</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>				
			</fo:table-row>			
</xsl:template>

</xsl:stylesheet>






