<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="'On Hand - Matrix by Location'" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
		<xsl:call-template name="main">
				<xsl:with-param name="posfrom" select="0" />    
				<xsl:with-param name="posto" select="8" /> 										
		</xsl:call-template>
		<xsl:if test="/all_results/results[@name = 'loca']/row[position() &gt; 7]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="7" />    
						<xsl:with-param name="posto" select="15" /> 										
				</xsl:call-template>		
		</xsl:if>
		<xsl:if test="/all_results/results[@name = 'loca']/row[position() &gt; 14]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="14" />    
						<xsl:with-param name="posto" select="22" /> 										
				</xsl:call-template>		
		</xsl:if>		
		<xsl:if test="/all_results/results[@name = 'loca']/row[position() &gt; 21]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="21" />    
						<xsl:with-param name="posto" select="29" /> 										
				</xsl:call-template>		
		</xsl:if>	
		<xsl:if test="/all_results/results[@name = 'loca']/row[position() &gt; 28]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="28" />    
						<xsl:with-param name="posto" select="36" /> 										
				</xsl:call-template>		
		</xsl:if>		
		<xsl:if test="/all_results/results[@name = 'loca']/row[position() &gt; 35]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="35" />    
						<xsl:with-param name="posto" select="43" /> 										
				</xsl:call-template>		
		</xsl:if>			
</xsl:template>

<xsl:template name="main">
		<xsl:param name="posfrom" />    
		<xsl:param name="posto" /> 
		
		<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="1.0in" />
				<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
						<fo:table-column column-width="1.0in" />
				</xsl:for-each>
				<fo:table-header>
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Item Description
										</fo:block>
								</fo:table-cell>									
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Item Code
										</fo:block>
								</fo:table-cell>																	
								<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
													<xsl:value-of select="./location" />
												</fo:block>
										</fo:table-cell>		
								</xsl:for-each>
						</fo:table-row>
				</fo:table-header>
				<fo:table-body>
						<xsl:call-template name="detail">
								<xsl:with-param name="posfrom" select="$posfrom" />    
								<xsl:with-param name="posto" select="$posto" />	
						</xsl:call-template>		
				</fo:table-body>
</fo:table>
</xsl:template>

<xsl:template name="detail">
		<xsl:param name="posfrom" />    
		<xsl:param name="posto" /> 

		<xsl:for-each select="/all_results/results[@name = 'items']/row">
				<xsl:variable name="unitid" select="./unitid" />
				<xsl:variable name="unitdesc" select="normalize-space(./unitdesc)" />
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
									<xsl:value-of select="$unitdesc" />
							</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<xsl:choose>
							<xsl:when test="./unitcode != ''" >
								<fo:block>
									<xsl:value-of select="./unitcode" />
								</fo:block>
							</xsl:when>
							<xsl:otherwise>
								<fo:block>
									<xsl:value-of select="./externalcd" />
								</fo:block>
							</xsl:otherwise>
							</xsl:choose>
						</fo:table-cell>						
						<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
								<xsl:variable name="company" select="normalize-space(./company)" />
								<xsl:variable name="loca" select="normalize-space(./location)" />
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:choose>
										<xsl:when test="/all_results/results[@name = 'mastsum']/row[normalize-space(./company) = $company and normalize-space(./location) = $loca and ./unitid = $unitid and normalize-space(./unitdesc) = $unitdesc]/qty > 0">
												<xsl:value-of select="format-number(/all_results/results[@name = 'mastsum']/row[normalize-space(./company) = $company and normalize-space(./location) = $loca and normalize-space(./unitid) = $unitid and  normalize-space(./unitdesc) = $unitdesc]/qty, '##,###,##0')"/> 												
										</xsl:when>
										<xsl:otherwise>
												<xsl:value-of select="format-number(0, '##,###,##0')"/>
										</xsl:otherwise>
										</xsl:choose>
									</fo:block>
								</fo:table-cell>		
						</xsl:for-each>																	
			</fo:table-row>
		</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
