<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: po_new.xsl,v 1.8 2018-09-04 18:03:03 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:java="http://xml.apache.org/xslt/java" 
				exclude-result-prefixes="java" 
				version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
    <xsl:import href="subtemplates.xsl"/>  
    
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="test" />
    
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set" />
            <xsl:call-template name="make-body" />
        </fo:root>
    </xsl:template>
	<xsl:template name="body_process">
	
		<xsl:variable name="company" select="/all_results/results[@name = 'company']/row" />
		<xsl:variable name="companyaddr" select="/all_results/results[@name = 'companyaddr']/row" />
		<xsl:variable name="pohdr" select="/all_results/results[@name = 'pohdr']/row" />
		<xsl:variable name="transfer" select="/all_results/results[@name = 'transfer']/row" />
		<xsl:variable name="attachid" select="$company/storageid" />
		<xsl:variable name="bill_to_id" select="$pohdr/billto" />
		<xsl:variable name="ship_to_id" select="$pohdr/shipto" />
		<xsl:variable name="bill_to_addr" select="/all_results/results[@name = 'companyaddr']/row[cid = $bill_to_id]" />
		<xsl:variable name="ship_to_addr" select="/all_results/results[@name = 'companyaddr']/row[cid = $ship_to_id]" />
		<xsl:variable name="companyicon" select="RU:getStorageBase64Encoded($attachid)" xmlns:RU="java:com.psasoft.reports.util.ReportUtilities" />
		
		<fo:table table-layout="fixed" width="100%">
			<fo:table-column column-width="75px" />
			<fo:table-column column-width="250px" />
			<fo:table-column column-width="75px" />
			<fo:table-column column-width="100px" />
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<fo:block>
							<fo:external-graphic src="data:image/jpeg;base64,{$companyicon}" content-height="auto" content-width="70px" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="report-title" space-after="10px" font-size="16pt" text-align="left">Purchase Order</fo:block>
						<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
							<xsl:value-of select="$company/companyname" />
						</fo:block>
						<xsl:if test="normalize-space($bill_to_addr/line1) != ''">
							<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
								<xsl:value-of select="$bill_to_addr/line1" />
							</fo:block>
						</xsl:if>
						<xsl:if test="normalize-space($bill_to_addr/line2) != ''">
							<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
								<xsl:value-of select="$bill_to_addr/line2" />
							</fo:block>
						</xsl:if>
						<xsl:if test="normalize-space($bill_to_addr/line3) != ''">
							<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
								<xsl:value-of select="$bill_to_addr/line3" />
							</fo:block>
						</xsl:if>
						<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
							<xsl:value-of select="$bill_to_addr/city" />
							<xsl:if test="normalize-space($bill_to_addr/city) != ''">
								<xsl:value-of select="', '" />
							</xsl:if>
							<xsl:value-of select="$bill_to_addr/state" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="$bill_to_addr/zip" />
							<xsl:value-of select="' '" />
							<xsl:if test="normalize-space($bill_to_addr/country) != ''">
								<xsl:value-of select="$bill_to_addr/country" />
							</xsl:if>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="component-1" font-weight="bold">PO Number</fo:block>
						<fo:block xsl:use-attribute-sets="component-1" font-weight="bold">PO Date</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="component-1">
							<xsl:value-of select="$pohdr/pono" />
						</fo:block>
						<fo:block xsl:use-attribute-sets="component-1">
							<xsl:value-of select="$pohdr/podate" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
		
		<fo:block text-align="center" start-indent="10pt" space-after="8pt" color="navy">
			<fo:leader leader-pattern="rule" leader-length="500pt" />
		</fo:block>
		
		<xsl:choose>
			<xsl:when test="$pohdr/status = 6 or $pohdr/status = 7">
				<fo:table table-layout="fixed" width="100%">
					<fo:table-column column-width="1.25in" />
					<fo:table-column column-width="2.0in" />
					<fo:table-column column-width="1.25in" />
					<fo:table-column column-width="2.0in" />
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">Old Company</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$transfer/oldcompany" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">New Company</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$transfer/newcompany" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">Old Location</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$transfer/oldlocation" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">New Location</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$transfer/newlocation" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</xsl:when>
			
			<xsl:otherwise>
				<fo:table table-layout="fixed" width="100%">
					<fo:table-column column-width="1.25in" />
					<fo:table-column column-width="2.5in" />
					<fo:table-column column-width="1.25in" />
					<fo:table-column column-width="2.5in" />
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">Vendor</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$pohdr/vendor" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">Vendor Account</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$pohdr/accountno" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">Address</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$pohdr/vline1" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">Vendor Terms</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$pohdr/terms" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block>
									<xsl:value-of select="' '" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<xsl:if test="normalize-space($pohdr/vline2) != ' '">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$pohdr/vline2" />
									</fo:block>
								</xsl:if>
								<xsl:if test="normalize-space($pohdr/vline3) != ' '">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$pohdr/vline3" />
									</fo:block>
								</xsl:if>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">Buyer</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$pohdr/name" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">City/State/Zip</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$pohdr/vcity" />
									<xsl:if test="normalize-space($pohdr/vcity) != ''">
										<xsl:value-of select="', '" />
									</xsl:if>
									<xsl:value-of select="$pohdr/vstate" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="$pohdr/vzip" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="$pohdr/vcountry" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell number-columns-spanned="4" height="16pt">
								<xsl:value-of select="' '" />
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" space-before="16pt" font-weight="bold">Bill To:</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" space-before="16pt" font-weight="bold">Ship To:</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">Address</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<xsl:if test="normalize-space($bill_to_addr/line1) != ''">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$bill_to_addr/line1" />
									</fo:block>
								</xsl:if>
								<xsl:if test="normalize-space($bill_to_addr/line2) != ''">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$bill_to_addr/line2" />
									</fo:block>
								</xsl:if>
								<xsl:if test="normalize-space($bill_to_addr/line3) != ''">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$bill_to_addr/line3" />
									</fo:block>
								</xsl:if>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">Address</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<xsl:if test="normalize-space($ship_to_addr/line1) != ''">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$ship_to_addr/line1" />
									</fo:block>
								</xsl:if>
								<xsl:if test="normalize-space($ship_to_addr/line2) != ''">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$ship_to_addr/line2" />
									</fo:block>
								</xsl:if>
								<xsl:if test="normalize-space($ship_to_addr/line3) != ''">
									<fo:block xsl:use-attribute-sets="component-2">
										<xsl:value-of select="$ship_to_addr/line3" />
									</fo:block>
								</xsl:if>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">City/State/Zip</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$bill_to_addr/city" />
									<xsl:if test="normalize-space($bill_to_addr/city) != ''">
										<xsl:value-of select="', '" />
									</xsl:if>
									<xsl:value-of select="$bill_to_addr/state" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="$bill_to_addr/zip" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="$bill_to_addr/country" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" font-weight="bold">City/State/Zip</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$ship_to_addr/city" />
									<xsl:if test="normalize-space($ship_to_addr/city) != ''">
										<xsl:value-of select="', '" />
									</xsl:if>
									<xsl:value-of select="$ship_to_addr/state" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="$ship_to_addr/zip" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="$ship_to_addr/country" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell number-columns-spanned="4" height="16pt">
								<xsl:value-of select="' '" />
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" space-before="12px" font-weight="bold">Preferred Shipper</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block xsl:use-attribute-sets="component-2" space-before="12px">
									<xsl:value-of select="$pohdr/primaryship" />
								</fo:block>
							</fo:table-cell>
							<xsl:choose>
							<xsl:when test="normalize-space($pohdr/altship) != ''">
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="component-2" space-before="12px" font-weight="bold">Alternate Shipping</fo:block>
								</fo:table-cell>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="component-2" space-before="12px">
										<xsl:value-of select="$pohdr/altship" />
									</fo:block>
								</fo:table-cell>
							</xsl:when>
							<xsl:otherwise>
								<fo:table-cell number-columns-spanned="2">
									<fo:block><xsl:value-of select="' '"/></fo:block>
								</fo:table-cell>
							</xsl:otherwise>
							</xsl:choose>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</xsl:otherwise>
		</xsl:choose>
		
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="0.6in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="0.6in" />
			<fo:table-column column-width="0.8in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-header>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Ordered Quantity</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Vendor Item Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Description</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Comments</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'podetail']/row">
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="./unitqty" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<xsl:choose>
								<xsl:when test="./externalcd != ''">
									<fo:block>
										<xsl:value-of select="./externalcd" />
									</fo:block>
								</xsl:when>
								<xsl:otherwise>
									<fo:block>
										<xsl:value-of select="./unitcode" />
									</fo:block>
								</xsl:otherwise>
							</xsl:choose>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="./vunitcd" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
								<xsl:value-of select="./itemdesc" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./unitcost, '##,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./ordercost, '##,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
								<xsl:value-of select="./comment" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
				<fo:table-row>
					<fo:table-cell number-columns-spanned="5">
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name = 'podetail']/row/ordercost), '#,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
</xsl:stylesheet>
