<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('GL Account Summary by Location ', $sold_date[1], ' to ', $sold_date[2])" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
		<xsl:call-template name="main">
				<xsl:with-param name="posfrom" select="0" />    
				<xsl:with-param name="posto" select="6" /> 										
		</xsl:call-template>
		<xsl:if test="/all_results/results[@name = 'loca']/row[position() &gt; 5]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="5" />    
						<xsl:with-param name="posto" select="11" /> 										
				</xsl:call-template>		
		</xsl:if>
		<xsl:if test="/all_results/results[@name = 'loca']/row[position() &gt; 10]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="10" />    
						<xsl:with-param name="posto" select="16" /> 										
				</xsl:call-template>		
		</xsl:if>		
</xsl:template>

<xsl:template name="main">
		<xsl:param name="posfrom" />    
		<xsl:param name="posto" /> 
		
		<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="3.0in" />
				<fo:table-column column-width="1.0in" />
				<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
						<fo:table-column column-width="1.0in" />
				</xsl:for-each>
				<fo:table-header>
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										GL Code
										</fo:block>
								</fo:table-cell>									
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Item Description
										</fo:block>
								</fo:table-cell>																
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Report Month
										</fo:block>
								</fo:table-cell>																									
								<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
													<xsl:value-of select="./location" />
												</fo:block>
										</fo:table-cell>		
								</xsl:for-each>
						</fo:table-row>
				</fo:table-header>
				<fo:table-body>
						<xsl:call-template name="detail">
								<xsl:with-param name="posfrom" select="$posfrom" />    
								<xsl:with-param name="posto" select="$posto" />	
						</xsl:call-template>		
				</fo:table-body>
</fo:table>
</xsl:template>

<xsl:template name="detail">
		<xsl:param name="posfrom" />    
		<xsl:param name="posto" /> 

		<xsl:for-each select="/all_results/results[@name = 'glcodes']/row">
				<xsl:variable name="glacct" select="./glacct" />
				<xsl:variable name="subacct" select="./subacct" />
				<xsl:variable name="item" select="./item" />
				<xsl:variable name="itmdsc" select="./itmdsc" />
				<xsl:variable name="cc" select="./ptrcc" />
				<xsl:variable name="yy" select="./ptryy" />
				<xsl:variable name="mm" select="./ptrmm" />
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:value-of select="$glacct" />
									<xsl:if test="$subacct &gt; 0">
											<xsl:value-of select="'-'" />
											<xsl:value-of select="$subacct" />
									</xsl:if>
							</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<xsl:choose>
							<xsl:when test="normalize-space($item) = 'PAY' and normalize-space($itmdsc) = ''" >
								<fo:block>
									<xsl:value-of select="'Payment'" />
								</fo:block>
							</xsl:when>
							<xsl:otherwise>
								<fo:block>
									<xsl:value-of select="$itmdsc" />
									<xsl:value-of select="' ('" />
									<xsl:value-of select="$item" />
									<xsl:value-of select="')'" />
								</fo:block>
							</xsl:otherwise>
							</xsl:choose>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:value-of select="format-number($mm, '#0')" />
									<xsl:value-of select="' / '" />
									<xsl:value-of select="format-number($cc, '00')" />
									<xsl:value-of select="format-number($yy, '00')" />
							</fo:block>
						</fo:table-cell>						
						<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
								<xsl:variable name="loca" select="./location" />
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
												<xsl:choose>
												<xsl:when test="/all_results/results[@name = 'sum']/row[./location = $loca and ./glacct = $glacct and ./subacct = $subacct and ./item = $item and ./itmdsc = $itmdsc and ./ptrcc = $cc and ./ptryy = $yy and ./ptrmm = $mm]/totinv != 0">
														<xsl:value-of select="format-number(/all_results/results[@name = 'sum']/row[./location = $loca and ./glacct = $glacct and ./subacct = $subacct and ./item = $item and ./itmdsc = $itmdsc and ./ptrcc = $cc and ./ptryy = $yy and ./ptrmm = $mm]/totinv, '$ ##,###,##0.00;$ -#,###,##0.00')"/> 												
												</xsl:when>
												<xsl:otherwise>
														<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												</xsl:otherwise>
												</xsl:choose>
										</fo:block>
								</fo:table-cell>		
						</xsl:for-each>																	
			</fo:table-row>
		</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
