<?xml version="1.0" encoding="utf-8"?>
	<!-- $Id: pos_invoice_listing.xsl,v 1.5 2012-02-14 18:17:01 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:java="http://xml.apache.org/xslt/java" 
				exclude-result-prefixes="java"
				version="2.0">
				
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="concat('POS Invoices Report ', $sold_date[1], ' to ', $sold_date[2])" />
	
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	
	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="/all_results/results[@name = 'data']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="normalize-space(location)">
					<xsl:variable name="soldloca" select="./location" />
					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<fo:table-column column-width="1.4in" />
						<fo:table-column column-width="0.25in" />
						<fo:table-column column-width="0.75in" />
						<fo:table-column column-width="0.9in" />
						<fo:table-column column-width="0.9in" />
						<fo:table-column column-width="0.75in" />
						<fo:table-column column-width="0.4in" />
						<fo:table-column column-width="1.4in" />
						<fo:table-column column-width="0.25in" />
						<fo:table-column column-width="0.75in" />
						<fo:table-column column-width="0.75in" />
						<fo:table-column column-width="0.75in" />
						<fo:table-column column-width="0.75in" />
						<fo:table-body>
							<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="12">
									<fo:block>
										<xsl:value-of select="'Location: '" />
										<xsl:value-of select="$soldloca" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row[location = $soldloca]/totinv) + sum(/all_results/results[@name = 'data']/row[location = $soldloca]/totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<xsl:for-each-group select="current-group()" group-by="normalize-space(ptdate)">
								<xsl:variable name="solddate" select="./ptdate" />
								<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left">
										<fo:block>
											<xsl:value-of select="' '" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="11">
										<fo:block>
											<xsl:value-of select="'Sold Date:  '" />
											<xsl:value-of select="$solddate" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row[location = $soldloca and ptdate = $solddate]/totinv) + sum(/all_results/results[@name = 'data']/row[location = $soldloca and ptdate = $solddate]/totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
								<xsl:for-each-group select="current-group()" group-by="normalize-space(ptrtyp)">
									<xsl:variable name="type" select="./ptrtyp" />
									<fo:table-row>
										<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="3">
											<fo:block>
												<xsl:value-of select="' '" />
											</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="9">
											<fo:block>
												<xsl:value-of select="'Transaction Type:  '" />
												<xsl:choose>
													<xsl:when test="normalize-space($type) = 'PURCHASE'">
														<xsl:value-of select="'Purchase'" />
													</xsl:when>
													<xsl:when test="normalize-space($type) = 'RETURN'">
														<xsl:value-of select="'Return'" />
													</xsl:when>
													<xsl:when test="normalize-space($type) = 'MISC'">
														<xsl:value-of select="'Micellaneous'" />
													</xsl:when>
													<xsl:when test="normalize-space($type) = 'ACCOUNT'">
														<xsl:value-of select="'Account Install'" />
													</xsl:when>
													<xsl:when test="normalize-space($type) = 'SERVICE'">
														<xsl:value-of select="'Service Install'" />
													</xsl:when>
													<xsl:when test="normalize-space($type) = 'PAYMENT'">
														<xsl:value-of select="'Payment'" />
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$type" />
													</xsl:otherwise>
												</xsl:choose>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
											<fo:block>
												<xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row[location = $soldloca and ptdate = $solddate and ptrtyp = $type]/totinv) + sum(/all_results/results[@name = 'data']/row[location = $soldloca and ptdate = $solddate and ptrtyp = $type]/totaltax), '$ ##,###,##0.00;$ -#,###,##0.00')" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
									<xsl:if test="$report_type = 2">
										<xsl:call-template name="detailhead" />
										<xsl:for-each select="/all_results/results[@name = 'data']/row[location = $soldloca and ptdate = $solddate and ptrtyp = $type]">
											<xsl:choose>
												<xsl:when test="tstats = 'O'">
													<fo:table-row background-color="#CCCC66">
															<xsl:call-template name="detailrow">
																<xsl:with-param name="row" select="."/>
															</xsl:call-template>		
													</fo:table-row>		
												</xsl:when>
												<xsl:otherwise>
													<fo:table-row background-color="#FFFFFF">
															<xsl:call-template name="detailrow">
																<xsl:with-param name="row" select="."/>
															</xsl:call-template>		
													</fo:table-row>		
												</xsl:otherwise>
											</xsl:choose>
										</xsl:for-each>
									</xsl:if>
								</xsl:for-each-group>
							</xsl:for-each-group>
						</fo:table-body>
					</fo:table>
				</xsl:for-each-group>
			</xsl:when>
			<xsl:otherwise>
				<fo:block>No Invoices Found</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="detailhead">
		<fo:table-row>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Trans #</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Sts</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Sold By</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Acct #</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Serv #</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Disc Date</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Sold Time</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Item</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Bill</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Item Amount</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Sub-Total Amount</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Total Tax Amount</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Total Invc Amount</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	
	<xsl:template name="detailrow">
		<xsl:param name="row" />

		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="./transno" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="./tstats" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="./uname" />
			</fo:block>
		</fo:table-cell>
		<xsl:choose>
			<xsl:when test="./ptcyc = 0 and ./ptacct = 0">
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center" number-columns-spanned="3">
					<fo:block>
						<xsl:value-of select="'Walk-In'" />
					</fo:block>
				</fo:table-cell>
			</xsl:when>
			<xsl:otherwise>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:if test="./ptcyc != 0 and ./ptacct != 0">
							<xsl:value-of select="format-number(./ptcyc, '000')" />
							<xsl:value-of select="'-'" />
							<xsl:value-of select="format-number(./ptacct, '0000000')" />
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:if test="./ptnpa != 0 and ./ptnxx != 0">
							<xsl:call-template name="phone">
								<xsl:with-param name="npa" select="./ptnpa" />
								<xsl:with-param name="nxx" select="./ptnxx" />
								<xsl:with-param name="line" select="./ptline" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:if test="./ptdcc != 0 and ./ptdyy != 0 and ./ptdmm != 0 and ./ptdd">
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./ptdcc" />
								<xsl:with-param name="yy" select="./ptdyy" />
								<xsl:with-param name="mm" select="./ptdmm" />
								<xsl:with-param name="dd" select="./ptddd" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
			</xsl:otherwise>
		</xsl:choose>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="format-number(./pttmhh, '00')" />
				<xsl:value-of select="':'" />
				<xsl:value-of select="format-number(./pttmmm, '00')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
			<fo:block>
				<xsl:choose>
					<xsl:when test="normalize-space(./ptrtyp) = 'PAYMENT'">
						<xsl:value-of select="'Payment'" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="./item" />
						<xsl:value-of select="' - '" />
						<xsl:value-of select="./itmdsc" />
					</xsl:otherwise>
				</xsl:choose>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells-black" text-align="center">
			<fo:block>
				<xsl:choose>
					<xsl:when test="./bill = 'Y'">
						<xsl:value-of select="./bill" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' '" />
					</xsl:otherwise>
				</xsl:choose>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number(./qty, '##0')" />
				<xsl:value-of select="' @ '" />
				<xsl:value-of select="format-number(./invamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number(./totinv, '$ ##,###,##0.00;$ -#,###,##0.00')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number(./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<fo:block>
				<xsl:value-of select="format-number(./totinv + ./totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
			</fo:block>
		</fo:table-cell>
			
	</xsl:template>
</xsl:stylesheet>