<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Sales Tax by Tax Code Report ', $sold_date[1], ' to ', $sold_date[2])" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
		<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="2.00in" />
				<fo:table-column column-width="0.50in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-header>
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Tax Entity
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Total Item Count
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Total Invoice Sales	
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Total Installment Sales	
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Total Taxable Sales	
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Total Return Amount
										</fo:block>
								</fo:table-cell>			
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Total Net Amount
										</fo:block>
								</fo:table-cell>													
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Total Taxes
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Total Return Taxes Amount
										</fo:block>
								</fo:table-cell>										
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Total Net Taxes Amount
										</fo:block>
								</fo:table-cell>													
						</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/fedtax) != 0">
							<xsl:call-template name="detailrow">
									<xsl:with-param name="descr" select="'Federal Taxes on Adjustments'"/>
									<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/qty)"/>
									<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/purchase)"/>
									<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/instamt)"/>
									<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/taxable)"/>
									<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'A']/returnamt)"/>
									<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/fedtax)"/>
									<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'A']/fedtax)"/>
							</xsl:call-template>
					</xsl:if>
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/fedtax) != 0">
							<xsl:call-template name="detailrow">
									<xsl:with-param name="descr" select="'Federal Taxes on Temp Items'"/>
									<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/qty)"/>
									<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/purchase)"/>
									<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/instamt)"/>
									<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/taxable)"/>
									<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'T']/returnamt)"/>
									<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/fedtax)"/>
									<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'T']/fedtax)"/>
							</xsl:call-template>
					</xsl:if>
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/fedtax) != 0">
							<xsl:call-template name="detailrow">
									<xsl:with-param name="descr" select="'Federal Taxes on Equipment'"/>
									<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/qty)"/>
									<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/purchase)"/>
									<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/instamt)"/>
									<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/taxable)"/>
									<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'E']/returnamt)"/>
									<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/fedtax)"/>
									<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'E']/fedtax)"/>
							</xsl:call-template>
					</xsl:if>
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'PURCHASE']/fedtax) != 0">
							<xsl:call-template name="detailrow">
									<xsl:with-param name="descr" select="'Total Federal Taxes'"/>
									<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/qty)"/>
									<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/purchase)"/>
									<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/instamt)"/>
									<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/taxable)"/>
									<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN']/returnamt)"/>
									<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/fedtax)"/>
									<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN']/fedtax)"/>
							</xsl:call-template>
					</xsl:if>										
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row/citytax) != 0">
						<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="10">
										<fo:block>
												<xsl:value-of select="'City Taxes'"/>
										</fo:block>
								</fo:table-cell>
						</fo:table-row>
						<xsl:for-each-group select="/all_results/results[@name = 'sum']/row[taxed = 'Y']" group-by="./ctname">
							<xsl:variable name="city" select="current-group()[position() = 1]/ctname"/>
	
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'A']/citytax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Adjustments- ', $city)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'A']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'A']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'A']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'A']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp = 'RETURN' and itmtyp = 'A']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'A']/citytax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp = 'RETURN' and itmtyp = 'A']/citytax)"/>
								</xsl:call-template>									
							</xsl:if>
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'T']/citytax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Temp Items- ', $city)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'T']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'T']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'T']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'T']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp = 'RETURN' and itmtyp = 'T']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'T']/citytax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp = 'RETURN' and itmtyp = 'T']/citytax)"/>
								</xsl:call-template>									
							</xsl:if>
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'E']/citytax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Equipment- ', $city)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'E']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'E']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'E']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'E']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp = 'RETURN' and itmtyp = 'E']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN' and itmtyp = 'E']/citytax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp = 'RETURN' and itmtyp = 'E']/citytax)"/>
								</xsl:call-template>									
							</xsl:if>
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN']/citytax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Total taxes for ', $city)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp = 'RETURN']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp != 'RETURN']/citytax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ctname = $city and ptrtyp = 'RETURN']/citytax)"/>
								</xsl:call-template>									
							</xsl:if>																		
						</xsl:for-each-group>
					</xsl:if>

					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y']/countytax) != 0">
						<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="10">
										<fo:block>
												<xsl:value-of select="'County Taxes'"/>
										</fo:block>
								</fo:table-cell>
						</fo:table-row>
						<xsl:for-each-group select="/all_results/results[@name = 'sum']/row" group-by="./cnname">
							<xsl:variable name="county" select="current-group()[position() = 1]/cnname"/>
	
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'A']/countytax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Adjustments-', $county)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'A']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'A']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'A']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'A']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp = 'RETURN' and itmtyp = 'A']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'A']/countytax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp = 'RETURN' and itmtyp = 'A']/countytax)"/>
								</xsl:call-template>									
							</xsl:if>
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'T']/countytax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Temp Items- ', $county)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'T']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'T']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'T']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'T']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp = 'RETURN' and itmtyp = 'T']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'T']/countytax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp = 'RETURN' and itmtyp = 'T']/countytax)"/>
								</xsl:call-template>									
							</xsl:if>
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'E']/countytax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Equipment- ', $county)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'E']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'E']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'E']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'E']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp = 'RETURN' and itmtyp = 'E']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN' and itmtyp = 'E']/countytax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp = 'RETURN' and itmtyp = 'E']/countytax)"/>
								</xsl:call-template>									
							</xsl:if>												
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN']/countytax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Total taxes for ', $county)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp = 'RETURN']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp != 'RETURN']/countytax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and cnname = $county and ptrtyp = 'RETURN']/countytax)"/>
								</xsl:call-template>									
							</xsl:if>
						</xsl:for-each-group>
					</xsl:if>

					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y']/statetax) != 0">
						<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="10">
										<fo:block>
												<xsl:value-of select="'State Taxes'"/>
										</fo:block>
								</fo:table-cell>
						</fo:table-row>
						<xsl:for-each-group select="/all_results/results[@name = 'sum']/row" group-by="./stname">
							<xsl:variable name="state" select="current-group()[position() = 1]/stname"/>
	
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'A']/statetax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Adjustments- ', $state)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'A']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'A']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'A']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'A']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp = 'RETURN' and itmtyp = 'A']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'A']/statetax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp = 'RETURN' and itmtyp = 'A']/statetax)"/>
								</xsl:call-template>									
							</xsl:if>
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'T']/statetax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Temp Items- ', $state)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'T']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'T']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'T']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'T']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp = 'RETURN' and itmtyp = 'T']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'T']/statetax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp = 'RETURN' and itmtyp = 'T']/statetax)"/>
								</xsl:call-template>									
							</xsl:if>
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'E']/statetax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Equipment- ', $state)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'E']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'E']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'E']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'E']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp = 'RETURN' and itmtyp = 'E']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN' and itmtyp = 'E']/statetax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp = 'RETURN' and itmtyp = 'E']/statetax)"/>
								</xsl:call-template>									
							</xsl:if>
							<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN']/statetax) != 0">
								<xsl:call-template name="detailrow">
										<xsl:with-param name="descr" select="concat('Total taxes for ', $state)"/>
										<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN']/qty)"/>
										<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN']/purchase)"/>
										<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN']/instamt)"/>
										<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN']/taxable)"/>
										<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp = 'RETURN']/returnamt)"/>
										<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp != 'RETURN']/statetax)"/>
										<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and stname = $state and ptrtyp = 'RETURN']/statetax)"/>
								</xsl:call-template>									
							</xsl:if>																		
						</xsl:for-each-group>
					</xsl:if>
					
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="10">
									<fo:block>
											<xsl:value-of select="' '"/>
									</fo:block>
							</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="10">
									<fo:block>
											<xsl:value-of select="'Final Totals'"/>
									</fo:block>
							</fo:table-cell>
					</fo:table-row>					
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/statetax) != 0">
						<xsl:call-template name="detailrow">
								<xsl:with-param name="descr" select="'Total Adjustment Taxes'"/>
								<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/qty)"/>
								<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/purchase)"/>
								<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/instamt)"/>
								<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/taxable)"/>
								<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'A']/returnamt)"/>
								<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'A']/statetax)"/>
								<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'A']/statetax)"/>
						</xsl:call-template>									
					</xsl:if>
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/statetax) != 0">
						<xsl:call-template name="detailrow">
								<xsl:with-param name="descr" select="'Total Temp Item Taxes'"/>
								<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/qty)"/>
								<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/purchase)"/>
								<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/instamt)"/>
								<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/taxable)"/>
								<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'T']/returnamt)"/>
								<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'T']/statetax)"/>
								<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'T']/statetax)"/>
						</xsl:call-template>									
					</xsl:if>
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/statetax) != 0">
						<xsl:call-template name="detailrow">
								<xsl:with-param name="descr" select="'Total Equipment Taxes'"/>
								<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/qty)"/>
								<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/purchase)"/>
								<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/instamt)"/>
								<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/taxable)"/>
								<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'E']/returnamt)"/>
								<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN' and itmtyp = 'E']/statetax)"/>
								<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN' and itmtyp = 'E']/statetax)"/>
						</xsl:call-template>									
					</xsl:if>																		
					<xsl:call-template name="detailrow">
							<xsl:with-param name="descr" select="'Total Taxes'"/>
							<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/qty)"/>
							<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/purchase)"/>
							<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/instamt)"/>
							<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/taxable)"/>
							<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN']/returnamt)"/>
							<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/fedtax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/citytax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/countytax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp != 'RETURN']/statetax)"/>
							<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN']/fedtax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN']/citytax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN']/countytax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'Y' and ptrtyp = 'RETURN']/statetax)"/>
					</xsl:call-template>		
					
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="10">
									<fo:block>
											<xsl:value-of select="' '"/>
									</fo:block>
							</fo:table-cell>
					</fo:table-row>
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'A']/taxable) != 0">
						<xsl:call-template name="detailrow">
								<xsl:with-param name="descr" select="'Total Adjustment Not Taxed'"/>
								<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'A']/qty)"/>
								<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'A']/purchase)"/>
								<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'A']/instamt)"/>
								<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'A']/taxable)"/>
								<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN' and itmtyp = 'A']/returnamt)"/>
								<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'A']/statetax)"/>
								<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN' and itmtyp = 'A']/statetax)"/>
						</xsl:call-template>									
					</xsl:if>
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'T']/taxable) != 0">
						<xsl:call-template name="detailrow">
								<xsl:with-param name="descr" select="'Total Temp Item Not Taxed'"/>
								<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'T']/qty)"/>
								<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'T']/purchase)"/>
								<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'T']/instamt)"/>
								<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'T']/taxable)"/>
								<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN' and itmtyp = 'T']/returnamt)"/>
								<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'T']/statetax)"/>
								<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN' and itmtyp = 'T']/statetax)"/>
						</xsl:call-template>									
					</xsl:if>
					<xsl:if test="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'E']/taxable) != 0">
						<xsl:call-template name="detailrow">
								<xsl:with-param name="descr" select="'Total Equipment Not Taxed'"/>
								<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'E']/qty)"/>
								<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'E']/purchase)"/>
								<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'E']/instamt)"/>
								<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'E']/taxable)"/>
								<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN' and itmtyp = 'E']/returnamt)"/>
								<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN' and itmtyp = 'E']/statetax)"/>
								<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN' and itmtyp = 'E']/statetax)"/>
						</xsl:call-template>									
					</xsl:if>																		
					<xsl:call-template name="detailrow">
							<xsl:with-param name="descr" select="'Total Not Taxed'"/>
							<xsl:with-param name="qty" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN']/qty)"/>
							<xsl:with-param name="sales" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN']/purchase)"/>
							<xsl:with-param name="install" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN']/instamt)"/>
							<xsl:with-param name="taxable" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN']/taxable)"/>
							<xsl:with-param name="return" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN']/returnamt)"/>
							<xsl:with-param name="totaltax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN']/fedtax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN']/citytax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN']/countytax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp != 'RETURN']/statetax)"/>
							<xsl:with-param name="returntax" select="sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN']/fedtax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN']/citytax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN']/countytax) + sum(/all_results/results[@name = 'sum']/row[taxed = 'N' and ptrtyp = 'RETURN']/statetax)"/>
					</xsl:call-template>										
				</fo:table-body>
		</fo:table>
</xsl:template>
    
<xsl:template name="detailrow">
		<xsl:param name="descr" />    
		<xsl:param name="qty" />    
		<xsl:param name="sales" />    
		<xsl:param name="install" />    
		<xsl:param name="taxable" />    
		<xsl:param name="return" />    
		<xsl:param name="totaltax" />    
		<xsl:param name="returntax" />    

		<xsl:if test="$sales != 0 or $return != 0">
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
									<xsl:value-of select="$descr" />
							</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number($qty, '##,###,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number($sales, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number($install, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number($taxable, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number($return, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>											
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number($taxable + $return, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number($totaltax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>												
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number($returntax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>												
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number($totaltax + $returntax, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</fo:table-cell>																		
			</fo:table-row>
		</xsl:if>
</xsl:template>

</xsl:stylesheet>
