<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" xmlns:util="java:com.psasoft.util.TextUtilities"
	xmlns:strutil="java:org.apache.commons.lang.StringUtils" exclude-result-prefixes="java" version="2.0">
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="'Provision Inquiry Report'" />
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="/all_results/results[@name = 'data']/row">
				<xsl:variable name="linesplit" select="'||'" />
				<xsl:variable name="newline">
					<xsl:text>&#13;&#10;</xsl:text>
				</xsl:variable>
				<fo:block xsl:use-attribute-sets="report-title">
					<xsl:value-of select="'Phone Number: '" />
					<xsl:call-template name="phone">
						<xsl:with-param name="npa" select="/all_results/results[@name = 'data']/row[position() = 1]/areacode" />
						<xsl:with-param name="nxx" select="/all_results/results[@name = 'data']/row[position() = 1]/exchange" />
						<xsl:with-param name="line" select="/all_results/results[@name = 'data']/row[position() = 1]/line" />
					</xsl:call-template>
				</fo:block>
				<xsl:for-each select="/all_results/results[@name = 'data']/row">
					<xsl:variable name="color">
						<xsl:choose>
							<xsl:when test="./prvsts = 'NEW'">
								<xsl:value-of select="'#FFFFCC'" />
							</xsl:when>
							<xsl:when test="./respcd = 'ERROR'">
								<xsl:value-of select="'#FFCC00'" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'white'" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<fo:table-column column-width="1.3in" />
						<fo:table-column column-width="1.3in" />
						<fo:table-column column-width="1.3in" />
						<fo:table-column column-width=".8in" />
						<fo:table-column column-width="1.3in" />
						<fo:table-column column-width=".8in" />
						<fo:table-column column-width=".8in" />
						<fo:table-column column-width="2in" />
						<fo:table-header>
							<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Submitted</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Started</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Completed</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Action</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Equipment</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Status</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Response</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Comment</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</fo:table-header>
						<fo:table-body>
							<fo:table-row background-color="{$color}">
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./newdate" />
										<xsl:value-of select="' '" />
										<xsl:value-of select="./newtime" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./inpgdate" />
										<xsl:value-of select="' '" />
										<xsl:value-of select="./inpgtime" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./cmpdate" />
										<xsl:value-of select="' '" />
										<xsl:value-of select="./cmptime" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./action" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
										<xsl:value-of select="./eqpdesc" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./prvsts" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./respcd" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
										<xsl:value-of select="util:removeBinary(./resptxt)" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</fo:table-body>
					</fo:table>
					<fo:block space-before="25px" 
							padding-left="25px" 
							font-family="Courier,monospace" 
							font-size="10px" 
							linefeed-treatment="preserve" 
							white-space-collapse="false" 
							white-space-treatment="preserve">
						<xsl:value-of select="strutil:replace(util:removeBinary(./extresponse), $linesplit, $newline)" />
					</fo:block>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px"> No Information Found
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>