<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
							  xmlns:fo="http://www.w3.org/1999/XSL/Format" 
							  xmlns:java="http://xml.apache.org/xslt/java" 
							  xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
							  xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
				              xmlns:saxon="http://saxon.sf.net/"							  
							  xmlns:fn="http://www.w3.org/2005/02/xpath-functions" 
								extension-element-prefixes="saxon"							  
							  exclude-result-prefixes="java" 
							  version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="concat('Quarantine Unassigned Numbers As Of ', $quarantine_as_of_date)" />

    <xsl:variable name="oldtype" />
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>	
    <xsl:template name="body_process">
		 <xsl:choose>
			<xsl:when test="/all_results/results[@name = 'unq']/row">
				<xsl:for-each-group select="/all_results/results[@name='unq']/row" group-by="./srvtyp">
					<xsl:variable name="type" select="current-group()[position() = 1]/srvtyp"/>
					<xsl:variable name="typedesc" select="current-group()[position() = 1]/srvdsc"/>
					<xsl:variable name="qdays" select="current-group()[position() = 1]/undays"/>
						<xsl:variable name="total" select="count(/all_results/results[@name='unq']/row[srvtyp = $type])" />
					
		    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always" space-before="10px" space-after="5px">
		    				<xsl:value-of select="$typedesc"/>
				    		<xsl:value-of select="': Length of Quarantine Period - '"/>
		    				<xsl:value-of select="$qdays"/>
						    <xsl:value-of select="' days, Total = '"/>
						    <xsl:value-of select="$total"/>
						
		    		</fo:block>					
						
				<fo:table table-layout="fixed" width="100%" space-before="5px">
				     <fo:table-column column-width="1.50in" />
					 <fo:table-column column-width="0.50in" />
					 <fo:table-column column-width="1.50in" />
					 <fo:table-column column-width="1.50in" />
				     <fo:table-header>
						<fo:table-row>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Phone No.</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Status</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Quarantine Start</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Quarantine End</fo:block>
					    	</fo:table-cell>														
						</fo:table-row>
					 </fo:table-header>
					 <fo:table-body>
						     <xsl:for-each select="/all_results/results[@name = 'unq']/row[srvtyp = $type]">	
						 		<fo:table-row number-columns-spanned="4">
	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
	                                        <xsl:value-of select="./mdn" />
	                                    </fo:block>
	                                </fo:table-cell>
	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
	                                        <xsl:value-of select="./status" />
	                                    </fo:block>
	                                </fo:table-cell>
	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
											<xsl:call-template name="date1parm-db">
												<xsl:with-param name="date" select="./qstart" />
											</xsl:call-template>	
	                                    </fo:block>
	                                </fo:table-cell>	
	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
											<xsl:call-template name="date1parm-db">
												<xsl:with-param name="date" select="./qend" />
											</xsl:call-template>	
	                                    </fo:block>
	                                </fo:table-cell>											
								</fo:table-row>
						 </xsl:for-each>
					 </fo:table-body>
				</fo:table>
			</xsl:for-each-group>	
			</xsl:when>
       		<xsl:when test="count(/all_results/results[@name = 'unq']/row) &lt; 1">
          		<fo:block xsl:use-attribute-sets="category-label">No Unassigned numbers are in quarantine.</fo:block>
       		</xsl:when>				
	 	</xsl:choose>
    </xsl:template>
</xsl:stylesheet>
