<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
							    xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
							    xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
								exclude-result-prefixes="java" 
								version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="concat('Sales Return Report ', $return_date_range[1], ' to ', $return_date_range[2])" />
    
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>
    <xsl:template name="body_process">
    		<xsl:choose>
				<xsl:when test="/all_results/results[@name = 'data']/row">	
						<xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="./locationid">
								<xsl:variable name="company" select="./company" />
								<xsl:variable name="location" select="./location" />
								<xsl:variable name="locationid" select="./locationid" />
								<fo:block xsl:use-attribute-sets="summary-headings">
										<xsl:value-of select="'Company:  '"/>
										<xsl:value-of select="$company"/>
								</fo:block>
								<fo:block xsl:use-attribute-sets="summary-headings">
										<xsl:value-of select="'Location:  '"/>
										<xsl:value-of select="$location"/>
								</fo:block>
								<xsl:call-template name="location">
									<xsl:with-param name="locaid" select="$locationid"/>
								</xsl:call-template>    		
								<xsl:if test="position() != last()">
									<fo:block break-after="page"/>
								</xsl:if>
						</xsl:for-each-group>
				</xsl:when>
				<xsl:otherwise>
						<fo:block space-before="16px">No Returns Found for Date Range</fo:block>
				</xsl:otherwise>
				</xsl:choose>							
    </xsl:template>
    
    <xsl:template name="location">
    		<xsl:param name="locaid" />
				<fo:table table-layout="fixed" width="100%" space-before="16px">
						<fo:table-column column-width="0.8in" />
						<fo:table-column column-width="1.3in" />
						<fo:table-column column-width="1.8in" />
						<fo:table-column column-width="0.9in" />
						<fo:table-column column-width="0.5in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.4in" />
						<fo:table-column column-width="0.8in" />
						<fo:table-column column-width="0.7in" />
						<fo:table-column column-width="0.7in" />
						<fo:table-header>
								<fo:table-row keep-with-next="always">
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Return Date
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Transaction Number
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												<fo:inline font-style="italic">Reason</fo:inline> / Comment
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Account # / Mobile (MDN)
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Item Code
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Item Desc
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Serial / IMEI
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Sale Date 	
												</fo:block>
										</fo:table-cell>										
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Sale Price 	
												</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
												Return Price
												</fo:block>
										</fo:table-cell>
								</fo:table-row>
					  </fo:table-header>
					  <fo:table-body>
						<xsl:for-each select="/all_results/results[@name = 'data']/row[locationid = $locaid]">
                            <xsl:variable name="unitid" select="./unitid" />
                            <xsl:variable name="serial2typ" select="./serial2typ" />
						
							<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
												<xsl:value-of select="./rtndate" />
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
												<xsl:value-of select="./salerefno" />
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block font-style="italic" wrap-option="wrap">
											<xsl:value-of select="./xferreason" />
										</fo:block>
										<fo:block wrap-option="wrap">
											<xsl:value-of select="./comment" />
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
											<xsl:if test="normalize-space(./ptcyc) &gt; '' and normalize-space(./ptacct) &gt; '' and ./ptcyc &gt; 0 and ./ptacct &gt; 0">
												<xsl:value-of select="format-number(./ptcyc, '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(./ptacct, '0000000')" />
											</xsl:if>
										</fo:block>
										<fo:block>
											<xsl:if test="normalize-space(./ptnpa) &gt; '' and normalize-space(./ptnxx) &gt; '' and normalize-space(./ptline) &gt; '' and ./ptnpa &gt; 0 and ./ptnxx &gt; 0 and ./ptline &gt; 0">
												<xsl:value-of select="format-number(./ptnpa, '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(./ptnxx, '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(./ptline, '0000')" />
											</xsl:if>
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
												<xsl:choose>
														<xsl:when test="./externalcd != ''">
																<fo:block>
																		<xsl:value-of select="./externalcd" />
																</fo:block>
														</xsl:when>
														<xsl:otherwise>
																<fo:block>
																		<xsl:value-of select="./unitcode" />
																</fo:block>
														</xsl:otherwise>
												</xsl:choose>										
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block wrap-option="wrap">
												<xsl:value-of select="./itemdesc" />
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
	                                        <fo:inline space-end="0.2in" space-start.precedence="force">
												<xsl:call-template name="formatserial">
													<xsl:with-param name="serial" select="./serialno2" />
													<xsl:with-param name="serial0" select="./serialno" />
													<xsl:with-param name="serial2typ" select="$serial2typ" />
													<xsl:with-param name="unitid" select="$unitid" />
													<xsl:with-param name="actpin" select="./actpin" />
													<xsl:with-param name="npa" select="./npa" />
													<xsl:with-param name="nxx" select="./nxx" />
													<xsl:with-param name="line" select="./line" />
												</xsl:call-template>
	                                        </fo:inline>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
												<xsl:value-of select="./saledate" />
										</fo:block>
									</fo:table-cell>									
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
												<xsl:value-of select="format-number(./saleprice, '##,##0.00')" />
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
												<xsl:value-of select="format-number(./rtnprice, '##,##0.00')" />
										</fo:block>
									</fo:table-cell>												
								</fo:table-row>
							</xsl:for-each>
						</fo:table-body>
				</fo:table>
    </xsl:template>
</xsl:stylesheet>
