<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: servexpire.xsl,v 1.3 2012-12-31 12:34:25 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
								exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
   <xsl:import href="subtemplates.xsl"/> 
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
	<xsl:variable name="title" select="concat('Contract Expiration Report ', $expire_date_range[1], ' to ', $expire_date_range[2])" />

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		<xsl:call-template name="make-layout-master-set-landscape" />
		<xsl:call-template name="make-body-landscape" />
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'data']/row) and $sort_type = 1">
		<xsl:for-each-group select="/all_results/results[@name='data']/row" group-by="./cumrkt">
			<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt" />
			<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />

			<xsl:for-each-group select="/all_results/results[@name='data']/row[cumrkt = $market]"  group-by="concat(./cnpa, ./cnxx)">
					<xsl:variable name="areacode" select="current-group()[position() = 1]/cnpa"/>
					<xsl:variable name="exchange" select="current-group()[position() = 1]/cnxx"/>
					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<xsl:call-template name="header">
								<xsl:with-param name="market" select="$market"/>
								<xsl:with-param name="marketname" select="$marketname"/>
								<xsl:with-param name="npa" select="$areacode"/>
								<xsl:with-param name="nxx" select="$exchange"/>
								<xsl:with-param name="agent" select="0"/>
								<xsl:with-param name="agbus" select="''"/>
								<xsl:with-param name="agfsnm" select="''"/>
								<xsl:with-param name="aglsnm" select="''"/>
						</xsl:call-template>										
						<fo:table-body>
								<xsl:for-each select="/all_results/results[@name = 'data']/row[cumrkt = $market and cnpa = $areacode and cnxx = $exchange]">
										<xsl:call-template name="detail">
											<xsl:with-param name="row" select="."/>
										</xsl:call-template>							
							 </xsl:for-each>
							</fo:table-body>
					</fo:table>			
		    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="10px" space-after="10px">
		    				<xsl:value-of select="'Total Services for Area Code / Exchange ( '"/>
		    				<xsl:value-of select="$areacode"/>
		    				<xsl:value-of select="'-'"/>
		    				<xsl:value-of select="$exchange"/>
		    				<xsl:value-of select="' ): '"/>
		    				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cumrkt = $market and cnpa = $areacode and cnxx = $exchange]), '###,##0')"/>
		    		</fo:block>								
				</xsl:for-each-group>	
	    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="0px" space-after="10px">
	    				<xsl:value-of select="'Total Services for Market ( '"/>
	    				<xsl:value-of select="$market"/>
	    				<xsl:value-of select="' - '"/>
	    				<xsl:value-of select="$marketname"/>
	    				<xsl:value-of select="' ): '"/>
	    				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cumrkt = $market]), '###,##0')"/>
	    		</fo:block>	
	    										
			</xsl:for-each-group>
			<fo:block xsl:use-attribute-sets="summary-headings">
					<xsl:value-of select="'Total Services:  '"/>
					<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row), '###,##0')"/>
			</fo:block>								
	</xsl:when>
	
	<xsl:when test="exists(/all_results/results[@name = 'data']/row) and $sort_type = 2">
		<xsl:for-each-group select="/all_results/results[@name='data']/row" group-by="./cumrkt">
			<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt" />
			<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />
	
			<xsl:for-each-group select="/all_results/results[@name='data']/row[cumrkt = $market]"  group-by="./agcd1">
					<xsl:variable name="agent" select="current-group()[position() = 1]/agcd1"/>
					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<xsl:call-template name="header">
								<xsl:with-param name="market" select="$market"/>
								<xsl:with-param name="marketname" select="$marketname"/>
								<xsl:with-param name="npa" select="0"/>
								<xsl:with-param name="nxx" select="0"/>
								<xsl:with-param name="agent" select="$agent"/>
								<xsl:with-param name="agbus" select="./agbus"/>
								<xsl:with-param name="agfsnm" select="./agfsnm"/>
								<xsl:with-param name="aglsnm" select="./aglsnm"/>
						</xsl:call-template>
						<fo:table-body>
								<xsl:for-each select="/all_results/results[@name = 'data']/row[cumrkt = $market and agcd1 = $agent]">
										<xsl:call-template name="detail">
											<xsl:with-param name="row" select="."/>
										</xsl:call-template>							
							 </xsl:for-each>
							</fo:table-body>
					</fo:table>			
		    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="10px" space-after="10px">
		    				<xsl:value-of select="'Total Services for Agent ( '"/>
		    				<xsl:value-of select="$agent"/>
		    				<xsl:value-of select="' ): '"/>
		    				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cumrkt = $market and agcd1 = $agent]), '###,##0')"/>
		    		</fo:block>								
				</xsl:for-each-group>
	    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="0px" space-after="10px">
	    				<xsl:value-of select="'Total Services for Market ( '"/>
	    				<xsl:value-of select="$market"/>
	    				<xsl:value-of select="' - '"/>
	    				<xsl:value-of select="$marketname"/>
	    				<xsl:value-of select="' ): '"/>
	    				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cumrkt = $market]), '###,##0')"/>
	    		</fo:block>								

			</xsl:for-each-group>					
			<fo:block xsl:use-attribute-sets="summary-headings">
					<xsl:value-of select="'Total Services:  '"/>
					<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row), '###,##0')"/>
			</fo:block>								
		</xsl:when>
		
		<xsl:when test="exists(/all_results/results[@name = 'data']/row) and $sort_type = 3">
			<xsl:for-each-group select="/all_results/results[@name='data']/row" group-by="./cumrkt">
				<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt" />
				<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />
				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<xsl:call-template name="header">
						<xsl:with-param name="market" select="$market" />
						<xsl:with-param name="marketname" select="$marketname" />
						<xsl:with-param name="npa" select="0" />
						<xsl:with-param name="nxx" select="0" />
						<xsl:with-param name="agent" select="0" />
						<xsl:with-param name="agbus" select="''" />
						<xsl:with-param name="agfsnm" select="''" />
						<xsl:with-param name="aglsnm" select="''" />
					</xsl:call-template>
					<fo:table-body>
						<xsl:for-each select="/all_results/results[@name = 'data']/row[cumrkt = $market]">
							<xsl:call-template name="detail">
								<xsl:with-param name="row" select="." />
							</xsl:call-template>
						</xsl:for-each>
					</fo:table-body>
				</fo:table>
				<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="0px" space-after="10px">
					<xsl:value-of select="'Total Services for Market ( '" />
					<xsl:value-of select="$market" />
					<xsl:value-of select="' - '" />
					<xsl:value-of select="$marketname" />
					<xsl:value-of select="' ): '" />
					<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cumrkt = $market]), '###,##0')" />
				</fo:block>
			</xsl:for-each-group>
			<fo:block xsl:use-attribute-sets="summary-headings">
				<xsl:value-of select="'Total Services:  '" />
				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row), '###,##0')" />
			</fo:block>
		</xsl:when>
		
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
				No Information Found
			</fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="header">
	<xsl:param name="market" />
	<xsl:param name="marketname" />
	<xsl:param name="npa" />
	<xsl:param name="nxx" />
	<xsl:param name="agent" />
	<xsl:param name="agbus" />
	<xsl:param name="agfsnm" />
	<xsl:param name="aglsnm" />
	
	<xsl:variable name="cols">
		<xsl:choose>
		<xsl:when test="$report_type = 2" >
			<xsl:value-of select="9"/>
		</xsl:when>											
		<xsl:otherwise>
			<xsl:value-of select="8"/>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:choose>
	<xsl:when test="$report_type = 2">
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="0.50in" />
		<fo:table-column column-width="0.50in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="0.50in" />
		<fo:table-column column-width="1.50in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="0.75in" />
	</xsl:when>
	<xsl:otherwise>
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="2.00in" />
		<fo:table-column column-width="0.50in" />
		<fo:table-column column-width="0.50in" />
		<fo:table-column column-width="2.25in" />
		<fo:table-column column-width="0.50in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
	</xsl:otherwise>
	</xsl:choose>
	<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell number-columns-spanned="{$cols}">
						<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always">
								<xsl:value-of select="'Market:  '"/>
								<xsl:value-of select="$market"/>
								<xsl:value-of select="' - '"/>
								<xsl:value-of select="$marketname"/>
						</fo:block>			
					</fo:table-cell>
			</fo:table-row>
			<fo:table-row keep-with-next="always">
					<fo:table-cell number-columns-spanned="{$cols}">
						<xsl:choose>
								<xsl:when test="$npa &gt; 0 and $nxx &gt; 0">
										<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always">
												<xsl:value-of select="'Area Code / Exchange:  '"/>
												<xsl:value-of select="$npa"/>
												<xsl:value-of select="' - '"/>
												<xsl:value-of select="format-number($nxx, '000')"/>
										</fo:block>			
								</xsl:when>
								<xsl:when test="$agent &gt; 0">
										<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always">
												<xsl:value-of select="'Agent:  '"/>
												<xsl:value-of select="$agent"/>
												<xsl:value-of select="' - '"/>
												<xsl:value-of select="$agbus"/>
												<xsl:value-of select="' '"/>
												<xsl:value-of select="$agfsnm"/>
												<xsl:value-of select="' '"/>
												<xsl:value-of select="$aglsnm"/>
										</fo:block>			
								</xsl:when>
						</xsl:choose>
					</fo:table-cell>
			</fo:table-row>
			<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Contract Expire Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Account</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>MDN</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Status</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Customer Name</fo:block>
					</fo:table-cell>								
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Plan Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Toll Plan</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Plan</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Plan Rate</fo:block>
					</fo:table-cell>
					<xsl:if test="$report_type = 1">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Home Number</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Work Number</fo:block>
						</fo:table-cell>
					</xsl:if>
					<xsl:if test="$report_type = 2">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Address</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>City, State</fo:block>
							</fo:table-cell>					
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Zip</fo:block>
							</fo:table-cell>						
					</xsl:if>
			</fo:table-row>
	</fo:table-header>
</xsl:template>

<xsl:template name="detail">
		<xsl:param name="row" />
		
		<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:call-template name="date4parm">
							<xsl:with-param name="cc" select="./scexcc"/>
							<xsl:with-param name="yy" select="./scexyy"/>
							<xsl:with-param name="mm" select="./scexmm"/>
							<xsl:with-param name="dd" select="./scexdd"/>
						</xsl:call-template>						
					</fo:block>
				</fo:table-cell>										
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:value-of select="format-number(./cycle, '000')" />
						<xsl:value-of select="'-'" />
						<xsl:value-of select="format-number(./account, '0000000')" />
					</fo:block>
				</fo:table-cell>																		
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:call-template name="phone">
							<xsl:with-param name="npa" select="./cnpa"/>
							<xsl:with-param name="nxx" select="./cnxx"/>
							<xsl:with-param name="line" select="./cline"/>
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:choose>
						<xsl:when test="./dcmm = 99">
								<xsl:value-of select="'Suspend Nonpay'"/>
						</xsl:when>
						<xsl:when test="./dcmm > 0">
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./dccc"/>
								<xsl:with-param name="yy" select="./dcyy"/>
								<xsl:with-param name="mm" select="./dcmm"/>
								<xsl:with-param name="dd" select="./dcdd"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="./mstat = 'S'">
								<xsl:value-of select="'Manual Suspend'"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'Active'"/>
						</xsl:otherwise>
						</xsl:choose>
						<xsl:value-of select="' '"/>
					</fo:block>
				</fo:table-cell>										
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
							<xsl:value-of select="./fname" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="./lname" />									
					</fo:block>
				</fo:table-cell>	
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:choose>
							<xsl:when test="./plan != ''">
								<xsl:value-of select="./plan"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="./crtpln"/>							
							</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
							<xsl:value-of select="./tlrt"/>
					</fo:block>
				</fo:table-cell>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./plandesc"/>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="right">
					<fo:block>
						<xsl:choose>
							<xsl:when test="./itmrat != ''">
									<xsl:value-of select="format-number(./itmrat, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="''"/>							
							</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
			 	<xsl:if test="$report_type = 1">
					<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
						<fo:block>
							<xsl:choose>
								<xsl:when test="./ctnpa != '0'">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="./ctnpa"/>
										<xsl:with-param name="nxx" select="./ctnxx"/>
										<xsl:with-param name="line" select="./ctline"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="''"/>							
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
						<fo:block>
							<xsl:choose>
								<xsl:when test="./ctnpa2 != '0'">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="./ctnpa2"/>
										<xsl:with-param name="nxx" select="./ctnxx2"/>
										<xsl:with-param name="line" select="./ctlin2"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="''"/>							
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
				</xsl:if>
				<xsl:if test="$report_type = 2">
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
								<fo:block>
										<xsl:value-of select="./adln1" />
								</fo:block>
								<fo:block>
										<xsl:value-of select="./adln2" />
								</fo:block>
								<fo:block>
										<xsl:value-of select="./adln3" />
								</fo:block>									
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
								<fo:block>
									<xsl:value-of select="./adcity" />
									<xsl:value-of select="', '" />
									<xsl:value-of select="./adst" />								
								</fo:block>
						</fo:table-cell>					
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
								<fo:block>
									<xsl:value-of select="format-number(number(substring(./adzip, 1, 5)), '00000')" />
									<xsl:if test="string-length(normalize-space(./adzip)) &gt; 5">
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number(number(substring(./adzip, 6, 4)), '0000')" />
									</xsl:if>								
								</fo:block>
						</fo:table-cell>						
				</xsl:if>
			</fo:table-row>			
</xsl:template>

</xsl:stylesheet>






