<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" exclude-result-prefixes="java"
	version="2.0">
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="concat('Service Order Statistics Report ', $order_date[1], ' to ', $order_date[2])" />
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:choose>
			<xsl:when test="/all_results/results[@name = 'sum']/row and $report_type = 1">
				<xsl:call-template name="make-layout-master-set" />
				<xsl:call-template name="make-body" />
			</xsl:when>
			<xsl:when test="/all_results/results[@name = 'detail']/row and $report_type = 2">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="make-layout-master-set" />
				<xsl:call-template name="make-body" />
			</xsl:otherwise>
			</xsl:choose>	
		</fo:root>
	</xsl:template>
	<xsl:template name="body_process">
		<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'sum']/row and $report_type = 1">
			<xsl:call-template name="summary" />
		</xsl:when>
		<xsl:when test="/all_results/results[@name = 'detail']/row and $report_type = 2">
			<xsl:call-template name="detail" />
		</xsl:when>
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
				No Information Found For selection criteria
			</fo:block>		
		</xsl:otherwise>
		</xsl:choose>	
	</xsl:template>
	
	<xsl:template name="detail">
		<xsl:for-each-group select="/all_results/results[@name = 'detail']/row" group-by="marketid">
			<xsl:variable name="market" select="current-group()[position() = 1]/marketid" />
			<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />	
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.25in" />
				<fo:table-column column-width="2.00in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="1.00in" />
				<fo:table-column column-width="1.75in" />
				<fo:table-column column-width="1.00in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="0.50in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="8" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="$market" />
								<xsl:value-of select="' - '" />
								<xsl:value-of select="$marketname" />
							</fo:block>					
							<xsl:if test="$user != '-1'">
								<fo:block xsl:use-attribute-sets="summary-headings" space-before="2px">
									<xsl:value-of select="'For User: '" />
									<xsl:value-of select="/all_results/results[@name = 'user']/row/name" />
									<xsl:value-of select="' ('" />
									<xsl:value-of select="/all_results/results[@name = 'user']/row/uname" />
									<xsl:value-of select="') '" />
								</fo:block>
							</xsl:if>					
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Trans Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Trans Type</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Eff Date</fo:block>
						</fo:table-cell>					
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Account</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Account Name</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Service</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Disc Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>CSR</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:call-template name="detailrow">
						<xsl:with-param name="market" select="$market" />
					</xsl:call-template>
					<fo:table-row keep-together="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="7">
							<fo:block>
								<xsl:value-of select="'Total'" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(count(/all_results/results[@name = 'detail']/row[marketid = $market]), '##,###,##0')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>	
		</xsl:for-each-group>
	</xsl:template>

	<xsl:template name="detailrow">
	<xsl:param name="market" />
	
		<xsl:for-each select="/all_results/results[@name = 'detail']/row[marketid = $market]">
			<fo:table-row keep-together="always">
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./trdate" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./trtime" />
					</fo:block>
				</fo:table-cell>			
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./type" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:value-of select="./effdt" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:value-of select="format-number(./cycle, '000')" />
						<xsl:value-of select="'-'" />
						<xsl:value-of select="format-number(./account, '0000000')" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./fname" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./lname" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:if test="./cnpa &gt; 0 and ./cnxx &gt; 0">
							<xsl:call-template name="phone">
								<xsl:with-param name="npa" select="./cnpa" />
								<xsl:with-param name="nxx" select="./cnxx" />
								<xsl:with-param name="line" select="./cline" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:if test="./dcmm &gt; 0 and ./dcmm != 99">
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./dccc" />
								<xsl:with-param name="yy" select="./dcyy" />
								<xsl:with-param name="mm" select="./dcmm" />
								<xsl:with-param name="dd" select="./dcdd" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./uname" />
					</fo:block>
				</fo:table-cell>				
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>
		
	<xsl:template name="summary">
		<xsl:for-each-group select="/all_results/results[@name = 'sum']/row" group-by="marketid">
			<xsl:variable name="market" select="current-group()[position() = 1]/marketid" />
			<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />	
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="2.50in" />
				<fo:table-column column-width="1.50in" />
				<fo:table-column column-width="1.50in" />
				<fo:table-column column-width="1.00in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="4" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="$market" />
								<xsl:value-of select="' - '" />
								<xsl:value-of select="$marketname" />
							</fo:block>					
							<xsl:if test="$user != '-1'">
								<fo:block xsl:use-attribute-sets="summary-headings" space-before="2px">
									<xsl:value-of select="'For User: '" />
									<xsl:value-of select="/all_results/results[@name = 'user']/row/name" />
									<xsl:value-of select="' ('" />
									<xsl:value-of select="/all_results/results[@name = 'user']/row/uname" />
									<xsl:value-of select="') '" />
								</fo:block>
							</xsl:if>					
						</fo:table-cell>
					</fo:table-row>			
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> Order Type</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> First Time in Range</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> Last Time in Range</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> Count</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:call-template name="summaryrow">
						<xsl:with-param name="market" select="$market" />
					</xsl:call-template>
					<fo:table-row keep-together="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="3">
							<fo:block>
								<xsl:value-of select="'Total'" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(sum(/all_results/results[@name = 'sum']/row[marketid = $market]/cnt), '##,###,##0')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</xsl:for-each-group>
	</xsl:template>
	
	<xsl:template name="summaryrow">
	<xsl:param name="market" />
		<xsl:for-each select="/all_results/results[@name = 'sum']/row[marketid = $market]">
			<fo:table-row keep-together="always">
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./type" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:value-of select="./mindate" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./mintime" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:value-of select="./maxdate" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./maxtime" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="right">
					<fo:block>
						<xsl:value-of select="format-number(./cnt, '##,###,##0')" />
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>