<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: sold_stats.xsl,v 1.6 2017-08-30 14:32:39 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
								exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
	<xsl:variable name="title" select="concat('Sold Statistics Report ', $sold_date[1], ' to ', $sold_date[2])" />



<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set"/>
		<xsl:call-template name="make-body"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
	<xsl:when test="/all_results/results[@name = 'data']/row">
		<xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="./cumrkt">
				<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt"/>
				<xsl:call-template name="detail">
					<xsl:with-param name="market" select="$market"/>
				</xsl:call-template>				
		</xsl:for-each-group>
	</xsl:when>
	<xsl:otherwise>
		<fo:block xsl:use-attribute-sets="category-label">
			No Information Found
		</fo:block>								
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="detail">
<xsl:param name="market" />

	<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="3.00in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-header>
					<fo:table-row keep-with-next="always">
							<fo:table-cell number-columns-spanned="6">
									<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
										Market: <xsl:value-of select="$market"/> - <xsl:value-of select="/all_results/results[@name = 'market']/row[mrktmr = $market]/descmr"/>
									</fo:block>							
							</fo:table-cell>
					</fo:table-row>
					<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Item Code</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Item Description</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Number Sold</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Minimum Sold Amount</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Maximum Sold Amount</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Last Sold Date</fo:block>
							</fo:table-cell>
					</fo:table-row>
			</fo:table-header>				
			<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'data']/row[cumrkt = $market]">
						<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<xsl:choose>
												<xsl:when test="./unitcode != ''">
														<fo:block>
																<xsl:value-of select="./unitcode" />
														</fo:block>
												</xsl:when>
												<xsl:otherwise>
														<fo:block>
																<xsl:value-of select="./externalcd" />
														</fo:block>
												</xsl:otherwise>
										</xsl:choose>								
								</fo:table-cell>										
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">									
									<fo:block>
												<xsl:value-of select="./itemdesc"/>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">									
									<fo:block>
										<xsl:value-of select="format-number(./soldcount, '##,###,##0')"/>
									</fo:block>
								</fo:table-cell>								
								<xsl:choose>
								<xsl:when test="./minsoldamt &gt; '' and ./minsoldamt != 0">
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">									
											<fo:block>
												<xsl:value-of select="format-number(./minsoldamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
											</fo:block>
										</fo:table-cell>
								</xsl:when>
								<xsl:otherwise>
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">									
											<fo:block>
												<xsl:value-of select="'-'"/>
											</fo:block>
										</fo:table-cell>
								</xsl:otherwise>
								</xsl:choose>											
								<xsl:choose>
								<xsl:when test="./maxsoldamt &gt; ''  and ./maxsoldamt != 0">
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">									
											<fo:block>
												<xsl:value-of select="format-number(./maxsoldamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
											</fo:block>
										</fo:table-cell>
								</xsl:when>
								<xsl:otherwise>
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">									
											<fo:block>
												<xsl:value-of select="'-'"/>
											</fo:block>
										</fo:table-cell>
								</xsl:otherwise>
								</xsl:choose>											
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">									
									<fo:block>
										 <xsl:value-of select="./lastsaledate"/>
									</fo:block>
								</fo:table-cell>								
							</fo:table-row>		
				 </xsl:for-each>
				</fo:table-body>
		</fo:table>				 
</xsl:template>
</xsl:stylesheet>






