<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: soldexcept.xsl,v 1.11 2017-10-02 14:52:01 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:java="http://xml.apache.org/xslt/java" 
				xmlns:exsl="http://exslt.org/functions" 
				xmlns:fn="http://www.w3.org/2005/02/xpath-functions" 
				exclude-result-prefixes="java" 
				version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
    <xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="'Sold Exception Report'" />
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>
    <xsl:template name="body_process">
        <xsl:choose>
            <xsl:when test="/all_results/results[@name = 'mastsum']/row">
                <xsl:for-each-group select="/all_results/results[@name = 'mastsum']/row" group-by="company">
                    <xsl:variable name="company" select="current-grouping-key()" />
                    <xsl:for-each-group select="current-group()" group-by="current-group()/loca">
                        <xsl:variable name="location" select="current-grouping-key()" />
                        <xsl:if test="position() &gt; 1">
                            <fo:block break-after="page" />
                        </xsl:if>
                        <fo:table table-layout="fixed" width="100%" space-before="16px">
                            <fo:table-column column-width="1.0in" />
                            <fo:table-column column-width="1.5in" />
                            <fo:table-column column-width="1.0in" />
                            <fo:table-column column-width="0.5in" />
                            <fo:table-column column-width="1.5in" />
                            <fo:table-column column-width="1.0in" />
                            <fo:table-column column-width="1.0in" />
                            <fo:table-column column-width="1.0in" />
                            <fo:table-column column-width="0.7in" />
                            <fo:table-header>
                                <fo:table-row keep-with-next="always">
                                    <fo:table-cell xsl:use-attribute-sets="summary-title" number-columns-spanned="7">
                                        <fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left">Company: 
                                        <xsl:value-of select="$company" />
                                        </fo:block>
                                        <fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="0px" space-after="6px" text-align="left">Location: 
                                        <xsl:value-of select="$location" />
                                        </fo:block>
                                    </fo:table-cell>
                                </fo:table-row>
                                <fo:table-row keep-with-next="always">
                                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                                        <fo:block>Item Code</fo:block>
                                    </fo:table-cell>
                                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                                        <fo:block>Item Description</fo:block>
                                    </fo:table-cell>
                                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                                        <fo:block>Sold Date</fo:block>
                                    </fo:table-cell>
                                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                                        <fo:block>Sold Price</fo:block>
                                    </fo:table-cell>
                                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                                        <fo:block>Sold Ref #</fo:block>
                                    </fo:table-cell>
                                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                                        <fo:block>Sold By</fo:block>
                                    </fo:table-cell>
                                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                                        <fo:block>Sold To Account</fo:block>
                                    </fo:table-cell>
                                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                                        <fo:block>Sold To Service Number</fo:block>
                                    </fo:table-cell>
                                    <fo:table-cell xsl:use-attribute-sets="table-headings">
                                        <fo:block>Quantity</fo:block>
                                    </fo:table-cell>
                                </fo:table-row>
                            </fo:table-header>
                            <fo:table-body>
                                <xsl:for-each select="/all_results/results[@name = 'mastsum']/row[company = $company and loca = $location]">
                                    <xsl:variable name="companyid" select="./companyid" />
                                    <xsl:variable name="locationid" select="./locationid" />
                                    <xsl:variable name="saledate" select="./saledate" />
                                    <xsl:variable name="saleby" select="./saleby" />
                                    <xsl:variable name="saleprice" select="./saleprice" />
                                    <xsl:variable name="salerefno" select="./salerefno" />
                                    <fo:table-row>
                                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
                                            <xsl:choose>
                                                <xsl:when test="./externalcd != ''">
                                                    <fo:block>
                                                        <xsl:value-of select="./externalcd" />
                                                    </fo:block>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <fo:block>
                                                        <xsl:value-of select="./unitcode" />
                                                    </fo:block>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </fo:table-cell>
                                        <fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
                                            <fo:block>
                                                <xsl:value-of select="./unitdesc" />
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
                                            <fo:block>
                                                <xsl:value-of select="./saledate" />
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                                            <fo:block>
                                                <xsl:value-of select="format-number(./saleprice, '##,###,##0.00')" />
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
                                            <fo:block>
                                                <xsl:value-of select="./salerefno" />
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
                                            <fo:block>
                                                <xsl:value-of select="./salebyname" />
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
                                            <fo:block>
                                                <xsl:if test="exists(./ptacct) and ./ptacct &gt; '0'">
													<!-- xsl:value-of select="format-number(./cycle, '000')" />
                                                    <xsl:value-of select="'-'" / -->
                                                    <xsl:value-of select="format-number(./ptacct, '0000000')" />
                                                </xsl:if>
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
                                            <fo:block>
                                                <xsl:if test="exists(./ptnpa) and ./ptnpa &gt; '0'">
                                                    <xsl:call-template name="phone">
                                                        <xsl:with-param name="npa" select="./ptnpa" />
                                                        <xsl:with-param name="nxx" select="./ptnxx" />
                                                        <xsl:with-param name="line" select="./ptline" />
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                                            <fo:block>
                                                <xsl:value-of select="format-number(./qty, '##,##0')" />
                                            </fo:block>
                                        </fo:table-cell>
                                    </fo:table-row>
                                    <xsl:if test="./serialized = '1'">
                                        <xsl:variable name="unitid" select="./unitid" />
                                        <xsl:variable name="seriallbl">
		                                    <xsl:call-template name="getserialname">
		                                        <xsl:with-param name="serial2typ" select="./serial2typ" />
		                                        <xsl:with-param name="s2typlabel" select="./s2typlabel" />
		                                    </xsl:call-template>
                                        </xsl:variable>
                                        <xsl:variable name="serialno">
                                            <xsl:for-each select="/all_results/results[@name = 'mastdtl']/row[companyid = $companyid and locationid = $locationid and saleby = $saleby and saleprice = $saleprice and saledate = $saledate and unitid = $unitid and salerefno = $salerefno]">
                                                <fo:inline space-end="0.2in" space-start.precedence="force">
                                                    <xsl:value-of select="./serialno2" />
                                                    <xsl:if test="normalize-space(./serialno)">
                                                        <xsl:value-of select="' (S#: '" />
                                                        <xsl:value-of select="./serialno" />
                                                        <xsl:value-of select="')'" />
                                                    </xsl:if>
                                                    <xsl:value-of select="' '" />
                                                </fo:inline>
                                            </xsl:for-each>
                                        </xsl:variable>
                                        <fo:table-row keep-with-previous.within-page="always">
                                            <fo:table-cell xsl:use-attribute-sets="table-cells">
                                                <fo:block>
                                                </fo:block>
                                            </fo:table-cell>
                                            <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="8">
                                                <fo:block>
                                                    <fo:inline>
                                                        <xsl:value-of select="$seriallbl" />
                                                    </fo:inline>
                                                    <fo:block space-start.precedence="force">
                                                        <xsl:value-of select="$serialno" />
                                                    </fo:block>
                                                </fo:block>
                                            </fo:table-cell>
                                        </fo:table-row>
                                    </xsl:if>
                                </xsl:for-each>
                            </fo:table-body>
                        </fo:table>
                    </xsl:for-each-group>
                </xsl:for-each-group>
            </xsl:when>
            <xsl:otherwise>
                <fo:block>Exceptions for selected date range not found</fo:block>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
