<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:date="http://exslt.org/dates-and-times" 
				extension-element-prefixes="date" 
				xmlns:java="http://xml.apache.org/xslt/java" 
			    xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
			    xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
				xmlns:util="java:com.psasoft.util.ConversionUtilities"
				exclude-result-prefixes="java" 
				version="2.0">
<!-- ======================================================================
      Templates
  ======================================================================= -->
<xsl:template name="account_service">
		<xsl:param name="row" />
		<fo:table font-size="8pt" space-before="6px">
				<fo:table-column column-width="1.2in" />
				<fo:table-column column-width="2.5in" />
				<fo:table-column column-width="1in" />
				<fo:table-column column-width="3in" />
				<fo:table-body>
						<fo:table-row keep-with-next="always">
								<fo:table-cell text-align="right" padding-right="4px">
										<fo:block xsl:use-attribute-sets="summary-headings">Account: </fo:block>
								</fo:table-cell>
								<fo:table-cell text-align="left">
									<fo:block xsl:use-attribute-sets="summary-headings">
											<xsl:value-of select="format-number($row/cycle, '000')" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number($row/bacct, '0000000')" />
									</fo:block>			
								</fo:table-cell>
								<fo:table-cell number-columns-spanned="2">
										<fo:block><xsl:value-of select="' '"/></fo:block>
								</fo:table-cell>								
						</fo:table-row>								
						<fo:table-row keep-with-previous="always" keep-with-next="always">								
								<fo:table-cell>
										<fo:block><xsl:value-of select="' '"/></fo:block>
								</fo:table-cell>								
								<fo:table-cell text-align="left">  						
										<fo:block xsl:use-attribute-sets="summary-headings">
												<xsl:value-of select="$row/fname" />
												<xsl:value-of select="$row/lname" />
										</fo:block>
										<xsl:if test="normalize-space($row/adln1)">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<xsl:value-of select="$row/adln1" />
												</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($row/adln2)">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<xsl:value-of select="$row/adln2" />
												</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($row/adln3)">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<xsl:value-of select="$row/adln3" />
												</fo:block>
										</xsl:if>
										<fo:block xsl:use-attribute-sets="summary-headings" space-after="12px">
												<xsl:value-of select="$row/adcity" />
												<xsl:value-of select="', '" />
												<xsl:value-of select="$row/adst" />
												<xsl:value-of select="' '" />
												<xsl:value-of select="substring($row/adzip, 1, 5)" />
												<xsl:if test="substring($row/adzip, 6, 4) != '0000'">
														<xsl:value-of select="'-'" />
														<xsl:value-of select="substring($row/adzip, 6, 4)" />
												</xsl:if>
										</fo:block>
								</fo:table-cell>
								<fo:table-cell text-align="right">
										<xsl:if test="normalize-space($row/esn) != ''">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<fo:inline xsl:use-attribute-sets="category-label">ESN: </fo:inline>
												</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($row/srno) != ''">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<fo:inline xsl:use-attribute-sets="category-label">Serial #: </fo:inline>
												</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($row/imei) != ''">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<fo:inline xsl:use-attribute-sets="category-label">IMEI: </fo:inline>
												</fo:block>
										</xsl:if>
										<fo:block xsl:use-attribute-sets="summary-headings">
										<fo:inline xsl:use-attribute-sets="category-label">Service #: </fo:inline>
										</fo:block>
										<xsl:if test="$row/dccc != 0 and $row/dcyy != 0 and $row/dcmm != 0 and $row/dcdd != 0">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<fo:inline xsl:use-attribute-sets="category-label">Disconnect Date: </fo:inline>
												</fo:block>
										</xsl:if>                        
								</fo:table-cell>                    
								<fo:table-cell text-align="left">
										<xsl:if test="normalize-space($row/esn) != ''">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<xsl:value-of select="$row/esn" />
												</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($row/srno) != ''">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<xsl:value-of select="$row/srno" />
												</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($row/imei) != ''">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<xsl:value-of select="$row/imei" />
												</fo:block>
										</xsl:if>
										<fo:block xsl:use-attribute-sets="summary-headings">
											<xsl:call-template name="phone">
												<xsl:with-param name="npa" select="$row/cnpa"/>
												<xsl:with-param name="nxx" select="$row/cnxx"/>
												<xsl:with-param name="line" select="$row/cline"/>
											</xsl:call-template>
										</fo:block>
										<xsl:if test="$row/dccc != 0 and $row/dcyy != 0 and $row/dcmm != 0 and $row/dcdd != 0">
												<fo:block xsl:use-attribute-sets="summary-headings">
													<xsl:call-template name="date4parm">
														<xsl:with-param name="cc" select="$row/dccc"/>
														<xsl:with-param name="yy" select="$row/dcyy"/>
														<xsl:with-param name="mm" select="$row/dcmm"/>
														<xsl:with-param name="dd" select="$row/dcdd"/>
													</xsl:call-template>													
												</fo:block>
										</xsl:if>                        
								</fo:table-cell>
						</fo:table-row>
				</fo:table-body>
		</fo:table>
</xsl:template>
<xsl:template name="account">
		<xsl:param name="row" />
		<fo:table font-size="8pt" space-before="6px">
				<fo:table-column column-width="1in" />
				<fo:table-column column-width="7in" />
				<fo:table-body>
						<fo:table-row keep-with-next="always">
								<fo:table-cell text-align="right">
										<fo:block xsl:use-attribute-sets="summary-headings">Account: </fo:block>
								</fo:table-cell>
								<fo:table-cell text-align="left">    
										<fo:block xsl:use-attribute-sets="summary-headings">
											<xsl:value-of select="format-number($row/cycle, '000')" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number($row/bacct, '0000000')" />
										</fo:block>	
								</fo:table-cell>
						</fo:table-row>
						<fo:table-row keep-with-previous="always" keep-with-next="always">
								<fo:table-cell>    
										<fo:block> </fo:block>	
								</fo:table-cell>								
								<fo:table-cell text-align="left">    
										<fo:block xsl:use-attribute-sets="summary-headings">
												<xsl:value-of select="$row/fname" />
												<xsl:value-of select="$row/lname" />
										</fo:block>
										<xsl:if test="normalize-space($row/adln1)">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<xsl:value-of select="$row/adln1" />
												</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($row/adln2)">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<xsl:value-of select="$row/adln2" />
												</fo:block>
										</xsl:if>
										<xsl:if test="normalize-space($row/adln3)">
												<fo:block xsl:use-attribute-sets="summary-headings">
														<xsl:value-of select="$row/adln3" />
												</fo:block>
										</xsl:if>
										<fo:block xsl:use-attribute-sets="summary-headings" space-after="12px">
												<xsl:value-of select="$row/adcity" />
												<xsl:value-of select="', '" />
												<xsl:value-of select="$row/adst" />
												<xsl:value-of select="' '" />
												<xsl:value-of select="substring($row/adzip, 1, 5)" />
												<xsl:if test="substring($row/adzip, 6, 4) != '0000'">
														<xsl:value-of select="'-'" />
														<xsl:value-of select="substring($row/adzip, 6, 4)" />
												</xsl:if>
										</fo:block>
								</fo:table-cell>                  
						</fo:table-row>
				</fo:table-body>
		</fo:table>
</xsl:template>
<xsl:template name="phone">
		<xsl:param name="npa" />
		<xsl:param name="nxx" />
		<xsl:param name="line" />
			<fo:inline>
				<xsl:value-of select="format-number(number($npa), '000')" />
				<xsl:value-of select="'-'"/>
				<xsl:value-of select="format-number(number($nxx), '000')" />
				<xsl:value-of select="'-'"/>
				<xsl:value-of select="format-number(number($line), '0000')" />
			</fo:inline>
</xsl:template>
<xsl:template name="date4parm">
		<xsl:param name="cc" />
		<xsl:param name="yy" />
		<xsl:param name="mm" />
		<xsl:param name="dd" />
		<fo:inline>
			<xsl:value-of select="format-number(number($mm), '00')"/>
			<xsl:value-of select="'/'"/>
			<xsl:value-of select="format-number(number($dd), '00')"/>
			<xsl:value-of select="'/'"/>
			<xsl:value-of select="format-number(number($cc), '00')"/>
			<xsl:value-of select="format-number(number($yy), '00')"/>
		</fo:inline>	
</xsl:template>
<xsl:template name="date1parm">
		<xsl:param name="date" />
		<fo:inline>
			<xsl:value-of select="format-number(number(substring($date, 5, 2)), '00')"/>
			<xsl:value-of select="'/'"/>
			<xsl:value-of select="format-number(number(substring($date, 7, 2)), '00')"/>
			<xsl:value-of select="'/'"/>
			<xsl:value-of select="format-number(number(substring($date, 1, 4)), '0000')"/>
		</fo:inline>	
</xsl:template>
<xsl:template name="date1parm-db">
		<xsl:param name="date" />
		<fo:inline>
			<xsl:value-of select="format-number(number(substring($date, 6, 2)), '00')"/>
			<xsl:value-of select="'/'"/>
			<xsl:value-of select="format-number(number(substring($date, 9, 2)), '00')"/>
			<xsl:value-of select="'/'"/>
			<xsl:value-of select="format-number(number(substring($date, 1, 4)), '0000')"/>
		</fo:inline>	
</xsl:template>
<xsl:template name="date1parm400">
		<xsl:param name="date" />
		<fo:inline>
			<xsl:value-of select="format-number(number(substring($date, 1, 4)), '0000')"/>
			<xsl:value-of select="'-'"/>
			<xsl:value-of select="format-number(number(substring($date, 5, 2)), '00')"/>
			<xsl:value-of select="'-'"/>
			<xsl:value-of select="format-number(number(substring($date, 7, 2)), '00')"/>
		</fo:inline>	
</xsl:template>
<xsl:template name="date1parmcr">
		<xsl:param name="date" />
		<fo:inline>
			<xsl:value-of select="format-number(number(substring($date, 5, 4)), '0000')"/>
			<xsl:value-of select="'-'"/>
			<xsl:value-of select="format-number(number(substring($date, 1, 2)), '00')"/>
			<xsl:value-of select="'-'"/>
			<xsl:value-of select="format-number(number(substring($date, 3, 2)), '00')"/>
		</fo:inline>	
</xsl:template>
<!--  
	inventory subroutines 
  -->
<xsl:template name="inventorystatus">
	<xsl:param name="status" />
	<xsl:param name="unitqty" />
	<xsl:choose>
		<xsl:when test="$unitqty &lt; 0 and $status = 2">
			<xsl:value-of select="'Sold - Exception'" />
		</xsl:when>
		<xsl:when test="$unitqty &lt; 0 and $status = 5">
			<xsl:value-of select="'Transferred - Exception'" />
		</xsl:when>
		<xsl:when test="$unitqty &lt; 0 and $status = 8">
			<xsl:value-of select="'Returned - Exception'" />
		</xsl:when>
		<xsl:when test="$status = 1">
			<xsl:value-of select="'New'" />
		</xsl:when>
		<xsl:when test="$status = 2">
			<xsl:value-of select="'Sold'" />
		</xsl:when>
		<xsl:when test="$status = 3">
			<xsl:value-of select="'Loan'" />
		</xsl:when>
		<xsl:when test="$status = 4">
			<xsl:value-of select="'Repair'" />
		</xsl:when>
		<xsl:when test="$status = 5">
			<xsl:value-of select="'Transferred'" />
		</xsl:when>
		<xsl:when test="$status = 6">
			<xsl:value-of select="'In Transit'" />
		</xsl:when>
		<xsl:when test="$status = 7">
			<xsl:value-of select="'Used'" />
		</xsl:when>
		<xsl:when test="$status = 8">
			<xsl:value-of select="'Returned'" />
		</xsl:when>
		<xsl:when test="$status = 9">
			<xsl:value-of select="'Resolved Exception'" />
		</xsl:when>
		<xsl:when test="$status = 10">
			<xsl:value-of select="'Missing'" />
		</xsl:when>
		<xsl:when test="$status = 11">
			<xsl:value-of select="'Damaged'" />
		</xsl:when>
		<xsl:when test="$status = 12">
			<xsl:value-of select="'Removed'" />
		</xsl:when>
		<xsl:when test="$status = 13">
			<xsl:value-of select="'Removed Writeoff'" />
		</xsl:when>
		<xsl:when test="$status = 14">
			<xsl:value-of select="'Held Unbilled'" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="'Unknown - '" />
			<xsl:value-of select="$status" />
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
<xsl:template name="getserialname">
	<xsl:param name="serial2typ" />
	<xsl:param name="s2typlabel" />
	<xsl:choose>
	    <xsl:when test="$serial2typ = '1'">
			<xsl:value-of select="$s2typlabel" />
		</xsl:when>
		<xsl:when test="$serial2typ = '2'">ESN</xsl:when>
		<xsl:when test="$serial2typ = '3'">IMEI</xsl:when>
		<xsl:when test="$serial2typ = '4'">ICCID</xsl:when>
		<xsl:when test="$serial2typ = '5'">MEID</xsl:when>
		<xsl:when test="$serial2typ = '6'">GSM Prepay Bundle</xsl:when>															
		<xsl:when test="$serial2typ = '7'">CDMA Prepay Bundle</xsl:when>
		<xsl:when test="$serial2typ = '8'">Prepay Card</xsl:when>
		<xsl:when test="$serial2typ = '9'">CCA MEID</xsl:when>
		<xsl:when test="$serial2typ = '10'">CCA IMEI</xsl:when>
	    <xsl:otherwise>Unknown</xsl:otherwise>
	</xsl:choose>
</xsl:template>
<xsl:template name="formatserial">
	<xsl:param name="serial" />
	<xsl:param name="serial0" />
	<xsl:param name="serial2typ" />
	<xsl:param name="unitid" />
	<xsl:param name="actpin" />
	<xsl:param name="npa" />
	<xsl:param name="nxx" />
	<xsl:param name="line" />

	<xsl:variable name="unit" select="invutil:getCatalogItem($unitid)" />
	<xsl:choose>
		<xsl:when test="$serial2typ = '2' and number($serial) != NaN">
			<xsl:value-of select="format-number($serial, '00000000000')" />
		</xsl:when>
		<xsl:when test="$serial2typ = '3' and number($serial) != NaN">
			<xsl:value-of select="format-number($serial, '000000000000000')" />
		</xsl:when>
		<xsl:when test="$serial2typ = '4' and number($serial) != NaN">
			<xsl:value-of select="format-number($serial, '00000000000000000000')" />
		</xsl:when>
		<xsl:when test="$serial2typ = '5' and normalize-space($serial) != ''">
			<xsl:variable name="serial" select="$serial" />
			<xsl:value-of select="$serial" />
			<xsl:choose>
			<xsl:when test="string-length(normalize-space($serial)) = 18">
				<xsl:value-of select="' ('" />
				<xsl:value-of select="util:getMEIDDecimalToHex(normalize-space($serial))"/>
				<xsl:value-of select="')'" />
				<!-- 
				<xsl:value-of select="' pESN: '" />
				<xsl:value-of select="util:getMEIDToESNDecimal(normalize-space($serial))"/>
				-->		
			</xsl:when>			
			<xsl:when test="string-length(normalize-space($serial)) = 14">
				<xsl:value-of select="' ('" />
				<xsl:value-of select="util:getMEIDHexToDecimal(normalize-space($serial))"/>
				<xsl:value-of select="')'" />
				<!-- 
				<xsl:value-of select="' pESN: '" />
				<xsl:value-of select="util:getMEIDToESNDecimal(normalize-space($serial))"/>
				-->		
			</xsl:when>			
			</xsl:choose>		
		</xsl:when>
		<xsl:when test="$serial2typ = '6'">
			<xsl:value-of select="'IMEI:'" />
			<xsl:value-of select="format-number($serial, '000000000000000')" />
			<xsl:value-of select="'&#160;'" />
			<xsl:if test="$serial0 > ''">
				<xsl:value-of select="'ICCID:'" />
				<xsl:value-of select="format-number($serial0, '00000000000000000000')" />
			</xsl:if>
			<xsl:if test="$npa > '' and $npa > '0'"> 
				<xsl:value-of select="'&#160;'" />
				<xsl:value-of select="'MDN:('" />
				<xsl:call-template name="phone">
					<xsl:with-param name="npa" select="$npa"/>
					<xsl:with-param name="nxx" select="$nxx"/>
					<xsl:with-param name="line" select="$line"/>
				</xsl:call-template>
				<xsl:value-of select="')'" />
			</xsl:if>
			<xsl:if test="normalize-space($actpin) > ''">
				<xsl:value-of select="'&#160;'" />
				<xsl:value-of select="'Act#('" />
				<xsl:value-of select="$actpin" />
				<xsl:value-of select="')'" />
			</xsl:if>
			<xsl:value-of select="'&#x000A;'" />
		</xsl:when>															
		<xsl:when test="$serial2typ = '7'">
			<xsl:value-of select="format-number($serial, '00000000000')" />
			<xsl:if test="$npa > '' and $npa > '0'"> 
				<xsl:value-of select="'&#160;'" />
				<xsl:value-of select="'MDN:('" />
				<xsl:call-template name="phone">
					<xsl:with-param name="npa" select="$npa"/>
					<xsl:with-param name="nxx" select="$nxx"/>
					<xsl:with-param name="line" select="$line"/>
				</xsl:call-template>
				<xsl:value-of select="')'" />
			</xsl:if>
			<xsl:if test="normalize-space($actpin) > ''">
				<xsl:value-of select="'&#160;'" />
				<xsl:value-of select="'Act#('" />
				<xsl:value-of select="$actpin" />
				<xsl:value-of select="')'" />
			</xsl:if>
			<xsl:value-of select="'&#x000A;'" />
		</xsl:when>															
		<xsl:when test="$serial2typ = '8'">
			<xsl:value-of select="$serial" />
			<xsl:if test="normalize-space($actpin) > ''">
				<xsl:value-of select="'&#160;'" />
				<xsl:value-of select="'Act#('" />
				<xsl:value-of select="$actpin" />
				<xsl:value-of select="')'" />
			</xsl:if>
			<xsl:value-of select="'&#x000A;'" />
		</xsl:when>		
		<xsl:when test="$serial2typ = '9'">
			<xsl:value-of select="$serial" />
			<xsl:choose>
			<xsl:when test="string-length(normalize-space($serial)) = 18">
				<xsl:value-of select="' ('" />
				<xsl:value-of select="util:getMEIDDecimalToHex(normalize-space($serial))"/>
				<xsl:value-of select="')'" />
				<xsl:value-of select="' pESN: '" />
				<xsl:value-of select="util:getMEIDToESNDecimal(normalize-space($serial))"/>
			</xsl:when>			
			<xsl:when test="string-length(normalize-space($serial)) = 14">
				<xsl:value-of select="' ('" />
				<xsl:value-of select="util:getMEIDHexToDecimal(normalize-space($serial))"/>
				<xsl:value-of select="')'" />
				<xsl:value-of select="' pESN: '" />
				<xsl:value-of select="util:getMEIDToESNDecimal(normalize-space($serial))"/>
			</xsl:when>			
			</xsl:choose>
			<xsl:value-of select="'&#160;'" />
			<xsl:value-of select="'MSL ('" />
			<xsl:value-of select="$serial0" />
			<xsl:value-of select="') '" />
		</xsl:when>
		<xsl:when test="$serial2typ = '10' ">
			<xsl:value-of select="format-number($serial, '000000000000000')" />
			<xsl:value-of select="'&#160;'" />
			<xsl:value-of select="'MSL ('" />
			<xsl:value-of select="$serial0" />
			<xsl:value-of select="') '" />
		</xsl:when>		
		<xsl:otherwise>
			<xsl:value-of select="$serial" />
		</xsl:otherwise>
	</xsl:choose>
    <xsl:text>&#x2007;&#x2007; </xsl:text>
</xsl:template>
<xsl:template name="transfertype">
	<xsl:param name="ttype" />
	<xsl:choose>
		<xsl:when test="$ttype = 1">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Transfer By Purchase Order'" />
			</fo:block>
		</xsl:when>
		<xsl:when test="$ttype = 2">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Transfer To Repair'" />
			</fo:block>
		</xsl:when>
		<xsl:when test="$ttype = 3">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Transfer Loan'" />
			</fo:block>
		</xsl:when>
		<xsl:when test="$ttype = 4">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Transfer Returned'" />
			</fo:block>
		</xsl:when>
		<xsl:when test="$ttype = 5">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Transfer Resolved Exception'" />
			</fo:block>
		</xsl:when>
		<xsl:when test="$ttype = 6">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Transfer Resolved Exception Forced'" />
			</fo:block>
		</xsl:when>
		<xsl:when test="$ttype = 7">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Transfer to Missing'" />
			</fo:block>
		</xsl:when>
		<xsl:when test="$ttype = 8">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Transfer Automatic'" />
			</fo:block>
		</xsl:when>
		<xsl:when test="$ttype = 9">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Remove from Inventory'" />
			</fo:block>
		</xsl:when>
		<xsl:when test="$ttype = 10">
			<fo:block xsl:use-attribute-sets="summary-headings" font-size="7px">
				<xsl:value-of select="'Remove - Writeoff'" />
			</fo:block>
		</xsl:when>
	</xsl:choose>
</xsl:template>
<xsl:template name="countryprovincedesc">
	<xsl:param name="code" />
<xsl:choose>
<xsl:when test="$code = 'AB'"><fo:block><xsl:value-of select="'Alberta'" /></fo:block></xsl:when>
<xsl:when test="$code = 'AD'"><fo:block><xsl:value-of select="'Andorra '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AE'"><fo:block><xsl:value-of select="'United Arab Emirates '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AF'"><fo:block><xsl:value-of select="'Afghanistan '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AG'"><fo:block><xsl:value-of select="'Antigua and Barbuda '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AI'"><fo:block><xsl:value-of select="'Anguilla '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AL'"><fo:block><xsl:value-of select="'Albania '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AM'"><fo:block><xsl:value-of select="'Armenia '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'AN'"><fo:block><xsl:value-of select="'Netherlands Antilles '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'AN'"><fo:block><xsl:value-of select="'Antigua and Barbuda '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AO'"><fo:block><xsl:value-of select="'Angola '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AQ'"><fo:block><xsl:value-of select="'Antarctica '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AR'"><fo:block><xsl:value-of select="'Argentina '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AS'"><fo:block><xsl:value-of select="'American Samoa'" /></fo:block></xsl:when>
<xsl:when test="$code = 'AT'"><fo:block><xsl:value-of select="'Austria '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AU'"><fo:block><xsl:value-of select="'Australia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AW'"><fo:block><xsl:value-of select="'Aruba '" /></fo:block></xsl:when>
<xsl:when test="$code = 'AZ'"><fo:block><xsl:value-of select="'Azerbaijan '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'BA'"><fo:block><xsl:value-of select="'Bosnia and Herzegovina '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'BA'"><fo:block><xsl:value-of select="'Bahamas '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BB'"><fo:block><xsl:value-of select="'Barbados '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BC'"><fo:block><xsl:value-of select="'British Columbia'" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'BD'"><fo:block><xsl:value-of select="'Bangladesh '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'BD'"><fo:block><xsl:value-of select="'Barbados '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BE'"><fo:block><xsl:value-of select="'Belgium '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BF'"><fo:block><xsl:value-of select="'Burkina Faso '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BG'"><fo:block><xsl:value-of select="'Bulgaria '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BH'"><fo:block><xsl:value-of select="'Bahrain '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BI'"><fo:block><xsl:value-of select="'Burundi '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BJ'"><fo:block><xsl:value-of select="'Benin '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BM'"><fo:block><xsl:value-of select="'Bermuda '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BN'"><fo:block><xsl:value-of select="'Brunei Darussalam '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BO'"><fo:block><xsl:value-of select="'Bolivia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BR'"><fo:block><xsl:value-of select="'Brazil '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BS'"><fo:block><xsl:value-of select="'Bahamas '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BT'"><fo:block><xsl:value-of select="'Bhutan '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'BV'"><fo:block><xsl:value-of select="'Bouvet Island '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'BV'"><fo:block><xsl:value-of select="'Virgin Islands, British '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BW'"><fo:block><xsl:value-of select="'Botswana '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BY'"><fo:block><xsl:value-of select="'Belarus '" /></fo:block></xsl:when>
<xsl:when test="$code = 'BZ'"><fo:block><xsl:value-of select="'Belize '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CA'"><fo:block><xsl:value-of select="'Canada '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CC'"><fo:block><xsl:value-of select="'Cocos (Keeling) Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CD'"><fo:block><xsl:value-of select="'Congo, the Democratic Republic of '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CF'"><fo:block><xsl:value-of select="'Central African Republic '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CG'"><fo:block><xsl:value-of select="'Congo '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CH'"><fo:block><xsl:value-of select="'Switzerland '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CI'"><fo:block><xsl:value-of select="'Ivory Coast '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CK'"><fo:block><xsl:value-of select="'Cook Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CL'"><fo:block><xsl:value-of select="'Chile '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CM'"><fo:block><xsl:value-of select="'Cameroon '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CN'"><fo:block><xsl:value-of select="'China '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CO'"><fo:block><xsl:value-of select="'Colombia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CQ'"><fo:block><xsl:value-of select="'Cayman Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CR'"><fo:block><xsl:value-of select="'Costa Rica '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CS'"><fo:block><xsl:value-of select="'Serbia and Montenegro '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CU'"><fo:block><xsl:value-of select="'Cuba '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CV'"><fo:block><xsl:value-of select="'Cape Verde '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CX'"><fo:block><xsl:value-of select="'Christmas Island '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CY'"><fo:block><xsl:value-of select="'Cyprus '" /></fo:block></xsl:when>
<xsl:when test="$code = 'CZ'"><fo:block><xsl:value-of select="'Czech Republic '" /></fo:block></xsl:when>
<xsl:when test="$code = 'DE'"><fo:block><xsl:value-of select="'Germany '" /></fo:block></xsl:when>
<xsl:when test="$code = 'DJ'"><fo:block><xsl:value-of select="'Djibouti '" /></fo:block></xsl:when>
<xsl:when test="$code = 'DK'"><fo:block><xsl:value-of select="'Denmark '" /></fo:block></xsl:when>
<xsl:when test="$code = 'DM'"><fo:block><xsl:value-of select="'Dominica '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'DO'"><fo:block><xsl:value-of select="'Dominican Republic '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'DR'"><fo:block><xsl:value-of select="'Dominican Republic '" /></fo:block></xsl:when>
<xsl:when test="$code = 'DZ'"><fo:block><xsl:value-of select="'Algeria '" /></fo:block></xsl:when>
<xsl:when test="$code = 'EC'"><fo:block><xsl:value-of select="'Ecuador '" /></fo:block></xsl:when>
<xsl:when test="$code = 'EE'"><fo:block><xsl:value-of select="'Estonia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'EG'"><fo:block><xsl:value-of select="'Egypt '" /></fo:block></xsl:when>
<xsl:when test="$code = 'EH'"><fo:block><xsl:value-of select="'Western Sahara '" /></fo:block></xsl:when>
<xsl:when test="$code = 'ER'"><fo:block><xsl:value-of select="'Eritrea '" /></fo:block></xsl:when>
<xsl:when test="$code = 'ES'"><fo:block><xsl:value-of select="'Spain '" /></fo:block></xsl:when>
<xsl:when test="$code = 'ET'"><fo:block><xsl:value-of select="'Ethiopia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'FI'"><fo:block><xsl:value-of select="'Finland '" /></fo:block></xsl:when>
<xsl:when test="$code = 'FJ'"><fo:block><xsl:value-of select="'Fiji '" /></fo:block></xsl:when>
<xsl:when test="$code = 'FK'"><fo:block><xsl:value-of select="'Falkland Islands (Malvinas) '" /></fo:block></xsl:when>
<xsl:when test="$code = 'FM'"><fo:block><xsl:value-of select="'Federated States of Micronesia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'FO'"><fo:block><xsl:value-of select="'Faroe Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'FR'"><fo:block><xsl:value-of select="'France '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GA'"><fo:block><xsl:value-of select="'Gabon '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GB'"><fo:block><xsl:value-of select="'United Kingdom '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GD'"><fo:block><xsl:value-of select="'Grenada '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GE'"><fo:block><xsl:value-of select="'Georgia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GF'"><fo:block><xsl:value-of select="'French Guiana '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GH'"><fo:block><xsl:value-of select="'Ghana '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GI'"><fo:block><xsl:value-of select="'Gibraltar '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GL'"><fo:block><xsl:value-of select="'Greenland '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GM'"><fo:block><xsl:value-of select="'Gambia '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'GN'"><fo:block><xsl:value-of select="'Guinea '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'GN'"><fo:block><xsl:value-of select="'Grenada and Carriacou '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GP'"><fo:block><xsl:value-of select="'Guadeloupe'" /></fo:block></xsl:when>
<xsl:when test="$code = 'GQ'"><fo:block><xsl:value-of select="'Equatorial Guinea '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GR'"><fo:block><xsl:value-of select="'Greece '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GS'"><fo:block><xsl:value-of select="'South Georgia and South Sandwich Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GT'"><fo:block><xsl:value-of select="'Guatemala '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GU'"><fo:block><xsl:value-of select="'Guam '" /></fo:block></xsl:when>
<xsl:when test="$code = 'GW'"><fo:block><xsl:value-of select="'Guinea Bissau'" /></fo:block></xsl:when>
<xsl:when test="$code = 'GY'"><fo:block><xsl:value-of select="'Guyana '" /></fo:block></xsl:when>
<xsl:when test="$code = 'HK'"><fo:block><xsl:value-of select="'Hong Kong '" /></fo:block></xsl:when>
<xsl:when test="$code = 'HM'"><fo:block><xsl:value-of select="'Heard Island and Mcdonald Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'HN'"><fo:block><xsl:value-of select="'Honduras'" /></fo:block></xsl:when>
<xsl:when test="$code = 'HR'"><fo:block><xsl:value-of select="'Croatia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'HT'"><fo:block><xsl:value-of select="'Haiti '" /></fo:block></xsl:when>
<xsl:when test="$code = 'HU'"><fo:block><xsl:value-of select="'Hungary '" /></fo:block></xsl:when>
<xsl:when test="$code = 'ID'"><fo:block><xsl:value-of select="'Indonesia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'IE'"><fo:block><xsl:value-of select="'Ireland '" /></fo:block></xsl:when>
<xsl:when test="$code = 'IL'"><fo:block><xsl:value-of select="'Israel '" /></fo:block></xsl:when>
<xsl:when test="$code = 'IN'"><fo:block><xsl:value-of select="'India '" /></fo:block></xsl:when>
<xsl:when test="$code = 'IO'"><fo:block><xsl:value-of select="'British Indian Ocean Territory '" /></fo:block></xsl:when>
<xsl:when test="$code = 'IQ'"><fo:block><xsl:value-of select="'Iraq '" /></fo:block></xsl:when>
<xsl:when test="$code = 'IR'"><fo:block><xsl:value-of select="'Iran, Islamic Republic of '" /></fo:block></xsl:when>
<xsl:when test="$code = 'IS'"><fo:block><xsl:value-of select="'Iceland '" /></fo:block></xsl:when>
<xsl:when test="$code = 'IT'"><fo:block><xsl:value-of select="'Italy '" /></fo:block></xsl:when>
<xsl:when test="$code = 'JM'"><fo:block><xsl:value-of select="'Jamaica '" /></fo:block></xsl:when>
<xsl:when test="$code = 'JO'"><fo:block><xsl:value-of select="'Jordan '" /></fo:block></xsl:when>
<xsl:when test="$code = 'JP'"><fo:block><xsl:value-of select="'Japan '" /></fo:block></xsl:when>
<xsl:when test="$code = 'KA'"><fo:block><xsl:value-of select="'Saint Kitts and Nevis '" /></fo:block></xsl:when>
<xsl:when test="$code = 'KE'"><fo:block><xsl:value-of select="'Kenya '" /></fo:block></xsl:when>
<xsl:when test="$code = 'KG'"><fo:block><xsl:value-of select="'Kyrgyzstan '" /></fo:block></xsl:when>
<xsl:when test="$code = 'KH'"><fo:block><xsl:value-of select="'Cambodia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'KI'"><fo:block><xsl:value-of select="'Kiribati '" /></fo:block></xsl:when>
<xsl:when test="$code = 'KM'"><fo:block><xsl:value-of select="'Comoros '" /></fo:block></xsl:when>
<!--   nonstandard <xsl:when test="$code = 'KN'"><fo:block><xsl:value-of select="'Saint Kitts and Nevis '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'KP'"><fo:block><xsl:value-of select="'Korea, Democratic Peoples Republic of '" /></fo:block></xsl:when>
<xsl:when test="$code = 'KR'"><fo:block><xsl:value-of select="'Korea, Republic of '" /></fo:block></xsl:when>
<xsl:when test="$code = 'KW'"><fo:block><xsl:value-of select="'Kuwait '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'KY'"><fo:block><xsl:value-of select="'Cayman Islands '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'KZ'"><fo:block><xsl:value-of select="'Kazakhstan '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LA'"><fo:block><xsl:value-of select="'Lao Peoples Democratic Republic '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LB'"><fo:block><xsl:value-of select="'Lebanon '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LC'"><fo:block><xsl:value-of select="'Saint Lucia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LI'"><fo:block><xsl:value-of select="'Liechtenstein '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LK'"><fo:block><xsl:value-of select="'Sri Lanka '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LR'"><fo:block><xsl:value-of select="'Liberia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LS'"><fo:block><xsl:value-of select="'Lesotho '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LT'"><fo:block><xsl:value-of select="'Lithuania '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LU'"><fo:block><xsl:value-of select="'Luxembourg '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LV'"><fo:block><xsl:value-of select="'Latvia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'LY'"><fo:block><xsl:value-of select="'Libyan Arab Jamahiriya '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MA'"><fo:block><xsl:value-of select="'Morocco '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MB'"><fo:block><xsl:value-of select="'Manitoba '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MC'"><fo:block><xsl:value-of select="'Monaco '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MD'"><fo:block><xsl:value-of select="'Moldova, Republic of '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MG'"><fo:block><xsl:value-of select="'Madagascar '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MH'"><fo:block><xsl:value-of select="'Marshall Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MK'"><fo:block><xsl:value-of select="'Macedonia, the Former Yugoslav Republic of '" /></fo:block></xsl:when>
<xsl:when test="$code = 'ML'"><fo:block><xsl:value-of select="'Mali '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MM'"><fo:block><xsl:value-of select="'Myanmar '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MN'"><fo:block><xsl:value-of select="'Mongolia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MO'"><fo:block><xsl:value-of select="'Macao '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MP'"><fo:block><xsl:value-of select="'Northern Mariana Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MQ'"><fo:block><xsl:value-of select="'Martinique '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MR'"><fo:block><xsl:value-of select="'Mauritania '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'MS'"><fo:block><xsl:value-of select="'Montserrat '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'MT'"><fo:block><xsl:value-of select="'Malta '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MU'"><fo:block><xsl:value-of select="'Mauritius '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MV'"><fo:block><xsl:value-of select="'Maldives '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MW'"><fo:block><xsl:value-of select="'Malawi '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MX'"><fo:block><xsl:value-of select="'Mexico '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MY'"><fo:block><xsl:value-of select="'Malaysia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'MZ'"><fo:block><xsl:value-of select="'Mozambique '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NA'"><fo:block><xsl:value-of select="'Namibia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NB'"><fo:block><xsl:value-of select="'New Brunswick'" /></fo:block></xsl:when>
<xsl:when test="$code = 'NC'"><fo:block><xsl:value-of select="'New Caledonia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NE'"><fo:block><xsl:value-of select="'Niger'" /></fo:block></xsl:when>
<!--  nonstandard ? <xsl:when test="$code = 'NF'"><fo:block><xsl:value-of select="'Norfolk Island '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'NF'"><fo:block><xsl:value-of select="'Newfoundland '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NG'"><fo:block><xsl:value-of select="'Nigeria '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NI'"><fo:block><xsl:value-of select="'Nicaragua '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NL'"><fo:block><xsl:value-of select="'Netherlands '" /></fo:block></xsl:when>
<!--  dup code <xsl:when test="$code = 'NL'"><fo:block><xsl:value-of select="'Newfoundland and Labrador'" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'NN'"><fo:block><xsl:value-of select="'Northern Mariana Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NO'"><fo:block><xsl:value-of select="'Norway '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NP'"><fo:block><xsl:value-of select="'Nepal '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NR'"><fo:block><xsl:value-of select="'Nauru '" /></fo:block></xsl:when>
<xsl:when test="$code = 'NS'"><fo:block><xsl:value-of select="'Nova Scotia'" /></fo:block></xsl:when>
<xsl:when test="$code = 'NT'"><fo:block><xsl:value-of select="'Northwest Territories'" /></fo:block></xsl:when>
<xsl:when test="$code = 'NU'"><fo:block><xsl:value-of select="'Niue '" /></fo:block></xsl:when>
<!--  dup code <xsl:when test="$code = 'NU'"><fo:block><xsl:value-of select="'Nunavut'" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'NZ'"><fo:block><xsl:value-of select="'New Zealand '" /></fo:block></xsl:when>
<xsl:when test="$code = 'OM'"><fo:block><xsl:value-of select="'Oman '" /></fo:block></xsl:when>
<xsl:when test="$code = 'ON'"><fo:block><xsl:value-of select="'Ontario'" /></fo:block></xsl:when>
<xsl:when test="$code = 'PA'"><fo:block><xsl:value-of select="'Panama '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PE'"><fo:block><xsl:value-of select="'Prince Edward Island'" /></fo:block></xsl:when>
<!--  dup code <xsl:when test="$code = 'PE'"><fo:block><xsl:value-of select="'Peru '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'PF'"><fo:block><xsl:value-of select="'French Polynesia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PG'"><fo:block><xsl:value-of select="'Papua New Guinea '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PH'"><fo:block><xsl:value-of select="'Philippines '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PK'"><fo:block><xsl:value-of select="'Pakistan '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PL'"><fo:block><xsl:value-of select="'Poland '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PM'"><fo:block><xsl:value-of select="'Saint Pierre and Miquelon '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PN'"><fo:block><xsl:value-of select="'Pitcairn '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PQ'"><fo:block><xsl:value-of select="'Quebec'" /></fo:block></xsl:when>
<xsl:when test="$code = 'PR'"><fo:block><xsl:value-of select="'Puerto Rico '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PS'"><fo:block><xsl:value-of select="'Palestinian Territory, Occupied '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PT'"><fo:block><xsl:value-of select="'Portugal '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PW'"><fo:block><xsl:value-of select="'Palau'" /></fo:block></xsl:when>
<xsl:when test="$code = 'PW'"><fo:block><xsl:value-of select="'Palau '" /></fo:block></xsl:when>
<xsl:when test="$code = 'PY'"><fo:block><xsl:value-of select="'Paraguay '" /></fo:block></xsl:when>
<xsl:when test="$code = 'QA'"><fo:block><xsl:value-of select="'Qatar '" /></fo:block></xsl:when>
<xsl:when test="$code = 'QC'"><fo:block><xsl:value-of select="'Quebec'" /></fo:block></xsl:when>
<xsl:when test="$code = 'RE'"><fo:block><xsl:value-of select="'Reunion '" /></fo:block></xsl:when>
<xsl:when test="$code = 'RO'"><fo:block><xsl:value-of select="'Romania '" /></fo:block></xsl:when>
<xsl:when test="$code = 'RT'"><fo:block><xsl:value-of select="'Montserrat '" /></fo:block></xsl:when>
<xsl:when test="$code = 'RU'"><fo:block><xsl:value-of select="'Russian Federation '" /></fo:block></xsl:when>
<xsl:when test="$code = 'RW'"><fo:block><xsl:value-of select="'Rwanda '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'SA'"><fo:block><xsl:value-of select="'Saudi Arabia '" /></fo:block></xsl:when>  -->
<xsl:when test="$code = 'SA'"><fo:block><xsl:value-of select="'Saint Lucia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SB'"><fo:block><xsl:value-of select="'Solomon Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SC'"><fo:block><xsl:value-of select="'Seychelles '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SD'"><fo:block><xsl:value-of select="'Sudan '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SE'"><fo:block><xsl:value-of select="'Sweden '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SF'"><fo:block><xsl:value-of select="'Sint Maarten '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SG'"><fo:block><xsl:value-of select="'Singapore '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SH'"><fo:block><xsl:value-of select="'Saint Helena '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SI'"><fo:block><xsl:value-of select="'Slovenia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SJ'"><fo:block><xsl:value-of select="'Svalbard and Jan Mayen '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SK'"><fo:block><xsl:value-of select="'Saskatchewan'" /></fo:block></xsl:when>
<xsl:when test="$code = 'SK'"><fo:block><xsl:value-of select="'Slovakia'" /></fo:block></xsl:when>
<xsl:when test="$code = 'SL'"><fo:block><xsl:value-of select="'Sierra Leone '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SM'"><fo:block><xsl:value-of select="'San Marino '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SN'"><fo:block><xsl:value-of select="'Senegal '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SO'"><fo:block><xsl:value-of select="'Somalia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SR'"><fo:block><xsl:value-of select="'Suriname '" /></fo:block></xsl:when>
<xsl:when test="$code = 'ST'"><fo:block><xsl:value-of select="'Sao Tome and Principe '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SV'"><fo:block><xsl:value-of select="'El Salvador '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SY'"><fo:block><xsl:value-of select="'Syrian Arab Republic '" /></fo:block></xsl:when>
<xsl:when test="$code = 'SZ'"><fo:block><xsl:value-of select="'Swaziland '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TC'"><fo:block><xsl:value-of select="'Turks and Caicos Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TD'"><fo:block><xsl:value-of select="'Chad '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TF'"><fo:block><xsl:value-of select="'French Southern Territories '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TG'"><fo:block><xsl:value-of select="'Togo '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TH'"><fo:block><xsl:value-of select="'Thailand '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TJ'"><fo:block><xsl:value-of select="'Tajikistan '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TK'"><fo:block><xsl:value-of select="'Tokelau '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TL'"><fo:block><xsl:value-of select="'Timor Leste'" /></fo:block></xsl:when>
<xsl:when test="$code = 'TM'"><fo:block><xsl:value-of select="'Turkmenistan '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TN'"><fo:block><xsl:value-of select="'Tunisia '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TO'"><fo:block><xsl:value-of select="'Tonga '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'TR'"><fo:block><xsl:value-of select="'Turkey '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'TR'"><fo:block><xsl:value-of select="'Trinidad and Tobago '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'TT'"><fo:block><xsl:value-of select="'Trinidad and Tobago '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'TV'"><fo:block><xsl:value-of select="'Tuvalu '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TW'"><fo:block><xsl:value-of select="'Taiwan, Province of China '" /></fo:block></xsl:when>
<xsl:when test="$code = 'TZ'"><fo:block><xsl:value-of select="'Tanzania, United Republic of '" /></fo:block></xsl:when>
<xsl:when test="$code = 'UA'"><fo:block><xsl:value-of select="'Ukraine '" /></fo:block></xsl:when>
<xsl:when test="$code = 'UG'"><fo:block><xsl:value-of select="'Uganda '" /></fo:block></xsl:when>
<xsl:when test="$code = 'UM'"><fo:block><xsl:value-of select="'United States Minor Outlying Islands '" /></fo:block></xsl:when>
<xsl:when test="$code = 'US'"><fo:block><xsl:value-of select="'United States '" /></fo:block></xsl:when>
<xsl:when test="$code = 'UY'"><fo:block><xsl:value-of select="'Uruguay '" /></fo:block></xsl:when>
<xsl:when test="$code = 'UZ'"><fo:block><xsl:value-of select="'Uzbekistan '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'VC'"><fo:block><xsl:value-of select="'Saint Vincent and the Grenadines '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'VG'"><fo:block><xsl:value-of select="'Virgin Islands, British '" /></fo:block></xsl:when>
<xsl:when test="$code = 'VI'"><fo:block><xsl:value-of select="'Virgin Islands, U.S. '" /></fo:block></xsl:when>
<xsl:when test="$code = 'VN'"><fo:block><xsl:value-of select="'Viet Nam '" /></fo:block></xsl:when>
<!--  nonstandard <xsl:when test="$code = 'VU'"><fo:block><xsl:value-of select="'Vanuatu '" /></fo:block></xsl:when> -->
<xsl:when test="$code = 'VU'"><fo:block><xsl:value-of select="'Nunavut '" /></fo:block></xsl:when>
<xsl:when test="$code = 'WF'"><fo:block><xsl:value-of select="'Wallis and Futuna '" /></fo:block></xsl:when>
<xsl:when test="$code = 'WS'"><fo:block><xsl:value-of select="'Samoa '" /></fo:block></xsl:when>
<xsl:when test="$code = 'YE'"><fo:block><xsl:value-of select="'Yemen '" /></fo:block></xsl:when>
<xsl:when test="$code = 'YT'"><fo:block><xsl:value-of select="'Yukon Territories'" /></fo:block></xsl:when>
<xsl:when test="$code = 'ZA'"><fo:block><xsl:value-of select="'South Africa '" /></fo:block></xsl:when>
<xsl:when test="$code = 'ZF'"><fo:block><xsl:value-of select="'Saint Vincent and the Grenadines '" /></fo:block></xsl:when>
<xsl:when test="$code = 'ZW'"><fo:block><xsl:value-of select="'Zimbabwe'" /></fo:block></xsl:when>
<xsl:otherwise><fo:block><xsl:value-of select="$code" /></fo:block></xsl:otherwise>
</xsl:choose>
</xsl:template>	
</xsl:stylesheet>
