<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: voucher.xsl,v 1.7 2014-11-12 18:21:17 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
								exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Deposit Refund Voucher'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set"/>
		<xsl:call-template name="make-body"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account_service">
		<xsl:with-param name="row" select="/all_results/results[@name = 'dep']/row[position() = 1]"/>
	</xsl:call-template>
	<fo:table table-layout="fixed" width="100%" space-before="16px">
		<fo:table-column column-width="3.0in" />
		<fo:table-column column-width="3.0in" />
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'dep']/row">    
					<fo:table-row>
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="'Original Deposit Date'"/>
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="left">
							<fo:block>
								<xsl:call-template name="date4parm">
									<xsl:with-param name="cc" select="./dpcc"/>
									<xsl:with-param name="yy" select="./dpyy"/>
									<xsl:with-param name="mm" select="./dpmm"/>
									<xsl:with-param name="dd" select="./dpdd"/>
								</xsl:call-template>	
							</fo:block>			
						</fo:table-cell>	
					</fo:table-row>	
					<fo:table-row>
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="'Amount of Deposit Refunded on '"/>
								<fo:inline>
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="./rfcc"/>
										<xsl:with-param name="yy" select="./rfyy"/>
										<xsl:with-param name="mm" select="./rfmm"/>
										<xsl:with-param name="dd" select="./rfdd"/>
									</xsl:call-template>	
								</fo:inline>		
							 </fo:block>	
						</fo:table-cell>	
						<fo:table-cell text-align="right" >
							<fo:block>
								<xsl:value-of select="format-number(number($curr_refund), '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
							</fo:block>			
						</fo:table-cell>	
					</fo:table-row>	
					<fo:table-row>
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="'Amount of Interest Refunded on '"/>
								<fo:inline>
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="./rfcc"/>
										<xsl:with-param name="yy" select="./rfyy"/>
										<xsl:with-param name="mm" select="./rfmm"/>
										<xsl:with-param name="dd" select="./rfdd"/>
									</xsl:call-template>	
								</fo:inline>									
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="right" >
							<fo:block>
								<xsl:value-of select="format-number(number($curr_refund_interest), '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
							</fo:block>			
						</fo:table-cell>	
					</fo:table-row>						
					<fo:table-row>
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="'Total Amount Refunded on '"/>
								<fo:inline>
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="./rfcc"/>
										<xsl:with-param name="yy" select="./rfyy"/>
										<xsl:with-param name="mm" select="./rfmm"/>
										<xsl:with-param name="dd" select="./rfdd"/>
									</xsl:call-template>	
								</fo:inline>									
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="right" >
							<fo:block>
								<xsl:value-of select="format-number(number($curr_refund) + number($curr_refund_interest), '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
							</fo:block>			
						</fo:table-cell>	
					</fo:table-row>								
					<fo:table-row>
						<fo:table-cell text-align="right" padding-right="10px">
							<fo:block xsl:use-attribute-sets="summary-headings">
								<xsl:value-of select="'Type'"/>
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="left">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./refsts = 'I'">
											<xsl:value-of select="'Interest Only'"/>
									</xsl:when>
									<xsl:when test="./refsts = 'T' and ./intamt != 0">
											<xsl:value-of select="'Total Refund and Interest'"/>
									</xsl:when>
									<xsl:when test="./refsts = 'T' and ./intamt = 0">
											<xsl:value-of select="'Total Refund'"/>
									</xsl:when>
									<xsl:otherwise>
											<xsl:value-of select="'Other'"/>
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>			
						</fo:table-cell>	
					</fo:table-row>							
			 </xsl:for-each>
			</fo:table-body>
	</fo:table>    
</xsl:template>

</xsl:stylesheet>






